(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    715465,      20160]
NotebookOptionsPosition[    704916,      19864]
NotebookOutlinePosition[    705291,      19880]
CellTagsIndexPosition[    705248,      19877]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Cosmological field equations in kinetic gravity braiding", "Section",
 CellChangeTimes->{{3.7776839679253263`*^9, 3.777683978264307*^9}, {
  3.8187756405466623`*^9, 3.8187756426959515`*^9}}],

Cell[TextData[{
 "We derive the cosmological field equations in kinetic gravity braiding. In \
doing so, we use ",
 StyleBox["xAct",
  FontSlant->"Italic"],
 "\[CloseCurlyQuote]s derivative ",
 StyleBox["xCoba",
  FontSlant->"Italic"],
 " for component calculations.\n\nAuthor: Reginald Christian Bernardo"
}], "Text",
 CellChangeTimes->{{3.7776839874671593`*^9, 3.7776840999033537`*^9}, {
  3.777684175044571*^9, 3.777684176293292*^9}, {3.777684376105797*^9, 
  3.777684427833199*^9}, {3.818774040311528*^9, 3.818774072395518*^9}, {
  3.818775646244462*^9, 3.8187756496683044`*^9}, {3.8187756854392786`*^9, 
  3.8187756910981803`*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["0.1 Setup",
 FontColor->RGBColor[1, 0.5, 0]]], "Subsection",
 CellChangeTimes->{{3.777684103615888*^9, 3.777684108386374*^9}, 
   3.7776846492181263`*^9}],

Cell["Setting up...", "Text",
 CellChangeTimes->{{3.818774121500385*^9, 3.8187741236801124`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"import", " ", "xCoba"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"<<", "xAct`xPert`"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"<<", "xAct`xCoba`"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", "aesthetics", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"$CovDFormat", "=", "\"\<Prefix\>\""}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"define", " ", "manifold", " ", "and", " ", "metric"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dim", "=", "4"}], ";"}], "    ", "\[IndentingNewLine]", 
   RowBox[{"DefManifold", "[", 
    RowBox[{"M", ",", "dim", ",", 
     RowBox[{"{", 
      RowBox[{
      "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "i", ",", "j", ",", 
       "k", ",", "l", ",", "p", ",", "q", ",", "r", ",", "s"}], "}"}]}], 
    "]"}], "\[IndentingNewLine]", 
   RowBox[{"DefMetric", "[", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"g", "[", 
      RowBox[{
       RowBox[{"-", "b"}], ",", 
       RowBox[{"-", "c"}]}], "]"}], ",", "CD", ",", 
     RowBox[{"{", 
      RowBox[{"\"\<;\>\"", ",", "\"\<\[Del]\>\""}], "}"}], ",", 
     RowBox[{"WeightedWithBasis", "\[Rule]", "AIndex"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PrintAs", "[", "RiemannCD", "]"}], "^=", "\"\<R\>\""}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"PrintAs", "[", "RicciCD", "]"}], "^=", "\"\<R\>\""}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"PrintAs", "[", "RicciScalarCD", "]"}], "^=", "\"\<R\>\""}], 
    ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"PrintAs", "[", "ChristoffelCD", "]"}], "^=", 
     "\"\<\[CapitalGamma]\>\""}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"PrintAs", "[", "EinsteinCD", "]"}], "^=", "\"\<G\>\""}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PrintAs", "[", "Detg", "]"}], "^=", "\"\<g\>\""}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "define", " ", "scalar", " ", "field", " ", "and", " ", "potentials"}], 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefTensor", "[", 
     RowBox[{
      RowBox[{"\[Phi]", "[", "]"}], ",", "M"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", "K", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", "G", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefConstantSymbol", "[", "\[Kappa]", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{
  3.7776842285875587`*^9, {3.777684343005937*^9, 3.77768437303294*^9}, {
   3.777684449042101*^9, 3.777684630351591*^9}, {3.777685859005588*^9, 
   3.777685859671356*^9}, {3.777686291180215*^9, 3.777686292009376*^9}}],

Cell[CellGroupData[{

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.8187743934396987`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xPerm`  version \"\>", 
   "\[InvisibleSpace]", "\<\"1.2.3\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2015", ",", "8", ",", "23"}], "}"}]}],
  SequenceForm["Package xAct`xPerm`  version ", "1.2.3", ", ", {2015, 8, 23}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.8187743934396987`*^9}],

Cell[BoxData["\<\"CopyRight (C) 2003-2018, Jose M. Martin-Garcia, under the \
General Public License.\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.8187743934553213`*^9}],

Cell[BoxData["\<\"Connecting to external MinGW executable...\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.8187743935114574`*^9}],

Cell[BoxData["\<\"Connection established.\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.818774393646285*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.818774393646285*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xTensor`  version \"\>", 
   "\[InvisibleSpace]", "\<\"1.1.3\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2018", ",", "2", ",", "28"}], "}"}]}],
  SequenceForm[
  "Package xAct`xTensor`  version ", "1.1.3", ", ", {2018, 2, 28}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.8187743936617193`*^9}],

Cell[BoxData["\<\"CopyRight (C) 2002-2018, Jose M. Martin-Garcia, under the \
General Public License.\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.8187743936617193`*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.8187743938598146`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xPert`  version \"\>", 
   "\[InvisibleSpace]", "\<\"1.0.6\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2018", ",", "2", ",", "28"}], "}"}]}],
  SequenceForm["Package xAct`xPert`  version ", "1.0.6", ", ", {2018, 2, 28}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.8187743938754387`*^9}],

Cell[BoxData["\<\"CopyRight (C) 2005-2018, David Brizuela, Jose M. \
Martin-Garcia and Guillermo A. Mena Marugan, under the General Public \
License.\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.8187743938754387`*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.8187743938754387`*^9}],

Cell[BoxData["\<\"These packages come with ABSOLUTELY NO WARRANTY; for \
details type Disclaimer[]. This is free software, and you are welcome to \
redistribute it under certain conditions. See the General Public License for \
details.\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.818774393891062*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.818774393891062*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Variable \"\>", "\[InvisibleSpace]", "$PrePrint", 
   "\[InvisibleSpace]", "\<\" assigned value \"\>", "\[InvisibleSpace]", 
   "ScreenDollarIndices"}],
  SequenceForm[
  "** Variable ", $PrePrint, " assigned value ", 
   xAct`xTensor`ScreenDollarIndices],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.818774393906681*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Variable \"\>", "\[InvisibleSpace]", "$CovDFormat", 
   "\[InvisibleSpace]", "\<\" changed from \"\>", 
   "\[InvisibleSpace]", "\<\"Prefix\"\>", "\[InvisibleSpace]", "\<\" to \"\>",
    "\[InvisibleSpace]", "\<\"Postfix\"\>"}],
  SequenceForm[
  "** Variable ", xAct`xTensor`$CovDFormat, " changed from ", "Prefix", 
   " to ", "Postfix"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.818774393906681*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Option \"\>", "\[InvisibleSpace]", "AllowUpperDerivatives", 
   "\[InvisibleSpace]", "\<\" of \"\>", "\[InvisibleSpace]", "ContractMetric",
    "\[InvisibleSpace]", "\<\" changed from \"\>", "\[InvisibleSpace]", 
   "False", "\[InvisibleSpace]", "\<\" to \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm[
  "** Option ", xAct`xTensor`AllowUpperDerivatives, " of ", 
   xAct`xTensor`ContractMetric, " changed from ", False, " to ", True],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.818774393906681*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Option \"\>", "\[InvisibleSpace]", "MetricOn", 
   "\[InvisibleSpace]", "\<\" of \"\>", "\[InvisibleSpace]", "MakeRule", 
   "\[InvisibleSpace]", "\<\" changed from \"\>", "\[InvisibleSpace]", "None",
    "\[InvisibleSpace]", "\<\" to \"\>", "\[InvisibleSpace]", "All"}],
  SequenceForm[
  "** Option ", xAct`xTensor`MetricOn, " of ", xAct`xTensor`MakeRule, 
   " changed from ", None, " to ", All],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.8187743939223037`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Option \"\>", "\[InvisibleSpace]", "ContractMetrics", 
   "\[InvisibleSpace]", "\<\" of \"\>", "\[InvisibleSpace]", "MakeRule", 
   "\[InvisibleSpace]", "\<\" changed from \"\>", "\[InvisibleSpace]", 
   "False", "\[InvisibleSpace]", "\<\" to \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm[
  "** Option ", xAct`xTensor`ContractMetrics, " of ", xAct`xTensor`MakeRule, 
   " changed from ", False, " to ", True],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.8187743939223037`*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.8187743939724026`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xCoba`  version \"\>", 
   "\[InvisibleSpace]", "\<\"0.8.4\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2018", ",", "2", ",", "28"}], "}"}]}],
  SequenceForm["Package xAct`xCoba`  version ", "0.8.4", ", ", {2018, 2, 28}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.8187743939724026`*^9}],

Cell[BoxData["\<\"CopyRight (C) 2005-2018, David Yllanes and Jose M. \
Martin-Garcia, under the General Public License.\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.818774393988024*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.818774393988024*^9}],

Cell[BoxData["\<\"These packages come with ABSOLUTELY NO WARRANTY; for \
details type Disclaimer[]. This is free software, and you are welcome to \
redistribute it under certain conditions. See the General Public License for \
details.\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.818774393988024*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.818774394003644*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefManifold", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"manifold \"\>", "\[InvisibleSpace]", "M", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefManifold, ": Defining ", "manifold ", $CellContext`M,
    ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.8187743942223024`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefVBundle", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vbundle \"\>", "\[InvisibleSpace]", "TangentM", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefVBundle, ": Defining ", 
   "vbundle ", $CellContext`TangentM, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.8187743942223024`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric metric tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"g", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric metric tensor ", 
   $CellContext`g[-$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.81877439424627*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"antisymmetric tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"epsilong", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}], ",", 
     RowBox[{"-", "e"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "antisymmetric tensor ", 
   $CellContext`epsilong[-$CellContext`b, -$CellContext`c, -$CellContext`d, \
-$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.8187743942532606`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tetrametric \"\>", "\[InvisibleSpace]", 
   RowBox[{"Tetrag", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}], ",", 
     RowBox[{"-", "e"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tetrametric ", 
   $CellContext`Tetrag[-$CellContext`b, -$CellContext`c, -$CellContext`d, \
-$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.8187743942554464`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tetrametric \"\>", "\[InvisibleSpace]", 
   RowBox[{"Tetrag\[Dagger]", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}], ",", 
     RowBox[{"-", "e"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tetrametric ", 
   $CellContext`Tetrag\[Dagger][-$CellContext`b, -$CellContext`c, \
-$CellContext`d, -$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.8187743942554464`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefCovD", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"covariant derivative \"\>", "\[InvisibleSpace]", 
   RowBox[{"CD", "[", 
    RowBox[{"-", "b"}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefCovD, ": Defining ", "covariant derivative ", 
   $CellContext`CD[-$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.8187743942554464`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vanishing torsion tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"TorsionCD", "[", 
    RowBox[{"b", ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "vanishing torsion tensor ", 
   $CellContext`TorsionCD[$CellContext`b, -$CellContext`c, -$CellContext`d], 
   ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.8187743942710724`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Christoffel tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"ChristoffelCD", "[", 
    RowBox[{"b", ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", 
   "symmetric Christoffel tensor ", 
   $CellContext`ChristoffelCD[$CellContext`b, -$CellContext`c, \
-$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.8187743942710724`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Riemann tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"RiemannCD", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}], ",", 
     RowBox[{"-", "e"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "Riemann tensor ", 
   $CellContext`RiemannCD[-$CellContext`b, -$CellContext`c, -$CellContext`d, \
-$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.8187743942866917`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Ricci tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"RicciCD", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric Ricci tensor ", 
   $CellContext`RicciCD[-$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.8187743942866917`*^9}],

Cell[BoxData["\<\"** DefCovD:  Contractions of Riemann automatically replaced \
by Ricci.\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.8187743942866917`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Ricci scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"RicciScalarCD", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "Ricci scalar ", 
   $CellContext`RicciScalarCD[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.8187743943023114`*^9}],

Cell[BoxData["\<\"** DefCovD:  Contractions of Ricci automatically replaced \
by RicciScalar.\"\>"], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.8187743943023114`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Einstein tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"EinsteinCD", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric Einstein tensor ", 
   $CellContext`EinsteinCD[-$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.8187743943023114`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Weyl tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"WeylCD", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}], ",", 
     RowBox[{"-", "e"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "Weyl tensor ", 
   $CellContext`WeylCD[-$CellContext`b, -$CellContext`c, -$CellContext`d, \
-$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.818774394342203*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric TFRicci tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"TFRicciCD", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric TFRicci tensor ", 
   $CellContext`TFRicciCD[-$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.818774394444929*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Kretschmann scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"KretschmannCD", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "Kretschmann scalar ", 
   $CellContext`KretschmannCD[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.818774394487837*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefCovD:  Computing RiemannToWeylRules for dim \"\>", 
   "\[InvisibleSpace]", "4"}],
  SequenceForm["** DefCovD:  Computing RiemannToWeylRules for dim ", 4],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.818774394487837*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefCovD:  Computing RicciToTFRicci for dim \"\>", 
   "\[InvisibleSpace]", "4"}],
  SequenceForm["** DefCovD:  Computing RicciToTFRicci for dim ", 4],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.818774394624365*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefCovD:  Computing RicciToEinsteinRules for dim \"\>", 
   "\[InvisibleSpace]", "4"}],
  SequenceForm["** DefCovD:  Computing RicciToEinsteinRules for dim ", 4],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.8187743946453876`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"weight +2 density \"\>", "\[InvisibleSpace]", 
   RowBox[{"Detg", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"Determinant.\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "weight +2 density ", 
   $CellContext`Detg[], ". ", "Determinant."],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.818774394664274*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[Phi]", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[Phi][], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.818774394669292*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", "K", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", "scalar function ", K,
    ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.818774394673297*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", "G", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`G, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.818774394673297*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefConstantSymbol", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"constant symbol \"\>", "\[InvisibleSpace]", 
   "\[Kappa]", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefConstantSymbol, ": Defining ", 
   "constant symbol ", $CellContext`\[Kappa], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777684623631207*^9, 3.777684640101819*^9}, 
   3.777685869536087*^9, 3.777686300204898*^9, 3.777686739425736*^9, 
   3.777686823107345*^9, 3.777687681568688*^9, 3.777687989832806*^9, 
   3.777688053589197*^9, 3.7777744324235396`*^9, 3.777778832255833*^9, 
   3.818774394673297*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["0.2 CP code",
 FontColor->RGBColor[1, 0.5, 0]]], "Subsection",
 CellChangeTimes->{{3.77768465587844*^9, 3.777684673012726*^9}}],

Cell[TextData[{
 "Here is a code from the notebook ",
 StyleBox["ActionVariation_Metric_Fields.nb",
  FontSlant->"Italic"],
 " in the ",
 ButtonBox["xAct examples website",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://github.com/xAct-contrib/examples"], None},
  ButtonNote->"https://github.com/xAct-contrib/examples"],
 " that we use for deriving the covariant field equations using xPert..."
}], "Text",
 CellChangeTimes->{{3.777684697448556*^9, 3.777684715449011*^9}, {
  3.8187740824272475`*^9, 3.8187741055961123`*^9}, {3.8187762482898345`*^9, 
  3.818776288686818*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"PerturbAction", "[", 
   RowBox[{"expr_", ",", 
    RowBox[{
     RowBox[{
      RowBox[{"g_", "?", "MetricQ"}], "[", 
      RowBox[{
       RowBox[{"a_", "?", "UpIndexQ"}], ",", 
       RowBox[{"b_", "?", "UpIndexQ"}]}], "]"}], "|", 
     RowBox[{
      RowBox[{"g_", "?", "MetricQ"}], "[", 
      RowBox[{
       RowBox[{"a_", "?", "DownIndexQ"}], ",", 
       RowBox[{"b_", "?", "DownIndexQ"}]}], "]"}]}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"pertexpr", ",", "res", ",", "dgloc", ",", 
      RowBox[{"(*", 
       RowBox[{"dummyloc", ","}], "*)"}], "hp"}], "}"}], ",", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{
      "We", " ", "define", " ", "the", " ", "metric", " ", "perturbation"}], 
      ",", " ", 
      RowBox[{"if", " ", "not", " ", "defined", " ", "already"}]}], " ", 
     "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"dgloc", "=", 
      RowBox[{"SymbolJoin", "[", 
       RowBox[{"\"\<\[Delta]\>\"", ",", "g"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"hp", "=", 
      RowBox[{"Head", "@", 
       RowBox[{"Perturbation", "[", 
        RowBox[{"g", "[", 
         RowBox[{
          RowBox[{"DownIndex", "@", "a"}], ",", 
          RowBox[{"DownIndex", "@", "b"}]}], "]"}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"hp", "===", "Perturbation"}], ",", 
       RowBox[{"DefMetricPerturbation", "[", 
        RowBox[{"g", ",", "dgloc", ",", 
         RowBox[{"SymbolJoin", "[", 
          RowBox[{"\"\<\[Epsilon]\>\"", ",", "g"}], "]"}]}], "]"}], ",", 
       RowBox[{"dgloc", "=", "hp"}]}], "]"}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"$DefInfoQ", "=", "False"}], "}"}], ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
        "We", " ", "perturb", " ", "wrt", " ", "to", " ", "the", " ", 
         "metric", " ", "and", " ", "if", " ", "it", " ", "is", " ", "the", 
         " ", "inverse", " ", "metric", " ", "we", " ", "put", " ", "a", " ", 
         "minus", " ", "sign"}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"pertexpr", "=", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"DownIndexQ", "[", "a", "]"}], ",", "1", ",", 
              RowBox[{"-", "1"}]}], "]"}], ")"}], "*", 
           RowBox[{"ToCanonical", "@", 
            RowBox[{"ContractMetric", "@", 
             RowBox[{"ExpandPerturbation", "@", 
              RowBox[{"Perturbation", "[", "expr", "]"}]}]}]}]}], "/.", 
          RowBox[{
           RowBox[{"Perturbation", "[", "tens_", "]"}], "\[RuleDelayed]", 
           "0"}]}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", 
         RowBox[{"We", " ", "then", " ", "use", " ", 
          RowBox[{"VarD", ".", " ", "It"}], " ", "happens", " ", "that", " ", 
          "some", " ", "trivial", " ", "Kronecker", " ", "appear", " ", 
          "which", " ", "need", " ", "to", " ", "be", " ", "handle", " ", 
          "manually"}], " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"res", "=", 
         RowBox[{"ToCanonical", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"SameDummies", "@", 
             RowBox[{"ContractMetric", "@", 
              RowBox[{
               RowBox[{"VarD", "[", 
                RowBox[{
                 RowBox[{"dgloc", "[", 
                  RowBox[{
                   RowBox[{"LI", "[", "1", "]"}], ",", "a", ",", "b"}], "]"}],
                  ",", 
                 RowBox[{"CovDOfMetric", "[", "g", "]"}]}], "]"}], "[", 
               "pertexpr", "]"}]}]}], ")"}], "/.", 
           RowBox[{
            RowBox[{"delta", "[", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"LI", "[", "n_", "]"}]}], ",", 
              RowBox[{"LI", "[", "m_", "]"}]}], "]"}], "\[RuleDelayed]", 
            RowBox[{"KroneckerDelta", "[", 
             RowBox[{
              RowBox[{"NoScalar", "[", "n", "]"}], ",", 
              RowBox[{"NoScalar", "[", "m", "]"}]}], "]"}]}]}], "]"}]}], 
        ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     "res"}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PerturbAction", "[", 
   RowBox[{"expr_", ",", 
    RowBox[{"tensor_", "?", "xTensorQ"}], ",", "covd_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"res", ",", "dummyloc", ",", "pertexpr", ",", "inds"}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"$DefInfoQ", "=", "False"}], "}"}], ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{
         "We", " ", "use", " ", "a", " ", "dummy", " ", "name", " ", "for", 
          " ", "the", " ", "variation", " ", "of", " ", "the", " ", 
          "tensor"}], ",", " ", 
         RowBox[{
         "and", " ", "use", " ", "it", " ", "to", " ", "replace", " ", "the", 
          " ", "formal", " ", "first", " ", "order", " ", "perturbation", " ",
           "the", " ", "tensor"}]}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
        "So", " ", "first", " ", "we", " ", "define", " ", "this", " ", 
         "dummy", " ", "tensor"}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"dummyloc", "=", 
         RowBox[{"SymbolJoin", "[", 
          RowBox[{"\"\<Var\>\"", ",", "tensor"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"inds", "=", 
         RowBox[{"DummyIn", "/@", 
          RowBox[{"SlotsOfTensor", "[", "tensor", "]"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"!", 
           RowBox[{"xTensorQ", "[", "dummyloc", "]"}]}], ",", 
          RowBox[{"DefTensor", "[", 
           RowBox[{
            RowBox[{"dummyloc", "@@", "inds"}], ",", 
            RowBox[{"First", "@", 
             RowBox[{"DependenciesOfTensor", "@", "tensor"}]}]}], "]"}]}], 
         "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"SymmetryGroupOfTensor", "[", "dummyloc", "]"}], "^=", 
         RowBox[{"SymmetryGroupOfTensor", "[", "tensor", "]"}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
         "Then", " ", "we", " ", "perturb", " ", "the", " ", "action", " ", 
          "and", " ", "replace", " ", 
          RowBox[{"Perturbation", "[", 
           RowBox[{"Tensor", "[", "..", "]"}], "]"}], " ", "by", " ", "this", 
          " ", "dummy", " ", "tensor"}], " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"pertexpr", "=", 
         RowBox[{"(", 
          RowBox[{"ToCanonical", "@", 
           RowBox[{"ContractMetric", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"ExpandPerturbation", "@", 
               RowBox[{"Perturbation", "[", "expr", "]"}]}], "/.", 
              RowBox[{
               RowBox[{"Perturbation", "[", 
                RowBox[{
                 RowBox[{"tens_", "?", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"#", "=!=", "tensor"}], ")"}], "&"}], ")"}]}], 
                 "[", "ar___", "]"}], "]"}], "\[RuleDelayed]", "0"}]}], "/.", 
             RowBox[{
              RowBox[{"Perturbation", "[", 
               RowBox[{"tensor", "[", "ind___", "]"}], "]"}], 
              "\[RuleDelayed]", 
              RowBox[{"dummyloc", "[", "ind", "]"}]}]}], "]"}]}], ")"}]}], 
        ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
          RowBox[{"With", " ", "this", " ", "simple", " ", "head"}], ",", " ", 
          RowBox[{"VarD", " ", "works", " ", 
           RowBox[{"correctly", ".", " ", "Again"}], " ", "we", " ", "need", 
           " ", "to", " ", "handel", " ", "some", " ", "trivial", " ", 
           "Kronecker"}]}], " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"res", "=", 
         RowBox[{"ToCanonical", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"SameDummies", "@", 
             RowBox[{"ContractMetric", "@", 
              RowBox[{
               RowBox[{"VarD", "[", 
                RowBox[{
                 RowBox[{"dummyloc", "@@", "inds"}], ",", "covd"}], "]"}], 
               "[", "pertexpr", "]"}]}]}], ")"}], "/.", 
           RowBox[{
            RowBox[{"delta", "[", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"LI", "[", "n_", "]"}]}], ",", 
              RowBox[{"LI", "[", "m_", "]"}]}], "]"}], "\[RuleDelayed]", 
            RowBox[{"KroneckerDelta", "[", 
             RowBox[{
              RowBox[{"NoScalar", "[", "n", "]"}], ",", 
              RowBox[{"NoScalar", "[", "m", "]"}]}], "]"}]}]}], "]"}]}], 
        ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     "res"}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PerturbAction", "[", 
   RowBox[{"expr_", ",", 
    RowBox[{"tensor_", "[", "inds___", "]"}]}], "]"}], ":=", 
  RowBox[{"PerturbAction", "[", 
   RowBox[{"expr", ",", 
    RowBox[{"tensor", "[", "inds", "]"}], ",", 
    RowBox[{"CovDOfMetric", "@", 
     RowBox[{"First", "@", "$Metrics"}]}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PerturbAction", "[", 
   RowBox[{"expr_", ",", 
    RowBox[{
     RowBox[{"tensor_", "?", "xTensorQ"}], "[", "inds___", "]"}], ",", 
    "covd_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"res", ",", "dummyloc", ",", "pertexpr"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"$DefInfoQ", "=", "False"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"dummyloc", "=", 
         RowBox[{"SymbolJoin", "[", 
          RowBox[{"\"\<Var\>\"", ",", "tensor"}], "]"}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"!", 
           RowBox[{"xTensorQ", "[", "dummyloc", "]"}]}], ",", 
          RowBox[{"DefTensor", "[", 
           RowBox[{
            RowBox[{"dummyloc", "[", "inds", "]"}], ",", 
            RowBox[{"First", "@", 
             RowBox[{"DependenciesOfTensor", "@", "tensor"}]}]}], "]"}]}], 
         "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"SymmetryGroupOfTensor", "[", "dummyloc", "]"}], "^=", 
         RowBox[{"SymmetryGroupOfTensor", "[", "tensor", "]"}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{"Perturbation", " ", "with", " ", "xPert"}], "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"pertexpr", "=", 
         RowBox[{"(", 
          RowBox[{"ToCanonical", "@", 
           RowBox[{"ContractMetric", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"ExpandPerturbation", "@", 
               RowBox[{"Perturbation", "[", "expr", "]"}]}], "/.", 
              RowBox[{
               RowBox[{"Perturbation", "[", 
                RowBox[{
                 RowBox[{"tens_", "?", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"#", "=!=", "tensor"}], ")"}], "&"}], ")"}]}], 
                 "[", "ar___", "]"}], "]"}], "\[RuleDelayed]", "0"}]}], "/.", 
             RowBox[{
              RowBox[{"Perturbation", "[", 
               RowBox[{"tensor", "[", "ind___", "]"}], "]"}], 
              "\[RuleDelayed]", 
              RowBox[{"dummyloc", "[", "ind", "]"}]}]}], "]"}]}], ")"}]}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
         "VarD", " ", "and", " ", "removal", " ", "of", " ", 
          "KroneckerDelta"}], "*)"}], "\[IndentingNewLine]", 
        RowBox[{"res", "=", 
         RowBox[{"ToCanonical", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"SameDummies", "@", 
             RowBox[{"ContractMetric", "@", 
              RowBox[{
               RowBox[{"VarD", "[", 
                RowBox[{
                 RowBox[{"dummyloc", "[", "inds", "]"}], ",", "covd"}], "]"}],
                "[", "pertexpr", "]"}]}]}], ")"}], "/.", 
           RowBox[{
            RowBox[{"delta", "[", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"LI", "[", "n_", "]"}]}], ",", 
              RowBox[{"LI", "[", "m_", "]"}]}], "]"}], "\[RuleDelayed]", 
            RowBox[{"KroneckerDelta", "[", 
             RowBox[{
              RowBox[{"NoScalar", "[", "n", "]"}], ",", 
              RowBox[{"NoScalar", "[", "m", "]"}]}], "]"}]}]}], "]"}]}], 
        ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     "res"}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"VarAction", "[", 
   RowBox[{"expr_", ",", 
    RowBox[{
     RowBox[{"g_", "?", "MetricQ"}], "[", 
     RowBox[{"as__", "?", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"UpIndexQ", "[", "#", "]"}], "||", 
          RowBox[{"DownIndexQ", "[", "#", "]"}]}], ")"}], "&"}], ")"}]}], 
     "]"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "sqrtg", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"sqrtg", "=", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"SignDetOfMetric", "[", "g", "]"}], 
        RowBox[{
         RowBox[{"Determinant", "[", "g", "]"}], "[", "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ToCanonical", "[", 
      RowBox[{
       RowBox[{"PerturbAction", "[", 
        RowBox[{"expr", ",", 
         RowBox[{"g", "[", "as", "]"}]}], "]"}], "+", 
       RowBox[{
        RowBox[{"ReplaceDummies", "@", "expr"}], "*", 
        RowBox[{
         RowBox[{"PerturbAction", "[", 
          RowBox[{"sqrtg", ",", 
           RowBox[{"g", "[", "as", "]"}]}], "]"}], "/", "sqrtg"}]}]}], " ", 
      "]"}]}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"VarAction", "[", 
   RowBox[{"expr_", ",", 
    RowBox[{"tensor_", "?", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"xTensorQ", "[", "#", "]"}], "&&", 
         RowBox[{"Not", "[", 
          RowBox[{"MetricQ", "[", "#", "]"}], "]"}]}], ")"}], "&"}], ")"}]}], 
    ",", 
    RowBox[{"g_", "?", "MetricQ"}]}], "]"}], ":=", 
  RowBox[{"PerturbAction", "[", 
   RowBox[{"expr", ",", "tensor", ",", 
    RowBox[{"CovDOfMetric", "[", "g", "]"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"VarAction", "[", 
     RowBox[{"expr_", ",", 
      RowBox[{"tensor_", "?", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"xTensorQ", "[", "#", "]"}], "&&", 
           RowBox[{"Not", "[", 
            RowBox[{"MetricQ", "[", "#", "]"}], "]"}]}], ")"}], "&"}], 
        ")"}]}]}], "]"}], ":=", 
    RowBox[{"VarAction", "[", 
     RowBox[{"expr", ",", "tensor", ",", 
      RowBox[{"First", "@", "$Metrics"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"VarAction", "[", 
   RowBox[{"expr_", ",", 
    RowBox[{
     RowBox[{"tensor_", "?", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"xTensorQ", "[", "#", "]"}], "&&", 
          RowBox[{"Not", "[", 
           RowBox[{"MetricQ", "[", "#", "]"}], "]"}]}], ")"}], "&"}], ")"}]}],
      "[", "inds___", "]"}], ",", 
    RowBox[{"g_", "?", "MetricQ"}]}], "]"}], ":=", 
  RowBox[{"PerturbAction", "[", 
   RowBox[{"expr", ",", 
    RowBox[{"tensor", "[", "inds", "]"}], ",", 
    RowBox[{"CovDOfMetric", "[", "g", "]"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"VarAction", "[", 
    RowBox[{"expr_", ",", 
     RowBox[{
      RowBox[{"tensor_", "?", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"xTensorQ", "[", "#", "]"}], "&&", 
           RowBox[{"Not", "[", 
            RowBox[{"MetricQ", "[", "#", "]"}], "]"}]}], ")"}], "&"}], 
        ")"}]}], "[", "inds___", "]"}]}], "]"}], ":=", 
   RowBox[{"VarAction", "[", 
    RowBox[{"expr", ",", 
     RowBox[{"tensor", "[", "inds", "]"}], ",", 
     RowBox[{"First", "@", "$Metrics"}]}], "]"}]}], ";"}]}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["I. Kinetic gravity braiding",
 FontColor->RGBColor[1, 0.5, 0]]], "Subsection",
 CellChangeTimes->{{3.777684771051243*^9, 3.777684777686041*^9}}],

Cell["Kinetic gravity braiding is defined by the Lagrangian...", "Text",
 CellChangeTimes->{{3.777685051160142*^9, 3.777685071298682*^9}, {
  3.8187744133910418`*^9, 3.8187744159876156`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"X", "=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{"1", "/", "2"}], ")"}]}], 
    RowBox[{
     RowBox[{"CD", "[", "b", "]"}], "[", 
     RowBox[{"\[Phi]", "[", "]"}], "]"}], 
    RowBox[{
     RowBox[{"CD", "[", 
      RowBox[{"-", "b"}], "]"}], "[", 
     RowBox[{"\[Phi]", "[", "]"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LK", "=", 
   RowBox[{"K", "[", 
    RowBox[{
     RowBox[{"\[Phi]", "[", "]"}], ",", "X"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LG", "=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"G", "[", 
      RowBox[{
       RowBox[{"\[Phi]", "[", "]"}], ",", "X"}], "]"}]}], 
    RowBox[{
     RowBox[{"CD", "[", "i", "]"}], "[", 
     RowBox[{
      RowBox[{"CD", "[", 
       RowBox[{"-", "i"}], "]"}], "[", 
      RowBox[{"\[Phi]", "[", "]"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"LEH", "=", 
    RowBox[{"\[Kappa]", " ", 
     RowBox[{"RicciScalarCD", "[", "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<L\>\"", "\[Equal]", 
  RowBox[{"LK", "+", "LG", "+", "LEH"}]}]}], "Input",
 CellChangeTimes->{{3.7776850890641727`*^9, 3.777685188201232*^9}, {
   3.777685232922462*^9, 3.777685328684702*^9}, {3.777685885612694*^9, 
   3.777685891586584*^9}, 3.818774421447861*^9}],

Cell[BoxData[
 RowBox[{"\<\"L\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox["K",
      ShowAutoStyles->False,
      AutoSpacing->False],
     K,
     Editable->False], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Phi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi][],
      Editable->False], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[Del]", "b"], "\[Phi]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`b][
        $CellContext`\[Phi][]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[$CellContext`b][
        $CellContext`\[Phi][]],
       Editable->False]}]}], "]"}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["R",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`RicciScalarCD[],
     Editable->False]}], "-", 
   RowBox[{
    RowBox[{
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Phi][]],
        Editable->False]}]}], "]"}], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "i"], 
       SubscriptBox["\[Del]", "i"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`i][
      $CellContext`CD[-$CellContext`i][
       $CellContext`\[Phi][]]],
     Editable->False]}]}]}]], "Output",
 CellChangeTimes->{3.7776858921055403`*^9, 3.777686312077167*^9, 
  3.777686750087504*^9, 3.777686833416018*^9, 3.7776876921697273`*^9, 
  3.7776879990617847`*^9, 3.777688061840715*^9, 3.777774900298315*^9, 
  3.7777788451422434`*^9, 3.8187744236192756`*^9}]
}, Open  ]],

Cell[TextData[{
 "We can derive the covariant field equations by varying this with respect to \
the fields ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["g", "bc"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " and ",
 Cell[BoxData[
  FormBox["\[Phi]", TraditionalForm]],
  FormatType->"TraditionalForm"],
 ". We separate this analysis into the ",
 StyleBox["k",
  FontSlant->"Italic"],
 "-essence (defined by ",
 Cell[BoxData[
  FormBox["K", TraditionalForm]],
  FormatType->"TraditionalForm"],
 "), braiding (defined by ",
 Cell[BoxData[
  FormBox["G", TraditionalForm]],
  FormatType->"TraditionalForm"],
 ") and Einstein-Hilbert sectors (tracked by ",
 Cell[BoxData[
  FormBox["\[Kappa]", TraditionalForm]],
  FormatType->"TraditionalForm"],
 ") of the theory.\n\nThe contributions to the metric field equation \
(modified Einstein equation) are as follows."
}], "Text",
 CellChangeTimes->{{3.777685562579516*^9, 3.777685695300316*^9}, {
  3.777686048518564*^9, 3.777686054051899*^9}, {3.8187744575615287`*^9, 
  3.818774464070261*^9}, {3.818774513251088*^9, 3.818774575915059*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"MFEbgK", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"VarAction", "[", 
       RowBox[{"LK", ",", 
        RowBox[{"g", "[", 
         RowBox[{"b", ",", "c"}], "]"}]}], "]"}], "//", "ContractMetric"}], "//",
      "ToCanonical"}], "//", "NoScalar"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MFEbgG", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"VarAction", "[", 
       RowBox[{"LG", ",", 
        RowBox[{"g", "[", 
         RowBox[{"b", ",", "c"}], "]"}]}], "]"}], "//", "ContractMetric"}], "//",
      "ToCanonical"}], "//", "NoScalar"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MFEbgEH", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"VarAction", "[", 
        RowBox[{"LEH", ",", 
         RowBox[{"g", "[", 
          RowBox[{"b", ",", "c"}], "]"}]}], "]"}], "//", "ContractMetric"}], "//",
       "RicciToEinstein"}], "//", "ToCanonical"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MFEbgEH", "+", "MFEbgK", "+", "MFEbgG"}], "\[Equal]", 
  "\"\<8 \[Pi] \!\(\*SubscriptBox[SuperscriptBox[\(T\), \((M)\)], \(bc\)]\)\>\
\""}]}], "Input",
 CellChangeTimes->{{3.7776857000160217`*^9, 3.777685820606783*^9}, {
  3.77768590902424*^9, 3.7776859472749968`*^9}, {3.7776859825127287`*^9, 
  3.777685995319107*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefParameter", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"parameter \"\>", "\[InvisibleSpace]", 
   "\[Epsilon]g", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefParameter, ": Defining ", 
   "parameter ", $CellContext`\[Epsilon]g, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686315060945*^9, 3.7776867501475697`*^9, 
  3.777686833529635*^9, 3.777687692229*^9, 3.777687999115205*^9, 
  3.777688061895612*^9, 3.7777749003673067`*^9, 3.7777788451735253`*^9, 
  3.8187744678697534`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[Delta]g", "[", 
    RowBox[{
     RowBox[{"LI", "[", "\<\"order\"\>", "]"}], ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[Delta]g[
    xAct`xTensor`LI["order"], -$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686315060945*^9, 3.7776867501475697`*^9, 
  3.777686833529635*^9, 3.777687692229*^9, 3.777687999115205*^9, 
  3.777688061895612*^9, 3.7777749003673067`*^9, 3.7777788451735253`*^9, 
  3.818774467877699*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"G", 
         StyleBox[GridBox[{
            {" ", " "},
            {"b", "c"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`EinsteinCD[-$CellContext`b, -$CellContext`c],
     Editable->False]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"b", "c"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`b, -$CellContext`c],
     Editable->False], " ", 
    RowBox[{
     InterpretationBox[
      StyleBox["K",
       ShowAutoStyles->False,
       AutoSpacing->False],
      K,
      Editable->False], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], 
       SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[$CellContext`d][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], 
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`d][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], 
       SubscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[-$CellContext`c][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`d][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"b", "c"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`b, -$CellContext`c],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`d][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "e"], 
       SubscriptBox["\[Del]", "d"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`e][
      $CellContext`CD[-$CellContext`d][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "e"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`e][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["K",
        ShowAutoStyles->False,
        AutoSpacing->False],
       K,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"b", "c"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`b, -$CellContext`c],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`d][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}]}], 
  "\[Equal]", "\<\"8 \[Pi] \\!\\(\\*SubscriptBox[SuperscriptBox[\\(T\\), \
\\((M)\\)], \\(bc\\)]\\)\"\>"}]], "Output",
 CellChangeTimes->{
  3.7776858223690443`*^9, 3.77768590307835*^9, 3.777685950506002*^9, {
   3.77768598845282*^9, 3.7776859964171047`*^9}, 3.7776863155900593`*^9, 
   3.777686750738288*^9, 3.777686834121142*^9, 3.777687692803525*^9, 
   3.7776879997021103`*^9, 3.7776880624830637`*^9, 3.7777749011159267`*^9, 
   3.7777788459597993`*^9, 3.8187744686405697`*^9}]
}, Open  ]],

Cell["\<\
The contributions to the scalar field equation are as follows.\
\>", "Text",
 CellChangeTimes->{{3.7776860372102003`*^9, 3.7776860454678583`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"BSEbgK", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"VarAction", "[", 
       RowBox[{"LK", ",", 
        RowBox[{"\[Phi]", "[", "]"}]}], "]"}], "//", "ContractMetric"}], "//",
      "ToCanonical"}], "//", "NoScalar"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"BSEbgG", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"VarAction", "[", 
        RowBox[{"LG", ",", 
         RowBox[{"\[Phi]", "[", "]"}]}], "]"}], "//", "ContractMetric"}], "//",
       "ToCanonical"}], "//", "NoScalar"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"BSEbgK", "+", "BSEbgG"}], "\[Equal]", "0"}]}], "Input",
 CellChangeTimes->{{3.7776860788488817`*^9, 3.777686143256228*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["\[Del]", "b"], 
        SubscriptBox["\[Del]", "c"], 
        SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`b][
       $CellContext`CD[-$CellContext`c][
        $CellContext`CD[$CellContext`c][
         $CellContext`\[Phi][]]]],
      Editable->False]}], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], 
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`CD[$CellContext`b][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[$CellContext`c][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SuperscriptBox["\[Del]", "c"], 
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[$CellContext`c][
       $CellContext`CD[-$CellContext`b][
        $CellContext`\[Phi][]]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], 
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`CD[$CellContext`b][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], 
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`CD[$CellContext`b][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["K",
        ShowAutoStyles->False,
        AutoSpacing->False],
       K,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], 
       SuperscriptBox["\[Del]", "d"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[$CellContext`d][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], 
       SubscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[-$CellContext`c][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "d"], 
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`d][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["K",
        ShowAutoStyles->False,
        AutoSpacing->False],
       K,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], 
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`CD[$CellContext`b][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["K",
       ShowAutoStyles->False,
       AutoSpacing->False],
      K,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Phi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi][],
      Editable->False], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         StyleBox["(",
          FontColor->RGBColor[1, 0, 0]], 
         RowBox[{
          InterpretationBox[
           StyleBox[
            RowBox[{
             SubscriptBox["\[Del]", "b"], "\[Phi]"}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`CD[-$CellContext`b][
            $CellContext`\[Phi][]],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`CD[$CellContext`b][
            $CellContext`\[Phi][]],
           Editable->False]}], 
         StyleBox[")",
          FontColor->RGBColor[1, 0, 0]]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
          $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
          $CellContext`\[Phi][]]],
       Editable->False]}]}], "]"}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[$CellContext`c][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Phi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["K",
        ShowAutoStyles->False,
        AutoSpacing->False],
       K,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Phi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Phi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Phi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Phi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Phi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Phi][]]],
        Editable->False]}]}], "]"}]}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.777686144760418*^9, 3.777686320706005*^9, 
  3.777686751287487*^9, 3.777686834684125*^9, 3.777687693385708*^9, 
  3.777688000265327*^9, 3.777688063051939*^9, 3.777774901848841*^9, 
  3.7777788466927967`*^9, 3.8187744818212423`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["II. Cosmological field equations",
 FontColor->RGBColor[1, 0.5, 0]]], "Subsection",
 CellChangeTimes->{{3.777686179101707*^9, 3.777686184072307*^9}, {
  3.8187756570043125`*^9, 3.818775662580818*^9}}],

Cell["\<\
We use xCoba to reduce the covariant expressions into their component forms. \
We start by defining the chart and the FRW metric...\
\>", "Text",
 CellChangeTimes->{{3.7776861974948483`*^9, 3.7776862533410788`*^9}, {
  3.818774201203678*^9, 3.8187742304994535`*^9}, {3.818774604993803*^9, 
  3.8187746132925653`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "define", " ", "chart", " ", "B", " ", "in", " ", "manifold", " ", "M"}], 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"DefChart", "[", 
     RowBox[{"B", ",", "M", ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "2", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"t", "[", "]"}], ",", 
        RowBox[{"x", "[", "]"}], ",", 
        RowBox[{"y", "[", "]"}], ",", 
        RowBox[{"z", "[", "]"}]}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"define", " ", "scale", " ", "factor", " ", "a", 
     StyleBox[
      RowBox[{"(", "t", ")"}],
      FontSlant->"Italic"], 
     StyleBox[" ",
      FontSlant->"Italic"], "and", " ", "FRW", " ", "metric"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", "a", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FRW", "=", 
     RowBox[{"DiagonalMatrix", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", 
        SuperscriptBox[
         RowBox[{"a", "[", 
          RowBox[{"t", "[", "]"}], "]"}], "2"], ",", 
        SuperscriptBox[
         RowBox[{"a", "[", 
          RowBox[{"t", "[", "]"}], "]"}], "2"], ",", 
        SuperscriptBox[
         RowBox[{"a", "[", 
          RowBox[{"t", "[", "]"}], "]"}], "2"]}], "}"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "tell", " ", "xCoba", " ", "FRW", " ", "is", " ", "the", " ", "metric", 
     " ", "and", " ", "compute", " ", "curvature", " ", "quantities"}], 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MetricInBasis", "[", 
     RowBox[{"g", ",", 
      RowBox[{"-", "B"}], ",", "FRW"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MetricCompute", "[", 
     RowBox[{"g", ",", "B", ",", "All", ",", 
      RowBox[{"CVSimplify", "\[Rule]", "Simplify"}]}], "]"}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.777686278318387*^9, 3.777686283132815*^9}, {
  3.777686345022435*^9, 3.777686431063656*^9}, {3.7776866634874153`*^9, 
  3.7776867062141743`*^9}, {3.777686803669854*^9, 3.777686804238579*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefChart", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"chart \"\>", "\[InvisibleSpace]", "B", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xCoba`DefChart, ": Defining ", "chart ", $CellContext`B, ". ", 
   ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.818774617998296*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"coordinate scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"t", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "coordinate scalar ", 
   $CellContext`t[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.8187746180032873`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"coordinate scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"x", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "coordinate scalar ", 
   $CellContext`x[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.818774618004339*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"coordinate scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"y", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "coordinate scalar ", 
   $CellContext`y[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.818774618004339*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"coordinate scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"z", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "coordinate scalar ", 
   $CellContext`z[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.818774618019966*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefMapping", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"mapping \"\>", "\[InvisibleSpace]", "B", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefMapping, ": Defining ", "mapping ", $CellContext`B, 
   ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.818774618019966*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefMapping", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"inverse mapping \"\>", "\[InvisibleSpace]", "iB",
    "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefMapping, ": Defining ", 
   "inverse mapping ", $CellContext`iB, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.818774618019966*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"mapping differential tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"diB", "[", 
    RowBox[{
     RowBox[{"-", "\[FormalA]"}], ",", "iBb"}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", 
   "mapping differential tensor ", 
   $CellContext`diB[-\[FormalA], $CellContext`iBb], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.8187746180355844`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"mapping differential tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"dB", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", "B\[FormalA]"}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", 
   "mapping differential tensor ", 
   $CellContext`dB[-$CellContext`b, $CellContext`B\[FormalA]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.8187746180355844`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefBasis", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"basis \"\>", "\[InvisibleSpace]", "B", 
   "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"Coordinated basis.\"\>"}],
  SequenceForm[
  "** ", xAct`xCoba`DefBasis, ": Defining ", "basis ", $CellContext`B, ". ", 
   "Coordinated basis."],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.818774618051206*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefCovD", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"parallel derivative \"\>", "\[InvisibleSpace]", 
   RowBox[{"PDB", "[", 
    RowBox[{"-", "b"}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefCovD, ": Defining ", "parallel derivative ", 
   $CellContext`PDB[-$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.818774618051206*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vanishing torsion tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"TorsionPDB", "[", 
    RowBox[{"b", ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "vanishing torsion tensor ", 
   $CellContext`TorsionPDB[$CellContext`b, -$CellContext`c, -$CellContext`d], 
   ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.818774618051206*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Christoffel tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"ChristoffelPDB", "[", 
    RowBox[{"b", ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", 
   "symmetric Christoffel tensor ", 
   $CellContext`ChristoffelPDB[$CellContext`b, -$CellContext`c, \
-$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.818774618066862*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vanishing Riemann tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"RiemannPDB", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}], ",", "e"}], "]"}], "\[InvisibleSpace]", "\<\". \"\>",
    "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "vanishing Riemann tensor ", 
   $CellContext`RiemannPDB[-$CellContext`b, -$CellContext`c, -$CellContext`d, \
$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.818774618066862*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vanishing Ricci tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"RicciPDB", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "vanishing Ricci tensor ", 
   $CellContext`RicciPDB[-$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.818774618066862*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"antisymmetric +1 density \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"etaUpB", "[", 
    RowBox[{"b", ",", "c", ",", "d", ",", "e"}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "antisymmetric +1 density ", 
   $CellContext`etaUpB[$CellContext`b, $CellContext`c, $CellContext`d, \
$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.818774618082447*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"antisymmetric -1 density \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"etaDownB", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}], ",", 
     RowBox[{"-", "e"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "antisymmetric -1 density ", 
   $CellContext`etaDownB[-$CellContext`b, -$CellContext`c, -$CellContext`d, \
-$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.818774618082447*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", "a", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`a, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.818774618082447*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{0, -$CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{"-", "1"}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{0, -$CellContext`B}, {
     0, -$CellContext`B}] -> -1, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.818774618098071*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{0, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{0, -$CellContext`B}, {
     1, -$CellContext`B}] -> 0, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.8187746181346307`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{0, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{0, -$CellContext`B}, {
     2, -$CellContext`B}] -> 0, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.8187746181415668`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{0, -$CellContext`B}, {
     3, -$CellContext`B}] -> 0, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.8187746181635237`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{1, -$CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{0, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`g[{1, -$CellContext`B}, {
     0, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
     1, -$CellContext`B}], " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.8187746181899767`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{1, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    SuperscriptBox[
     RowBox[{
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}], "2"]}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{1, -$CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`a[
      $CellContext`t[]]^2, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.818774618210354*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{1, -$CellContext`B}, {
     2, -$CellContext`B}] -> 0, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.818774618217475*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{1, -$CellContext`B}, {
     3, -$CellContext`B}] -> 0, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.818774618239442*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{2, -$CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{0, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`g[{2, -$CellContext`B}, {
     0, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
     2, -$CellContext`B}], " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.818774618263262*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{2, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`g[{2, -$CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`g[{1, -$CellContext`B}, {
     2, -$CellContext`B}], " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.8187746182860055`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{2, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    SuperscriptBox[
     RowBox[{
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}], "2"]}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{2, -$CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`a[
      $CellContext`t[]]^2, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.818774618293063*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{2, -$CellContext`B}, {
     3, -$CellContext`B}] -> 0, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.818774618315057*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{3, -$CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`g[{3, -$CellContext`B}, {
     0, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.818774618340247*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{3, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`g[{3, -$CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`g[{1, -$CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.818774618363763*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{3, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`g[{3, -$CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`g[{2, -$CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.818774618387619*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[{3, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    SuperscriptBox[
     RowBox[{
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}], "2"]}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "g"}],
  SequenceForm[
  "Added independent rule ", $CellContext`g[{3, -$CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`a[
      $CellContext`t[]]^2, " for tensor ", $CellContext`g],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.818774618393669*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"weight +2 density \"\>", "\[InvisibleSpace]", 
   RowBox[{"DetgB", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"Determinant.\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "weight +2 density ", 
   $CellContext`DetgB[], ". ", "Determinant."],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.818774618393669*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"ChristoffelCDPDB", "[", 
    RowBox[{"b", ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`ChristoffelCDPDB[$CellContext`b, -$CellContext`c, \
-$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777686644966304*^9, 3.7776867636280107`*^9, 
  3.777686841777457*^9, 3.777687703129505*^9, 3.777688005030776*^9, 
  3.7776880669758463`*^9, 3.7777749106894503`*^9, 3.7777788524852543`*^9, 
  3.81877461844582*^9}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 "We define the matter SET and consider the unitary scalar field, i.e, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Phi]", "=", 
    RowBox[{
     SubscriptBox["\[Phi]", "0"], "(", "t", ")"}]}], TraditionalForm]]],
 "..."
}], "Text",
 CellChangeTimes->{{3.777687075777155*^9, 3.7776871480056753`*^9}, {
  3.818774630405204*^9, 3.8187746589590607`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"DefTensor", "[", 
   RowBox[{
    RowBox[{"T", "[", 
     RowBox[{
      RowBox[{"-", "b"}], ",", 
      RowBox[{"-", "c"}]}], "]"}], ",", "M", ",", 
    RowBox[{"Symmetric", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "b"}], ",", 
       RowBox[{"-", "c"}]}], "}"}], "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PF", "=", 
   RowBox[{"DiagonalMatrix", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"\[Rho]", "[", 
        RowBox[{"t", "[", "]"}], "]"}]}], ",", 
      RowBox[{"P", "[", 
       RowBox[{"t", "[", "]"}], "]"}], ",", 
      RowBox[{"P", "[", 
       RowBox[{"t", "[", "]"}], "]"}], ",", 
      RowBox[{"P", "[", 
       RowBox[{"t", "[", "]"}], "]"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ComponentValue", "[", 
    RowBox[{
     RowBox[{"ComponentArray", "[", 
      RowBox[{"T", "[", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"{", 
          RowBox[{"b", ",", "B"}], "}"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"c", ",", "B"}], "}"}]}], "]"}], "]"}], ",", "PF"}], "]"}], 
   ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"compute", " ", "down"}], "-", 
    RowBox[{
    "down", " ", "components", " ", "of", " ", "matter", " ", "SET"}]}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ChangeComponents", "[", 
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"{", 
         RowBox[{"b", ",", "B"}], "}"}]}], ",", 
       RowBox[{"-", 
        RowBox[{"{", 
         RowBox[{"c", ",", "B"}], "}"}]}]}], "]"}], ",", 
     RowBox[{"T", "[", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"{", 
         RowBox[{"b", ",", "B"}], "}"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", "B"}], "}"}]}], "]"}]}], "]"}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"matter", " ", "SET"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "\"\<\!\(\*SubscriptBox[SuperscriptBox[\(T\), \(a\)], \(b\)]\)\>\"", 
   "\[Equal]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"T", "[", 
          RowBox[{
           RowBox[{"-", "b"}], ",", 
           RowBox[{"-", "c"}]}], "]"}], "//", 
         RowBox[{"ToBasis", "[", "B", "]"}]}], "//", "ComponentArray"}], "//",
        "ToValues"}], "//", "ToValues"}], "//", "MatrixForm"}], ")"}]}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"scalar", " ", "field", " ", "in", " ", "FRW"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefScalarFunction", "[", 
   RowBox[{"\[Phi]0", ",", 
    RowBox[{
    "PrintAs", "\[Rule]", 
     "\"\<\!\(\*SubscriptBox[\(\[Phi]\), \(0\)]\)\>\""}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ComponentValue", "[", 
   RowBox[{
    RowBox[{"\[Phi]", "[", "]"}], ",", " ", 
    RowBox[{"\[Phi]0", "[", 
     RowBox[{"t", "[", "]"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.777687168943804*^9, 3.77768729132369*^9}, 
   3.777687329868163*^9, {3.777687380512602*^9, 3.777687380956182*^9}, {
   3.777687591270731*^9, 3.7776876239071608`*^9}, {3.7776876647361097`*^9, 
   3.777687665072289*^9}, {3.777687809350095*^9, 3.777687809842127*^9}, {
   3.7776879675610027`*^9, 3.777687974209988*^9}, {3.7776880433914824`*^9, 
   3.777688044880334*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"T", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`T[-$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.81877467167945*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {0, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, $CellContext`B}, {0, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{0, -$CellContext`B}, {
     0, $CellContext`B}] -> $CellContext`T[{0, $CellContext`B}, {
     0, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.818774671701662*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, $CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{"-", 
     RowBox[{"\[Rho]", "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}]}]}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{0, $CellContext`B}, {
     0, -$CellContext`B}] -> -$CellContext`\[Rho][
      $CellContext`t[]], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.818774671707712*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {1, $CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{0, -$CellContext`B}, {
     1, $CellContext`B}] -> 0, " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.8187746717312346`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {2, $CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{0, -$CellContext`B}, {
     2, $CellContext`B}] -> 0, " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.8187746717382946`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {3, $CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{0, -$CellContext`B}, {
     3, $CellContext`B}] -> 0, " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.818774671758418*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {0, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, $CellContext`B}, {1, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{1, -$CellContext`B}, {
     0, $CellContext`B}] -> $CellContext`T[{0, $CellContext`B}, {
     1, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.8187746717824106`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, $CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{0, $CellContext`B}, {
     1, -$CellContext`B}] -> 0, " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.818774671790475*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {1, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, $CellContext`B}, {1, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{1, -$CellContext`B}, {
     1, $CellContext`B}] -> $CellContext`T[{1, $CellContext`B}, {
     1, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.8187746718161345`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, $CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{"P", "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{1, $CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`P[
     $CellContext`t[]], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.818774671820211*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {2, $CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{1, -$CellContext`B}, {
     2, $CellContext`B}] -> 0, " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.818774671846713*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {3, $CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{1, -$CellContext`B}, {
     3, $CellContext`B}] -> 0, " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.818774671852749*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, -$CellContext`B}, {0, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, $CellContext`B}, {2, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{2, -$CellContext`B}, {
     0, $CellContext`B}] -> $CellContext`T[{0, $CellContext`B}, {
     2, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.818774671875984*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, $CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{0, $CellContext`B}, {
     2, -$CellContext`B}] -> 0, " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.818774671882038*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, -$CellContext`B}, {1, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, $CellContext`B}, {2, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{2, -$CellContext`B}, {
     1, $CellContext`B}] -> $CellContext`T[{1, $CellContext`B}, {
     2, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.8187746719059176`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, $CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{1, $CellContext`B}, {
     2, -$CellContext`B}] -> 0, " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.8187746719110174`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, -$CellContext`B}, {2, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, $CellContext`B}, {2, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{2, -$CellContext`B}, {
     2, $CellContext`B}] -> $CellContext`T[{2, $CellContext`B}, {
     2, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.8187746719356136`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, $CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{"P", "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{2, $CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`P[
     $CellContext`t[]], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.818774671941661*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, -$CellContext`B}, {3, $CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{2, -$CellContext`B}, {
     3, $CellContext`B}] -> 0, " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.8187746719649277`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{3, -$CellContext`B}, {0, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, $CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{3, -$CellContext`B}, {
     0, $CellContext`B}] -> $CellContext`T[{0, $CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.8187746719894724`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, $CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{0, $CellContext`B}, {
     3, -$CellContext`B}] -> 0, " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.818774671994547*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{3, -$CellContext`B}, {1, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, $CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{3, -$CellContext`B}, {
     1, $CellContext`B}] -> $CellContext`T[{1, $CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.8187746720186777`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, $CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{1, $CellContext`B}, {
     3, -$CellContext`B}] -> 0, " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.818774672024727*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{3, -$CellContext`B}, {2, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, $CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{3, -$CellContext`B}, {
     2, $CellContext`B}] -> $CellContext`T[{2, $CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.81877467204871*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, $CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{2, $CellContext`B}, {
     3, -$CellContext`B}] -> 0, " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.818774672054707*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{3, -$CellContext`B}, {3, $CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{3, $CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{3, -$CellContext`B}, {
     3, $CellContext`B}] -> $CellContext`T[{3, $CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.8187746720771723`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], " "},
            {" ", 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{3, $CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{"P", "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{3, $CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`P[
     $CellContext`t[]], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.818774672083275*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {1, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {2, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {0, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {0, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{0, -$CellContext`B}, {
     0, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       1, $CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       2, $CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       0, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       0, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.818774672116781*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {1, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {2, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {0, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{0, -$CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`g[{1, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       1, $CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       2, $CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       0, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.818774672153515*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {1, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {2, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {0, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{0, -$CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`g[{1, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       1, $CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       2, $CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       0, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.818774672190462*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {1, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {2, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{3, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {0, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{0, -$CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`g[{1, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       1, $CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       2, $CellContext`B}] + $CellContext`g[{3, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       0, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.818774672244804*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{1, -$CellContext`B}, {
     0, -$CellContext`B}] -> $CellContext`T[{0, -$CellContext`B}, {
     1, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.8187746722604256`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Replaced independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {1, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {2, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {0, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" by \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {0, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, -$CellContext`B}, {2, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Replaced independent rule ", $CellContext`T[{0, -$CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`g[{1, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       1, $CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       2, $CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       0, -$CellContext`B}], 
   " by ", $CellContext`T[{0, -$CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       0, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{1, -$CellContext`B}, {
       2, $CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{1, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       1, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.8187746723286443`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, -$CellContext`B}, {2, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{1, -$CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{1, -$CellContext`B}, {
       2, $CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{1, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       1, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.8187746723748293`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, -$CellContext`B}, {2, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{1, -$CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{1, -$CellContext`B}, {
       2, $CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{1, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       1, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.818774672420718*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, -$CellContext`B}, {2, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{3, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{1, -$CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{1, -$CellContext`B}, {
       2, $CellContext`B}] + $CellContext`g[{3, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{1, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       1, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.818774672468117*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, -$CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{2, -$CellContext`B}, {
     0, -$CellContext`B}] -> $CellContext`T[{0, -$CellContext`B}, {
     2, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.818774672490757*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Replaced independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {1, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {2, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {0, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" by \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {0, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Replaced independent rule ", $CellContext`T[{0, -$CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`g[{1, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       1, $CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       2, $CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       0, -$CellContext`B}], 
   " by ", $CellContext`T[{0, -$CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       0, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{2, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{2, $CellContext`B}, {
       2, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.818774672551608*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{2, -$CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`T[{1, -$CellContext`B}, {
     2, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.818774672576392*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Replaced independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, -$CellContext`B}, {2, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" by \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Replaced independent rule ", $CellContext`T[{1, -$CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{1, -$CellContext`B}, {
       2, $CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{1, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       1, -$CellContext`B}], 
   " by ", $CellContext`T[{1, -$CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{2, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{2, $CellContext`B}, {
       2, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.818774672637803*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{2, -$CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{2, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{2, $CellContext`B}, {
       2, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.8187746726862445`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{3, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{2, -$CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{3, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{2, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{2, $CellContext`B}, {
       2, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.8187746727389526`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{3, -$CellContext`B}, {0, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{3, -$CellContext`B}, {
     0, -$CellContext`B}] -> $CellContext`T[{0, -$CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.8187746727688994`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Replaced independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {1, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {2, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{3, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {0, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" by \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["0",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{0, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {0, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{3, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Replaced independent rule ", $CellContext`T[{0, -$CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`g[{1, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       1, $CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       2, $CellContext`B}] + $CellContext`g[{3, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       0, -$CellContext`B}], 
   " by ", $CellContext`T[{0, -$CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       0, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{2, $CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{0, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{3, $CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.8187746728310647`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{3, -$CellContext`B}, {1, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{3, -$CellContext`B}, {
     1, -$CellContext`B}] -> $CellContext`T[{1, -$CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.8187746728596115`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Replaced independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, -$CellContext`B}, {2, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{3, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {1, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" by \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{1, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {1, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{3, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Replaced independent rule ", $CellContext`T[{1, -$CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       1, -$CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{1, -$CellContext`B}, {
       2, $CellContext`B}] + $CellContext`g[{3, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{1, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       1, -$CellContext`B}], 
   " by ", $CellContext`T[{1, -$CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       1, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{2, $CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{3, $CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.818774672920967*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{3, -$CellContext`B}, {2, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`T[{3, -$CellContext`B}, {
     2, -$CellContext`B}] -> $CellContext`T[{2, -$CellContext`B}, {
     3, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.818774672951601*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Replaced independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{3, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, -$CellContext`B}, {3, $CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, $CellContext`B}, {2, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" by \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{2, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {2, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{3, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Replaced independent rule ", $CellContext`T[{2, -$CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       2, -$CellContext`B}] + $CellContext`g[{3, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{2, -$CellContext`B}, {
       3, $CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{2, $CellContext`B}, {
       2, -$CellContext`B}], 
   " by ", $CellContext`T[{2, -$CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       2, -$CellContext`B}] $CellContext`T[{2, $CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{3, $CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.8187746730124435`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{3, -$CellContext`B}, {3, -$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{0, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["0",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{0, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{1, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["1",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{1, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{2, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["2",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{2, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`g[{3, -$CellContext`B}, {3, -$CellContext`B}],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"T", 
           StyleBox[GridBox[{
              {
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]], " "},
              {" ", 
               StyleBox["3",
                FontColor->RGBColor[1., 0., 0.]]}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`T[{3, $CellContext`B}, {3, -$CellContext`B}],
       Editable->False]}]}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "T"}],
  SequenceForm[
  "Added independent rule ", $CellContext`T[{3, -$CellContext`B}, {
     3, -$CellContext`B}] -> $CellContext`g[{0, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{0, $CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{1, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{1, $CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{2, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{2, $CellContext`B}, {
       3, -$CellContext`B}] + $CellContext`g[{3, -$CellContext`B}, {
       3, -$CellContext`B}] $CellContext`T[{3, $CellContext`B}, {
       3, -$CellContext`B}], " for tensor ", $CellContext`T],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.81877467306429*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Computed \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"T", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["b",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["c",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`T[{-$CellContext`b, -$CellContext`B}, {-$CellContext`c, \
-$CellContext`B}],
     Editable->False], "\[Rule]", 
    RowBox[{
     InterpretationBox[
      StyleBox[GridBox[{
         {"g", 
          StyleBox[GridBox[{
             {" ", " "},
             {
              StyleBox["d",
               FontColor->RGBColor[1., 0., 0.]], 
              StyleBox["c",
               FontColor->RGBColor[1., 0., 0.]]}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`g[{-$CellContext`d, -$CellContext`B}, {-$CellContext`c, \
-$CellContext`B}],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"T", 
          StyleBox[GridBox[{
             {" ", 
              StyleBox["d",
               FontColor->RGBColor[1., 0., 0.]]},
             {
              StyleBox["b",
               FontColor->RGBColor[1., 0., 0.]], " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`T[{-$CellContext`b, -$CellContext`B}, {$CellContext`d, \
$CellContext`B}],
      Editable->False]}]}], "\[InvisibleSpace]", "\<\" in \"\>", 
   "\[InvisibleSpace]", "0.9632979`7.4353056070164305", 
   "\[InvisibleSpace]", "\<\" Seconds\"\>"}],
  SequenceForm[
  "Computed ", $CellContext`T[{-$CellContext`b, -$CellContext`B}, \
{-$CellContext`c, -$CellContext`B}] -> $CellContext`g[{-$CellContext`d, \
-$CellContext`B}, {-$CellContext`c, -$CellContext`B}] \
$CellContext`T[{-$CellContext`b, -$CellContext`B}, {$CellContext`d, \
$CellContext`B}], " in ", 0.9632979`7.4353056070164305, " Seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.818774673088253*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[SuperscriptBox[\\(T\\), \\(a\\)], \
\\(b\\)]\\)\"\>", "\[Equal]", 
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       RowBox[{"\[Rho]", "[", 
        InterpretationBox[
         StyleBox["t",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`t[],
         Editable->False], "]"}], "0", "0", "0"},
      {"0", 
       RowBox[{
        SuperscriptBox[
         RowBox[{
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`a,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        RowBox[{"P", "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}]}], "0", "0"},
      {"0", "0", 
       RowBox[{
        SuperscriptBox[
         RowBox[{
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`a,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        RowBox[{"P", "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}]}], "0"},
      {"0", "0", "0", 
       RowBox[{
        SuperscriptBox[
         RowBox[{
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`a,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        RowBox[{"P", "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]}]], "Output",
 CellChangeTimes->{3.777687354562492*^9, 3.77768771134719*^9, 
  3.777688017053129*^9, 3.77768807695894*^9, 3.777774913194344*^9, 
  3.7777788540892677`*^9, 3.8187746731180167`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", 
   "\[Phi]0", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`\[Phi]0, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.8187746731336384`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Phi]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Phi][],
     Editable->False], "\[Rule]", 
    RowBox[{
     InterpretationBox[
      StyleBox[
       SubscriptBox["\[Phi]", "0"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]0,
      Editable->False], "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "\[Phi]"}],
  SequenceForm[
  "Added independent rule ", $CellContext`\[Phi][] -> $CellContext`\[Phi]0[
     $CellContext`t[]], " for tensor ", $CellContext`\[Phi]],
  Editable->False]], "Print",
 CellChangeTimes->{3.777687346920982*^9, 3.77768770896618*^9, 
  3.77768801452915*^9, 3.777688071777561*^9, 3.7777749112616835`*^9, 
  3.7777788530020967`*^9, 3.8187746731336384`*^9}]
}, Open  ]]
}, Open  ]],

Cell["The scalar field\[CloseCurlyQuote]s kinetic density becomes...", "Text",
 CellChangeTimes->{{3.777688706101716*^9, 3.7776887133805523`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Xcomp", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"X", "//", 
        RowBox[{"ToBasis", "[", "B", "]"}]}], "//", "TraceBasisDummy"}], "//",
       "ToValues"}], "//", "ToValues"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<X\>\"", "\[Equal]", "Xcomp"}]}], "Input"],

Cell[BoxData[
 RowBox[{"\<\"X\"\>", "\[Equal]", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}], "2"]}]}]], "Output",
 CellChangeTimes->{3.777688756737903*^9, 3.7777749132633443`*^9, 
  3.7777788541582656`*^9, 3.818774680364939*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["k",
  FontSlant->"Italic"],
 "-essence sector"
}], "Subsubsection",
 CellChangeTimes->{{3.777688122624342*^9, 3.777688129588325*^9}}],

Cell[TextData[{
 "The following rule simplifies the ",
 StyleBox["k",
  FontSlant->"Italic"],
 "-essence potentials explicitly appearing in the field equations..."
}], "Text",
 CellChangeTimes->{{3.777689243948004*^9, 3.777689262601183*^9}, {
  3.777689578804942*^9, 3.777689584271594*^9}, {3.8187743059152884`*^9, 
  3.818774306090442*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"simplifyK", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"K", "[", 
       RowBox[{"u_", ",", "v_"}], "]"}], "\[RuleDelayed]", 
      RowBox[{"K", "[", 
       RowBox[{
        RowBox[{"\[Phi]0", "[", 
         RowBox[{"t", "[", "]"}], "]"}], ",", "Xcomp"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", 
         RowBox[{"x_", ",", "y_"}], "]"}], "[", "K", "]"}], "[", 
       RowBox[{"u_", ",", "v_"}], "]"}], "\[RuleDelayed]", 
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", 
         RowBox[{"x", ",", "y"}], "]"}], "[", "K", "]"}], "[", 
       RowBox[{
        RowBox[{"\[Phi]0", "[", 
         RowBox[{"t", "[", "]"}], "]"}], ",", "Xcomp"}], "]"}]}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.818774686151891*^9, 3.81877476412632*^9}}],

Cell[TextData[{
 "The ",
 StyleBox["k",
  FontSlant->"Italic"],
 "-essence sector of the metric field equation becomes..."
}], "Text",
 CellChangeTimes->{{3.777688102903036*^9, 3.777688103802415*^9}, {
   3.777688140918531*^9, 3.7776881801810207`*^9}, {3.7776892885004587`*^9, 
   3.777689289129653*^9}, 3.777689431347332*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"MFEcompK", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"MFEbgK", "/.", "simplifyK"}], "//", 
       RowBox[{"ToBasis", "[", "B", "]"}]}], "//", "ComponentArray"}], "//", 
     "ToValues"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"MFEcompK", "//", "MatrixForm"}]}], "Input",
 CellChangeTimes->{{3.7776882968747187`*^9, 3.777688298546734*^9}, {
  3.777688362302208*^9, 3.7776884232164297`*^9}, {3.777689307076829*^9, 
  3.777689399529705*^9}, {3.7776895627183857`*^9, 3.777689566872184*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["K",
           ShowAutoStyles->False,
           AutoSpacing->False],
          K,
          Editable->False], "[", 
         RowBox[{
          RowBox[{
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}], ",", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["\[Phi]", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi]0,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", 
             InterpretationBox[
              StyleBox["t",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`t[],
              Editable->False], "]"}], "2"]}]}], "]"}]}], "-", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox["K",
            ShowAutoStyles->False,
            AutoSpacing->False],
           K,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}], ",", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["\[Phi]", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi]0,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", 
             InterpretationBox[
              StyleBox["t",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`t[],
              Editable->False], "]"}], "2"]}]}], "]"}]}]}], "0", "0", "0"},
     {"0", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       SuperscriptBox[
        RowBox[{
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`a,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}], "2"], " ", 
       RowBox[{
        InterpretationBox[
         StyleBox["K",
          ShowAutoStyles->False,
          AutoSpacing->False],
         K,
         Editable->False], "[", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], ",", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["\[Phi]", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]0,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", 
            InterpretationBox[
             StyleBox["t",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`t[],
             Editable->False], "]"}], "2"]}]}], "]"}]}], "0", "0"},
     {"0", "0", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       SuperscriptBox[
        RowBox[{
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`a,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}], "2"], " ", 
       RowBox[{
        InterpretationBox[
         StyleBox["K",
          ShowAutoStyles->False,
          AutoSpacing->False],
         K,
         Editable->False], "[", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], ",", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["\[Phi]", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]0,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", 
            InterpretationBox[
             StyleBox["t",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`t[],
             Editable->False], "]"}], "2"]}]}], "]"}]}], "0"},
     {"0", "0", "0", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       SuperscriptBox[
        RowBox[{
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`a,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}], "2"], " ", 
       RowBox[{
        InterpretationBox[
         StyleBox["K",
          ShowAutoStyles->False,
          AutoSpacing->False],
         K,
         Editable->False], "[", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], ",", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["\[Phi]", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]0,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", 
            InterpretationBox[
             StyleBox["t",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`t[],
             Editable->False], "]"}], "2"]}]}], "]"}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.777688299113648*^9, {3.777688365726948*^9, 3.777688423760202*^9}, {
   3.777689370900238*^9, 3.777689400361327*^9}, 3.777689567350685*^9, 
   3.7777749133323374`*^9, 3.7777788542207603`*^9, 3.8187747737626705`*^9}]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox["k-",
  FontSlant->"Italic"],
 "essence sector of the scalar field equation becomes..."
}], "Text",
 CellChangeTimes->{{3.7776894086870604`*^9, 3.777689427441592*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"BSEcompK", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"BSEbgK", "/.", "simplifyK"}], "//", 
        RowBox[{"ToBasis", "[", "B", "]"}]}], "//", "TraceBasisDummy"}], "//",
       "ToValues"}], "//", "ToValues"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "BSEcompK"}], "Input",
 CellChangeTimes->{{3.777689506690275*^9, 3.777689523879896*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"3", " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`a,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["K",
         ShowAutoStyles->False,
         AutoSpacing->False],
        K,
        Editable->False], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "[", 
        InterpretationBox[
         StyleBox["t",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`t[],
         Editable->False], "]"}], ",", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"]}]}], "]"}]}], 
    RowBox[{
     InterpretationBox[
      StyleBox["a",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`a,
      Editable->False], "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}]]}], "-", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       SubscriptBox["\[Phi]", "0"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]0,
      Editable->False], "\[Prime]\[Prime]",
     MultilineFunction->None], "[", 
    InterpretationBox[
     StyleBox["t",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`t[],
     Editable->False], "]"}], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["K",
       ShowAutoStyles->False,
       AutoSpacing->False],
      K,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", 
        InterpretationBox[
         StyleBox["t",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`t[],
         Editable->False], "]"}], "2"]}]}], "]"}]}], "-", 
  RowBox[{
   SuperscriptBox[
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       SubscriptBox["\[Phi]", "0"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]0,
      Editable->False], "\[Prime]\[Prime]",
     MultilineFunction->None], "[", 
    InterpretationBox[
     StyleBox["t",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`t[],
     Editable->False], "]"}], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["K",
       ShowAutoStyles->False,
       AutoSpacing->False],
      K,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", 
        InterpretationBox[
         StyleBox["t",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`t[],
         Editable->False], "]"}], "2"]}]}], "]"}]}], "+", 
  RowBox[{
   SuperscriptBox[
    InterpretationBox[
     StyleBox["K",
      ShowAutoStyles->False,
      AutoSpacing->False],
     K,
     Editable->False], 
    TagBox[
     RowBox[{"(", 
      RowBox[{"1", ",", "0"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{
    RowBox[{
     InterpretationBox[
      StyleBox[
       SubscriptBox["\[Phi]", "0"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]0,
      Editable->False], "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}], ",", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "\[Prime]",
        MultilineFunction->None], "[", 
       InterpretationBox[
        StyleBox["t",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`t[],
        Editable->False], "]"}], "2"]}]}], "]"}], "-", 
  RowBox[{
   SuperscriptBox[
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["K",
       ShowAutoStyles->False,
       AutoSpacing->False],
      K,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", 
        InterpretationBox[
         StyleBox["t",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`t[],
         Editable->False], "]"}], "2"]}]}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.777689524632443*^9, 3.7777749134325795`*^9, 
  3.7777788543053923`*^9, 3.8187747771358123`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["braiding sector", "Subsubsection",
 CellChangeTimes->{{3.777688184006239*^9, 3.777688185896373*^9}}],

Cell["\<\
The following rule simplifies the braiding potentials explicitly appearing in \
the field equations...\
\>", "Text",
 CellChangeTimes->{{3.777689591562269*^9, 3.777689596602059*^9}, {
  3.818774298237294*^9, 3.818774298381836*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"simplifyG", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Derivative", "[", 
        RowBox[{"x_", ",", "y_"}], "]"}], "[", "G", "]"}], "[", 
      RowBox[{"u_", ",", "v_"}], "]"}], "\[RuleDelayed]", 
     RowBox[{
      RowBox[{
       RowBox[{"Derivative", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "[", "G", "]"}], "[", 
      RowBox[{
       RowBox[{"\[Phi]0", "[", 
        RowBox[{"t", "[", "]"}], "]"}], ",", "Xcomp"}], "]"}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.777689693212407*^9, 3.777689698564372*^9}, 
   3.7776898972258472`*^9, {3.8187747897456713`*^9, 3.818774810071846*^9}}],

Cell["The braiding sector of the metric field equation becomes...", "Text",
 CellChangeTimes->{{3.777688191499263*^9, 3.777688196325246*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"MFEcompG", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"MFEbgG", "/.", "simplifyG"}], "//", 
            RowBox[{"ToBasis", "[", "B", "]"}]}], "//", "ComponentArray"}], "//",
           "TraceBasisDummy"}], "//", "ToValues"}], "//", "ToValues"}], "//", 
       RowBox[{"ToBasis", "[", "B", "]"}]}], "//", "TraceBasisDummy"}], "//", 
     "ToValues"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"MFEcompG", "//", "MatrixForm"}]}], "Input",
 CellChangeTimes->{{3.777689907911278*^9, 3.7776899274376907`*^9}, {
  3.777690075127079*^9, 3.7776900758801317`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"3", " ", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`a,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["\[Phi]", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]0,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", 
            InterpretationBox[
             StyleBox["t",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`t[],
             Editable->False], "]"}], "3"], " ", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["\[Phi]", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]0,
              Editable->False], "[", 
             InterpretationBox[
              StyleBox["t",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`t[],
              Editable->False], "]"}], ",", 
            RowBox[{
             FractionBox["1", "2"], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                InterpretationBox[
                 StyleBox[
                  SubscriptBox["\[Phi]", "0"],
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`\[Phi]0,
                 Editable->False], "\[Prime]",
                MultilineFunction->None], "[", 
               InterpretationBox[
                StyleBox["t",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`t[],
                Editable->False], "]"}], "2"]}]}], "]"}]}], 
         RowBox[{"2", " ", 
          RowBox[{
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`a,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}]}]]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}], ",", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["\[Phi]", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi]0,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", 
             InterpretationBox[
              StyleBox["t",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`t[],
              Editable->False], "]"}], "2"]}]}], "]"}]}]}], "0", "0", "0"},
     {"0", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`a,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]\[Prime]",
          MultilineFunction->None], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}], ",", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["\[Phi]", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi]0,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", 
             InterpretationBox[
              StyleBox["t",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`t[],
              Editable->False], "]"}], "2"]}]}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`a,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}], ",", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["\[Phi]", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi]0,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", 
             InterpretationBox[
              StyleBox["t",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`t[],
              Editable->False], "]"}], "2"]}]}], "]"}]}]}], "0", "0"},
     {"0", "0", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`a,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]\[Prime]",
          MultilineFunction->None], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}], ",", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["\[Phi]", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi]0,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", 
             InterpretationBox[
              StyleBox["t",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`t[],
              Editable->False], "]"}], "2"]}]}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`a,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}], ",", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["\[Phi]", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi]0,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", 
             InterpretationBox[
              StyleBox["t",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`t[],
              Editable->False], "]"}], "2"]}]}], "]"}]}]}], "0"},
     {"0", "0", "0", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`a,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]\[Prime]",
          MultilineFunction->None], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}], ",", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["\[Phi]", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi]0,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", 
             InterpretationBox[
              StyleBox["t",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`t[],
              Editable->False], "]"}], "2"]}]}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`a,
           Editable->False], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}], ",", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["\[Phi]", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi]0,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", 
             InterpretationBox[
              StyleBox["t",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`t[],
              Editable->False], "]"}], "2"]}]}], "]"}]}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.7776899188625603`*^9, 3.777689928107102*^9}, 
   3.7776900796798573`*^9, 3.777774914699628*^9, 3.7777788554549522`*^9, 
   3.8187748164845147`*^9}]
}, Open  ]],

Cell["The braiding sector of the scalar field equation becomes...", "Text",
 CellChangeTimes->{{3.7776909751880207`*^9, 3.777690982623814*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"BSEcompG", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"BSEbgG", "/.", "simplifyG"}], "//", 
             RowBox[{"SeparateMetric", "[", "g", "]"}]}], "//", 
            RowBox[{"ToBasis", "[", "B", "]"}]}], "//", "TraceBasisDummy"}], "//",
           "ToValues"}], "//", "ToValues"}], "//", 
        RowBox[{"ToBasis", "[", "B", "]"}]}], "//", "TraceBasisDummy"}], "//",
       "ToValues"}], "//", "ToValues"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "BSEcompG"}], "Input",
 CellChangeTimes->{{3.7776909883971148`*^9, 3.7776910016389427`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"6", " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`a,
         Editable->False], "\[Prime]",
        MultilineFunction->None], "[", 
       InterpretationBox[
        StyleBox["t",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`t[],
        Editable->False], "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "\[Prime]",
        MultilineFunction->None], "[", 
       InterpretationBox[
        StyleBox["t",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`t[],
        Editable->False], "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "[", 
        InterpretationBox[
         StyleBox["t",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`t[],
         Editable->False], "]"}], ",", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"]}]}], "]"}]}], 
    SuperscriptBox[
     RowBox[{
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}], "2"]]}], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "\[Prime]\[Prime]",
      MultilineFunction->None], "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", 
       InterpretationBox[
        StyleBox["t",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`t[],
        Editable->False], "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}], "2"]}]}], "]"}]}], 
   RowBox[{
    InterpretationBox[
     StyleBox["a",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`a,
     Editable->False], "[", 
    InterpretationBox[
     StyleBox["t",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`t[],
     Editable->False], "]"}]], "-", 
  FractionBox[
   RowBox[{"6", " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]\[Prime]",
      MultilineFunction->None], "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", 
       InterpretationBox[
        StyleBox["t",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`t[],
        Editable->False], "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}], "2"]}]}], "]"}]}], 
   RowBox[{
    InterpretationBox[
     StyleBox["a",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`a,
     Editable->False], "[", 
    InterpretationBox[
     StyleBox["t",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`t[],
     Editable->False], "]"}]], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}], "3"], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]\[Prime]",
      MultilineFunction->None], "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", 
       InterpretationBox[
        StyleBox["t",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`t[],
        Editable->False], "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}], "2"]}]}], "]"}]}], 
   RowBox[{
    InterpretationBox[
     StyleBox["a",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`a,
     Editable->False], "[", 
    InterpretationBox[
     StyleBox["t",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`t[],
     Editable->False], "]"}]], "+", 
  FractionBox[
   RowBox[{"6", " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", 
       InterpretationBox[
        StyleBox["t",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`t[],
        Editable->False], "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}], "2"]}]}], "]"}]}], 
   RowBox[{
    InterpretationBox[
     StyleBox["a",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`a,
     Editable->False], "[", 
    InterpretationBox[
     StyleBox["t",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`t[],
     Editable->False], "]"}]], "+", 
  RowBox[{"2", " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       SubscriptBox["\[Phi]", "0"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]0,
      Editable->False], "\[Prime]\[Prime]",
     MultilineFunction->None], "[", 
    InterpretationBox[
     StyleBox["t",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`t[],
     Editable->False], "]"}], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", 
        InterpretationBox[
         StyleBox["t",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`t[],
         Editable->False], "]"}], "2"]}]}], "]"}]}], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}], "3"], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", 
       InterpretationBox[
        StyleBox["t",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`t[],
        Editable->False], "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}], "2"]}]}], "]"}]}], 
   RowBox[{
    InterpretationBox[
     StyleBox["a",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`a,
     Editable->False], "[", 
    InterpretationBox[
     StyleBox["t",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`t[],
     Editable->False], "]"}]], "+", 
  RowBox[{
   SuperscriptBox[
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       SubscriptBox["\[Phi]", "0"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]0,
      Editable->False], "\[Prime]\[Prime]",
     MultilineFunction->None], "[", 
    InterpretationBox[
     StyleBox["t",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`t[],
     Editable->False], "]"}], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", 
        InterpretationBox[
         StyleBox["t",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`t[],
         Editable->False], "]"}], "2"]}]}], "]"}]}], "+", 
  RowBox[{
   SuperscriptBox[
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", 
     InterpretationBox[
      StyleBox["t",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`t[],
      Editable->False], "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "[", 
      InterpretationBox[
       StyleBox["t",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`t[],
       Editable->False], "]"}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", 
        InterpretationBox[
         StyleBox["t",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`t[],
         Editable->False], "]"}], "2"]}]}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.777691106014162*^9, 3.777775054405594*^9, 
  3.7777789804754457`*^9, 3.8187749445118384`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Einstein-Hilbert sector", "Subsubsection",
 CellChangeTimes->{{3.777688201163343*^9, 3.777688207778205*^9}}],

Cell["\<\
The Einstein-Hilbert part of the metric field equation leads to the \
well-known expression...\
\>", "Text",
 CellChangeTimes->{{3.777688213392612*^9, 3.777688254005632*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"MFEcompEH", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"MFEbgEH", "//", 
        RowBox[{"ToBasis", "[", "B", "]"}]}], "//", "ComponentArray"}], "//", 
      "ToValues"}], "//", "ToValues"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"MFEcompEH", "//", "MatrixForm"}]}], "Input",
 CellChangeTimes->{{3.7776882690362864`*^9, 3.77768827442028*^9}, {
  3.777688304780467*^9, 3.777688307637043*^9}, {3.777689533780676*^9, 
  3.777689554857657*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{"3", " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`a,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", 
          InterpretationBox[
           StyleBox["t",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`t[],
           Editable->False], "]"}], "2"]}], 
       SuperscriptBox[
        RowBox[{
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`a,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}], "2"]], "0", "0", "0"},
     {"0", 
      RowBox[{
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox["a",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`a,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", 
            InterpretationBox[
             StyleBox["t",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`t[],
             Editable->False], "]"}], "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`a,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`a,
             Editable->False], "\[Prime]\[Prime]",
            MultilineFunction->None], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}]}]}], ")"}]}], "0", "0"},
     {"0", "0", 
      RowBox[{
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox["a",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`a,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", 
            InterpretationBox[
             StyleBox["t",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`t[],
             Editable->False], "]"}], "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`a,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`a,
             Editable->False], "\[Prime]\[Prime]",
            MultilineFunction->None], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}]}]}], ")"}]}], "0"},
     {"0", "0", "0", 
      RowBox[{
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox["a",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`a,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", 
            InterpretationBox[
             StyleBox["t",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`t[],
             Editable->False], "]"}], "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`a,
            Editable->False], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`a,
             Editable->False], "\[Prime]\[Prime]",
            MultilineFunction->None], "[", 
           InterpretationBox[
            StyleBox["t",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`t[],
            Editable->False], "]"}]}]}], ")"}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.7776882700069513`*^9, 3.777688274856617*^9}, 
   3.77768830809842*^9, {3.777689543457099*^9, 3.777689555592108*^9}, 
   3.7777750544961696`*^9, 3.777778980542407*^9, 3.818774962694229*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Matter sector", "Subsubsection",
 CellChangeTimes->{{3.7776918567665777`*^9, 3.7776918584310303`*^9}}],

Cell["\<\
The matter sector is defined by the perfect fluid in the usual way, i.e.,...\
\>", "Text",
 CellChangeTimes->{{3.777691860535028*^9, 3.777691879356771*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Tcomp", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"T", "[", 
         RowBox[{
          RowBox[{"-", "b"}], ",", 
          RowBox[{"-", "c"}]}], "]"}], "//", 
        RowBox[{"ToBasis", "[", "B", "]"}]}], "//", "ComponentArray"}], "//", 
      "ToValues"}], "//", "ToValues"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Tcomp", "//", "MatrixForm"}]}], "Input",
 CellChangeTimes->{{3.777691882286499*^9, 3.777691908500108*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"\[Rho]", "[", 
       InterpretationBox[
        StyleBox["t",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`t[],
        Editable->False], "]"}], "0", "0", "0"},
     {"0", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`a,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}], "2"], " ", 
       RowBox[{"P", "[", 
        InterpretationBox[
         StyleBox["t",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`t[],
         Editable->False], "]"}]}], "0", "0"},
     {"0", "0", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`a,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}], "2"], " ", 
       RowBox[{"P", "[", 
        InterpretationBox[
         StyleBox["t",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`t[],
         Editable->False], "]"}]}], "0"},
     {"0", "0", "0", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`a,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t[],
          Editable->False], "]"}], "2"], " ", 
       RowBox[{"P", "[", 
        InterpretationBox[
         StyleBox["t",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`t[],
         Editable->False], "]"}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.7776918927994843`*^9, 3.7776919090199127`*^9}, 
   3.7777750545163126`*^9, 3.777778980573655*^9, 3.818774972265598*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Cosmological",
  FontSlant->"Italic"],
 " field equations"
}], "Subsubsection",
 CellChangeTimes->{{3.777691578623334*^9, 3.777691581852126*^9}, {
  3.8187755994813*^9, 3.8187756207370768`*^9}}],

Cell["\<\
The Friedmann equations follow by equating the gravitational sector with the \
matter sector. The spatial isotropy and homogeneity imply that there are only \
two independent components for background tensors. We equate only the \
time-time part and the space-space parts.

This leads us to...\
\>", "Text",
 CellChangeTimes->{{3.777691583933619*^9, 3.777691615951915*^9}, {
  3.7776916581539373`*^9, 3.777691737928487*^9}, {3.8187749860932045`*^9, 
  3.8187750118131514`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"MFEgrav", "=", 
    RowBox[{"MFEcompK", "+", "MFEcompG", "+", "MFEcompEH"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FE1", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Collect", "[", 
       RowBox[{
        RowBox[{"MFEgrav", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", "\[Kappa]"}], "]"}], 
      "\[Equal]", 
      RowBox[{
       FractionBox["1", "2"], 
       RowBox[{"Tcomp", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}]}]}], ")"}], "/.", 
    RowBox[{
     RowBox[{"t", "[", "]"}], "\[Rule]", "t"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FE2", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Collect", "[", 
        RowBox[{
         RowBox[{"MFEgrav", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "2"}], "]"}], "]"}], ",", "\[Kappa]"}], "]"}], 
       "\[Equal]", 
       RowBox[{
        FractionBox["1", "2"], 
        RowBox[{"Tcomp", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "2"}], "]"}], "]"}]}]}], ")"}], "/.", 
     RowBox[{
      RowBox[{"t", "[", "]"}], "\[Rule]", "t"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "FE1", \
"\[IndentingNewLine]", "FE2"}], "Input",
 CellChangeTimes->{{3.7776916276755943`*^9, 3.7776916525962667`*^9}, {
  3.777691742666757*^9, 3.7776917856871977`*^9}, {3.777691925270817*^9, 
  3.77769195636649*^9}, {3.7776921465647984`*^9, 3.777692164420169*^9}, {
  3.777692242891243*^9, 3.777692257048708*^9}, {3.7777788092476945`*^9, 
  3.777778817884759*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{
     InterpretationBox[
      StyleBox["K",
       ShowAutoStyles->False,
       AutoSpacing->False],
      K,
      Editable->False], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], "+", 
   FractionBox[
    RowBox[{"3", " ", 
     InterpretationBox[
      StyleBox["\[Kappa]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Kappa],
      Editable->False], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`a,
         Editable->False], "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], 
    SuperscriptBox[
     RowBox[{
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "[", "t", "]"}], "2"]], "-", 
   FractionBox[
    RowBox[{"3", " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`a,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "[", "t", "]"}], ",", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], 
    RowBox[{"2", " ", 
     RowBox[{
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "[", "t", "]"}]}]], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["K",
        ShowAutoStyles->False,
        AutoSpacing->False],
       K,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}]}], 
  "\[Equal]", 
  FractionBox[
   RowBox[{"\[Rho]", "[", "t", "]"}], "2"]}]], "Output",
 CellChangeTimes->{
  3.7776917728469143`*^9, 3.7776919572971992`*^9, {3.777692153934587*^9, 
   3.777692172752434*^9}, 3.777692257530259*^9, 3.7777750545565844`*^9, 
   3.7777789805957794`*^9, 3.818775030757934*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", 
    SuperscriptBox[
     RowBox[{
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     InterpretationBox[
      StyleBox["K",
       ShowAutoStyles->False,
       AutoSpacing->False],
      K,
      Editable->False], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`a,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`a,
         Editable->False], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`a,
          Editable->False], "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox[
     RowBox[{
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "[", "t", "]"}], "2"], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox[
     RowBox[{
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "[", "t", "]"}], "2"], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}]}], 
  "\[Equal]", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    RowBox[{
     InterpretationBox[
      StyleBox["a",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`a,
      Editable->False], "[", "t", "]"}], "2"], " ", 
   RowBox[{"P", "[", "t", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.7776917728469143`*^9, 3.7776919572971992`*^9, {3.777692153934587*^9, 
   3.777692172752434*^9}, 3.777692257530259*^9, 3.7777750545565844`*^9, 
   3.7777789805957794`*^9, 3.8187750307735877`*^9}]
}, Open  ]],

Cell["The scalar field equation is given by...", "Text",
 CellChangeTimes->{{3.77769204849536*^9, 3.7776920855198097`*^9}, {
  3.818775054620398*^9, 3.8187750662640667`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SFE", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"BSEcompK", "+", "BSEcompG"}], "\[Equal]", "0"}], ")"}], "/.", 
     RowBox[{
      RowBox[{"t", "[", "]"}], "\[Rule]", "t"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "SFE"}], "Input",
 CellChangeTimes->{{3.7776920886511297`*^9, 3.777692119722003*^9}, {
  3.7776921676273823`*^9, 3.7776921698194113`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"6", " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`a,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "[", "t", "]"}], ",", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["\[Phi]", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]0,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], 
     SuperscriptBox[
      RowBox[{
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`a,
        Editable->False], "[", "t", "]"}], "2"]]}], "-", 
   FractionBox[
    RowBox[{"3", " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`a,
        Editable->False], "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "[", "t", "]"}], ",", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], 
    RowBox[{
     InterpretationBox[
      StyleBox["a",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`a,
      Editable->False], "[", "t", "]"}]], "-", 
   FractionBox[
    RowBox[{"6", " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`a,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "[", "t", "]"}], ",", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], 
    RowBox[{
     InterpretationBox[
      StyleBox["a",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`a,
      Editable->False], "[", "t", "]"}]], "-", 
   FractionBox[
    RowBox[{"3", " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`a,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["K",
         ShowAutoStyles->False,
         AutoSpacing->False],
        K,
        Editable->False], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "[", "t", "]"}], ",", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], 
    RowBox[{
     InterpretationBox[
      StyleBox["a",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`a,
      Editable->False], "[", "t", "]"}]], "-", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["K",
        ShowAutoStyles->False,
        AutoSpacing->False],
       K,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], "-", 
   FractionBox[
    RowBox[{"3", " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`a,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "[", "t", "]"}], ",", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], 
    RowBox[{
     InterpretationBox[
      StyleBox["a",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`a,
      Editable->False], "[", "t", "]"}]], "-", 
   RowBox[{
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["K",
        ShowAutoStyles->False,
        AutoSpacing->False],
       K,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], "+", 
   FractionBox[
    RowBox[{"6", " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`a,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "[", "t", "]"}], ",", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], 
    RowBox[{
     InterpretationBox[
      StyleBox["a",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`a,
      Editable->False], "[", "t", "]"}]], "+", 
   RowBox[{"2", " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["K",
       ShowAutoStyles->False,
       AutoSpacing->False],
      K,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "[", "t", "]"}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}], "-", 
   FractionBox[
    RowBox[{"3", " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`a,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "[", "t", "]"}], ",", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], 
    RowBox[{
     InterpretationBox[
      StyleBox["a",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`a,
      Editable->False], "[", "t", "]"}]], "+", 
   RowBox[{
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], "-", 
   RowBox[{
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["K",
        ShowAutoStyles->False,
        AutoSpacing->False],
       K,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}]}], 
  "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.7776921202754517`*^9, 3.777692170398808*^9, 
  3.777775054698418*^9, 3.777778980689516*^9, 3.8187750684242935`*^9}]
}, Open  ]],

Cell[TextData[{
 "We can also express the above equations in terms of the Hubble parameter, \
i.e., ",
 Cell[BoxData[
  FormBox[
   RowBox[{"H", "=", 
    RowBox[{
     RowBox[{"a", "'"}], "/", "a"}]}], TraditionalForm]]],
 ". To do so, we prepare the rule..."
}], "Text",
 CellChangeTimes->{{3.777775493657487*^9, 3.7777755429139214`*^9}, {
  3.8187750755040264`*^9, 3.8187751070196466`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ruleatoH", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"a", "'"}], "[", "t", "]"}], 
          RowBox[{"a", "[", "t", "]"}]], "\[Equal]", 
         RowBox[{"H", "[", "t", "]"}]}], ",", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{
           FractionBox[
            RowBox[{
             RowBox[{"a", "'"}], "[", "t", "]"}], 
            RowBox[{"a", "[", "t", "]"}]], ",", "t"}], "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{"H", "'"}], "[", "t", "]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"a", "'"}], "[", "t", "]"}], ",", 
        RowBox[{
         RowBox[{"a", "''"}], "[", "t", "]"}]}], "}"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", "ruleatoH"}], "Input",
 CellChangeTimes->{{3.7777755456033773`*^9, 3.7777756362451468`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`a,
       Editable->False], "[", "t", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"], "+", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], ")"}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7777756367768545`*^9, 3.7777789807585144`*^9, 
  3.8187751101046934`*^9}]
}, Open  ]],

Cell["\<\
The Friedmann equations and the scalar field equation then become...\
\>", "Text",
 CellChangeTimes->{{3.7777756500826187`*^9, 3.7777756611479483`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"FE1H", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"FE1", "/.", "ruleatoH"}], "/.", 
     RowBox[{"\[Kappa]", "\[Rule]", 
      FractionBox["1", "2"]}]}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FE2H", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"FE2", "/.", "ruleatoH"}], "/.", 
     RowBox[{"\[Kappa]", "\[Rule]", 
      FractionBox["1", "2"]}]}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SFEH", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"SFE", "/.", "ruleatoH"}], "/.", 
      RowBox[{"\[Kappa]", "\[Rule]", 
       FractionBox["1", "2"]}]}], "//", "Simplify"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "FE1H", \
"\[IndentingNewLine]", "FE2H", "\[IndentingNewLine]", "SFEH"}], "Input",
 CellChangeTimes->{{3.777775662568621*^9, 3.7777757131341105`*^9}, {
  3.7777759224295654`*^9, 3.7777759337843575`*^9}, {3.777779779801956*^9, 
  3.7777797926685333`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Rho]", "[", "t", "]"}], "+", 
   RowBox[{
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "[", "t", "]"}], ",", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["\[Phi]", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]0,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], 
      "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["K",
          ShowAutoStyles->False,
          AutoSpacing->False],
         K,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "[", "t", "]"}], ",", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["\[Phi]", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]0,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], 
     ")"}]}]}], "\[Equal]", 
  RowBox[{
   RowBox[{"3", " ", 
    SuperscriptBox[
     RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox["K",
      ShowAutoStyles->False,
      AutoSpacing->False],
     K,
     Editable->False], "[", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "[", "t", "]"}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}], "+", 
   RowBox[{
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], 
     "]"}]}]}]}]], "Output",
 CellChangeTimes->{
  3.777775713949669*^9, {3.7777759241847105`*^9, 3.777775935163118*^9}, 
   3.7777789808965063`*^9, 3.7777797943623886`*^9, 3.8187751151470366`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox["a",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`a,
     Editable->False], "[", "t", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", 
      SuperscriptBox[
       RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox["K",
        ShowAutoStyles->False,
        AutoSpacing->False],
       K,
       Editable->False], "[", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "[", "t", "]"}], ",", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}], "+", 
     RowBox[{"P", "[", "t", "]"}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox["H", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}], "-", 
     RowBox[{
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "[", "t", "]"}], ",", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["\[Phi]", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]0,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], "-", 
     RowBox[{
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "[", "t", "]"}], ",", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["\[Phi]", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]0,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}]}], 
    ")"}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{
  3.777775713949669*^9, {3.7777759241847105`*^9, 3.777775935163118*^9}, 
   3.7777789808965063`*^9, 3.7777797943623886`*^9, 3.8187751151470366`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["K",
       ShowAutoStyles->False,
       AutoSpacing->False],
      K,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "[", "t", "]"}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "[", "t", "]"}], ",", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["\[Phi]", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]0,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], 
      "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "[", "t", "]"}], ",", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["\[Phi]", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]0,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}]}], 
     ")"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}]}], 
  "\[Equal]", 
  RowBox[{
   RowBox[{"9", " ", 
    SuperscriptBox[
     RowBox[{"H", "[", "t", "]"}], "2"], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], "+", 
   RowBox[{"3", " ", 
    RowBox[{
     SuperscriptBox["H", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["K",
        ShowAutoStyles->False,
        AutoSpacing->False],
       K,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["K",
        ShowAutoStyles->False,
        AutoSpacing->False],
       K,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], "+", 
   RowBox[{"3", " ", 
    RowBox[{"H", "[", "t", "]"}], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["\[Phi]", "0"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]0,
       Editable->False], "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["K",
          ShowAutoStyles->False,
          AutoSpacing->False],
         K,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "[", "t", "]"}], ",", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              SubscriptBox["\[Phi]", "0"],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]0,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           SubscriptBox["\[Phi]", "0"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]0,
          Editable->False], "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["\[Phi]", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]0,
              Editable->False], "[", "t", "]"}], ",", 
            RowBox[{
             FractionBox["1", "2"], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                InterpretationBox[
                 StyleBox[
                  SubscriptBox["\[Phi]", "0"],
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`\[Phi]0,
                 Editable->False], "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], 
         "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["\[Phi]", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]0,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            RowBox[{
             InterpretationBox[
              StyleBox[
               SubscriptBox["\[Phi]", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]0,
              Editable->False], "[", "t", "]"}], ",", 
            RowBox[{
             FractionBox["1", "2"], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                InterpretationBox[
                 StyleBox[
                  SubscriptBox["\[Phi]", "0"],
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`\[Phi]0,
                 Editable->False], "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "2"]}]}], 
           "]"}]}]}], ")"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "[", "t", "]"}], ",", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["\[Phi]", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]0,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], 
      "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "[", "t", "]"}], ",", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["\[Phi]", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]0,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}]}], 
     ")"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["K",
        ShowAutoStyles->False,
        AutoSpacing->False],
       K,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], 
     "]"}]}]}]}]], "Output",
 CellChangeTimes->{
  3.777775713949669*^9, {3.7777759241847105`*^9, 3.777775935163118*^9}, 
   3.7777789808965063`*^9, 3.7777797943623886`*^9, 3.818775115178282*^9}]
}, Open  ]],

Cell[TextData[{
 "To serve as a check, we can compare ",
 StyleBox["SFEH",
  FontSlant->"Italic"],
 " with the expression (Eq. (2.5)) presented in ",
 ButtonBox["arXiv:1807.09800",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://arxiv.org/abs/1807.09800"], None},
  ButtonNote->"https://arxiv.org/abs/1807.09800"],
 " (",
 StyleBox["Albuquerque, et al.",
  FontSlant->"Italic"],
 ")..."
}], "Text",
 CellChangeTimes->{{3.7777806392759233`*^9, 3.777780649019097*^9}, {
  3.7777807474150515`*^9, 3.7777808107705307`*^9}, {3.8187752469159503`*^9, 
  3.8187752611844983`*^9}, {3.8187753190239906`*^9, 3.8187753915175266`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"J", "[", "t", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Phi]0", "'"}], "[", "t", "]"}], 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["K",
         ShowAutoStyles->False,
         AutoSpacing->False],
        K,
        Editable->False], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "[", "t", "]"}], ",", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], "+", 
    RowBox[{"6", 
     RowBox[{"H", "[", "t", "]"}], 
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "2"], 
       SuperscriptBox[
        RowBox[{
         RowBox[{"\[Phi]0", "'"}], "[", "t", "]"}], "2"]}], ")"}], 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "[", "t", "]"}], ",", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], "-", 
    RowBox[{"2", 
     RowBox[{
      RowBox[{"\[Phi]0", "'"}], "[", "t", "]"}], 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox[
          SubscriptBox["\[Phi]", "0"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]0,
         Editable->False], "[", "t", "]"}], ",", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"P", "[", "t", "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["K",
        ShowAutoStyles->False,
        AutoSpacing->False],
       K,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         SubscriptBox["\[Phi]", "0"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]0,
        Editable->False], "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}], "-", 
    RowBox[{
     SuperscriptBox[
      RowBox[{
       RowBox[{"\[Phi]0", "'"}], "[", "t", "]"}], "2"], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox[
            SubscriptBox["\[Phi]", "0"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]0,
           Editable->False], "[", "t", "]"}], ",", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               SubscriptBox["\[Phi]", "0"],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]0,
              Editable->False], "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Phi]0", "''"}], "[", "t", "]"}], 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{
          RowBox[{
           InterpretationBox[
            StyleBox[
             SubscriptBox["\[Phi]", "0"],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]0,
            Editable->False], "[", "t", "]"}], ",", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                SubscriptBox["\[Phi]", "0"],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi]0,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}]}], 
      ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SFEcheck", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox["1", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "3"]], 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "3"], 
           RowBox[{"J", "[", "t", "]"}]}], ",", "t"}], "]"}]}], "\[Equal]", 
       RowBox[{"P", "[", "t", "]"}]}], ")"}], "/.", "ruleatoH"}], "//", 
    "Simplify"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.777781002746241*^9, 3.7777810970928707`*^9}, {
  3.777781130372286*^9, 3.7777812971149993`*^9}, {3.7777815779024687`*^9, 
  3.777781581625745*^9}, {3.7777816153396316`*^9, 3.7777816182259693`*^9}}],

Cell[TextData[{
 "It can easily be shown that ",
 StyleBox["SFEcheck",
  FontSlant->"Italic"],
 " is equivalent to ",
 StyleBox["SFEH",
  FontSlant->"Italic"],
 "..."
}], "Text",
 CellChangeTimes->{{3.777781624657537*^9, 3.777781677380106*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Phi]0", "''"}], "[", "t", "]"}], "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{"SFEH", ",", 
        RowBox[{
         RowBox[{"\[Phi]0", "''"}], "[", "t", "]"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Phi]0", "''"}], "[", "t", "]"}], "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{"SFEcheck", ",", 
        RowBox[{
         RowBox[{"\[Phi]0", "''"}], "[", "t", "]"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ")"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.777781682149948*^9, 3.777781712863505*^9}, {
  3.777781799217659*^9, 3.7777817993695564`*^9}, {3.7777820998144083`*^9, 
  3.7777821274107647`*^9}, {3.777782536866577*^9, 3.7777825430379353`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.77778212806709*^9, {3.7777825382098856`*^9, 3.777782543446007*^9}, 
   3.818775403983182*^9}]
}, Open  ]],

Cell[TextData[{
 "[Results saved in ",
 StyleBox["friedmann_kgb.m",
  FontSlant->"Italic"],
 ".]"
}], "Text",
 CellChangeTimes->{{3.777782838515044*^9, 3.7777828634869347`*^9}, {
  3.7777829587549086`*^9, 3.777782971258998*^9}, {3.818775528222844*^9, 
  3.818775563369727*^9}}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"SetDirectory", "[", 
    RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";", 
   "\[IndentingNewLine]", 
   RowBox[{"DumpSave", "[", 
    RowBox[{"\"\<friedmann_kgb.m\>\"", ",", 
     RowBox[{"{", 
      RowBox[{"FE1H", ",", "FE2H", ",", "SFEH"}], "}"}]}], "]"}], ";"}], 
  "*)"}]], "Input",
 CellChangeTimes->{{3.777782868698241*^9, 3.777782869553407*^9}, {
  3.7777829003649545`*^9, 3.7777829500263066`*^9}, {3.818775569336776*^9, 
  3.8187755716595984`*^9}}]
}, Closed]]
}, Closed]]
}, Open  ]]
},
WindowSize->{698, 827},
WindowMargins->{{1125, Automatic}, {Automatic, 82}},
ShowSelection->True,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (September 21, 2016)",
StyleDefinitions->"ReverseColor.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 196, 2, 111, "Section"],
Cell[779, 26, 636, 14, 87, "Text"],
Cell[CellGroupData[{
Cell[1440, 44, 178, 3, 49, "Subsection"],
Cell[1621, 49, 97, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[1743, 54, 2923, 81, 453, "Input"],
Cell[CellGroupData[{
Cell[4691, 139, 402, 6, 22, "Print"],
Cell[5096, 147, 671, 13, 22, "Print"],
Cell[5770, 162, 423, 6, 22, "Print"],
Cell[6196, 170, 382, 5, 22, "Print"],
Cell[6581, 177, 361, 5, 22, "Print"],
Cell[6945, 184, 400, 6, 22, "Print"],
Cell[7348, 192, 678, 14, 22, "Print"],
Cell[8029, 208, 423, 6, 22, "Print"],
Cell[8455, 216, 402, 6, 22, "Print"],
Cell[8860, 224, 671, 13, 22, "Print"],
Cell[9534, 239, 471, 7, 40, "Print"],
Cell[10008, 248, 402, 6, 22, "Print"],
Cell[10413, 256, 555, 8, 58, "Print"],
Cell[10971, 266, 400, 6, 22, "Print"],
Cell[11374, 274, 642, 13, 22, "Print"],
Cell[12019, 289, 726, 14, 22, "Print"],
Cell[12748, 305, 827, 14, 22, "Print"],
Cell[13578, 321, 787, 14, 22, "Print"],
Cell[14368, 337, 805, 14, 22, "Print"],
Cell[15176, 353, 402, 6, 22, "Print"],
Cell[15581, 361, 671, 13, 22, "Print"],
Cell[16255, 376, 439, 6, 40, "Print"],
Cell[16697, 384, 400, 6, 22, "Print"],
Cell[17100, 392, 555, 8, 58, "Print"],
Cell[17658, 402, 400, 6, 22, "Print"],
Cell[18061, 410, 734, 14, 22, "Print"],
Cell[18798, 426, 744, 14, 22, "Print"],
Cell[19545, 442, 891, 19, 22, "Print"],
Cell[20439, 463, 996, 21, 22, "Print"],
Cell[21438, 486, 971, 20, 22, "Print"],
Cell[22412, 508, 989, 20, 22, "Print"],
Cell[23404, 530, 818, 16, 22, "Print"],
Cell[24225, 548, 942, 20, 22, "Print"],
Cell[25170, 570, 960, 21, 22, "Print"],
Cell[26133, 593, 986, 21, 22, "Print"],
Cell[27122, 616, 904, 19, 22, "Print"],
Cell[28029, 637, 411, 6, 22, "Print"],
Cell[28443, 645, 785, 14, 22, "Print"],
Cell[29231, 661, 415, 6, 22, "Print"],
Cell[29649, 669, 916, 19, 22, "Print"],
Cell[30568, 690, 969, 20, 22, "Print"],
Cell[31540, 712, 910, 19, 22, "Print"],
Cell[32453, 733, 798, 15, 22, "Print"],
Cell[33254, 750, 544, 10, 22, "Print"],
Cell[33801, 762, 536, 10, 22, "Print"],
Cell[34340, 774, 550, 10, 22, "Print"],
Cell[34893, 786, 802, 15, 22, "Print"],
Cell[35698, 803, 757, 14, 22, "Print"],
Cell[36458, 819, 745, 14, 22, "Print"],
Cell[37206, 835, 758, 14, 22, "Print"],
Cell[37967, 851, 776, 15, 22, "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[38804, 873, 151, 2, 41, "Subsection"],
Cell[38958, 877, 589, 14, 86, "Text"],
Cell[39550, 893, 16940, 426, 3276, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[56527, 1324, 168, 2, 41, "Subsection"],
Cell[56698, 1328, 191, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[56914, 1334, 1386, 44, 137, "Input"],
Cell[58303, 1380, 2974, 101, 53, "Output"]
}, Open  ]],
Cell[61292, 1484, 1097, 31, 106, "Text"],
Cell[CellGroupData[{
Cell[62414, 1519, 1373, 39, 120, "Input"],
Cell[CellGroupData[{
Cell[63812, 1562, 688, 14, 22, "Print"],
Cell[64503, 1578, 878, 18, 22, "Print"]
}, Open  ]],
Cell[65396, 1599, 23492, 748, 148, "Output"]
}, Open  ]],
Cell[88903, 2350, 156, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[89084, 2357, 786, 23, 100, "Input"],
Cell[89873, 2382, 33557, 1103, 243, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[123479, 3491, 224, 3, 41, "Subsection"],
Cell[123706, 3496, 327, 6, 68, "Text"],
Cell[CellGroupData[{
Cell[124058, 3506, 2263, 62, 317, "Input"],
Cell[CellGroupData[{
Cell[126346, 3572, 649, 13, 22, "Print"],
Cell[126998, 3587, 705, 14, 22, "Print"],
Cell[127706, 3603, 703, 14, 22, "Print"],
Cell[128412, 3619, 703, 14, 22, "Print"],
Cell[129118, 3635, 703, 14, 22, "Print"],
Cell[129824, 3651, 659, 13, 22, "Print"],
Cell[130486, 3666, 677, 13, 22, "Print"],
Cell[131166, 3681, 828, 18, 42, "Print"],
Cell[131997, 3701, 837, 18, 42, "Print"],
Cell[132837, 3721, 689, 14, 22, "Print"],
Cell[133529, 3737, 747, 15, 40, "Print"],
Cell[134279, 3754, 873, 19, 40, "Print"],
Cell[135155, 3775, 891, 20, 58, "Print"],
Cell[136049, 3797, 919, 20, 40, "Print"],
Cell[136971, 3819, 835, 18, 40, "Print"],
Cell[137809, 3839, 845, 17, 40, "Print"],
Cell[138657, 3858, 937, 21, 40, "Print"],
Cell[139597, 3881, 689, 13, 40, "Print"],
Cell[140289, 3896, 1812, 45, 26, "Print"],
Cell[142104, 3943, 1793, 44, 26, "Print"],
Cell[143900, 3989, 1793, 44, 26, "Print"],
Cell[145696, 4035, 1793, 44, 26, "Print"],
Cell[147492, 4081, 3018, 77, 26, "Print"],
Cell[150513, 4160, 2190, 59, 26, "Print"],
Cell[152706, 4221, 1791, 44, 26, "Print"],
Cell[154500, 4267, 1791, 44, 26, "Print"],
Cell[156294, 4313, 3016, 77, 26, "Print"],
Cell[159313, 4392, 3018, 77, 26, "Print"],
Cell[162334, 4471, 2190, 59, 26, "Print"],
Cell[164527, 4532, 1791, 44, 26, "Print"],
Cell[166321, 4578, 3016, 77, 26, "Print"],
Cell[169340, 4657, 3016, 77, 26, "Print"],
Cell[172359, 4736, 3016, 77, 26, "Print"],
Cell[175378, 4815, 2190, 59, 26, "Print"],
Cell[177571, 4876, 735, 14, 40, "Print"],
Cell[178309, 4892, 839, 17, 40, "Print"]
}, Open  ]]
}, Open  ]],
Cell[179175, 4913, 366, 10, 49, "Text"],
Cell[CellGroupData[{
Cell[179566, 4927, 3525, 108, 426, "Input"],
Cell[CellGroupData[{
Cell[183116, 5039, 728, 15, 22, "Print"],
Cell[183847, 5056, 2959, 76, 26, "Print"],
Cell[186809, 5134, 1988, 52, 26, "Print"],
Cell[188800, 5188, 1738, 43, 26, "Print"],
Cell[190541, 5233, 1738, 43, 26, "Print"],
Cell[192282, 5278, 1736, 43, 26, "Print"],
Cell[194021, 5323, 2961, 76, 26, "Print"],
Cell[196985, 5401, 1736, 43, 26, "Print"],
Cell[198724, 5446, 2961, 76, 26, "Print"],
Cell[201688, 5524, 1949, 51, 26, "Print"],
Cell[203640, 5577, 1736, 43, 26, "Print"],
Cell[205379, 5622, 1736, 43, 26, "Print"],
Cell[207118, 5667, 2959, 76, 26, "Print"],
Cell[210080, 5745, 1736, 43, 26, "Print"],
Cell[211819, 5790, 2961, 76, 26, "Print"],
Cell[214783, 5868, 1738, 43, 26, "Print"],
Cell[216524, 5913, 2961, 76, 26, "Print"],
Cell[219488, 5991, 1949, 51, 26, "Print"],
Cell[221440, 6044, 1738, 43, 26, "Print"],
Cell[223181, 6089, 2961, 76, 26, "Print"],
Cell[226145, 6167, 1736, 43, 26, "Print"],
Cell[227884, 6212, 2961, 76, 26, "Print"],
Cell[230848, 6290, 1736, 43, 26, "Print"],
Cell[232587, 6335, 2958, 76, 26, "Print"],
Cell[235548, 6413, 1736, 43, 26, "Print"],
Cell[237287, 6458, 2961, 76, 26, "Print"],
Cell[240251, 6536, 1949, 51, 26, "Print"],
Cell[242203, 6589, 12259, 312, 62, "Print"],
Cell[254465, 6903, 12259, 312, 62, "Print"],
Cell[266727, 7217, 12259, 312, 62, "Print"],
Cell[278989, 7531, 12259, 312, 62, "Print"],
Cell[291251, 7845, 2965, 76, 26, "Print"],
Cell[294219, 7923, 24134, 617, 84, "Print"],
Cell[318356, 8542, 12261, 312, 62, "Print"],
Cell[330620, 8856, 12259, 312, 62, "Print"],
Cell[342882, 9170, 12259, 312, 62, "Print"],
Cell[355144, 9484, 2963, 76, 26, "Print"],
Cell[358110, 9562, 24132, 617, 84, "Print"],
Cell[382245, 10181, 2963, 76, 26, "Print"],
Cell[385211, 10259, 24132, 617, 84, "Print"],
Cell[409346, 10878, 12261, 312, 62, "Print"],
Cell[421610, 11192, 12261, 312, 62, "Print"],
Cell[433874, 11506, 2965, 76, 26, "Print"],
Cell[436842, 11584, 24134, 617, 84, "Print"],
Cell[460979, 12203, 2965, 76, 26, "Print"],
Cell[463947, 12281, 24132, 617, 84, "Print"],
Cell[488082, 12900, 2963, 76, 26, "Print"],
Cell[491048, 12978, 24134, 617, 84, "Print"],
Cell[515185, 13597, 12258, 312, 62, "Print"],
Cell[527446, 13911, 4501, 115, 26, "Print"]
}, Open  ]],
Cell[531962, 14029, 3108, 97, 122, "Output"],
Cell[CellGroupData[{
Cell[535095, 14130, 654, 13, 40, "Print"],
Cell[535752, 14145, 1092, 31, 22, "Print"]
}, Open  ]]
}, Open  ]],
Cell[536871, 14180, 146, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[537042, 14185, 367, 11, 118, "Input"],
Cell[537412, 14198, 680, 22, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[538129, 14225, 160, 5, 38, "Subsubsection"],
Cell[538292, 14232, 341, 8, 49, "Text"],
Cell[538636, 14242, 876, 26, 81, "Input"],
Cell[539515, 14270, 326, 8, 49, "Text"],
Cell[CellGroupData[{
Cell[539866, 14282, 584, 13, 118, "Input"],
Cell[540453, 14297, 9670, 307, 118, "Output"]
}, Open  ]],
Cell[550138, 14607, 202, 6, 49, "Text"],
Cell[CellGroupData[{
Cell[550365, 14617, 445, 12, 139, "Input"],
Cell[550813, 14631, 9619, 354, 190, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[560481, 14991, 106, 1, 30, "Subsubsection"],
Cell[560590, 14994, 241, 5, 49, "Text"],
Cell[560834, 15001, 680, 19, 81, "Input"],
Cell[561517, 15022, 141, 1, 49, "Text"],
Cell[CellGroupData[{
Cell[561683, 15027, 744, 19, 177, "Input"],
Cell[562430, 15048, 22975, 716, 127, "Output"]
}, Open  ]],
Cell[585420, 15767, 143, 1, 29, "Text"],
Cell[CellGroupData[{
Cell[585588, 15772, 749, 20, 161, "Input"],
Cell[586340, 15794, 22213, 810, 377, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[608602, 16610, 114, 1, 30, "Subsubsection"],
Cell[608719, 16613, 184, 4, 49, "Text"],
Cell[CellGroupData[{
Cell[608928, 16621, 540, 14, 118, "Input"],
Cell[609471, 16637, 7208, 225, 118, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[616728, 16868, 108, 1, 30, "Subsubsection"],
Cell[616839, 16871, 166, 3, 49, "Text"],
Cell[CellGroupData[{
Cell[617030, 16878, 543, 16, 118, "Input"],
Cell[617576, 16896, 2871, 94, 97, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[620496, 16996, 221, 6, 30, "Subsubsection"],
Cell[620720, 17004, 487, 10, 163, "Text"],
Cell[CellGroupData[{
Cell[621232, 17018, 1680, 50, 300, "Input"],
Cell[622915, 17070, 6566, 227, 167, "Output"],
Cell[629484, 17299, 6250, 217, 170, "Output"]
}, Open  ]],
Cell[635749, 17519, 174, 2, 29, "Text"],
Cell[CellGroupData[{
Cell[635948, 17525, 449, 12, 82, "Input"],
Cell[636400, 17539, 23410, 808, 546, "Output"]
}, Open  ]],
Cell[659825, 18350, 393, 11, 67, "Text"],
Cell[CellGroupData[{
Cell[660243, 18365, 1023, 31, 134, "Input"],
Cell[661269, 18398, 1392, 49, 45, "Output"]
}, Open  ]],
Cell[662676, 18450, 162, 3, 48, "Text"],
Cell[CellGroupData[{
Cell[662863, 18457, 1006, 29, 212, "Input"],
Cell[663872, 18488, 5470, 185, 168, "Output"],
Cell[669345, 18675, 4781, 156, 116, "Output"],
Cell[674129, 18833, 20025, 669, 460, "Output"]
}, Open  ]],
Cell[694169, 19505, 633, 17, 67, "Text"],
Cell[694805, 19524, 7936, 264, 347, "Input"],
Cell[702744, 19790, 244, 9, 49, "Text"],
Cell[CellGroupData[{
Cell[703013, 19803, 904, 25, 82, "Input"],
Cell[703920, 19830, 146, 3, 43, "Output"]
}, Open  ]],
Cell[704081, 19836, 277, 8, 30, "Text"],
Cell[704361, 19846, 515, 13, 68, "Input"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)

