(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   1911696,      56410]
NotebookOptionsPosition[   1891712,      55850]
NotebookOutlinePosition[   1892066,      55865]
CellTagsIndexPosition[   1892023,      55862]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Cosmological perturbations in KGB", "Section",
 CellChangeTimes->{{3.8089988459872313`*^9, 3.808998854997134*^9}}],

Cell[TextData[{
 "We derive the quadratic action for perturbations in kinetic gravity \
braiding (KGB) using ",
 StyleBox["xPand",
  FontSlant->"Italic"],
 ".\n\nThe second-order action for KGB can be found in ",
 ButtonBox["arXiv:1008.0603",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://arxiv.org/abs/1008.0603"], None},
  ButtonNote->"https://arxiv.org/abs/1008.0603"],
 " (",
 StyleBox["Kobayashi, Yamaguchi, and Yokohama",
  FontSlant->"Italic"],
 ") and ",
 ButtonBox["arXiv:1008.0048",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://arxiv.org/abs/1008.0048"], None},
  ButtonNote->"https://arxiv.org/abs/1008.0048"],
 " (",
 StyleBox["Deffayet, Pujolas, Sawicki, and Vikman",
  FontSlant->"Italic"],
 ").\n\nAuthor: Reginald Christian Bernardo"
}], "Text",
 CellChangeTimes->{{3.808998944961481*^9, 3.8089989573662977`*^9}, {
  3.8098423926000004`*^9, 3.809842465741768*^9}, {3.818773874566391*^9, 
  3.8187739477097673`*^9}, {3.8187757209454403`*^9, 3.8187757279736843`*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["0. Setup",
 FontColor->RGBColor[1, 0.5, 0.5]]], "Subsection",
 CellChangeTimes->{{3.7825182775292244`*^9, 3.7825182823093467`*^9}, {
  3.808998986131352*^9, 3.8089989869162517`*^9}}],

Cell["Import xPand. Start xAct.", "Text",
 CellChangeTimes->{{3.7825182849962177`*^9, 3.7825183338597527`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"<<", "xAct`xPand`"}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "optional", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"$CovDFormat", "=", "\"\<Prefix\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"$PrePrint", "=", "ScreenDollarIndices"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Options", "[", "MakeRule", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "ContractMetric", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefManifold", "[", 
   RowBox[{"M", ",", "4", ",", 
    RowBox[{"{", 
     RowBox[{
     "b", ",", "c", ",", "d", ",", "e", ",", "i", ",", "j", ",", "l", ",", 
      "q", ",", "s"}], "}"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefMetric", "[", 
   RowBox[{
    RowBox[{"-", "1"}], ",", 
    RowBox[{"g", "[", 
     RowBox[{
      RowBox[{"-", "b"}], ",", 
      RowBox[{"-", "c"}]}], "]"}], ",", "CD", ",", 
    RowBox[{"{", 
     RowBox[{"\"\<;\>\"", ",", "\"\<\[Del]\>\""}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PrintAs", "[", "RiemannCD", "]"}], "^=", "\"\<R\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PrintAs", "[", "RicciCD", "]"}], "^=", "\"\<R\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"PrintAs", "[", "RicciScalarCD", "]"}], "^=", "\"\<R\>\""}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"PrintAs", "[", "ChristoffelCD", "]"}], "^=", 
   "\"\<\[CapitalGamma]\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"PrintAs", "[", "EinsteinCD", "]"}], "^=", "\"\<G\>\""}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7825183433574996`*^9, 3.782518374600165*^9}, {
   3.7825184372181983`*^9, 3.78251845390189*^9}, 3.7825184884561234`*^9, 
   3.78252514501201*^9}],

Cell[CellGroupData[{

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354559874*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xPerm`  version \"\>", 
   "\[InvisibleSpace]", "\<\"1.2.3\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2015", ",", "8", ",", "23"}], "}"}]}],
  SequenceForm["Package xAct`xPerm`  version ", "1.2.3", ", ", {2015, 8, 23}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354574398*^9}],

Cell[BoxData["\<\"CopyRight (C) 2003-2018, Jose M. Martin-Garcia, under the \
General Public License.\"\>"], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.8098673545905237`*^9}],

Cell[BoxData["\<\"Connecting to external MinGW executable...\"\>"], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.8098673546290646`*^9}],

Cell[BoxData["\<\"Connection established.\"\>"], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.8098673547197905`*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.8098673547242346`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xTensor`  version \"\>", 
   "\[InvisibleSpace]", "\<\"1.1.3\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2018", ",", "2", ",", "28"}], "}"}]}],
  SequenceForm[
  "Package xAct`xTensor`  version ", "1.1.3", ", ", {2018, 2, 28}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.80986735472968*^9}],

Cell[BoxData["\<\"CopyRight (C) 2002-2018, Jose M. Martin-Garcia, under the \
General Public License.\"\>"], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354738067*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.8098673549107294`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xPert`  version \"\>", 
   "\[InvisibleSpace]", "\<\"1.0.6\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2018", ",", "2", ",", "28"}], "}"}]}],
  SequenceForm["Package xAct`xPert`  version ", "1.0.6", ", ", {2018, 2, 28}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354922859*^9}],

Cell[BoxData["\<\"CopyRight (C) 2005-2018, David Brizuela, Jose M. \
Martin-Garcia and Guillermo A. Mena Marugan, under the General Public \
License.\"\>"], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354931986*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Variable \"\>", "\[InvisibleSpace]", "$PrePrint", 
   "\[InvisibleSpace]", "\<\" assigned value \"\>", "\[InvisibleSpace]", 
   "ScreenDollarIndices"}],
  SequenceForm[
  "** Variable ", $PrePrint, " assigned value ", 
   xAct`xTensor`ScreenDollarIndices],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.8098673549415636`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Variable \"\>", "\[InvisibleSpace]", "$CovDFormat", 
   "\[InvisibleSpace]", "\<\" changed from \"\>", 
   "\[InvisibleSpace]", "\<\"Prefix\"\>", "\[InvisibleSpace]", "\<\" to \"\>",
    "\[InvisibleSpace]", "\<\"Postfix\"\>"}],
  SequenceForm[
  "** Variable ", xAct`xTensor`$CovDFormat, " changed from ", "Prefix", 
   " to ", "Postfix"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354948949*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Option \"\>", "\[InvisibleSpace]", "AllowUpperDerivatives", 
   "\[InvisibleSpace]", "\<\" of \"\>", "\[InvisibleSpace]", "ContractMetric",
    "\[InvisibleSpace]", "\<\" changed from \"\>", "\[InvisibleSpace]", 
   "False", "\[InvisibleSpace]", "\<\" to \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm[
  "** Option ", xAct`xTensor`AllowUpperDerivatives, " of ", 
   xAct`xTensor`ContractMetric, " changed from ", False, " to ", True],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.8098673549549294`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Option \"\>", "\[InvisibleSpace]", "MetricOn", 
   "\[InvisibleSpace]", "\<\" of \"\>", "\[InvisibleSpace]", "MakeRule", 
   "\[InvisibleSpace]", "\<\" changed from \"\>", "\[InvisibleSpace]", "None",
    "\[InvisibleSpace]", "\<\" to \"\>", "\[InvisibleSpace]", "All"}],
  SequenceForm[
  "** Option ", xAct`xTensor`MetricOn, " of ", xAct`xTensor`MakeRule, 
   " changed from ", None, " to ", All],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.80986735496064*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Option \"\>", "\[InvisibleSpace]", "ContractMetrics", 
   "\[InvisibleSpace]", "\<\" of \"\>", "\[InvisibleSpace]", "MakeRule", 
   "\[InvisibleSpace]", "\<\" changed from \"\>", "\[InvisibleSpace]", 
   "False", "\[InvisibleSpace]", "\<\" to \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm[
  "** Option ", xAct`xTensor`ContractMetrics, " of ", xAct`xTensor`MakeRule, 
   " changed from ", False, " to ", True],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.8098673549671216`*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354972774*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xPand`  version \"\>", 
   "\[InvisibleSpace]", "\<\"0.4.3\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2018", ",", "4", ",", "28"}], "}"}]}],
  SequenceForm["Package xAct`xPand`  version ", "0.4.3", ", ", {2018, 4, 28}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354978722*^9}],

Cell[BoxData["\<\"CopyRight (C) 2012-2018, Cyril Pitrou, Xavier Roy and \
Obinna Umeh under the General Public License.\"\>"], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.8098673549833145`*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354988097*^9}],

Cell[BoxData["\<\"These packages come with ABSOLUTELY NO WARRANTY; for \
details type Disclaimer[]. This is free software, and you are welcome to \
redistribute it under certain conditions. See the General Public License for \
details.\"\>"], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867354992491*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.8098673550006847`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefManifold", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"manifold \"\>", "\[InvisibleSpace]", "M", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefManifold, ": Defining ", "manifold ", $CellContext`M,
    ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.8098673550055504`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefVBundle", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vbundle \"\>", "\[InvisibleSpace]", "TangentM", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefVBundle, ": Defining ", 
   "vbundle ", $CellContext`TangentM, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867355012007*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric metric tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"g", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric metric tensor ", 
   $CellContext`g[-$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.8098673550178714`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"antisymmetric tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"epsilong", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}], ",", 
     RowBox[{"-", "e"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "antisymmetric tensor ", 
   $CellContext`epsilong[-$CellContext`b, -$CellContext`c, -$CellContext`d, \
-$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867355023352*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tetrametric \"\>", "\[InvisibleSpace]", 
   RowBox[{"Tetrag", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}], ",", 
     RowBox[{"-", "e"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tetrametric ", 
   $CellContext`Tetrag[-$CellContext`b, -$CellContext`c, -$CellContext`d, \
-$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.8098673550289993`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tetrametric \"\>", "\[InvisibleSpace]", 
   RowBox[{"Tetrag\[Dagger]", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}], ",", 
     RowBox[{"-", "e"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tetrametric ", 
   $CellContext`Tetrag\[Dagger][-$CellContext`b, -$CellContext`c, \
-$CellContext`d, -$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867355035209*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefCovD", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"covariant derivative \"\>", "\[InvisibleSpace]", 
   RowBox[{"CD", "[", 
    RowBox[{"-", "b"}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefCovD, ": Defining ", "covariant derivative ", 
   $CellContext`CD[-$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.8098673550415916`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vanishing torsion tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"TorsionCD", "[", 
    RowBox[{"b", ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "vanishing torsion tensor ", 
   $CellContext`TorsionCD[$CellContext`b, -$CellContext`c, -$CellContext`d], 
   ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867355046521*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Christoffel tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"ChristoffelCD", "[", 
    RowBox[{"b", ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", 
   "symmetric Christoffel tensor ", 
   $CellContext`ChristoffelCD[$CellContext`b, -$CellContext`c, \
-$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867355052246*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Riemann tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"RiemannCD", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}], ",", 
     RowBox[{"-", "e"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "Riemann tensor ", 
   $CellContext`RiemannCD[-$CellContext`b, -$CellContext`c, -$CellContext`d, \
-$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867355057513*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Ricci tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"RicciCD", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric Ricci tensor ", 
   $CellContext`RicciCD[-$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.80986735506264*^9}],

Cell[BoxData["\<\"** DefCovD:  Contractions of Riemann automatically replaced \
by Ricci.\"\>"], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.8098673550670304`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Ricci scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"RicciScalarCD", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "Ricci scalar ", 
   $CellContext`RicciScalarCD[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867355072242*^9}],

Cell[BoxData["\<\"** DefCovD:  Contractions of Ricci automatically replaced \
by RicciScalar.\"\>"], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867355077037*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Einstein tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"EinsteinCD", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric Einstein tensor ", 
   $CellContext`EinsteinCD[-$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867355084919*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Weyl tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"WeylCD", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}], ",", 
     RowBox[{"-", "e"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "Weyl tensor ", 
   $CellContext`WeylCD[-$CellContext`b, -$CellContext`c, -$CellContext`d, \
-$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.8098673551257563`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric TFRicci tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"TFRicciCD", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric TFRicci tensor ", 
   $CellContext`TFRicciCD[-$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.8098673552280307`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Kretschmann scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"KretschmannCD", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "Kretschmann scalar ", 
   $CellContext`KretschmannCD[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.8098673552995505`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefCovD:  Computing RiemannToWeylRules for dim \"\>", 
   "\[InvisibleSpace]", "4"}],
  SequenceForm["** DefCovD:  Computing RiemannToWeylRules for dim ", 4],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.8098673553050447`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefCovD:  Computing RicciToTFRicci for dim \"\>", 
   "\[InvisibleSpace]", "4"}],
  SequenceForm["** DefCovD:  Computing RicciToTFRicci for dim ", 4],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867355431184*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefCovD:  Computing RicciToEinsteinRules for dim \"\>", 
   "\[InvisibleSpace]", "4"}],
  SequenceForm["** DefCovD:  Computing RicciToEinsteinRules for dim ", 4],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.809867355461673*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"weight +2 density \"\>", "\[InvisibleSpace]", 
   RowBox[{"Detg", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"Determinant.\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "weight +2 density ", 
   $CellContext`Detg[], ". ", "Determinant."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7825185158836894`*^9, 3.782519070628558*^9, 3.782523458651413*^9, 
   3.7825236628691297`*^9, 3.782525116168165*^9, 3.782525156806095*^9, 
   3.7950860734864182`*^9, 3.7950926987889147`*^9, 3.7955891490456553`*^9, 
   3.7955973627349358`*^9, 3.7956074435587835`*^9, 3.7956101895516644`*^9, 
   3.795665796129815*^9, 3.8089990609931045`*^9, 3.808999277575098*^9, 
   3.80899950207856*^9, 3.8089997167981615`*^9, {3.8089998375351944`*^9, 
   3.8089998665924673`*^9}, 3.8090005015979557`*^9, 3.8090012036928835`*^9, 
   3.809002849121295*^9, 3.809049683294072*^9, 3.809054719121109*^9, 
   3.8090603973793325`*^9, 3.8090759250076847`*^9, 3.8090784088553*^9, 
   3.809084183744298*^9, 3.809086100867617*^9, 3.8090880299128036`*^9, 
   3.8091407142315283`*^9, 3.809146645887328*^9, 3.8091488930085535`*^9, 
   3.8091577125100384`*^9, 3.8091648160653963`*^9, 3.8091677541439137`*^9, 
   3.80917170545436*^9, 3.809320074926362*^9, 3.809335753378419*^9, 
   3.809341518461176*^9, 3.809347765462438*^9, 3.8095722962623024`*^9, 
   3.809591620419052*^9, 3.8095921501363206`*^9, 3.809592496807186*^9, 
   3.809593154089283*^9, 3.8095953822228594`*^9, 3.8095981577060394`*^9, 
   3.80961501448958*^9, 3.8097454131882715`*^9, 3.8097456226127386`*^9, 
   3.8097507011296844`*^9, 3.8097525403813105`*^9, 3.809753064498721*^9, 
   3.809763085028386*^9, 3.8097666052150707`*^9, 3.809772041914637*^9, 
   3.8097834025015583`*^9, 3.809787112149003*^9, 3.8097875223821726`*^9, 
   3.809830990393667*^9, 3.80983928865056*^9, 3.809843513414195*^9, 
   3.809844331922161*^9, 3.809863388474654*^9, 3.8098673554740486`*^9}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 "At this point, we can perform a 3+1 decomposition using SetSlicing[]. We \
consider a normal vector ",
 StyleBox["n",
  FontSlant->"Italic"],
 ", induced/spatial metric ",
 StyleBox["h",
  FontSlant->"Italic"],
 ", a covariant derivative ",
 StyleBox["cd",
  FontSlant->"Italic"],
 " on the hypersurface, and curved Friedmann-Lemaitre slices (other options: \
Minkowski, FLCurved, FLFlat, Bianchi, BianchiA, BianchiI).\n\nAlso, we define \
the metric perturbation dg, matter velocity u, and velocity perturbation du."
}], "Text",
 CellChangeTimes->{{3.7825186735499053`*^9, 3.782518674143591*^9}, {
  3.7825187279901934`*^9, 3.78251879986409*^9}, {3.782518842432133*^9, 
  3.782518918086373*^9}, {3.782518961576024*^9, 3.7825190227180634`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"3", "+", 
    RowBox[{"1", " ", "decomposition"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"SetSlicing", "[", 
     RowBox[{"g", ",", "n", ",", "h", ",", "cd", ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<|\>\"", ",", "\"\<\!\(\*OverscriptBox[\(D\), \(_\)]\)\>\""}], 
       "}"}], ",", "\"\<FLFlat\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "metric", " ", "and", " ", "matter", " ", "velocity", " ", 
     "perturbations"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefMetricFields", "[", 
     RowBox[{"g", ",", "dg", ",", "h"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefMatterFields", "[", 
     RowBox[{"u", ",", "du", ",", "h"}], "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.7825190258890524`*^9, 3.7825190613808794`*^9}, {
  3.7825236552303047`*^9, 3.782523655636672*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"n", "[", "s$1021", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`n[$CellContext`s$1021], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.8098673556429462`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric metric tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"h", "[", 
    RowBox[{
     RowBox[{"-", "s$1021"}], ",", 
     RowBox[{"-", "s$1022"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric metric tensor ", 
   $CellContext`h[-$CellContext`s$1021, -$CellContext`s$1022], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.8098673556473193`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"antisymmetric tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"epsilonh", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "antisymmetric tensor ", 
   $CellContext`epsilonh[-$CellContext`b, -$CellContext`c, -$CellContext`d], 
   ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.8098673556549296`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tetrametric \"\>", "\[InvisibleSpace]", 
   RowBox[{"Tetrah", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}], ",", 
     RowBox[{"-", "e"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tetrametric ", 
   $CellContext`Tetrah[-$CellContext`b, -$CellContext`c, -$CellContext`d, \
-$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867355711953*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tetrametric \"\>", "\[InvisibleSpace]", 
   RowBox[{"Tetrah\[Dagger]", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}], ",", 
     RowBox[{"-", "e"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tetrametric ", 
   $CellContext`Tetrah\[Dagger][-$CellContext`b, -$CellContext`c, \
-$CellContext`d, -$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867355720451*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefCovD", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"covariant derivative \"\>", "\[InvisibleSpace]", 
   RowBox[{"cd", "[", 
    RowBox[{"-", "s$1021"}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefCovD, ": Defining ", "covariant derivative ", 
   $CellContext`cd[-$CellContext`s$1021], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.8098673557261405`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vanishing torsion tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"Torsioncd", "[", 
    RowBox[{"b", ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "vanishing torsion tensor ", 
   $CellContext`Torsioncd[$CellContext`b, -$CellContext`c, -$CellContext`d], 
   ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867355732808*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Christoffel tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"Christoffelcd", "[", 
    RowBox[{"b", ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", 
   "symmetric Christoffel tensor ", 
   $CellContext`Christoffelcd[$CellContext`b, -$CellContext`c, \
-$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.8098673557390947`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Riemann tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"Riemanncd", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}], ",", 
     RowBox[{"-", "e"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "Riemann tensor ", 
   $CellContext`Riemanncd[-$CellContext`b, -$CellContext`c, -$CellContext`d, \
-$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.8098673557778797`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Ricci tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"Riccicd", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric Ricci tensor ", 
   $CellContext`Riccicd[-$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867355883707*^9}],

Cell[BoxData["\<\"** DefCovD:  Contractions of Riemann automatically replaced \
by Ricci.\"\>"], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.8098673559315257`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Ricci scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"RicciScalarcd", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "Ricci scalar ", 
   $CellContext`RicciScalarcd[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.8098673559375324`*^9}],

Cell[BoxData["\<\"** DefCovD:  Contractions of Ricci automatically replaced \
by RicciScalar.\"\>"], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.8098673559650598`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Einstein tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"Einsteincd", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric Einstein tensor ", 
   $CellContext`Einsteincd[-$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.8098673559736605`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vanishing Weyl tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"Weylcd", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}], ",", 
     RowBox[{"-", "e"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "vanishing Weyl tensor ", 
   $CellContext`Weylcd[-$CellContext`b, -$CellContext`c, -$CellContext`d, \
-$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867356031579*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric TFRicci tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"TFRiccicd", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric TFRicci tensor ", 
   $CellContext`TFRiccicd[-$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.8098673560386143`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Kretschmann scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"Kretschmanncd", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "Kretschmann scalar ", 
   $CellContext`Kretschmanncd[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.8098673560904903`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefCovD:  Computing RiemannToWeylRules for dim \"\>", 
   "\[InvisibleSpace]", "3"}],
  SequenceForm["** DefCovD:  Computing RiemannToWeylRules for dim ", 3],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867356097728*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefCovD:  Computing RicciToTFRicci for dim \"\>", 
   "\[InvisibleSpace]", "3"}],
  SequenceForm["** DefCovD:  Computing RicciToTFRicci for dim ", 3],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.8098673561259675`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefCovD:  Computing RicciToEinsteinRules for dim \"\>", 
   "\[InvisibleSpace]", "3"}],
  SequenceForm["** DefCovD:  Computing RicciToEinsteinRules for dim ", 3],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867356133901*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"weight +2 density \"\>", "\[InvisibleSpace]", 
   RowBox[{"Deth", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"Determinant.\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "weight +2 density ", 
   $CellContext`Deth[], ". ", "Determinant."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867356169174*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"extrinsic curvature tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"ExtrinsicKh", "[", 
    RowBox[{"b", ",", "c"}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"Associated to vector n\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "extrinsic curvature tensor ", 
   $CellContext`ExtrinsicKh[$CellContext`b, $CellContext`c], ". ", 
   "Associated to vector n"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867356175856*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"acceleration vector \"\>", "\[InvisibleSpace]", 
   RowBox[{"Accelerationn", "[", "b", "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"Associated to vector n\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "acceleration vector ", 
   $CellContext`Accelerationn[$CellContext`b], ". ", "Associated to vector n"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.8098673562101283`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefInertHead", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"projector inert-head \"\>", "\[InvisibleSpace]", 
   "Projectorh", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefInertHead, ": Defining ", 
   "projector inert-head ", $CellContext`Projectorh, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867356229267*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"   Rules \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", 
     "8"}], "}"}], 
   "\[InvisibleSpace]", "\<\" have been declared as UpValues for \"\>", 
   "\[InvisibleSpace]", "h", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm["   Rules ", 
   Shallow[{1, 2, 3, 4, 5, 6, 7, 8}], 
   " have been declared as UpValues for ", $CellContext`h, "."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.8098673562527084`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"   Rules \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", 
     "8"}], "}"}], 
   "\[InvisibleSpace]", "\<\" have been declared as UpValues for \"\>", 
   "\[InvisibleSpace]", "h", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm["   Rules ", 
   Shallow[{1, 2, 3, 4, 5, 6, 7, 8}], 
   " have been declared as UpValues for ", $CellContext`h, "."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867356273237*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"   Rules \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], 
   "\[InvisibleSpace]", "\<\" have been declared as UpValues for \"\>", 
   "\[InvisibleSpace]", "n", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm["   Rules ", 
   Shallow[{1, 2}], " have been declared as UpValues for ", $CellContext`n, 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867356279794*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"   Rules \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}], 
   "\[InvisibleSpace]", "\<\" have been declared as UpValues for \"\>", 
   "\[InvisibleSpace]", "n", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm["   Rules ", 
   Shallow[{1, 2, 3, 4}], 
   " have been declared as UpValues for ", $CellContext`n, "."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867356287402*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"   Rules \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", 
     "8"}], "}"}], 
   "\[InvisibleSpace]", "\<\" have been declared as UpValues for \"\>", 
   "\[InvisibleSpace]", "n", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm["   Rules ", 
   Shallow[{1, 2, 3, 4, 5, 6, 7, 8}], 
   " have been declared as UpValues for ", $CellContext`n, "."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867356301675*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[ScriptCapitalN]0h", "[", 
    RowBox[{
     RowBox[{"LI", "[", "xAct`xPand`Private`p$2070", "]"}], ",", 
     RowBox[{"LI", "[", "xAct`xPand`Private`q$2070", "]"}]}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[ScriptCapitalN]0h[
    xAct`xTensor`LI[xAct`xPand`Private`p$2070], 
    xAct`xTensor`LI[xAct`xPand`Private`q$2070]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.8098673566820407`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[ScriptCapitalN]ih", "[", "b", "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[ScriptCapitalN]ih[$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.8098673566889267`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[ScriptCapitalN]h", "[", 
    RowBox[{"-", "b"}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[ScriptCapitalN]h[-$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.8098673566945133`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"d\[ScriptCapitalN]h", "[", 
    RowBox[{
     RowBox[{"LI", "[", "\<\"order\"\>", "]"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`d\[ScriptCapitalN]h[
    xAct`xTensor`LI["order"], -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867356700987*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"ah", "[", 
    RowBox[{
     RowBox[{"LI", "[", "xAct`xPand`Private`p$2089", "]"}], ",", 
     RowBox[{"LI", "[", "xAct`xPand`Private`q$2089", "]"}]}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`ah[
    xAct`xTensor`LI[xAct`xPand`Private`p$2089], 
    xAct`xTensor`LI[xAct`xPand`Private`q$2089]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867356706623*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"Hh", "[", 
    RowBox[{
     RowBox[{"LI", "[", "xAct`xPand`Private`p$2095", "]"}], ",", 
     RowBox[{"LI", "[", "xAct`xPand`Private`q$2095", "]"}]}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`Hh[
    xAct`xTensor`LI[xAct`xPand`Private`p$2095], 
    xAct`xTensor`LI[xAct`xPand`Private`q$2095]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867356712432*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric metric tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"gah2", "[", 
    RowBox[{
     RowBox[{"-", "s$2102"}], ",", 
     RowBox[{"-", "s$2103"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric metric tensor ", 
   $CellContext`gah2[-$CellContext`s$2102, -$CellContext`s$2103], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867356719248*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"inverse metric tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"Invgah2", "[", 
    RowBox[{"s$2102", ",", "s$2103"}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"Metric is frozen!\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "inverse metric tensor ", 
   $CellContext`Invgah2[$CellContext`s$2102, $CellContext`s$2103], ". ", 
   "Metric is frozen!"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.8098673567251525`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"antisymmetric tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"epsilongah2", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}], ",", 
     RowBox[{"-", "e"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "antisymmetric tensor ", 
   $CellContext`epsilongah2[-$CellContext`b, -$CellContext`c, \
-$CellContext`d, -$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867356731621*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tetrametric \"\>", "\[InvisibleSpace]", 
   RowBox[{"Tetragah2", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}], ",", 
     RowBox[{"-", "e"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tetrametric ", 
   $CellContext`Tetragah2[-$CellContext`b, -$CellContext`c, -$CellContext`d, \
-$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867356738055*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tetrametric \"\>", "\[InvisibleSpace]", 
   RowBox[{"Tetragah2\[Dagger]", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}], ",", 
     RowBox[{"-", "e"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tetrametric ", 
   $CellContext`Tetragah2\[Dagger][-$CellContext`b, -$CellContext`c, \
-$CellContext`d, -$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867356744057*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefCovD", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"covariant derivative \"\>", "\[InvisibleSpace]", 
   RowBox[{"CDah2", "[", 
    RowBox[{"-", "s$2102"}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefCovD, ": Defining ", "covariant derivative ", 
   $CellContext`CDah2[-$CellContext`s$2102], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.80986735675147*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vanishing torsion tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"TorsionCDah2", "[", 
    RowBox[{"b", ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "vanishing torsion tensor ", 
   $CellContext`TorsionCDah2[$CellContext`b, -$CellContext`c, \
-$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867356757909*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Christoffel tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"ChristoffelCDah2", "[", 
    RowBox[{"b", ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", 
   "symmetric Christoffel tensor ", 
   $CellContext`ChristoffelCDah2[$CellContext`b, -$CellContext`c, \
-$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867356763984*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Riemann tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"RiemannDownCDah2", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}], ",", 
     RowBox[{"-", "e"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "Riemann tensor ", 
   $CellContext`RiemannDownCDah2[-$CellContext`b, -$CellContext`c, \
-$CellContext`d, -$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.8098673567704535`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Riemann tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"RiemannCDah2", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}], ",", "e"}], "]"}], "\[InvisibleSpace]", "\<\". \"\>",
    "\[InvisibleSpace]", "\<\"Antisymmetric only in the first pair.\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "Riemann tensor ", 
   $CellContext`RiemannCDah2[-$CellContext`b, -$CellContext`c, \
-$CellContext`d, $CellContext`e], ". ", 
   "Antisymmetric only in the first pair."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867356776376*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Ricci tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"RicciCDah2", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric Ricci tensor ", 
   $CellContext`RicciCDah2[-$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.8098673567833276`*^9}],

Cell[BoxData["\<\"** DefCovD:  Contractions of Riemann automatically replaced \
by Ricci.\"\>"], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867356788829*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Ricci scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"RicciScalarCDah2", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "Ricci scalar ", 
   $CellContext`RicciScalarCDah2[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.8098673567939787`*^9}],

Cell[BoxData["\<\"** DefCovD:  Contractions of Ricci automatically replaced \
by RicciScalar.\"\>"], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.8098673568001027`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Einstein tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"EinsteinCDah2", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric Einstein tensor ", 
   $CellContext`EinsteinCDah2[-$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.8098673568067636`*^9}],

Cell[BoxData["\<\"** MakeRule: Potential problems moving indices on the \
LHS.\"\>"], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867356813347*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Weyl tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"WeylCDah2", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}], ",", 
     RowBox[{"-", "e"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "Weyl tensor ", 
   $CellContext`WeylCDah2[-$CellContext`b, -$CellContext`c, -$CellContext`d, \
-$CellContext`e], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867356833431*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric TFRicci tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"TFRicciCDah2", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric TFRicci tensor ", 
   $CellContext`TFRicciCDah2[-$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867356916609*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Kretschmann scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"KretschmannCDah2", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "Kretschmann scalar ", 
   $CellContext`KretschmannCDah2[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.80986735696167*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefCovD:  Computing RiemannToWeylRules for dim \"\>", 
   "\[InvisibleSpace]", "4"}],
  SequenceForm["** DefCovD:  Computing RiemannToWeylRules for dim ", 4],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.8098673569690905`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefCovD:  Computing RicciToEinsteinRules for dim \"\>", 
   "\[InvisibleSpace]", "4"}],
  SequenceForm["** DefCovD:  Computing RicciToEinsteinRules for dim ", 4],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.80986735714367*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"weight +2 density \"\>", "\[InvisibleSpace]", 
   RowBox[{"Detgah2", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"Determinant.\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "weight +2 density ", 
   $CellContext`Detgah2[], ". ", "Determinant."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867357173728*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"   Rules \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", 
     "8"}], "}"}], 
   "\[InvisibleSpace]", "\<\" have been declared as UpValues for \"\>", 
   "\[InvisibleSpace]", "g", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm["   Rules ", 
   Shallow[{1, 2, 3, 4, 5, 6, 7, 8}], 
   " have been declared as UpValues for ", $CellContext`g, "."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867357205984*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"   Rules \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "1", "}"}], 
   "\[InvisibleSpace]", "\<\" have been declared as UpValues for \"\>", 
   "\[InvisibleSpace]", "g", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm["   Rules ", 
   Shallow[{1}], " have been declared as UpValues for ", $CellContext`g, "."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867357213178*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"Connectionh", "[", 
    RowBox[{
     RowBox[{"-", "s$1021"}], ",", 
     RowBox[{"-", "s$1022"}], ",", 
     RowBox[{"-", "s$1023"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`Connectionh[-$CellContext`s$1021, -$CellContext`s$1022, \
-$CellContext`s$1023], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867357222604*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"CSh", "[", 
    RowBox[{
     RowBox[{"-", "s$1021"}], ",", 
     RowBox[{"-", "s$1022"}], ",", 
     RowBox[{"-", "s$1023"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`CSh[-$CellContext`s$1021, -$CellContext`s$1022, \
-$CellContext`s$1023], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867357278014*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"nth", "[", 
    RowBox[{
     RowBox[{"-", "s$1021"}], ",", 
     RowBox[{"-", "s$1022"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`nth[-$CellContext`s$1021, -$CellContext`s$1022], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867357340147*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"avh", "[", 
    RowBox[{"-", "s$1021"}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`avh[-$CellContext`s$1021], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.8098673573670626`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"   Rules \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}], 
   "\[InvisibleSpace]", "\<\" have been declared as UpValues for \"\>", 
   "\[InvisibleSpace]", "avh", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm["   Rules ", 
   Shallow[{1, 2, 3, 4}], 
   " have been declared as UpValues for ", $CellContext`avh, "."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867357400281*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"Kh", "[", 
    RowBox[{
     RowBox[{"LI", "[", "xAct`xPand`Private`p$2815", "]"}], ",", 
     RowBox[{"LI", "[", "xAct`xPand`Private`q$2815", "]"}], ",", 
     RowBox[{"-", "s$1021"}], ",", 
     RowBox[{"-", "s$1022"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`Kh[
    xAct`xTensor`LI[xAct`xPand`Private`p$2815], 
    xAct`xTensor`LI[
    xAct`xPand`Private`q$2815], -$CellContext`s$1021, -$CellContext`s$1022], 
   ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.8098673574101696`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefParameter", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"parameter \"\>", "\[InvisibleSpace]", 
   "\[Epsilon]", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefParameter, ": Defining ", "parameter ", 
   xAct`xPand`\[Epsilon], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.8098673577275114`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"dg", "[", 
    RowBox[{
     RowBox[{"LI", "[", "\<\"order\"\>", "]"}], ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`dg[
    xAct`xTensor`LI["order"], -$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867357734582*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[Phi]h", "[", 
    RowBox[{
     RowBox[{"LI", "[", "xAct`xPand`Private`p$3082", "]"}], ",", 
     RowBox[{"LI", "[", "xAct`xPand`Private`q$3082", "]"}]}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[Phi]h[
    xAct`xTensor`LI[xAct`xPand`Private`p$3082], 
    xAct`xTensor`LI[xAct`xPand`Private`q$3082]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.8098673577417088`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"Bsh", "[", 
    RowBox[{
     RowBox[{"LI", "[", "xAct`xPand`Private`p$3088", "]"}], ",", 
     RowBox[{"LI", "[", "xAct`xPand`Private`q$3088", "]"}]}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`Bsh[
    xAct`xTensor`LI[xAct`xPand`Private`p$3088], 
    xAct`xTensor`LI[xAct`xPand`Private`q$3088]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867357748323*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"Bvh", "[", 
    RowBox[{
     RowBox[{"LI", "[", "xAct`xPand`Private`p$3094", "]"}], ",", 
     RowBox[{"LI", "[", "xAct`xPand`Private`q$3094", "]"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`Bvh[
    xAct`xTensor`LI[xAct`xPand`Private`p$3094], 
    xAct`xTensor`LI[xAct`xPand`Private`q$3094], -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.8098673577548943`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[Psi]h", "[", 
    RowBox[{
     RowBox[{"LI", "[", "xAct`xPand`Private`p$3101", "]"}], ",", 
     RowBox[{"LI", "[", "xAct`xPand`Private`q$3101", "]"}]}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[Psi]h[
    xAct`xTensor`LI[xAct`xPand`Private`p$3101], 
    xAct`xTensor`LI[xAct`xPand`Private`q$3101]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.8098673577613025`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"Esh", "[", 
    RowBox[{
     RowBox[{"LI", "[", "xAct`xPand`Private`p$3107", "]"}], ",", 
     RowBox[{"LI", "[", "xAct`xPand`Private`q$3107", "]"}]}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`Esh[
    xAct`xTensor`LI[xAct`xPand`Private`p$3107], 
    xAct`xTensor`LI[xAct`xPand`Private`q$3107]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867357768202*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"Evh", "[", 
    RowBox[{
     RowBox[{"LI", "[", "xAct`xPand`Private`p$3113", "]"}], ",", 
     RowBox[{"LI", "[", "xAct`xPand`Private`q$3113", "]"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`Evh[
    xAct`xTensor`LI[xAct`xPand`Private`p$3113], 
    xAct`xTensor`LI[xAct`xPand`Private`q$3113], -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867357774464*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"Eth", "[", 
    RowBox[{
     RowBox[{"LI", "[", "xAct`xPand`Private`p$3120", "]"}], ",", 
     RowBox[{"LI", "[", "xAct`xPand`Private`q$3120", "]"}], ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`Eth[
    xAct`xTensor`LI[xAct`xPand`Private`p$3120], 
    xAct`xTensor`LI[
    xAct`xPand`Private`q$3120], -$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867357780682*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"Th", "[", 
    RowBox[{
     RowBox[{"LI", "[", "xAct`xPand`Private`p$3130", "]"}], ",", 
     RowBox[{"LI", "[", "xAct`xPand`Private`q$3130", "]"}]}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`Th[
    xAct`xTensor`LI[xAct`xPand`Private`p$3130], 
    xAct`xTensor`LI[xAct`xPand`Private`q$3130]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.8098673577876005`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"Lsh", "[", 
    RowBox[{
     RowBox[{"LI", "[", "xAct`xPand`Private`p$3136", "]"}], ",", 
     RowBox[{"LI", "[", "xAct`xPand`Private`q$3136", "]"}]}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`Lsh[
    xAct`xTensor`LI[xAct`xPand`Private`p$3136], 
    xAct`xTensor`LI[xAct`xPand`Private`q$3136]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.8098673577937665`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"Lvh", "[", 
    RowBox[{
     RowBox[{"LI", "[", "xAct`xPand`Private`p$3142", "]"}], ",", 
     RowBox[{"LI", "[", "xAct`xPand`Private`q$3142", "]"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`Lvh[
    xAct`xTensor`LI[xAct`xPand`Private`p$3142], 
    xAct`xTensor`LI[xAct`xPand`Private`q$3142], -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.8098673578004045`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[CurlyPhi]", "[", 
    RowBox[{
     RowBox[{"LI", "[", "xAct`xPand`Private`p$3152", "]"}], ",", 
     RowBox[{"LI", "[", "xAct`xPand`Private`q$3152", "]"}]}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   xAct`xPand`\[CurlyPhi][
    xAct`xTensor`LI[xAct`xPand`Private`p$3152], 
    xAct`xTensor`LI[xAct`xPand`Private`q$3152]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.8098673578086786`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[Rho]u", "[", 
    RowBox[{
     RowBox[{"LI", "[", "xAct`xPand`Private`p$3158", "]"}], ",", 
     RowBox[{"LI", "[", "xAct`xPand`Private`q$3158", "]"}]}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[Rho]u[
    xAct`xTensor`LI[xAct`xPand`Private`p$3158], 
    xAct`xTensor`LI[xAct`xPand`Private`q$3158]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.8098673578164625`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"Pu", "[", 
    RowBox[{
     RowBox[{"LI", "[", "xAct`xPand`Private`p$3164", "]"}], ",", 
     RowBox[{"LI", "[", "xAct`xPand`Private`q$3164", "]"}]}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`Pu[
    xAct`xTensor`LI[xAct`xPand`Private`p$3164], 
    xAct`xTensor`LI[xAct`xPand`Private`q$3164]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867357823948*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"Vspathu", "[", 
    RowBox[{
     RowBox[{"LI", "[", "xAct`xPand`Private`p$3170", "]"}], ",", 
     RowBox[{"LI", "[", "xAct`xPand`Private`q$3170", "]"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`Vspathu[
    xAct`xTensor`LI[xAct`xPand`Private`p$3170], 
    xAct`xTensor`LI[xAct`xPand`Private`q$3170], -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.8098673578309827`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"V0hu", "[", 
    RowBox[{
     RowBox[{"LI", "[", "xAct`xPand`Private`p$3177", "]"}], ",", 
     RowBox[{"LI", "[", "xAct`xPand`Private`q$3177", "]"}]}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`V0hu[
    xAct`xTensor`LI[xAct`xPand`Private`p$3177], 
    xAct`xTensor`LI[xAct`xPand`Private`q$3177]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867357837522*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"Vshu", "[", 
    RowBox[{
     RowBox[{"LI", "[", "xAct`xPand`Private`p$3183", "]"}], ",", 
     RowBox[{"LI", "[", "xAct`xPand`Private`q$3183", "]"}]}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`Vshu[
    xAct`xTensor`LI[xAct`xPand`Private`p$3183], 
    xAct`xTensor`LI[xAct`xPand`Private`q$3183]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867357843729*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"Vvhu", "[", 
    RowBox[{
     RowBox[{"LI", "[", "xAct`xPand`Private`p$3189", "]"}], ",", 
     RowBox[{"LI", "[", "xAct`xPand`Private`q$3189", "]"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`Vvhu[
    xAct`xTensor`LI[xAct`xPand`Private`p$3189], 
    xAct`xTensor`LI[xAct`xPand`Private`q$3189], -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.8098673578502593`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"u", "[", "b", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`u[$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.809867357855325*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"du", "[", 
    RowBox[{
     RowBox[{"LI", "[", "\<\"order\"\>", "]"}], ",", "b"}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`du[
    xAct`xTensor`LI["order"], $CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.782518933426367*^9, 3.7825190757836056`*^9, 3.782523459635563*^9, 
   3.782523663806409*^9, 3.782525117108451*^9, 3.7825251579939585`*^9, 
   3.7950862837902193`*^9, 3.7950926998042803`*^9, 3.7955891502026033`*^9, 
   3.79559736372303*^9, 3.795607444550793*^9, 3.7956101904252634`*^9, 
   3.795665797177288*^9, 3.808999062068224*^9, 3.8089992784786453`*^9, 
   3.80899950312772*^9, 3.8089997178503475`*^9, {3.808999838582394*^9, 
   3.808999867676567*^9}, 3.8090005026102467`*^9, 3.8090012047390876`*^9, 
   3.809002850173478*^9, 3.809049684356902*^9, 3.809054720151601*^9, 
   3.8090603984060984`*^9, 3.8090759260109663`*^9, 3.809078409900503*^9, 
   3.8090841848353777`*^9, 3.809086101966538*^9, 3.8090880309899225`*^9, 
   3.8091407153131075`*^9, 3.8091466468671975`*^9, 3.80914889413695*^9, 
   3.809157713635228*^9, 3.80916481759538*^9, 3.8091677558178687`*^9, 
   3.809171706987059*^9, 3.8093200759735923`*^9, 3.809335754361265*^9, 
   3.809341519446168*^9, 3.809347766545469*^9, 3.809572297370821*^9, 
   3.8095916216075153`*^9, 3.8095921511486444`*^9, 3.809592497820997*^9, 
   3.8095931550732613`*^9, 3.8095953836577682`*^9, 3.8095981586616163`*^9, 
   3.809615015458855*^9, 3.8097454142979727`*^9, 3.8097456235962505`*^9, 
   3.809750702336501*^9, 3.809752541440981*^9, 3.809753065504697*^9, 
   3.809763086044648*^9, 3.8097666062923913`*^9, 3.8097720429800506`*^9, 
   3.80978340361351*^9, 3.8097871132592*^9, 3.809787523527987*^9, 
   3.80983099152089*^9, 3.8098392896321115`*^9, 3.809843514413561*^9, 
   3.809844332938201*^9, 3.8098633895524254`*^9, 3.8098673578604307`*^9}]
}, Open  ]]
}, Open  ]],

Cell["To make the output more appealing (setup by Cyril Pitrou)...", "Text",
 CellChangeTimes->{{3.7825190897648697`*^9, 3.7825191048549433`*^9}, {
  3.8089992499300137`*^9, 3.8089992553724546`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "aesthetics", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"MakeBoxes", "[", 
     RowBox[{"\[Epsilon]", ",", "StandardForm"}], "]"}], ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"StyleBox", "[", 
     RowBox[{
      RowBox[{"ToString", "[", "$PerturbationParameter", "]"}], ",", 
      RowBox[{"FontColor", "\[Rule]", 
       RowBox[{"RGBColor", "[", 
        RowBox[{"0.0", ",", " ", "1.0", ",", " ", "0.0"}], "]"}]}]}], "]"}]}],
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"organizes", " ", "in", " ", "perturbation", " ", "order"}], 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"org", "[", "expr_", "]"}], ":=", 
    RowBox[{"NoScalar", "@", 
     RowBox[{"Collect", "[", 
      RowBox[{
       RowBox[{"ContractMetric", "[", "expr", "]"}], ",", 
       "$PerturbationParameter", ",", "ToCanonical"}], "]"}]}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "kills", " ", "unwanted", " ", "second", " ", "order", " ", "terms"}], 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{"kill2O", ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"bigexpr", ":", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"expr_", "[", 
          RowBox[{
           RowBox[{"LI", "[", "x_", "]"}], ",", 
           RowBox[{"LI", "[", "y_", "]"}], ",", "___"}], "]"}], "/;", 
         RowBox[{"x", ">", "1"}]}], ")"}]}], ")"}], "\[RuleDelayed]", 
     "0"}]}]}]}]], "Input",
 CellChangeTimes->{{3.782519180915222*^9, 3.7825191813838277`*^9}, {
  3.7825234440142326`*^9, 3.782523447294854*^9}, {3.7825243602994394`*^9, 
  3.782524397922141*^9}, {3.8089990225499334`*^9, 3.8089990227912903`*^9}}],

Cell["\<\
Finally, we consider the redefined xPand master function (see xPand \
documentation)...\
\>", "Text",
 CellChangeTimes->{{3.782519123944364*^9, 3.782519159920286*^9}, {
  3.7825244099193015`*^9, 3.782524416730192*^9}, {3.795086343008244*^9, 
  3.795086360859985*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"MyToxPand", "[", 
   RowBox[{"expr_", ",", "gauge_", ",", "order_"}], "]"}], ":=", 
  RowBox[{"ToxPand", "[", 
   RowBox[{
   "expr", ",", "dg", ",", "u", ",", "du", ",", "h", ",", " ", "gauge", ",", 
    "order"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7825191709020844`*^9, 3.7825191720580745`*^9}, {
  3.7950863704065037`*^9, 3.7950863707231817`*^9}}],

Cell["For variational differentiation...", "Text",
 CellChangeTimes->{{3.8089992354687047`*^9, 3.808999241166506*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"PerturbAction", "[", 
   RowBox[{"expr_", ",", 
    RowBox[{
     RowBox[{
      RowBox[{"g_", "?", "MetricQ"}], "[", 
      RowBox[{
       RowBox[{"a_", "?", "UpIndexQ"}], ",", 
       RowBox[{"b_", "?", "UpIndexQ"}]}], "]"}], "|", 
     RowBox[{
      RowBox[{"g_", "?", "MetricQ"}], "[", 
      RowBox[{
       RowBox[{"a_", "?", "DownIndexQ"}], ",", 
       RowBox[{"b_", "?", "DownIndexQ"}]}], "]"}]}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"pertexpr", ",", "res", ",", "dgloc", ",", 
      RowBox[{"(*", 
       RowBox[{"dummyloc", ","}], "*)"}], "hp"}], "}"}], ",", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{
      "We", " ", "define", " ", "the", " ", "metric", " ", "perturbation"}], 
      ",", " ", 
      RowBox[{"if", " ", "not", " ", "defined", " ", "already"}]}], " ", 
     "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"dgloc", "=", 
      RowBox[{"SymbolJoin", "[", 
       RowBox[{"\"\<\[Delta]\>\"", ",", "g"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"hp", "=", 
      RowBox[{"Head", "@", 
       RowBox[{"Perturbation", "[", 
        RowBox[{"g", "[", 
         RowBox[{
          RowBox[{"DownIndex", "@", "a"}], ",", 
          RowBox[{"DownIndex", "@", "b"}]}], "]"}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"hp", "===", "Perturbation"}], ",", 
       RowBox[{"DefMetricPerturbation", "[", 
        RowBox[{"g", ",", "dgloc", ",", 
         RowBox[{"SymbolJoin", "[", 
          RowBox[{"\"\<\[Epsilon]\>\"", ",", "g"}], "]"}]}], "]"}], ",", 
       RowBox[{"dgloc", "=", "hp"}]}], "]"}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"$DefInfoQ", "=", "False"}], "}"}], ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
        "We", " ", "perturb", " ", "wrt", " ", "to", " ", "the", " ", 
         "metric", " ", "and", " ", "if", " ", "it", " ", "is", " ", "the", 
         " ", "inverse", " ", "metric", " ", "we", " ", "put", " ", "a", " ", 
         "minus", " ", "sign"}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"pertexpr", "=", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"DownIndexQ", "[", "a", "]"}], ",", "1", ",", 
              RowBox[{"-", "1"}]}], "]"}], ")"}], "*", 
           RowBox[{"ToCanonical", "@", 
            RowBox[{"ContractMetric", "@", 
             RowBox[{"ExpandPerturbation", "@", 
              RowBox[{"Perturbation", "[", "expr", "]"}]}]}]}]}], "/.", 
          RowBox[{
           RowBox[{"Perturbation", "[", "tens_", "]"}], "\[RuleDelayed]", 
           "0"}]}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", 
         RowBox[{"We", " ", "then", " ", "use", " ", 
          RowBox[{"VarD", ".", " ", "It"}], " ", "happens", " ", "that", " ", 
          "some", " ", "trivial", " ", "Kronecker", " ", "appear", " ", 
          "which", " ", "need", " ", "to", " ", "be", " ", "handle", " ", 
          "manually"}], " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"res", "=", 
         RowBox[{"ToCanonical", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"SameDummies", "@", 
             RowBox[{"ContractMetric", "@", 
              RowBox[{
               RowBox[{"VarD", "[", 
                RowBox[{
                 RowBox[{"dgloc", "[", 
                  RowBox[{
                   RowBox[{"LI", "[", "1", "]"}], ",", "a", ",", "b"}], "]"}],
                  ",", 
                 RowBox[{"CovDOfMetric", "[", "g", "]"}]}], "]"}], "[", 
               "pertexpr", "]"}]}]}], ")"}], "/.", 
           RowBox[{
            RowBox[{"delta", "[", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"LI", "[", "n_", "]"}]}], ",", 
              RowBox[{"LI", "[", "m_", "]"}]}], "]"}], "\[RuleDelayed]", 
            RowBox[{"KroneckerDelta", "[", 
             RowBox[{
              RowBox[{"NoScalar", "[", "n", "]"}], ",", 
              RowBox[{"NoScalar", "[", "m", "]"}]}], "]"}]}]}], "]"}]}], 
        ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     "res"}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PerturbAction", "[", 
   RowBox[{"expr_", ",", 
    RowBox[{"tensor_", "?", "xTensorQ"}], ",", "covd_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"res", ",", "dummyloc", ",", "pertexpr", ",", "inds"}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"$DefInfoQ", "=", "False"}], "}"}], ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{
         "We", " ", "use", " ", "a", " ", "dummy", " ", "name", " ", "for", 
          " ", "the", " ", "variation", " ", "of", " ", "the", " ", 
          "tensor"}], ",", " ", 
         RowBox[{
         "and", " ", "use", " ", "it", " ", "to", " ", "replace", " ", "the", 
          " ", "formal", " ", "first", " ", "order", " ", "perturbation", " ",
           "the", " ", "tensor"}]}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
        "So", " ", "first", " ", "we", " ", "define", " ", "this", " ", 
         "dummy", " ", "tensor"}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"dummyloc", "=", 
         RowBox[{"SymbolJoin", "[", 
          RowBox[{"\"\<Var\>\"", ",", "tensor"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"inds", "=", 
         RowBox[{"DummyIn", "/@", 
          RowBox[{"SlotsOfTensor", "[", "tensor", "]"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"!", 
           RowBox[{"xTensorQ", "[", "dummyloc", "]"}]}], ",", 
          RowBox[{"DefTensor", "[", 
           RowBox[{
            RowBox[{"dummyloc", "@@", "inds"}], ",", 
            RowBox[{"First", "@", 
             RowBox[{"DependenciesOfTensor", "@", "tensor"}]}]}], "]"}]}], 
         "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"SymmetryGroupOfTensor", "[", "dummyloc", "]"}], "^=", 
         RowBox[{"SymmetryGroupOfTensor", "[", "tensor", "]"}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
         "Then", " ", "we", " ", "perturb", " ", "the", " ", "action", " ", 
          "and", " ", "replace", " ", 
          RowBox[{"Perturbation", "[", 
           RowBox[{"Tensor", "[", "..", "]"}], "]"}], " ", "by", " ", "this", 
          " ", "dummy", " ", "tensor"}], " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"pertexpr", "=", 
         RowBox[{"(", 
          RowBox[{"ToCanonical", "@", 
           RowBox[{"ContractMetric", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"ExpandPerturbation", "@", 
               RowBox[{"Perturbation", "[", "expr", "]"}]}], "/.", 
              RowBox[{
               RowBox[{"Perturbation", "[", 
                RowBox[{
                 RowBox[{"tens_", "?", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"#", "=!=", "tensor"}], ")"}], "&"}], ")"}]}], 
                 "[", "ar___", "]"}], "]"}], "\[RuleDelayed]", "0"}]}], "/.", 
             RowBox[{
              RowBox[{"Perturbation", "[", 
               RowBox[{"tensor", "[", "ind___", "]"}], "]"}], 
              "\[RuleDelayed]", 
              RowBox[{"dummyloc", "[", "ind", "]"}]}]}], "]"}]}], ")"}]}], 
        ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
          RowBox[{"With", " ", "this", " ", "simple", " ", "head"}], ",", " ", 
          RowBox[{"VarD", " ", "works", " ", 
           RowBox[{"correctly", ".", " ", "Again"}], " ", "we", " ", "need", 
           " ", "to", " ", "handel", " ", "some", " ", "trivial", " ", 
           "Kronecker"}]}], " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"res", "=", 
         RowBox[{"ToCanonical", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"SameDummies", "@", 
             RowBox[{"ContractMetric", "@", 
              RowBox[{
               RowBox[{"VarD", "[", 
                RowBox[{
                 RowBox[{"dummyloc", "@@", "inds"}], ",", "covd"}], "]"}], 
               "[", "pertexpr", "]"}]}]}], ")"}], "/.", 
           RowBox[{
            RowBox[{"delta", "[", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"LI", "[", "n_", "]"}]}], ",", 
              RowBox[{"LI", "[", "m_", "]"}]}], "]"}], "\[RuleDelayed]", 
            RowBox[{"KroneckerDelta", "[", 
             RowBox[{
              RowBox[{"NoScalar", "[", "n", "]"}], ",", 
              RowBox[{"NoScalar", "[", "m", "]"}]}], "]"}]}]}], "]"}]}], 
        ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     "res"}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PerturbAction", "[", 
   RowBox[{"expr_", ",", 
    RowBox[{"tensor_", "[", "inds___", "]"}]}], "]"}], ":=", 
  RowBox[{"PerturbAction", "[", 
   RowBox[{"expr", ",", 
    RowBox[{"tensor", "[", "inds", "]"}], ",", 
    RowBox[{"CovDOfMetric", "@", 
     RowBox[{"First", "@", "$Metrics"}]}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PerturbAction", "[", 
   RowBox[{"expr_", ",", 
    RowBox[{
     RowBox[{"tensor_", "?", "xTensorQ"}], "[", "inds___", "]"}], ",", 
    "covd_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"res", ",", "dummyloc", ",", "pertexpr"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"$DefInfoQ", "=", "False"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"dummyloc", "=", 
         RowBox[{"SymbolJoin", "[", 
          RowBox[{"\"\<Var\>\"", ",", "tensor"}], "]"}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"!", 
           RowBox[{"xTensorQ", "[", "dummyloc", "]"}]}], ",", 
          RowBox[{"DefTensor", "[", 
           RowBox[{
            RowBox[{"dummyloc", "[", "inds", "]"}], ",", 
            RowBox[{"First", "@", 
             RowBox[{"DependenciesOfTensor", "@", "tensor"}]}]}], "]"}]}], 
         "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"SymmetryGroupOfTensor", "[", "dummyloc", "]"}], "^=", 
         RowBox[{"SymmetryGroupOfTensor", "[", "tensor", "]"}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{"Perturbation", " ", "with", " ", "xPert"}], "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"pertexpr", "=", 
         RowBox[{"(", 
          RowBox[{"ToCanonical", "@", 
           RowBox[{"ContractMetric", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"ExpandPerturbation", "@", 
               RowBox[{"Perturbation", "[", "expr", "]"}]}], "/.", 
              RowBox[{
               RowBox[{"Perturbation", "[", 
                RowBox[{
                 RowBox[{"tens_", "?", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"#", "=!=", "tensor"}], ")"}], "&"}], ")"}]}], 
                 "[", "ar___", "]"}], "]"}], "\[RuleDelayed]", "0"}]}], "/.", 
             RowBox[{
              RowBox[{"Perturbation", "[", 
               RowBox[{"tensor", "[", "ind___", "]"}], "]"}], 
              "\[RuleDelayed]", 
              RowBox[{"dummyloc", "[", "ind", "]"}]}]}], "]"}]}], ")"}]}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
         "VarD", " ", "and", " ", "removal", " ", "of", " ", 
          "KroneckerDelta"}], "*)"}], "\[IndentingNewLine]", 
        RowBox[{"res", "=", 
         RowBox[{"ToCanonical", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"SameDummies", "@", 
             RowBox[{"ContractMetric", "@", 
              RowBox[{
               RowBox[{"VarD", "[", 
                RowBox[{
                 RowBox[{"dummyloc", "[", "inds", "]"}], ",", "covd"}], "]"}],
                "[", "pertexpr", "]"}]}]}], ")"}], "/.", 
           RowBox[{
            RowBox[{"delta", "[", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"LI", "[", "n_", "]"}]}], ",", 
              RowBox[{"LI", "[", "m_", "]"}]}], "]"}], "\[RuleDelayed]", 
            RowBox[{"KroneckerDelta", "[", 
             RowBox[{
              RowBox[{"NoScalar", "[", "n", "]"}], ",", 
              RowBox[{"NoScalar", "[", "m", "]"}]}], "]"}]}]}], "]"}]}], 
        ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     "res"}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"VarAction", "[", 
   RowBox[{"expr_", ",", 
    RowBox[{
     RowBox[{"g_", "?", "MetricQ"}], "[", 
     RowBox[{"as__", "?", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"UpIndexQ", "[", "#", "]"}], "||", 
          RowBox[{"DownIndexQ", "[", "#", "]"}]}], ")"}], "&"}], ")"}]}], 
     "]"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "sqrtg", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"sqrtg", "=", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"SignDetOfMetric", "[", "g", "]"}], 
        RowBox[{
         RowBox[{"Determinant", "[", "g", "]"}], "[", "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ToCanonical", "[", 
      RowBox[{
       RowBox[{"PerturbAction", "[", 
        RowBox[{"expr", ",", 
         RowBox[{"g", "[", "as", "]"}]}], "]"}], "+", 
       RowBox[{
        RowBox[{"ReplaceDummies", "@", "expr"}], "*", 
        RowBox[{
         RowBox[{"PerturbAction", "[", 
          RowBox[{"sqrtg", ",", 
           RowBox[{"g", "[", "as", "]"}]}], "]"}], "/", "sqrtg"}]}]}], " ", 
      "]"}]}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"VarAction", "[", 
   RowBox[{"expr_", ",", 
    RowBox[{"tensor_", "?", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"xTensorQ", "[", "#", "]"}], "&&", 
         RowBox[{"Not", "[", 
          RowBox[{"MetricQ", "[", "#", "]"}], "]"}]}], ")"}], "&"}], ")"}]}], 
    ",", 
    RowBox[{"g_", "?", "MetricQ"}]}], "]"}], ":=", 
  RowBox[{"PerturbAction", "[", 
   RowBox[{"expr", ",", "tensor", ",", 
    RowBox[{"CovDOfMetric", "[", "g", "]"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"VarAction", "[", 
     RowBox[{"expr_", ",", 
      RowBox[{"tensor_", "?", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"xTensorQ", "[", "#", "]"}], "&&", 
           RowBox[{"Not", "[", 
            RowBox[{"MetricQ", "[", "#", "]"}], "]"}]}], ")"}], "&"}], 
        ")"}]}]}], "]"}], ":=", 
    RowBox[{"VarAction", "[", 
     RowBox[{"expr", ",", "tensor", ",", 
      RowBox[{"First", "@", "$Metrics"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"VarAction", "[", 
   RowBox[{"expr_", ",", 
    RowBox[{
     RowBox[{"tensor_", "?", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"xTensorQ", "[", "#", "]"}], "&&", 
          RowBox[{"Not", "[", 
           RowBox[{"MetricQ", "[", "#", "]"}], "]"}]}], ")"}], "&"}], ")"}]}],
      "[", "inds___", "]"}], ",", 
    RowBox[{"g_", "?", "MetricQ"}]}], "]"}], ":=", 
  RowBox[{"PerturbAction", "[", 
   RowBox[{"expr", ",", 
    RowBox[{"tensor", "[", "inds", "]"}], ",", 
    RowBox[{"CovDOfMetric", "[", "g", "]"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"VarAction", "[", 
    RowBox[{"expr_", ",", 
     RowBox[{
      RowBox[{"tensor_", "?", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"xTensorQ", "[", "#", "]"}], "&&", 
           RowBox[{"Not", "[", 
            RowBox[{"MetricQ", "[", "#", "]"}], "]"}]}], ")"}], "&"}], 
        ")"}]}], "[", "inds___", "]"}]}], "]"}], ":=", 
   RowBox[{"VarAction", "[", 
    RowBox[{"expr", ",", 
     RowBox[{"tensor", "[", "inds", "]"}], ",", 
     RowBox[{"First", "@", "$Metrics"}]}], "]"}]}], ";"}]}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["I. Kinetic gravity braiding",
 FontColor->RGBColor[1, 0.5, 0.5]]], "Subsection",
 CellChangeTimes->{{3.808999081759553*^9, 3.808999086361288*^9}}],

Cell["The Lagrangian of the theory is...", "Text",
 CellChangeTimes->{{3.8089993041211004`*^9, 3.808999309865737*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"DefScalarFunction", "/@", 
   RowBox[{"{", 
    RowBox[{"V", ",", "G"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefConstantSymbol", "[", "\[Kappa]", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefTensor", "[", 
   RowBox[{
    RowBox[{"\[Chi]", "[", "]"}], ",", "M"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"X", "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], 
    RowBox[{
     RowBox[{"CD", "[", "b", "]"}], "[", 
     RowBox[{"\[Chi]", "[", "]"}], "]"}], 
    RowBox[{
     RowBox[{"CD", "[", 
      RowBox[{"-", "b"}], "]"}], "[", 
     RowBox[{"\[Chi]", "[", "]"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LK", "=", 
   RowBox[{"V", "[", 
    RowBox[{
     RowBox[{"\[Chi]", "[", "]"}], ",", "X"}], "]"}]}], 
  RowBox[{"(*", 
   RowBox[{"quadratic", " ", "sector"}], "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LG", "=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"G", "[", 
      RowBox[{
       RowBox[{"\[Chi]", "[", "]"}], ",", "X"}], "]"}]}], 
    RowBox[{
     RowBox[{"CD", "[", "i", "]"}], "[", 
     RowBox[{
      RowBox[{"CD", "[", 
       RowBox[{"-", "i"}], "]"}], "[", 
      RowBox[{"\[Chi]", "[", "]"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"LEH", "=", 
    RowBox[{"\[Kappa]", " ", 
     RowBox[{"RicciScalarCD", "[", "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<L\>\"", "\[Equal]", 
  RowBox[{"LK", "+", "LG", "+", "LEH"}]}]}], "Input",
 CellChangeTimes->{{3.808999175526078*^9, 3.808999193534913*^9}, {
  3.808999316637615*^9, 3.808999351739683*^9}, {3.8089994011096125`*^9, 
  3.808999408740201*^9}, {3.8089996605984926`*^9, 3.8089996975785723`*^9}, {
  3.8089997673659344`*^9, 3.8089997768874655`*^9}, {3.8089998528452425`*^9, 
  3.808999853062698*^9}, {3.809001162579857*^9, 3.8090011873735385`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", "V", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`V, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.808999849535145*^9, 3.8089998732885556`*^9}, 
   3.8090005203797145`*^9, 3.8090012172835665`*^9, 3.809002855835367*^9, 
   3.809049708576667*^9, 3.8090547325831537`*^9, 3.809060405509062*^9, 
   3.809075931719654*^9, 3.8090784179670577`*^9, 3.809084195275453*^9, 
   3.809086111067222*^9, 3.8090880396826706`*^9, 3.8091407266534176`*^9, 
   3.8091466554636164`*^9, 3.8091489016433144`*^9, 3.8091577217249985`*^9, 
   3.8091648268128986`*^9, 3.809167763532688*^9, 3.8091718034791174`*^9, 
   3.8093200835075583`*^9, 3.809335760736752*^9, 3.8093415251925287`*^9, 
   3.8093477741789637`*^9, 3.809572304578987*^9, 3.8095916286354165`*^9, 
   3.809592160280301*^9, 3.8095925043886485`*^9, 3.8095931635296097`*^9, 
   3.8095954008042974`*^9, 3.8095981658011093`*^9, 3.809615024914343*^9, 
   3.8097454211913815`*^9, 3.8097456310220075`*^9, 3.8097507115697966`*^9, 
   3.8097525507269173`*^9, 3.8097530724013767`*^9, 3.809763096669182*^9, 
   3.809766612800762*^9, 3.809772052651227*^9, 3.80978343291051*^9, 
   3.8097871230390725`*^9, 3.8097875259871807`*^9, 3.8098309938503046`*^9, 
   3.809839292016372*^9, 3.809843516657727*^9, 3.8098443351888256`*^9, 
   3.8098633918097563`*^9, 3.8098673580098705`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", "G", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`G, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.808999849535145*^9, 3.8089998732885556`*^9}, 
   3.8090005203797145`*^9, 3.8090012172835665`*^9, 3.809002855835367*^9, 
   3.809049708576667*^9, 3.8090547325831537`*^9, 3.809060405509062*^9, 
   3.809075931719654*^9, 3.8090784179670577`*^9, 3.809084195275453*^9, 
   3.809086111067222*^9, 3.8090880396826706`*^9, 3.8091407266534176`*^9, 
   3.8091466554636164`*^9, 3.8091489016433144`*^9, 3.8091577217249985`*^9, 
   3.8091648268128986`*^9, 3.809167763532688*^9, 3.8091718034791174`*^9, 
   3.8093200835075583`*^9, 3.809335760736752*^9, 3.8093415251925287`*^9, 
   3.8093477741789637`*^9, 3.809572304578987*^9, 3.8095916286354165`*^9, 
   3.809592160280301*^9, 3.8095925043886485`*^9, 3.8095931635296097`*^9, 
   3.8095954008042974`*^9, 3.8095981658011093`*^9, 3.809615024914343*^9, 
   3.8097454211913815`*^9, 3.8097456310220075`*^9, 3.8097507115697966`*^9, 
   3.8097525507269173`*^9, 3.8097530724013767`*^9, 3.809763096669182*^9, 
   3.809766612800762*^9, 3.809772052651227*^9, 3.80978343291051*^9, 
   3.8097871230390725`*^9, 3.8097875259871807`*^9, 3.8098309938503046`*^9, 
   3.809839292016372*^9, 3.809843516657727*^9, 3.8098443351888256`*^9, 
   3.8098633918097563`*^9, 3.8098673580131044`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefConstantSymbol", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"constant symbol \"\>", "\[InvisibleSpace]", 
   "\[Kappa]", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefConstantSymbol, ": Defining ", 
   "constant symbol ", $CellContext`\[Kappa], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.808999849535145*^9, 3.8089998732885556`*^9}, 
   3.8090005203797145`*^9, 3.8090012172835665`*^9, 3.809002855835367*^9, 
   3.809049708576667*^9, 3.8090547325831537`*^9, 3.809060405509062*^9, 
   3.809075931719654*^9, 3.8090784179670577`*^9, 3.809084195275453*^9, 
   3.809086111067222*^9, 3.8090880396826706`*^9, 3.8091407266534176`*^9, 
   3.8091466554636164`*^9, 3.8091489016433144`*^9, 3.8091577217249985`*^9, 
   3.8091648268128986`*^9, 3.809167763532688*^9, 3.8091718034791174`*^9, 
   3.8093200835075583`*^9, 3.809335760736752*^9, 3.8093415251925287`*^9, 
   3.8093477741789637`*^9, 3.809572304578987*^9, 3.8095916286354165`*^9, 
   3.809592160280301*^9, 3.8095925043886485`*^9, 3.8095931635296097`*^9, 
   3.8095954008042974`*^9, 3.8095981658011093`*^9, 3.809615024914343*^9, 
   3.8097454211913815`*^9, 3.8097456310220075`*^9, 3.8097507115697966`*^9, 
   3.8097525507269173`*^9, 3.8097530724013767`*^9, 3.809763096669182*^9, 
   3.809766612800762*^9, 3.809772052651227*^9, 3.80978343291051*^9, 
   3.8097871230390725`*^9, 3.8097875259871807`*^9, 3.8098309938503046`*^9, 
   3.809839292016372*^9, 3.809843516657727*^9, 3.8098443351888256`*^9, 
   3.8098633918097563`*^9, 3.8098673580202527`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[Chi]", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[Chi][], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.808999849535145*^9, 3.8089998732885556`*^9}, 
   3.8090005203797145`*^9, 3.8090012172835665`*^9, 3.809002855835367*^9, 
   3.809049708576667*^9, 3.8090547325831537`*^9, 3.809060405509062*^9, 
   3.809075931719654*^9, 3.8090784179670577`*^9, 3.809084195275453*^9, 
   3.809086111067222*^9, 3.8090880396826706`*^9, 3.8091407266534176`*^9, 
   3.8091466554636164`*^9, 3.8091489016433144`*^9, 3.8091577217249985`*^9, 
   3.8091648268128986`*^9, 3.809167763532688*^9, 3.8091718034791174`*^9, 
   3.8093200835075583`*^9, 3.809335760736752*^9, 3.8093415251925287`*^9, 
   3.8093477741789637`*^9, 3.809572304578987*^9, 3.8095916286354165`*^9, 
   3.809592160280301*^9, 3.8095925043886485`*^9, 3.8095931635296097`*^9, 
   3.8095954008042974`*^9, 3.8095981658011093`*^9, 3.809615024914343*^9, 
   3.8097454211913815`*^9, 3.8097456310220075`*^9, 3.8097507115697966`*^9, 
   3.8097525507269173`*^9, 3.8097530724013767`*^9, 3.809763096669182*^9, 
   3.809766612800762*^9, 3.809772052651227*^9, 3.80978343291051*^9, 
   3.8097871230390725`*^9, 3.8097875259871807`*^9, 3.8098309938503046`*^9, 
   3.809839292016372*^9, 3.809843516657727*^9, 3.8098443351888256`*^9, 
   3.8098633918097563`*^9, 3.809867358025486*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\<\"L\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["R",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`RicciScalarCD[],
     Editable->False]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox["V",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`V,
     Editable->False], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Chi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Chi][],
      Editable->False], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[Del]", "b"], "\[Chi]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`b][
        $CellContext`\[Chi][]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[$CellContext`b][
        $CellContext`\[Chi][]],
       Editable->False]}]}], "]"}], "-", 
   RowBox[{
    RowBox[{
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`b][
         $CellContext`\[Chi][]],
        Editable->False]}]}], "]"}], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "i"], 
       SubscriptBox["\[Del]", "i"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`i][
      $CellContext`CD[-$CellContext`i][
       $CellContext`\[Chi][]]],
     Editable->False]}]}]}]], "Output",
 CellChangeTimes->{{3.8089993937383313`*^9, 3.8089994103050203`*^9}, 
   3.808999508534257*^9, 3.808999615003456*^9, 3.808999728314355*^9, 
   3.8089997789778337`*^9, {3.8089998496118917`*^9, 3.8089998733075047`*^9}, 
   3.8090005203937173`*^9, 3.809001217303507*^9, 3.8090028558573074`*^9, 
   3.809049708592515*^9, 3.8090547326482267`*^9, 3.809060405581639*^9, 
   3.8090759317745075`*^9, 3.8090784180508814`*^9, 3.8090841953392825`*^9, 
   3.809086111125476*^9, 3.809088039737887*^9, 3.80914072670062*^9, 
   3.809146655526019*^9, 3.809148901725876*^9, 3.809157721763899*^9, 
   3.8091648268938923`*^9, 3.8091677635772157`*^9, 3.8091718035080295`*^9, 
   3.8093200835698724`*^9, 3.8093357607902007`*^9, 3.8093415252629533`*^9, 
   3.809347774308766*^9, 3.8095723046102295`*^9, 3.809591628926898*^9, 
   3.8095921603236074`*^9, 3.809592504473201*^9, 3.8095931635976486`*^9, 
   3.8095954008612375`*^9, 3.809598165850277*^9, 3.8096150250236917`*^9, 
   3.8097454212538233`*^9, 3.8097456310376635`*^9, 3.809750711651189*^9, 
   3.8097525507855196`*^9, 3.8097530725518503`*^9, 3.8097630971445985`*^9, 
   3.8097666128470044`*^9, 3.8097720529332037`*^9, 3.8097834330939503`*^9, 
   3.8097871230982385`*^9, 3.8097875260167446`*^9, 3.8098309938677616`*^9, 
   3.8098392920387754`*^9, 3.8098435166813974`*^9, 3.8098443352070065`*^9, 
   3.809863391825446*^9, 3.809867358034668*^9}]
}, Open  ]],

Cell["The scalar field\[CloseCurlyQuote]s stress-energy tensor (SET) is...", \
"Text",
 CellChangeTimes->{{3.8089993968639727`*^9, 3.808999431352763*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"TK", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     RowBox[{"SortCovDs", "[", 
      RowBox[{
       RowBox[{"VarAction", "[", 
        RowBox[{"LK", ",", 
         RowBox[{"g", "[", 
          RowBox[{"b", ",", "c"}], "]"}]}], "]"}], ",", "CD"}], "]"}]}], "//",
     "ToCanonical"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"TG", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"SortCovDs", "[", 
       RowBox[{
        RowBox[{"VarAction", "[", 
         RowBox[{"LG", ",", 
          RowBox[{"g", "[", 
           RowBox[{"b", ",", "c"}], "]"}]}], "]"}], ",", "CD"}], "]"}]}], "//",
      "ToCanonical"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SuperscriptBox[SubscriptBox[\(T\), \(bc\)], \
\((K)\)]\)\>\"", "\[Equal]", "TK"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SuperscriptBox[SubscriptBox[\(T\), \(bc\)], \
\((G)\)]\)\>\"", "\[Equal]", "TG"}]}], "Input",
 CellChangeTimes->{{3.808999441292127*^9, 3.8089994628205423`*^9}, {
  3.8089999727674923`*^9, 3.8090001073654113`*^9}, {3.809745498792444*^9, 
  3.8097455582804823`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SuperscriptBox[SubscriptBox[\\(T\\), \\(bc\\)], \\((K)\
\\)]\\)\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"b", "c"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`b, -$CellContext`c],
     Editable->False], " ", 
    RowBox[{
     InterpretationBox[
      StyleBox["V",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`V,
      Editable->False], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Chi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Chi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Chi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Chi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Chi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["V",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`V,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Chi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Chi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Chi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Chi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Chi][]]],
        Editable->False]}]}], "]"}]}]}]}]], "Output",
 CellChangeTimes->{{3.808999457906684*^9, 3.808999467709461*^9}, 
   3.8089995158018513`*^9, 3.8089995618626404`*^9, {3.808999619741781*^9, 
   3.80899964102485*^9}, 3.8089997951984777`*^9, {3.8090000703614273`*^9, 
   3.809000108897411*^9}, 3.8090005235053544`*^9, 3.8090012222023726`*^9, 
   3.8090028567020493`*^9, 3.809049713841962*^9, 3.8090547335440145`*^9, 
   3.8090604065424905`*^9, 3.809075932638261*^9, 3.8090784189746685`*^9, 
   3.8090841963226495`*^9, 3.8090861122550163`*^9, 3.8090880407129145`*^9, 
   3.8091407277413373`*^9, 3.8091466568608694`*^9, 3.809148902654929*^9, 
   3.8091577225126605`*^9, 3.809164828117792*^9, 3.8091677649162607`*^9, 
   3.8091718044200115`*^9, 3.8093200844138365`*^9, 3.8093357616390395`*^9, 
   3.8093415262568016`*^9, 3.8093477756040373`*^9, 3.809572305438156*^9, 
   3.809591629911666*^9, 3.809592161225831*^9, 3.8095925053770895`*^9, 
   3.809593164752731*^9, 3.8095954017406816`*^9, 3.8095981667170973`*^9, 
   3.809615025790388*^9, 3.8097454221600065`*^9, 3.809745559296891*^9, 
   3.8097456339594154`*^9, 3.8097507126037674`*^9, 3.809752551681884*^9, 
   3.809753073465721*^9, 3.8097630981076994`*^9, 3.8097666136191497`*^9, 
   3.809772053808535*^9, 3.809783434066723*^9, 3.8097871239873867`*^9, 
   3.8097875266788197`*^9, 3.809830994577841*^9, 3.809839292652156*^9, 
   3.8098435172807937`*^9, 3.8098443358691225`*^9, 3.8098633925052767`*^9, 
   3.809867358665715*^9}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SuperscriptBox[SubscriptBox[\\(T\\), \\(bc\\)], \\((G)\
\\)]\\)\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["\[Del]", "b"], "\[Chi]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Chi][]],
      Editable->False]}], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], 
       SuperscriptBox["\[Del]", "d"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[$CellContext`d][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Chi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Chi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Chi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Chi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Chi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], 
       SubscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "d"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`d][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Chi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Chi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Chi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Chi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Chi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], 
       SubscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[-$CellContext`c][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "d"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`d][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Chi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Chi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Chi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Chi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Chi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"b", "c"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`b, -$CellContext`c],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "d"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`d][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "e"], 
       SubscriptBox["\[Del]", "d"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`e][
      $CellContext`CD[-$CellContext`d][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "e"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`e][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Chi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Chi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Chi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Chi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Chi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Chi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Chi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Chi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Chi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Chi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"b", "c"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`b, -$CellContext`c],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "d"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`d][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Chi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Chi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Chi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Chi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Chi][]]],
        Editable->False]}]}], "]"}]}]}]}]], "Output",
 CellChangeTimes->{{3.808999457906684*^9, 3.808999467709461*^9}, 
   3.8089995158018513`*^9, 3.8089995618626404`*^9, {3.808999619741781*^9, 
   3.80899964102485*^9}, 3.8089997951984777`*^9, {3.8090000703614273`*^9, 
   3.809000108897411*^9}, 3.8090005235053544`*^9, 3.8090012222023726`*^9, 
   3.8090028567020493`*^9, 3.809049713841962*^9, 3.8090547335440145`*^9, 
   3.8090604065424905`*^9, 3.809075932638261*^9, 3.8090784189746685`*^9, 
   3.8090841963226495`*^9, 3.8090861122550163`*^9, 3.8090880407129145`*^9, 
   3.8091407277413373`*^9, 3.8091466568608694`*^9, 3.809148902654929*^9, 
   3.8091577225126605`*^9, 3.809164828117792*^9, 3.8091677649162607`*^9, 
   3.8091718044200115`*^9, 3.8093200844138365`*^9, 3.8093357616390395`*^9, 
   3.8093415262568016`*^9, 3.8093477756040373`*^9, 3.809572305438156*^9, 
   3.809591629911666*^9, 3.809592161225831*^9, 3.8095925053770895`*^9, 
   3.809593164752731*^9, 3.8095954017406816`*^9, 3.8095981667170973`*^9, 
   3.809615025790388*^9, 3.8097454221600065`*^9, 3.809745559296891*^9, 
   3.8097456339594154`*^9, 3.8097507126037674`*^9, 3.809752551681884*^9, 
   3.809753073465721*^9, 3.8097630981076994`*^9, 3.8097666136191497`*^9, 
   3.809772053808535*^9, 3.809783434066723*^9, 3.8097871239873867`*^9, 
   3.8097875266788197`*^9, 3.809830994577841*^9, 3.809839292652156*^9, 
   3.8098435172807937`*^9, 3.8098443358691225`*^9, 3.8098633925052767`*^9, 
   3.8098673587016068`*^9}]
}, Open  ]],

Cell["The Einstein equation is given by...", "Text",
 CellChangeTimes->{{3.8090002161012144`*^9, 3.8090002210997953`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"DefTensor", "[", 
   RowBox[{
    RowBox[{"TM", "[", 
     RowBox[{
      RowBox[{"-", "b"}], ",", 
      RowBox[{"-", "c"}]}], "]"}], ",", "M", ",", 
    RowBox[{"Symmetric", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "b"}], ",", 
       RowBox[{"-", "c"}]}], "}"}], "]"}], ",", 
    RowBox[{"PrintAs", "\[Rule]", "\"\<T\>\""}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EE", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"VarAction", "[", 
      RowBox[{"LEH", ",", 
       RowBox[{"g", "[", 
        RowBox[{"b", ",", "c"}], "]"}]}], "]"}], "-", 
     FractionBox["TK", "2"], "-", 
     FractionBox["TG", "2"]}], "\[Equal]", 
    FractionBox[
     RowBox[{"TM", "[", 
      RowBox[{
       RowBox[{"-", "b"}], ",", 
       RowBox[{"-", "c"}]}], "]"}], "2"]}]}], 
  ";"}], "\[IndentingNewLine]", "EE"}], "Input",
 CellChangeTimes->{{3.8090002330548143`*^9, 3.809000288100606*^9}, {
  3.809000344969448*^9, 3.80900035935003*^9}, {3.809000410032897*^9, 
  3.8090004871306577`*^9}, {3.8097455683774195`*^9, 3.8097455919466085`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"TM", "[", 
    RowBox[{
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`TM[-$CellContext`b, -$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.809745637351522*^9, 3.80975071275555*^9, 
  3.8097525517893867`*^9, 3.8097530735739527`*^9, 3.8097630982904124`*^9, 
  3.8097666137102947`*^9, 3.8097720539338245`*^9, 3.8097834345443945`*^9, 
  3.80978712408158*^9, 3.809787526784481*^9, 3.809830994737776*^9, 
  3.8098392927609634`*^9, 3.8098435173592725`*^9, 3.809844336073147*^9, 
  3.8098633926563663`*^9, 3.809867358784483*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"R", 
         StyleBox[GridBox[{
            {" ", " "},
            {"b", "c"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`RicciCD[-$CellContext`b, -$CellContext`c],
     Editable->False]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"b", "c"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`b, -$CellContext`c],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["R",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`RicciScalarCD[],
     Editable->False]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"g", 
             StyleBox[GridBox[{
                {" ", " "},
                {"b", "c"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`g[-$CellContext`b, -$CellContext`c],
         Editable->False]}], " ", 
       RowBox[{
        InterpretationBox[
         StyleBox["V",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`V,
         Editable->False], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Chi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Chi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "b"], "\[Chi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`b][
                $CellContext`\[Chi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`b][
                $CellContext`\[Chi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
              $CellContext`\[Chi][]] $CellContext`CD[$CellContext`b][
              $CellContext`\[Chi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["V",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`V,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Chi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Chi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "b"], "\[Chi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`b][
                $CellContext`\[Chi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`b][
                $CellContext`\[Chi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
              $CellContext`\[Chi][]] $CellContext`CD[$CellContext`b][
              $CellContext`\[Chi][]]],
           Editable->False]}]}], "]"}]}]}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SuperscriptBox["\[Del]", "d"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[$CellContext`d][
          $CellContext`\[Chi][]]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Chi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Chi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "b"], "\[Chi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`b][
                $CellContext`\[Chi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`b][
                $CellContext`\[Chi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
              $CellContext`\[Chi][]] $CellContext`CD[$CellContext`b][
              $CellContext`\[Chi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SubscriptBox["\[Del]", "b"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[Chi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Chi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Chi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "b"], "\[Chi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`b][
                $CellContext`\[Chi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`b][
                $CellContext`\[Chi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
              $CellContext`\[Chi][]] $CellContext`CD[$CellContext`b][
              $CellContext`\[Chi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], 
          SubscriptBox["\[Del]", "c"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`CD[-$CellContext`c][
          $CellContext`\[Chi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Chi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Chi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "b"], "\[Chi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`b][
                $CellContext`\[Chi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`b][
                $CellContext`\[Chi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
              $CellContext`\[Chi][]] $CellContext`CD[$CellContext`b][
              $CellContext`\[Chi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"b", "c"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`b, -$CellContext`c],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "e"], 
          SubscriptBox["\[Del]", "d"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`e][
         $CellContext`CD[-$CellContext`d][
          $CellContext`\[Chi][]]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "e"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`e][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Chi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Chi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "b"], "\[Chi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`b][
                $CellContext`\[Chi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`b][
                $CellContext`\[Chi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
              $CellContext`\[Chi][]] $CellContext`CD[$CellContext`b][
              $CellContext`\[Chi][]]],
           Editable->False]}]}], "]"}]}], "+", 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "b"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "c"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Chi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Chi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "b"], "\[Chi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`b][
                $CellContext`\[Chi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`b][
                $CellContext`\[Chi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
              $CellContext`\[Chi][]] $CellContext`CD[$CellContext`b][
              $CellContext`\[Chi][]]],
           Editable->False]}]}], "]"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"b", "c"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`b, -$CellContext`c],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[Del]", "d"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`d][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["\[Del]", "d"], "\[Chi]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[$CellContext`d][
         $CellContext`\[Chi][]],
        Editable->False], " ", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Chi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Chi][],
          Editable->False], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[Del]", "b"], "\[Chi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`b][
                $CellContext`\[Chi][]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`b][
                $CellContext`\[Chi][]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
              $CellContext`\[Chi][]] $CellContext`CD[$CellContext`b][
              $CellContext`\[Chi][]]],
           Editable->False]}]}], "]"}]}]}], ")"}]}]}], "\[Equal]", 
  FractionBox[
   InterpretationBox[
    StyleBox[GridBox[{
       {"T", 
        StyleBox[GridBox[{
           {" ", " "},
           {"b", "c"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`TM[-$CellContext`b, -$CellContext`c],
    Editable->False], "2"]}]], "Output",
 CellChangeTimes->{{3.8090004636574526`*^9, 3.8090004891761823`*^9}, 
   3.8090005350365105`*^9, 3.809001229000187*^9, 3.8090028568925056`*^9, 
   3.8090497199317613`*^9, 3.809054733826643*^9, 3.8090604067332954`*^9, 
   3.809075932863594*^9, 3.8090784193163967`*^9, 3.8090841965762515`*^9, 
   3.8090861127048125`*^9, 3.8090880409742155`*^9, 3.8091407286539936`*^9, 
   3.8091466573663497`*^9, 3.8091489028413954`*^9, 3.809157722709076*^9, 
   3.8091648284344425`*^9, 3.8091677652146883`*^9, 3.8091718046419344`*^9, 
   3.8093200846169434`*^9, 3.8093357618468943`*^9, 3.809341526696372*^9, 
   3.8093477758514643`*^9, 3.80957230562372*^9, 3.809591630197565*^9, 
   3.8095921614404907`*^9, 3.809592505562637*^9, 3.809593165016089*^9, 
   3.8095954019822416`*^9, 3.8095981669370327`*^9, 3.8096150260090895`*^9, 
   3.8097454223474655`*^9, {3.8097455765514507`*^9, 3.809745593728563*^9}, 
   3.809745637492113*^9, 3.8097507128749995`*^9, 3.8097525520060835`*^9, 
   3.809753073908574*^9, 3.809763098501851*^9, 3.8097666138188777`*^9, 
   3.8097720540259995`*^9, 3.8097834346351075`*^9, 3.809787124455844*^9, 
   3.8097875268954215`*^9, 3.8098309948861184`*^9, 3.809839292855951*^9, 
   3.809843517497403*^9, 3.8098443361725893`*^9, 3.8098633927213507`*^9, 
   3.8098673589414434`*^9}]
}, Open  ]],

Cell["The scalar field equation is given by...", "Text",
 CellChangeTimes->{{3.809000600461502*^9, 3.8090006073401012`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"SFE", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"SortCovDs", "[", 
       RowBox[{
        RowBox[{"VarAction", "[", 
         RowBox[{
          RowBox[{"LK", "+", "LG"}], ",", 
          RowBox[{"\[Chi]", "[", "]"}]}], "]"}], ",", "CD"}], "]"}], "//", 
      "ToCanonical"}], ")"}], "\[Equal]", "0"}]}], 
  ";"}], "\[IndentingNewLine]", "SFE"}], "Input",
 CellChangeTimes->{{3.809000608205785*^9, 3.8090006456795444`*^9}, {
  3.8090012400256944`*^9, 3.8090012410539446`*^9}, {3.809745446354581*^9, 
  3.8097454750657454`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["\[Del]", "b"], 
        SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`b][
       $CellContext`CD[$CellContext`b][
        $CellContext`\[Chi][]]],
      Editable->False]}], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[$CellContext`c][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Chi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Chi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Chi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Chi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Chi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"R", 
         StyleBox[GridBox[{
            {" ", " "},
            {"b", "c"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`RicciCD[-$CellContext`b, -$CellContext`c],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Chi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Chi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Chi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Chi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Chi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SubscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], 
       SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`CD[$CellContext`b][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Chi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Chi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Chi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Chi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Chi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], 
       SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`CD[$CellContext`b][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["V",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`V,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Chi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Chi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Chi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Chi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Chi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SubscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], 
       SuperscriptBox["\[Del]", "d"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[$CellContext`d][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Chi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Chi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Chi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Chi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Chi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "d"], 
       SubscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`d][
      $CellContext`CD[-$CellContext`c][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "d"], 
       SubscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`d][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Chi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Chi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Chi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Chi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Chi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SubscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["V",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`V,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Chi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Chi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Chi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Chi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Chi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], 
       SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`CD[$CellContext`b][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Chi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Chi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Chi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Chi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Chi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["V",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`V,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Chi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Chi][],
      Editable->False], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         StyleBox["(",
          FontColor->RGBColor[1, 0, 0]], 
         RowBox[{
          InterpretationBox[
           StyleBox[
            RowBox[{
             SubscriptBox["\[Del]", "b"], "\[Chi]"}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`CD[-$CellContext`b][
            $CellContext`\[Chi][]],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`CD[$CellContext`b][
            $CellContext`\[Chi][]],
           Editable->False]}], 
         StyleBox[")",
          FontColor->RGBColor[1, 0, 0]]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
          $CellContext`\[Chi][]] $CellContext`CD[$CellContext`b][
          $CellContext`\[Chi][]]],
       Editable->False]}]}], "]"}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[$CellContext`c][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Chi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Chi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Chi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Chi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Chi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "c"], 
       SubscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`c][
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Chi][]]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "c"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`c][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Chi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Chi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Chi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Chi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Chi][]]],
        Editable->False]}]}], "]"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["V",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`V,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Chi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Chi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Chi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Chi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Chi][]]],
        Editable->False]}]}], "]"}]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[$CellContext`b][
      $CellContext`\[Chi][]],
     Editable->False], " ", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      InterpretationBox[
       StyleBox["\[Chi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Chi][],
       Editable->False], ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[Del]", "b"], "\[Chi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`b][
             $CellContext`\[Chi][]],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[$CellContext`b][
             $CellContext`\[Chi][]],
            Editable->False]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[$CellContext`CD[-$CellContext`b][
           $CellContext`\[Chi][]] $CellContext`CD[$CellContext`b][
           $CellContext`\[Chi][]]],
        Editable->False]}]}], "]"}]}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{
  3.8090006466419687`*^9, 3.80900124285712*^9, 3.809002857596655*^9, 
   3.8090497238467855`*^9, 3.8090547347178564`*^9, 3.8090604075781417`*^9, 
   3.809075933634167*^9, 3.8090784203060837`*^9, 3.809084198129816*^9, 
   3.8090861134338655`*^9, 3.8090880416952887`*^9, 3.809140729342307*^9, 
   3.8091466584377117`*^9, 3.8091489035308022`*^9, 3.8091577233688574`*^9, 
   3.8091648293383293`*^9, 3.809167766247755*^9, 3.8091718053969145`*^9, 
   3.809320085289344*^9, 3.8093357626008444`*^9, 3.809341527501058*^9, 
   3.8093477765586104`*^9, 3.8095723062954383`*^9, 3.809591631211376*^9, 
   3.8095921621846385`*^9, 3.8095925069203157`*^9, 3.8095931658526516`*^9, 
   3.809595402701291*^9, 3.8095981677101316`*^9, 3.8096150266811604`*^9, 
   3.8097454230816975`*^9, {3.809745454544505*^9, 3.809745476301226*^9}, 
   3.8097456423375053`*^9, 3.8097507137660627`*^9, 3.809752552820507*^9, 
   3.809753074781193*^9, 3.809763099408345*^9, 3.8097666146436267`*^9, 
   3.809772054898158*^9, 3.80978343551204*^9, 3.809787125350216*^9, 
   3.809787527689106*^9, 3.809830996262435*^9, 3.809839293625589*^9, 
   3.8098435181841736`*^9, 3.809844336985299*^9, 3.8098633935799713`*^9, 
   3.8098673598660197`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["II. Prelude to scalar perturbations",
 FontColor->RGBColor[1, 0.5, 0.5]]], "Subsection",
 CellChangeTimes->{{3.8090013023390503`*^9, 3.8090013082392273`*^9}, {
  3.8097882301663237`*^9, 3.8097882487190294`*^9}}],

Cell["\<\
In this section, we study the scalar perturbations in KGB. But to do so, let\
\[CloseCurlyQuote]s first see how the metric is perturbed in xPand.\
\>", "Text",
 CellChangeTimes->{{3.8090013981447315`*^9, 3.8090014392118893`*^9}, {
  3.809001945913478*^9, 3.8090019460890083`*^9}, {3.8090497592374315`*^9, 
  3.809049768493402*^9}}],

Cell[CellGroupData[{

Cell["Metric perturbations in xPand", "Subsubsection",
 CellChangeTimes->{{3.8090019522734656`*^9, 3.8090019706532965`*^9}, {
  3.809049771856024*^9, 3.809049779320335*^9}}],

Cell[TextData[{
 "Master function = ",
 StyleBox["MyToxPand[...]",
  FontSlant->"Italic"]
}], "Text",
 CellChangeTimes->{{3.809049790855445*^9, 3.809049799847314*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"$ConformalTime", "=", "False"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SubscriptBox[\(g\), \(bc\)]\)\>\"", "\[Equal]", 
  RowBox[{"VisualizeTensor", "[", 
   RowBox[{
    RowBox[{"MyToxPand", "[", 
     RowBox[{
      RowBox[{"g", "[", 
       RowBox[{
        RowBox[{"-", "b"}], ",", 
        RowBox[{"-", "c"}]}], "]"}], ",", "\"\<AnyGauge\>\"", ",", "1"}], 
     "]"}], ",", "h"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.809001649168256*^9, 3.8090016526868453`*^9}, {
  3.8090547567638707`*^9, 3.809054758147912*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"ChristoffelCDCDah2", "[", 
    RowBox[{"b", ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`ChristoffelCDCDah2[$CellContext`b, -$CellContext`c, \
-$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8090014824761505`*^9, 3.80900159333062*^9, 3.809001655004644*^9, 
   3.8090028626949854`*^9, 3.809049808980049*^9, 3.8090547597829328`*^9, 
   3.809060416578611*^9, 3.809076035012023*^9, 3.8090784292317934`*^9, 
   3.809078462241829*^9, 3.809084206533466*^9, 3.8090861199285407`*^9, 
   3.8090880484253206`*^9, 3.809140779445527*^9, 3.809146664543461*^9, 
   3.8091489100261784`*^9, 3.809157732346407*^9, 3.8091648364233427`*^9, 
   3.809167771281661*^9, 3.8091718120527678`*^9, 3.809320091634606*^9, 
   3.8093357731767955`*^9, 3.809341535878251*^9, 3.809347782526517*^9, 
   3.809572314985752*^9, 3.8095916466396456`*^9, 3.809592167129263*^9, {
   3.809592511146103*^9, 3.8095925215135255`*^9}, 3.809593209200676*^9, 
   3.809595412351263*^9, 3.809598175039338*^9, 3.8096150356209645`*^9, 
   3.809745670909998*^9, 3.8097507419608355`*^9, 3.8097525695927596`*^9, 
   3.8097530806357555`*^9, 3.8097631092580404`*^9, 3.8097666215986705`*^9, 
   3.809772064111775*^9, 3.809783442903546*^9, 3.809787134808862*^9, 
   3.809787527781146*^9, 3.809830996452614*^9, 3.8098392937551136`*^9, 
   3.8098435183168592`*^9, 3.809844337105424*^9, 3.8098633936970673`*^9, 
   3.8098673599538975`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The Splitting of \"\>", "\[InvisibleSpace]", 
   RowBox[{
    StyleBox["\[Epsilon]",
     FontColor->RGBColor[0., 1., 0.]], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]g", 
         StyleBox[GridBox[{
            {"1", " ", " "},
            {" ", "b", "c"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dg[
      xAct`xTensor`LI[1], -$CellContext`b, -$CellContext`c],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       RowBox[{
        StyleBox["(",
         FontColor->RGBColor[1, 0, 0]], 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], 
        StyleBox[")",
         FontColor->RGBColor[1, 0, 0]]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xTensor`Scalar[
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]]],
      Editable->False], "2"]}], 
   "\[InvisibleSpace]", "\<\" +... was performed in \"\>", 
   "\[InvisibleSpace]", "0.3589185`", 
   "\[InvisibleSpace]", "\<\" seconds.\"\>"}],
  SequenceForm["The Splitting of ", xAct`xPand`\[Epsilon] $CellContext`dg[
     xAct`xTensor`LI[1], -$CellContext`b, -$CellContext`c] xAct`xTensor`Scalar[
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]]]^2, " +... was performed in ", 0.3589185, 
   " seconds."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8090014824761505`*^9, 3.80900159333062*^9, 3.809001655004644*^9, 
   3.8090028626949854`*^9, 3.809049808980049*^9, 3.8090547597829328`*^9, 
   3.809060416578611*^9, 3.809076035012023*^9, 3.8090784292317934`*^9, 
   3.809078462241829*^9, 3.809084206533466*^9, 3.8090861199285407`*^9, 
   3.8090880484253206`*^9, 3.809140779445527*^9, 3.809146664543461*^9, 
   3.8091489100261784`*^9, 3.809157732346407*^9, 3.8091648364233427`*^9, 
   3.809167771281661*^9, 3.8091718120527678`*^9, 3.809320091634606*^9, 
   3.8093357731767955`*^9, 3.809341535878251*^9, 3.809347782526517*^9, 
   3.809572314985752*^9, 3.8095916466396456`*^9, 3.809592167129263*^9, {
   3.809592511146103*^9, 3.8095925215135255`*^9}, 3.809593209200676*^9, 
   3.809595412351263*^9, 3.809598175039338*^9, 3.8096150356209645`*^9, 
   3.809745670909998*^9, 3.8097507419608355`*^9, 3.8097525695927596`*^9, 
   3.8097530806357555`*^9, 3.8097631092580404`*^9, 3.8097666215986705`*^9, 
   3.809772064111775*^9, 3.809783442903546*^9, 3.809787134808862*^9, 
   3.809787527781146*^9, 3.809830996452614*^9, 3.8098392937551136`*^9, 
   3.8098435183168592`*^9, 3.809844337105424*^9, 3.8098633936970673`*^9, 
   3.8098673604269714`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(g\\), \\(bc\\)]\\)\"\>", "\[Equal]", 
  TagBox[GridBox[{
     {"", "n", "h"},
     {"n", 
      RowBox[{
       RowBox[{"-", "1"}], "-", 
       RowBox[{"2", " ", 
        StyleBox["\[Epsilon]",
         FontColor->RGBColor[0., 1., 0.]], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[Phi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]h[],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]],
          Editable->False], ")"}]}]}], 
      RowBox[{
       StyleBox["\[Epsilon]",
        FontColor->RGBColor[0., 1., 0.]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["a",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`ah[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              OverscriptBox["\[Null]", 
               StyleBox[
                RowBox[{"(", "1", ")"}],
                FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
              OverscriptBox[
               InterpretationBox[
                StyleBox[GridBox[{
                   {"B", 
                    StyleBox[GridBox[{
                    {" "},
                    {"c"}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                    FontSize->Rational[39, 4]]}
                  },
                  
                  GridBoxAlignment->{
                   "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`Bvh[-$CellContext`c],
                Editable->False], ""]}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[
             xAct`xTensor`LI[1], 
             xAct`xTensor`LI[0], -$CellContext`c],
            Editable->False], ")"}]}], "+", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["a",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`ah[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox[
               OverscriptBox["D", "_"], "c"], 
              OverscriptBox["\[Null]", 
               StyleBox[
                RowBox[{"(", "1", ")"}],
                FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
              OverscriptBox[
               InterpretationBox[
                StyleBox["B",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`Bsh[],
                Editable->False], ""]}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`cd[-$CellContext`c][
             $CellContext`Bsh[
              xAct`xTensor`LI[1], 
              xAct`xTensor`LI[0]]],
            Editable->False], ")"}]}]}], ")"}]}]},
     {"h", 
      RowBox[{
       StyleBox["\[Epsilon]",
        FontColor->RGBColor[0., 1., 0.]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["a",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`ah[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              OverscriptBox["\[Null]", 
               StyleBox[
                RowBox[{"(", "1", ")"}],
                FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
              OverscriptBox[
               InterpretationBox[
                StyleBox[GridBox[{
                   {"B", 
                    StyleBox[GridBox[{
                    {" "},
                    {"b"}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                    FontSize->Rational[39, 4]]}
                  },
                  
                  GridBoxAlignment->{
                   "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`Bvh[-$CellContext`b],
                Editable->False], ""]}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[
             xAct`xTensor`LI[1], 
             xAct`xTensor`LI[0], -$CellContext`b],
            Editable->False], ")"}]}], "+", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["a",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`ah[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox[
               OverscriptBox["D", "_"], "b"], 
              OverscriptBox["\[Null]", 
               StyleBox[
                RowBox[{"(", "1", ")"}],
                FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
              OverscriptBox[
               InterpretationBox[
                StyleBox["B",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`Bsh[],
                Editable->False], ""]}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`cd[-$CellContext`b][
             $CellContext`Bsh[
              xAct`xTensor`LI[1], 
              xAct`xTensor`LI[0]]],
            Editable->False], ")"}]}]}], ")"}]}], 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False], "2"], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {
             OverscriptBox["h", "-"], 
             StyleBox[GridBox[{
                {" ", " "},
                {"b", "c"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`h[-$CellContext`b, -$CellContext`c],
         Editable->False]}], "+", 
       RowBox[{
        StyleBox["\[Epsilon]",
         FontColor->RGBColor[0., 1., 0.]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              OverscriptBox[
               InterpretationBox[
                StyleBox["a",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`ah[],
                Editable->False], ""],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[
              xAct`xTensor`LI[0], 
              xAct`xTensor`LI[0]],
             Editable->False], "2"], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               OverscriptBox["\[Null]", 
                StyleBox[
                 RowBox[{"(", "1", ")"}],
                 FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
               OverscriptBox[
                InterpretationBox[
                 StyleBox[GridBox[{
                    {"E", 
                    StyleBox[GridBox[{
                    {" ", " "},
                    {"b", "c"}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                    FontSize->Rational[39, 4]]}
                   },
                   
                   GridBoxAlignment->{
                    "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`Eth[-$CellContext`b, -$CellContext`c],
                 Editable->False], ""]}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Eth[
              xAct`xTensor`LI[1], 
              xAct`xTensor`LI[0], -$CellContext`b, -$CellContext`c],
             Editable->False], ")"}]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              OverscriptBox[
               InterpretationBox[
                StyleBox["a",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`ah[],
                Editable->False], ""],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[
              xAct`xTensor`LI[0], 
              xAct`xTensor`LI[0]],
             Editable->False], "2"], " ", 
           InterpretationBox[
            StyleBox[GridBox[{
               {
                OverscriptBox["h", "-"], 
                StyleBox[GridBox[{
                   {" ", " "},
                   {"b", "c"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`h[-$CellContext`b, -$CellContext`c],
            Editable->False], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               OverscriptBox["\[Null]", 
                StyleBox[
                 RowBox[{"(", "1", ")"}],
                 FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
               OverscriptBox[
                InterpretationBox[
                 StyleBox["\[Psi]",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`\[Psi]h[],
                 Editable->False], ""]}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[
              xAct`xTensor`LI[1], 
              xAct`xTensor`LI[0]],
             Editable->False], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              OverscriptBox[
               InterpretationBox[
                StyleBox["a",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`ah[],
                Editable->False], ""],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[
              xAct`xTensor`LI[0], 
              xAct`xTensor`LI[0]],
             Editable->False], "2"], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox[
                OverscriptBox["D", "_"], "b"], 
               OverscriptBox["\[Null]", 
                StyleBox[
                 RowBox[{"(", "1", ")"}],
                 FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
               OverscriptBox[
                InterpretationBox[
                 StyleBox[GridBox[{
                    {"E", 
                    StyleBox[GridBox[{
                    {" "},
                    {"c"}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                    FontSize->Rational[39, 4]]}
                   },
                   
                   GridBoxAlignment->{
                    "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`Evh[-$CellContext`c],
                 Editable->False], ""]}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`cd[-$CellContext`b][
              $CellContext`Evh[
               xAct`xTensor`LI[1], 
               xAct`xTensor`LI[0], -$CellContext`c]],
             Editable->False], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              OverscriptBox[
               InterpretationBox[
                StyleBox["a",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`ah[],
                Editable->False], ""],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[
              xAct`xTensor`LI[0], 
              xAct`xTensor`LI[0]],
             Editable->False], "2"], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox[
                OverscriptBox["D", "_"], "c"], 
               OverscriptBox["\[Null]", 
                StyleBox[
                 RowBox[{"(", "1", ")"}],
                 FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
               OverscriptBox[
                InterpretationBox[
                 StyleBox[GridBox[{
                    {"E", 
                    StyleBox[GridBox[{
                    {" "},
                    {"b"}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                    FontSize->Rational[39, 4]]}
                   },
                   
                   GridBoxAlignment->{
                    "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`Evh[-$CellContext`b],
                 Editable->False], ""]}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`cd[-$CellContext`c][
              $CellContext`Evh[
               xAct`xTensor`LI[1], 
               xAct`xTensor`LI[0], -$CellContext`b]],
             Editable->False], ")"}]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              OverscriptBox[
               InterpretationBox[
                StyleBox["a",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`ah[],
                Editable->False], ""],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[
              xAct`xTensor`LI[0], 
              xAct`xTensor`LI[0]],
             Editable->False], "2"], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox[
                OverscriptBox["D", "_"], "c"], 
               SubscriptBox[
                OverscriptBox["D", "_"], "b"], 
               OverscriptBox["\[Null]", 
                StyleBox[
                 RowBox[{"(", "1", ")"}],
                 FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
               OverscriptBox[
                InterpretationBox[
                 StyleBox["E",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`Esh[],
                 Editable->False], ""]}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`cd[-$CellContext`c][
              $CellContext`cd[-$CellContext`b][
               $CellContext`Esh[
                xAct`xTensor`LI[1], 
                xAct`xTensor`LI[0]]]],
             Editable->False], ")"}]}]}], ")"}]}]}]}
    },
    AutoDelete->False,
    GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"]}]], "Output",
 CellChangeTimes->{
  3.809001483113479*^9, 3.809001593439329*^9, 3.8090016550854273`*^9, 
   3.8090028632375326`*^9, 3.8090498096096992`*^9, 3.8090547605584636`*^9, 
   3.809060417793621*^9, 3.8090760361170645`*^9, 3.809078429796282*^9, 
   3.8090784623871036`*^9, 3.809084207662321*^9, 3.809086121098425*^9, 
   3.809088049703864*^9, 3.8091407804306765`*^9, 3.8091466660747557`*^9, 
   3.809148911255302*^9, 3.8091577332292967`*^9, 3.8091648374249306`*^9, 
   3.8091677722021236`*^9, 3.809171812705846*^9, 3.809320092135292*^9, 
   3.8093357737199807`*^9, 3.8093415364112835`*^9, 3.809347783356436*^9, 
   3.8095723155092926`*^9, 3.809591647149824*^9, 3.809592167753914*^9, {
   3.809592511712607*^9, 3.8095925216591043`*^9}, 3.8095932098783855`*^9, 
   3.8095954130134363`*^9, 3.8095981756337876`*^9, 3.8096150361833324`*^9, 
   3.809745671502551*^9, 3.809750742618573*^9, 3.809752570258539*^9, 
   3.809753081241168*^9, 3.8097631099151835`*^9, 3.809766622300575*^9, 
   3.8097720647127724`*^9, 3.80978344360497*^9, 3.809787135559623*^9, 
   3.809787528317494*^9, 3.8098309971908607`*^9, 3.8098392942745686`*^9, 
   3.8098435188254075`*^9, 3.8098443376341753`*^9, 3.8098633942671585`*^9, 
   3.809867360548339*^9}]
}, Open  ]],

Cell[TextData[{
 "We want to work with so-called unitary gauge wherein the scalar field ",
 Cell[BoxData[
  FormBox["\[Chi]", TraditionalForm]]],
 " will be used instead as a clock (i.e., ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Delta]\[Chi]", "=", "0"}], TraditionalForm]]],
 "). This is already built-in in xPand through the (pre-defined) scalar field \
",
 Cell[BoxData[
  FormBox["\[CurlyPhi]", TraditionalForm]]],
 " and \[OpenCurlyDoubleQuote]ScalarFieldComovingGauge\[CloseCurlyDoubleQuote]\
. To focus on scalar perturbations, we remove the vector and tensor modes as \
well..."
}], "Text",
 CellChangeTimes->{{3.809001509413098*^9, 3.809001579764947*^9}, {
  3.80900170773559*^9, 3.8090017269890904`*^9}, {3.8090029568142567`*^9, 
  3.809003027623808*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"$FirstOrderVectorPerturbations", "=", "False"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"$FirstOrderTensorPerturbations", "=", "False"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SubscriptBox[\(g\), \(bc\)]\)\>\"", "\[Equal]", 
  RowBox[{"VisualizeTensor", "[", 
   RowBox[{
    RowBox[{"MyToxPand", "[", 
     RowBox[{
      RowBox[{"g", "[", 
       RowBox[{
        RowBox[{"-", "b"}], ",", 
        RowBox[{"-", "c"}]}], "]"}], ",", "\"\<ScalarFieldComovingGauge\>\"", 
      ",", "1"}], "]"}], ",", "h"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\[Chi]\>\"", "\[Equal]", 
  RowBox[{"MyToxPand", "[", 
   RowBox[{
    RowBox[{"\[CurlyPhi]", "[", "]"}], ",", 
    "\"\<ScalarFieldComovingGauge\>\"", ",", "1"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.809001588256193*^9, 3.809001588764868*^9}, {
   3.809001739148564*^9, 3.809001814533961*^9}, {3.8090020287528877`*^9, 
   3.809002037200289*^9}, {3.8090021666073713`*^9, 3.8090021979634953`*^9}, {
   3.8090024577994833`*^9, 3.8090024798983326`*^9}, {3.8090030341333995`*^9, 
   3.8090030674233537`*^9}, 3.809003283632002*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The Splitting of \"\>", "\[InvisibleSpace]", 
   RowBox[{
    StyleBox["\[Epsilon]",
     FontColor->RGBColor[0., 1., 0.]], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]g", 
         StyleBox[GridBox[{
            {"1", " ", " "},
            {" ", "b", "c"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dg[
      xAct`xTensor`LI[1], -$CellContext`b, -$CellContext`c],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       RowBox[{
        StyleBox["(",
         FontColor->RGBColor[1, 0, 0]], 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], 
        StyleBox[")",
         FontColor->RGBColor[1, 0, 0]]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xTensor`Scalar[
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]]],
      Editable->False], "2"]}], 
   "\[InvisibleSpace]", "\<\" +... was performed in \"\>", 
   "\[InvisibleSpace]", "0.1755836`", 
   "\[InvisibleSpace]", "\<\" seconds.\"\>"}],
  SequenceForm["The Splitting of ", xAct`xPand`\[Epsilon] $CellContext`dg[
     xAct`xTensor`LI[1], -$CellContext`b, -$CellContext`c] xAct`xTensor`Scalar[
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]]]^2, " +... was performed in ", 0.1755836, 
   " seconds."],
  Editable->False]], "Print",
 CellChangeTimes->{{3.8090018096589503`*^9, 3.809001815289888*^9}, {
   3.809002170885928*^9, 3.809002199103447*^9}, {3.8090024636118994`*^9, 
   3.8090024807640176`*^9}, 3.8090030682980075`*^9, 3.809049832653005*^9, 
   3.809054777729801*^9, 3.8090604183085284`*^9, 3.8090760365987835`*^9, 
   3.8090784627860374`*^9, 3.8090842086796675`*^9, {3.809086121709725*^9, 
   3.8090861506322784`*^9}, 3.8090880501367064`*^9, 3.8091407808234143`*^9, 
   3.8091466664567614`*^9, 3.8091489116996136`*^9, 3.8091577336335554`*^9, 
   3.8091648380104666`*^9, 3.809167772882174*^9, 3.8091718131117597`*^9, 
   3.8093200924945827`*^9, 3.8093357741390533`*^9, 3.8093415368034344`*^9, 
   3.8093477838075504`*^9, 3.8095723158610787`*^9, 3.809591647555679*^9, 
   3.809592170333468*^9, 3.809592522038416*^9, 3.8095932102958336`*^9, 
   3.809595413437623*^9, 3.8095981760524473`*^9, 3.809615036574436*^9, 
   3.809745671861849*^9, 3.8097507430274453`*^9, 3.8097525707486367`*^9, 
   3.809753081681387*^9, 3.8097631104566593`*^9, 3.8097666226890345`*^9, 
   3.8097720651054573`*^9, 3.8097834440840425`*^9, 3.8097871360260744`*^9, 
   3.8097875287374*^9, 3.809830997662758*^9, 3.809839294688173*^9, 
   3.8098435192015486`*^9, 3.8098443380828805`*^9, 3.8098633947142773`*^9, 
   3.8098673611263566`*^9}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(g\\), \\(bc\\)]\\)\"\>", "\[Equal]", 
  TagBox[GridBox[{
     {"", "n", "h"},
     {"n", 
      RowBox[{
       RowBox[{"-", "1"}], "-", 
       RowBox[{"2", " ", 
        StyleBox["\[Epsilon]",
         FontColor->RGBColor[0., 1., 0.]], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[Phi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]h[],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]],
          Editable->False], ")"}]}]}], 
      RowBox[{
       StyleBox["\[Epsilon]",
        FontColor->RGBColor[0., 1., 0.]], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "c"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["B",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Bsh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`c][
          $CellContext`Bsh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}]},
     {"h", 
      RowBox[{
       StyleBox["\[Epsilon]",
        FontColor->RGBColor[0., 1., 0.]], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "b"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["B",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Bsh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`b][
          $CellContext`Bsh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False], "2"], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {
             OverscriptBox["h", "-"], 
             StyleBox[GridBox[{
                {" ", " "},
                {"b", "c"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`h[-$CellContext`b, -$CellContext`c],
         Editable->False]}], "-", 
       RowBox[{"2", " ", 
        StyleBox["\[Epsilon]",
         FontColor->RGBColor[0., 1., 0.]], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False], "2"], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {
             OverscriptBox["h", "-"], 
             StyleBox[GridBox[{
                {" ", " "},
                {"b", "c"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`h[-$CellContext`b, -$CellContext`c],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[Psi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Psi]h[],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]],
          Editable->False], ")"}]}]}]}
    },
    AutoDelete->False,
    GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"]}]], "Output",
 CellChangeTimes->{{3.809001809758685*^9, 3.8090018153746605`*^9}, {
   3.8090021709706993`*^9, 3.809002199202181*^9}, {3.809002463695674*^9, 
   3.8090024808647466`*^9}, 3.809003068368817*^9, 3.8090498327221265`*^9, 
   3.809054777867469*^9, 3.8090604183691406`*^9, 3.809076036669591*^9, 
   3.809078462840891*^9, 3.809084208817232*^9, {3.809086121777543*^9, 
   3.8090861507140265`*^9}, 3.8090880501995945`*^9, 3.809140780875533*^9, 
   3.809146666519554*^9, 3.8091489117627883`*^9, 3.8091577336901417`*^9, 
   3.8091648380684137`*^9, 3.809167772980832*^9, 3.8091718131775856`*^9, 
   3.8093200925414534`*^9, 3.809335774189946*^9, 3.8093415368462906`*^9, 
   3.8093477838575926`*^9, 3.809572315907939*^9, 3.809591647625682*^9, 
   3.8095921704063563`*^9, 3.809592522111569*^9, 3.809593210367633*^9, 
   3.809595413494956*^9, 3.809598176092546*^9, 3.8096150366056795`*^9, 
   3.8097456718930874`*^9, 3.8097507430821867`*^9, 3.809752570803478*^9, 
   3.8097530817350807`*^9, 3.8097631105201316`*^9, 3.809766622747864*^9, 
   3.809772065181288*^9, 3.8097834441236897`*^9, 3.8097871360921717`*^9, 
   3.809787528788787*^9, 3.809830997726832*^9, 3.80983929475448*^9, 
   3.8098435192600517`*^9, 3.809844338129992*^9, 3.809863394768072*^9, 
   3.8098673611737657`*^9}],

Cell[BoxData[
 TemplateBox[{
  "ToCanonical","noident",
   "\"Unknown expression not canonicalized: \\!\\(\\*RowBox[{\\\"LI\\\", \
\\\"[\\\", \\\"0\\\", \\\"]\\\"}]\\) .\"",2,51,1,16722567384493544385,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.809003068550367*^9, 3.8090498331793785`*^9, 3.8090547781353836`*^9, 
   3.809060418547251*^9, 3.8090760368451176`*^9, 3.809078463031437*^9, 
   3.809084209007717*^9, {3.809086121957136*^9, 3.8090861509154396`*^9}, 
   3.809088050374072*^9, 3.8091407810815487`*^9, 3.809146666691824*^9, 
   3.809148911924102*^9, 3.8091577338436375`*^9, 3.8091648382840805`*^9, 
   3.8091677732762775`*^9, 3.8091718133690724`*^9, 3.809320092744556*^9, 
   3.8093357743552322`*^9, 3.809341536992896*^9, 3.8093477840344877`*^9, 
   3.809572316126607*^9, 3.809591647830458*^9, 3.8095921705964932`*^9, 
   3.809592522281763*^9, 3.809593210527153*^9, 3.8095954136720605`*^9, 
   3.809598176263069*^9, 3.8096150367931666`*^9, 3.8097456721117864`*^9, 
   3.8097507432465096`*^9, 3.8097525709616966`*^9, 3.809753081900196*^9, 
   3.8097631107629013`*^9, 3.8097666229221587`*^9, 3.809772065388482*^9, 
   3.809783444281989*^9, 3.8097871362691736`*^9, 3.809787528965269*^9, 
   3.809830998017828*^9, 3.809839294914886*^9, 3.809843519417584*^9, 
   3.8098443382920074`*^9, 3.809863394937544*^9, 3.8098673613338547`*^9}],

Cell[BoxData[
 TemplateBox[{
  "ToCanonical","noident",
   "\"Unknown expression not canonicalized: \\!\\(\\*RowBox[{\\\"LI\\\", \
\\\"[\\\", \\\"0\\\", \\\"]\\\"}]\\) .\"",2,51,2,16722567384493544385,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.809003068550367*^9, 3.8090498331793785`*^9, 3.8090547781353836`*^9, 
   3.809060418547251*^9, 3.8090760368451176`*^9, 3.809078463031437*^9, 
   3.809084209007717*^9, {3.809086121957136*^9, 3.8090861509154396`*^9}, 
   3.809088050374072*^9, 3.8091407810815487`*^9, 3.809146666691824*^9, 
   3.809148911924102*^9, 3.8091577338436375`*^9, 3.8091648382840805`*^9, 
   3.8091677732762775`*^9, 3.8091718133690724`*^9, 3.809320092744556*^9, 
   3.8093357743552322`*^9, 3.809341536992896*^9, 3.8093477840344877`*^9, 
   3.809572316126607*^9, 3.809591647830458*^9, 3.8095921705964932`*^9, 
   3.809592522281763*^9, 3.809593210527153*^9, 3.8095954136720605`*^9, 
   3.809598176263069*^9, 3.8096150367931666`*^9, 3.8097456721117864`*^9, 
   3.8097507432465096`*^9, 3.8097525709616966`*^9, 3.809753081900196*^9, 
   3.8097631107629013`*^9, 3.8097666229221587`*^9, 3.809772065388482*^9, 
   3.809783444281989*^9, 3.8097871362691736`*^9, 3.809787528965269*^9, 
   3.809830998017828*^9, 3.809839294914886*^9, 3.809843519417584*^9, 
   3.8098443382920074`*^9, 3.809863394937544*^9, 3.8098673613761787`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The Splitting of \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox["\[CurlyPhi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       xAct`xPand`\[CurlyPhi][],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    xAct`xPand`\[CurlyPhi][
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0]],
    Editable->False], "\[InvisibleSpace]", "\<\" +... was performed in \"\>", 
   "\[InvisibleSpace]", "0.0704276`", 
   "\[InvisibleSpace]", "\<\" seconds.\"\>"}],
  SequenceForm["The Splitting of ", 
   xAct`xPand`\[CurlyPhi][
    xAct`xTensor`LI[0], 
    xAct`xTensor`LI[0]], " +... was performed in ", 0.0704276, " seconds."],
  Editable->False]], "Print",
 CellChangeTimes->{{3.8090018096589503`*^9, 3.809001815289888*^9}, {
   3.809002170885928*^9, 3.809002199103447*^9}, {3.8090024636118994`*^9, 
   3.8090024807640176`*^9}, 3.8090030682980075`*^9, 3.809049832653005*^9, 
   3.809054777729801*^9, 3.8090604183085284`*^9, 3.8090760365987835`*^9, 
   3.8090784627860374`*^9, 3.8090842086796675`*^9, {3.809086121709725*^9, 
   3.8090861506322784`*^9}, 3.8090880501367064`*^9, 3.8091407808234143`*^9, 
   3.8091466664567614`*^9, 3.8091489116996136`*^9, 3.8091577336335554`*^9, 
   3.8091648380104666`*^9, 3.809167772882174*^9, 3.8091718131117597`*^9, 
   3.8093200924945827`*^9, 3.8093357741390533`*^9, 3.8093415368034344`*^9, 
   3.8093477838075504`*^9, 3.8095723158610787`*^9, 3.809591647555679*^9, 
   3.809592170333468*^9, 3.809592522038416*^9, 3.8095932102958336`*^9, 
   3.809595413437623*^9, 3.8095981760524473`*^9, 3.809615036574436*^9, 
   3.809745671861849*^9, 3.8097507430274453`*^9, 3.8097525707486367`*^9, 
   3.809753081681387*^9, 3.8097631104566593`*^9, 3.8097666226890345`*^9, 
   3.8097720651054573`*^9, 3.8097834440840425`*^9, 3.8097871360260744`*^9, 
   3.8097875287374*^9, 3.809830997662758*^9, 3.809839294688173*^9, 
   3.8098435192015486`*^9, 3.8098443380828805`*^9, 3.8098633947142773`*^9, 
   3.809867361396488*^9}],

Cell[BoxData[
 RowBox[{"\<\"\[Chi]\"\>", "\[Equal]", 
  InterpretationBox[
   StyleBox[
    OverscriptBox[
     InterpretationBox[
      StyleBox["\[CurlyPhi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xPand`\[CurlyPhi][],
      Editable->False], ""],
    ShowAutoStyles->False,
    AutoSpacing->False],
   xAct`xPand`\[CurlyPhi][
    xAct`xTensor`LI[0], 
    xAct`xTensor`LI[0]],
   Editable->False]}]], "Output",
 CellChangeTimes->{{3.809001809758685*^9, 3.8090018153746605`*^9}, {
   3.8090021709706993`*^9, 3.809002199202181*^9}, {3.809002463695674*^9, 
   3.8090024808647466`*^9}, 3.809003068368817*^9, 3.8090498327221265`*^9, 
   3.809054777867469*^9, 3.8090604183691406`*^9, 3.809076036669591*^9, 
   3.809078462840891*^9, 3.809084208817232*^9, {3.809086121777543*^9, 
   3.8090861507140265`*^9}, 3.8090880501995945`*^9, 3.809140780875533*^9, 
   3.809146666519554*^9, 3.8091489117627883`*^9, 3.8091577336901417`*^9, 
   3.8091648380684137`*^9, 3.809167772980832*^9, 3.8091718131775856`*^9, 
   3.8093200925414534`*^9, 3.809335774189946*^9, 3.8093415368462906`*^9, 
   3.8093477838575926`*^9, 3.809572315907939*^9, 3.809591647625682*^9, 
   3.8095921704063563`*^9, 3.809592522111569*^9, 3.809593210367633*^9, 
   3.809595413494956*^9, 3.809598176092546*^9, 3.8096150366056795`*^9, 
   3.8097456718930874`*^9, 3.8097507430821867`*^9, 3.809752570803478*^9, 
   3.8097530817350807`*^9, 3.8097631105201316`*^9, 3.809766622747864*^9, 
   3.809772065181288*^9, 3.8097834441236897`*^9, 3.8097871360921717`*^9, 
   3.809787528788787*^9, 3.809830997726832*^9, 3.80983929475448*^9, 
   3.8098435192600517`*^9, 3.809844338129992*^9, 3.809863394768072*^9, 
   3.8098673614001436`*^9}]
}, Open  ]],

Cell["\<\
Metric perturbations are of course tied to the matter perturbations via the \
Einstein equation. To see this, we set the matter fluid to be a perfect \
fluid...\
\>", "Text",
 CellChangeTimes->{{3.8090500806015544`*^9, 3.8090501096461964`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"assume", " ", "perfect", " ", "fluid", " ", "matter"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"$Dust", "=", "False"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"IndexSet", "[", 
     RowBox[{
      RowBox[{"TM", "[", 
       RowBox[{"\[Alpha]_", ",", "\[Beta]_"}], "]"}], ",", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"\[Rho]", "[", "u", "]"}], "[", "]"}], "+", 
           RowBox[{"If", "[", 
            RowBox[{"$Dust", ",", "0", ",", 
             RowBox[{
              RowBox[{"P", "[", "u", "]"}], "[", "]"}]}], "]"}]}], ")"}], 
         RowBox[{"u", "[", "\[Alpha]", "]"}], 
         RowBox[{"u", "[", "\[Beta]", "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"If", "[", 
           RowBox[{"$Dust", ",", "0", ",", 
            RowBox[{
             RowBox[{"P", "[", "u", "]"}], "[", "]"}]}], "]"}], ")"}], 
         RowBox[{"g", "[", 
          RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}]}]}], ")"}]}], "]"}], 
    ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", "aesthetics", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PrintAs", "[", "\[Rho]u", "]"}], "^=", "\"\<\[Rho]\>\""}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PrintAs", "[", "Pu", "]"}], "^=", "\"\<P\>\""}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PrintAs", "[", "Vvhu", "]"}], "^=", 
     "\"\<\!\(\*OverscriptBox[\(V\), \(_\)]\)\>\""}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PrintAs", "[", "Vshu", "]"}], "^=", "\"\<V\>\""}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8090501408667974`*^9, 3.809050141884303*^9}, {
  3.809076016548745*^9, 3.8090760240057635`*^9}}],

Cell["The matter SET\[CloseCurlyQuote]s linearized perturbations is given \
by...", "Text",
 CellChangeTimes->{{3.8090501162682533`*^9, 3.8090501377579*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"TMO1", "=", 
    RowBox[{"MyToxPand", "[", 
     RowBox[{
      RowBox[{"TM", "[", 
       RowBox[{
        RowBox[{"-", "b"}], ",", 
        RowBox[{"-", "c"}]}], "]"}], ",", "\"\<ScalarFieldComovingGauge\>\"", 
      ",", "1"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SuperscriptBox[SubscriptBox[\(T\), \(bc\)], \
\((M)\)]\)\>\"", "\[Equal]", 
  RowBox[{"VisualizeTensor", "[", 
   RowBox[{"TMO1", ",", "h"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.809050149339057*^9, 3.809050210831416*^9}, {
  3.8090502431335955`*^9, 3.8090502526423283`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The Splitting of \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"b", "c"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`b, -$CellContext`c],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["P",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Pu[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Pu[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       RowBox[{
        StyleBox["(",
         FontColor->RGBColor[1, 0, 0]], 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], 
        StyleBox[")",
         FontColor->RGBColor[1, 0, 0]]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xTensor`Scalar[
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]]],
      Editable->False], "2"]}], 
   "\[InvisibleSpace]", "\<\" +... was performed in \"\>", 
   "\[InvisibleSpace]", "0.5650819`", 
   "\[InvisibleSpace]", "\<\" seconds.\"\>"}],
  SequenceForm[
  "The Splitting of ", $CellContext`g[-$CellContext`b, -$CellContext`c] \
$CellContext`Pu[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0]] xAct`xTensor`Scalar[
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]]]^2, " +... was performed in ", 0.5650819, 
   " seconds."],
  Editable->False]], "Print",
 CellChangeTimes->{{3.8090502203460903`*^9, 3.8090502541409264`*^9}, 
   3.8090548403148804`*^9, 3.809060430444855*^9, 3.80907604773146*^9, 
   3.809078474587468*^9, 3.8090842247664857`*^9, 3.8090861338093586`*^9, 
   3.809086170121122*^9, 3.8090880621216464`*^9, 3.809140782005935*^9, 
   3.8091414967558727`*^9, 3.809141607030174*^9, 3.8091466675706315`*^9, 
   3.8091489127560496`*^9, 3.809157734694581*^9, 3.809164839521454*^9, 
   3.809167774732952*^9, 3.80917181432189*^9, 3.809320093557227*^9, 
   3.809335775260855*^9, 3.8093415378420677`*^9, 3.8093477849030237`*^9, 
   3.8095723169523277`*^9, 3.8095916486988244`*^9, 3.80959217591294*^9, 
   3.8095925231173906`*^9, 3.809593211425152*^9, 3.809595414565771*^9, 
   3.8095981771896048`*^9, 3.8096150376215124`*^9, 3.809745672909069*^9, 
   3.809750744300085*^9, 3.80975257182962*^9, 3.809753082819126*^9, 
   3.8097631120988493`*^9, 3.8097666238066444`*^9, 3.8097720663666663`*^9, 
   3.8097834452134047`*^9, 3.8097871371483355`*^9, 3.8097875298150787`*^9, 
   3.809830999159005*^9, 3.8098392956797085`*^9, 3.809843520302083*^9, 
   3.809844339181048*^9, 3.8098633958216915`*^9, 3.809867362181674*^9}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SuperscriptBox[SubscriptBox[\\(T\\), \\(bc\\)], \\((M)\
\\)]\\)\"\>", "\[Equal]", 
  TagBox[GridBox[{
     {"", "n", "h"},
     {"n", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Rho]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Rho]u[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Rho]u[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "+", 
       RowBox[{
        StyleBox["\[Epsilon]",
         FontColor->RGBColor[0., 1., 0.]], " ", 
        RowBox[{"(", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            RowBox[{
             OverscriptBox["\[Null]", 
              StyleBox[
               RowBox[{"(", "1", ")"}],
               FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[Rho]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Rho]u[],
               Editable->False], ""]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Rho]u[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]],
           Editable->False], "+", 
          RowBox[{"2", " ", 
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[Rho]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Rho]u[],
               Editable->False], ""],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Rho]u[
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[0]],
            Editable->False], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               OverscriptBox["\[Null]", 
                StyleBox[
                 RowBox[{"(", "1", ")"}],
                 FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
               OverscriptBox[
                InterpretationBox[
                 StyleBox["\[Phi]",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`\[Phi]h[],
                 Editable->False], ""]}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[
              xAct`xTensor`LI[1], 
              xAct`xTensor`LI[0]],
             Editable->False], ")"}]}]}], ")"}]}]}], 
      RowBox[{
       StyleBox["\[Epsilon]",
        FontColor->RGBColor[0., 1., 0.]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["a",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`ah[],
               Editable->False], ""],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[0]],
            Editable->False]}], " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[Rho]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Rho]u[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Rho]u[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox[
               OverscriptBox["D", "_"], "c"], 
              OverscriptBox["\[Null]", 
               StyleBox[
                RowBox[{"(", "1", ")"}],
                FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
              OverscriptBox[
               InterpretationBox[
                StyleBox["B",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`Bsh[],
                Editable->False], ""]}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`cd[-$CellContext`c][
             $CellContext`Bsh[
              xAct`xTensor`LI[1], 
              xAct`xTensor`LI[0]]],
            Editable->False], ")"}]}], "-", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["a",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`ah[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["P",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Pu[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Pu[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox[
               OverscriptBox["D", "_"], "c"], 
              OverscriptBox["\[Null]", 
               StyleBox[
                RowBox[{"(", "1", ")"}],
                FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
              OverscriptBox[
               InterpretationBox[
                StyleBox["V",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`Vshu[],
                Editable->False], ""]}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`cd[-$CellContext`c][
             $CellContext`Vshu[
              xAct`xTensor`LI[1], 
              xAct`xTensor`LI[0]]],
            Editable->False], ")"}]}], "-", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["a",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`ah[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[Rho]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Rho]u[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Rho]u[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox[
               OverscriptBox["D", "_"], "c"], 
              OverscriptBox["\[Null]", 
               StyleBox[
                RowBox[{"(", "1", ")"}],
                FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
              OverscriptBox[
               InterpretationBox[
                StyleBox["V",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`Vshu[],
                Editable->False], ""]}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`cd[-$CellContext`c][
             $CellContext`Vshu[
              xAct`xTensor`LI[1], 
              xAct`xTensor`LI[0]]],
            Editable->False], ")"}]}]}], ")"}]}]},
     {"h", 
      RowBox[{
       StyleBox["\[Epsilon]",
        FontColor->RGBColor[0., 1., 0.]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["a",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`ah[],
               Editable->False], ""],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[0]],
            Editable->False]}], " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[Rho]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Rho]u[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Rho]u[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox[
               OverscriptBox["D", "_"], "b"], 
              OverscriptBox["\[Null]", 
               StyleBox[
                RowBox[{"(", "1", ")"}],
                FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
              OverscriptBox[
               InterpretationBox[
                StyleBox["B",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`Bsh[],
                Editable->False], ""]}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`cd[-$CellContext`b][
             $CellContext`Bsh[
              xAct`xTensor`LI[1], 
              xAct`xTensor`LI[0]]],
            Editable->False], ")"}]}], "-", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["a",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`ah[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["P",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Pu[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Pu[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox[
               OverscriptBox["D", "_"], "b"], 
              OverscriptBox["\[Null]", 
               StyleBox[
                RowBox[{"(", "1", ")"}],
                FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
              OverscriptBox[
               InterpretationBox[
                StyleBox["V",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`Vshu[],
                Editable->False], ""]}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`cd[-$CellContext`b][
             $CellContext`Vshu[
              xAct`xTensor`LI[1], 
              xAct`xTensor`LI[0]]],
            Editable->False], ")"}]}], "-", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["a",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`ah[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[Rho]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Rho]u[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Rho]u[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox[
               OverscriptBox["D", "_"], "b"], 
              OverscriptBox["\[Null]", 
               StyleBox[
                RowBox[{"(", "1", ")"}],
                FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
              OverscriptBox[
               InterpretationBox[
                StyleBox["V",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`Vshu[],
                Editable->False], ""]}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`cd[-$CellContext`b][
             $CellContext`Vshu[
              xAct`xTensor`LI[1], 
              xAct`xTensor`LI[0]]],
            Editable->False], ")"}]}]}], ")"}]}], 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False], "2"], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {
             OverscriptBox["h", "-"], 
             StyleBox[GridBox[{
                {" ", " "},
                {"b", "c"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`h[-$CellContext`b, -$CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["P",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Pu[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Pu[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False]}], "+", 
       RowBox[{
        StyleBox["\[Epsilon]",
         FontColor->RGBColor[0., 1., 0.]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              OverscriptBox[
               InterpretationBox[
                StyleBox["a",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`ah[],
                Editable->False], ""],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[
              xAct`xTensor`LI[0], 
              xAct`xTensor`LI[0]],
             Editable->False], "2"], " ", 
           InterpretationBox[
            StyleBox[GridBox[{
               {
                OverscriptBox["h", "-"], 
                StyleBox[GridBox[{
                   {" ", " "},
                   {"b", "c"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`h[-$CellContext`b, -$CellContext`c],
            Editable->False], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               OverscriptBox["\[Null]", 
                StyleBox[
                 RowBox[{"(", "1", ")"}],
                 FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
               OverscriptBox[
                InterpretationBox[
                 StyleBox["P",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`Pu[],
                 Editable->False], ""]}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Pu[
              xAct`xTensor`LI[1], 
              xAct`xTensor`LI[0]],
             Editable->False], ")"}]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              OverscriptBox[
               InterpretationBox[
                StyleBox["a",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`ah[],
                Editable->False], ""],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[
              xAct`xTensor`LI[0], 
              xAct`xTensor`LI[0]],
             Editable->False], "2"], " ", 
           InterpretationBox[
            StyleBox[GridBox[{
               {
                OverscriptBox["h", "-"], 
                StyleBox[GridBox[{
                   {" ", " "},
                   {"b", "c"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`h[-$CellContext`b, -$CellContext`c],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["P",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Pu[],
               Editable->False], ""],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Pu[
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[0]],
            Editable->False], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               OverscriptBox["\[Null]", 
                StyleBox[
                 RowBox[{"(", "1", ")"}],
                 FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
               OverscriptBox[
                InterpretationBox[
                 StyleBox["\[Psi]",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`\[Psi]h[],
                 Editable->False], ""]}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[
              xAct`xTensor`LI[1], 
              xAct`xTensor`LI[0]],
             Editable->False], ")"}]}]}], ")"}]}]}]}
    },
    AutoDelete->False,
    GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"]}]], "Output",
 CellChangeTimes->{{3.8090502205037384`*^9, 3.8090502542917647`*^9}, 
   3.8090548404941015`*^9, 3.809060430571891*^9, 3.809076047885964*^9, 
   3.809078474824833*^9, 3.80908422489419*^9, 3.8090861339320307`*^9, 
   3.809086170276894*^9, 3.8090880622483077`*^9, 3.809140782156752*^9, 
   3.8091414969704037`*^9, 3.809141607175949*^9, 3.809146667700205*^9, 
   3.8091489129065228`*^9, 3.8091577348164935`*^9, 3.8091648396623445`*^9, 
   3.809167774917405*^9, 3.8091718144525404`*^9, 3.809320093650954*^9, 
   3.8093357753702326`*^9, 3.809341537941017*^9, 3.809347785004532*^9, 
   3.8095723170617075`*^9, 3.8095916488199043`*^9, 3.8095921760752*^9, 
   3.8095925232449956`*^9, 3.809593211556579*^9, 3.8095954146957073`*^9, 
   3.809598177297328*^9, 3.8096150377152348`*^9, 3.8097456730184174`*^9, 
   3.809750744419433*^9, 3.8097525719514894`*^9, 3.8097530829371786`*^9, 
   3.8097631122531815`*^9, 3.809766623932806*^9, 3.809772066484711*^9, 
   3.8097834453125014`*^9, 3.8097871372955427`*^9, 3.809787529946123*^9, 
   3.809830999236024*^9, 3.809839295796392*^9, 3.8098435204298716`*^9, 
   3.8098443392801824`*^9, 3.809863395924249*^9, 3.8098673623048973`*^9}]
}, Open  ]],

Cell["\<\
We can assume that matter perturbations to vanish (for simplicity) using the \
following rule...\
\>", "Text",
 CellChangeTimes->{{3.8091408022602615`*^9, 3.8091408256640377`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"NoMat", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Rho]u", "[", 
       RowBox[{
        RowBox[{"LI", "[", "1", "]"}], ",", 
        RowBox[{"LI", "[", "x_", "]"}]}], "]"}], "\[RuleDelayed]", "0"}], ",", 
     RowBox[{
      RowBox[{"Pu", "[", 
       RowBox[{
        RowBox[{"LI", "[", "1", "]"}], ",", 
        RowBox[{"LI", "[", "x_", "]"}]}], "]"}], "\[RuleDelayed]", "0"}], ",", 
     RowBox[{
      RowBox[{"Vvhu", "[", 
       RowBox[{
        RowBox[{"LI", "[", "1", "]"}], ",", 
        RowBox[{"LI", "[", "x_", "]"}], ",", "y_"}], "]"}], "\[RuleDelayed]", 
      "0"}], ",", 
     RowBox[{
      RowBox[{"Vshu", "[", 
       RowBox[{
        RowBox[{"LI", "[", "1", "]"}], ",", 
        RowBox[{"LI", "[", "x_", "]"}]}], "]"}], "\[RuleDelayed]", "0"}]}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8091408271021547`*^9, 3.809140881850674*^9}, {
  3.8091409223395576`*^9, 3.8091409539060335`*^9}, {3.809141442426152*^9, 
  3.809141447252304*^9}, {3.809141524523992*^9, 3.809141548479573*^9}, {
  3.8091415803303843`*^9, 3.809141596709383*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Einstein equation", "Subsubsection",
 CellChangeTimes->{{3.8090499295055723`*^9, 3.809049960429556*^9}, {
  3.8090503490380135`*^9, 3.809050351123428*^9}}],

Cell["\<\
Before we start, we introduce the following simplifying rules...\
\>", "Text",
 CellChangeTimes->{{3.809745697338831*^9, 3.809745709123094*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Cosmic\[CurlyPhi]", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"cd", "[", "x_", "]"}], "[", 
      RowBox[{"Scalar", "[", 
       RowBox[{"\[CurlyPhi]", "[", 
        RowBox[{
         RowBox[{"LI", "[", "y_", "]"}], ",", 
         RowBox[{"LI", "[", "z_", "]"}]}], "]"}], "]"}], "]"}], 
     "\[RuleDelayed]", "0"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CollectXh", "[", "expr_", "]"}], ":=", 
    RowBox[{"Collect", "[", 
     RowBox[{"expr", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[Phi]h", "[", 
         RowBox[{
          RowBox[{"LI", "[", "1", "]"}], ",", "_"}], "]"}], ",", 
        RowBox[{
         RowBox[{"cd", "[", 
          RowBox[{"-", "x_"}], "]"}], "[", 
         RowBox[{
          RowBox[{"cd", "[", "x_", "]"}], "[", 
          RowBox[{"\[Phi]h", "[", 
           RowBox[{
            RowBox[{"LI", "[", "1", "]"}], ",", "_"}], "]"}], "]"}], "]"}], 
        ",", 
        RowBox[{
         RowBox[{"cd", "[", 
          RowBox[{"-", "x_"}], "]"}], "[", 
         RowBox[{
          RowBox[{"cd", "[", "x_", "]"}], "[", 
          RowBox[{"Bsh", "[", 
           RowBox[{
            RowBox[{"LI", "[", "1", "]"}], ",", "_"}], "]"}], "]"}], "]"}], 
        ",", 
        RowBox[{"\[Psi]h", "[", 
         RowBox[{
          RowBox[{"LI", "[", "1", "]"}], ",", "_"}], "]"}], ",", 
        RowBox[{
         RowBox[{"cd", "[", 
          RowBox[{"-", "x_"}], "]"}], "[", 
         RowBox[{
          RowBox[{"cd", "[", "x_", "]"}], "[", 
          RowBox[{"\[Psi]h", "[", 
           RowBox[{
            RowBox[{"LI", "[", "1", "]"}], ",", "_"}], "]"}], "]"}], "]"}]}], 
       "}"}], ",", "Simplify"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"simpV", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"V", "[", 
       RowBox[{"u_", ",", "v_"}], "]"}], "\[RuleDelayed]", "V"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", 
         RowBox[{"x_", ",", "y_"}], "]"}], "[", "V", "]"}], "[", 
       RowBox[{"u_", ",", "v_"}], "]"}], "\[RuleDelayed]", 
      RowBox[{
       RowBox[{"Derivative", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "[", "V", "]"}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"simpG", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"G", "[", 
       RowBox[{"u_", ",", "v_"}], "]"}], "\[RuleDelayed]", "G"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", 
         RowBox[{"x_", ",", "y_"}], "]"}], "[", "G", "]"}], "[", 
       RowBox[{"u_", ",", "v_"}], "]"}], "\[RuleDelayed]", 
      RowBox[{
       RowBox[{"Derivative", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "[", "G", "]"}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"simp", "=", 
    RowBox[{"Union", "[", 
     RowBox[{"simpV", ",", "simpG"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ScalarHa", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Scalar", "[", 
       RowBox[{"Hh", "[", 
        RowBox[{"x_", ",", "y_"}], "]"}], "]"}], "\[RuleDelayed]", 
      RowBox[{"Hh", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"Scalar", "[", 
       RowBox[{"ah", "[", 
        RowBox[{"x_", ",", "y_"}], "]"}], "]"}], "\[RuleDelayed]", 
      RowBox[{"ah", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.809745892742982*^9, 3.8097459302075405`*^9}, {
  3.8097460900218306`*^9, 3.8097460904130616`*^9}, {3.80974703648549*^9, 
  3.8097470502874546`*^9}, {3.809747213135512*^9, 3.8097472154476852`*^9}, {
  3.8097478396394787`*^9, 3.809747912895046*^9}, {3.809750207869665*^9, 
  3.809750254855452*^9}}],

Cell["The linearized Einstein equation is given by...", "Text",
 CellChangeTimes->{{3.809049961838655*^9, 3.809049976630645*^9}, {
  3.8090503635129356`*^9, 3.809050367879915*^9}, {3.8090504440224543`*^9, 
  3.809050452191159*^9}, {3.809745901981021*^9, 3.8097459120928235`*^9}, {
  3.809745947619691*^9, 3.809745952339695*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"EElhs", "=", 
   RowBox[{
    RowBox[{"MyToxPand", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"EE", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "/.", 
       RowBox[{
        RowBox[{"\[Chi]", "[", "]"}], "\[Rule]", 
        RowBox[{"\[CurlyPhi]", "[", "]"}]}]}], ",", 
      "\"\<ScalarFieldComovingGauge\>\"", ",", "1"}], "]"}], "//", 
    "ToCanonical"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EErhs", "=", 
   RowBox[{
    RowBox[{"MyToxPand", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"EE", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "/.", 
       RowBox[{
        RowBox[{"\[Chi]", "[", "]"}], "\[Rule]", 
        RowBox[{"\[CurlyPhi]", "[", "]"}]}]}], ",", 
      "\"\<ScalarFieldComovingGauge\>\"", ",", "1"}], "]"}], "//", 
    "ToCanonical"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.8090499785477257`*^9, 3.809049987986545*^9}, {
  3.80905004099387*^9, 3.8090500729354935`*^9}, {3.8090502758037047`*^9, 
  3.8090502787293077`*^9}, {3.8090503422269316`*^9, 3.80905049407967*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The Splitting of \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"R", 
         StyleBox[GridBox[{
            {" ", " "},
            {"b", "c"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`RicciCD[-$CellContext`b, -$CellContext`c],
     Editable->False]}], 
   "\[InvisibleSpace]", "\<\" +... was performed in \"\>", 
   "\[InvisibleSpace]", "10.1952926`", 
   "\[InvisibleSpace]", "\<\" seconds.\"\>"}],
  SequenceForm[
  "The Splitting of ", $CellContext`\[Kappa] \
$CellContext`RicciCD[-$CellContext`b, -$CellContext`c], 
   " +... was performed in ", 10.1952926, " seconds."],
  Editable->False]], "Print",
 CellChangeTimes->{{3.8090504248217993`*^9, 3.8090504336309495`*^9}, 
   3.809050517320629*^9, 3.8090548740658846`*^9, 3.809060445132214*^9, 
   3.8090760831083665`*^9, 3.8090784968050385`*^9, 3.809084245012328*^9, 
   3.809086148460005*^9, 3.8090861977767067`*^9, 3.809088086935272*^9, 
   3.809141636404343*^9, 3.809146696200091*^9, 3.8091489380499525`*^9, 
   3.809157753929881*^9, 3.809164862623271*^9, 3.8091677968725834`*^9, 
   3.8091718376127214`*^9, 3.8093201133134594`*^9, 3.8093357925749907`*^9, 
   3.809341557051388*^9, 3.809347803984537*^9, 3.8095723733003016`*^9, 
   3.809592201375599*^9, 3.8095925776866007`*^9, 3.8095932292651596`*^9, 
   3.8095954323515434`*^9, 3.8096150597687793`*^9, 3.80974596792234*^9, 
   3.809750762179494*^9, 3.8097728455689096`*^9, 3.8097871589388328`*^9, 
   3.809787542810892*^9, 3.809831012983491*^9, 3.8098393077430367`*^9, 
   3.809843532321418*^9, 3.8098443516052656`*^9, 3.80986340833774*^9, 
   3.8098673745382104`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The Splitting of \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {" ", " "},
            {"b", "c"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`b, -$CellContext`c],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["P",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Pu[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Pu[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       RowBox[{
        StyleBox["(",
         FontColor->RGBColor[1, 0, 0]], 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], 
        StyleBox[")",
         FontColor->RGBColor[1, 0, 0]]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xTensor`Scalar[
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]]],
      Editable->False], "2"]}], 
   "\[InvisibleSpace]", "\<\" +... was performed in \"\>", 
   "\[InvisibleSpace]", "0.5690118`", 
   "\[InvisibleSpace]", "\<\" seconds.\"\>"}],
  SequenceForm[
  "The Splitting of ", 
   Rational[1, 
     2] $CellContext`g[-$CellContext`b, -$CellContext`c] $CellContext`Pu[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0]] xAct`xTensor`Scalar[
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]]]^2, " +... was performed in ", 0.5690118, 
   " seconds."],
  Editable->False]], "Print",
 CellChangeTimes->{{3.8090504248217993`*^9, 3.8090504336309495`*^9}, 
   3.809050517320629*^9, 3.8090548740658846`*^9, 3.809060445132214*^9, 
   3.8090760831083665`*^9, 3.8090784968050385`*^9, 3.809084245012328*^9, 
   3.809086148460005*^9, 3.8090861977767067`*^9, 3.809088086935272*^9, 
   3.809141636404343*^9, 3.809146696200091*^9, 3.8091489380499525`*^9, 
   3.809157753929881*^9, 3.809164862623271*^9, 3.8091677968725834`*^9, 
   3.8091718376127214`*^9, 3.8093201133134594`*^9, 3.8093357925749907`*^9, 
   3.809341557051388*^9, 3.809347803984537*^9, 3.8095723733003016`*^9, 
   3.809592201375599*^9, 3.8095925776866007`*^9, 3.8095932292651596`*^9, 
   3.8095954323515434`*^9, 3.8096150597687793`*^9, 3.80974596792234*^9, 
   3.809750762179494*^9, 3.8097728455689096`*^9, 3.8097871589388328`*^9, 
   3.809787542810892*^9, 3.809831012983491*^9, 3.8098393077430367`*^9, 
   3.809843532321418*^9, 3.8098443516052656`*^9, 3.80986340833774*^9, 
   3.809867375776477*^9}]
}, Open  ]]
}, Open  ]],

Cell["\<\
We extract the components of the Einstein equation beginning with the \
zeroth-order (a.k.a. Friedmann equations)...\
\>", "Text",
 CellChangeTimes->{{3.8090505319881516`*^9, 3.8090505661567354`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"EE0lhs", "=", 
   RowBox[{"ExtractOrder", "[", 
    RowBox[{"EElhs", ",", "0"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"EE0rhs", "=", 
    RowBox[{"ExtractOrder", "[", 
     RowBox[{"EErhs", ",", "0"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FE1", "=", 
   RowBox[{
    RowBox[{"ExtractComponents", "[", 
     RowBox[{
      RowBox[{"EE0lhs", "-", "EE0rhs"}], ",", "h", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Time\>\"", ",", "\"\<Time\>\""}], "}"}]}], "]"}], 
    "\[Equal]", "0"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FE2", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"h", "[", 
          RowBox[{"b", ",", "c"}], "]"}], 
         RowBox[{"ExtractComponents", "[", 
          RowBox[{
           RowBox[{"EE0lhs", "-", "EE0rhs"}], ",", "h", ",", 
           RowBox[{"{", 
            RowBox[{"\"\<Space\>\"", ",", "\"\<Space\>\""}], "}"}]}], "]"}]}],
         "//", "ToCanonical"}], "//", "NoScalar"}], ")"}], "\[Equal]", 
     "0"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"FE1", "/.", "simp"}], "\[IndentingNewLine]", 
 RowBox[{"FE2", "/.", "simp"}]}], "Input",
 CellChangeTimes->{{3.8090505700988817`*^9, 3.8090508165198274`*^9}, {
  3.809746004120426*^9, 3.8097460658741207`*^9}, {3.809746126471141*^9, 
  3.8097461299249997`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox[
    InterpretationBox[
     StyleBox["V",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`V,
     Editable->False], "2"], "+", 
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["H",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Hh[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}], "-", 
   FractionBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[Rho]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Rho]u[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Rho]u[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], "-", 
   RowBox[{
    FractionBox["3", "2"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[CurlyPhi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][],
         Editable->False], "."],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xPand`\[CurlyPhi][
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[1]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[CurlyPhi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][],
         Editable->False], "."],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xPand`\[CurlyPhi][
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[1]],
      Editable->False], "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["V",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`V,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[CurlyPhi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][],
         Editable->False], "."],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xPand`\[CurlyPhi][
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[1]],
      Editable->False], "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None]}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{
  3.8090508175491824`*^9, 3.809054882584309*^9, 3.809060447140249*^9, 
   3.8090760898383627`*^9, 3.8090785056952553`*^9, 3.8090842471197214`*^9, 
   3.809086203160305*^9, 3.809088088767414*^9, 3.809141638268659*^9, 
   3.809146698176319*^9, 3.8091489400425696`*^9, 3.8091577558810945`*^9, 
   3.8091648654949455`*^9, 3.8091677999389105`*^9, 3.809171839934263*^9, 
   3.8093201152507706`*^9, 3.8093357946522474`*^9, 3.8093415590691013`*^9, 
   3.809347808347336*^9, 3.8095723752543964`*^9, 3.8095922051067433`*^9, 
   3.8095925797609367`*^9, 3.809593231424421*^9, 3.8095954344876614`*^9, 
   3.809615061691269*^9, {3.8097460601692605`*^9, 3.8097460664370737`*^9}, 
   3.8097461304722223`*^9, 3.8097507640781884`*^9, 3.809772847569378*^9, 
   3.809787161427353*^9, 3.809787544687709*^9, 3.809831014866585*^9, 
   3.8098393095181446`*^9, 3.809843534070053*^9, 3.809844353421838*^9, 
   3.8098634101799145`*^9, 3.8098673763200226`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["3", "2"]}], " ", 
    InterpretationBox[
     StyleBox["V",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`V,
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}], "-", 
   RowBox[{"9", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["H",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Hh[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}], "-", 
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], "."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False]}], "-", 
   RowBox[{
    FractionBox["3", "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["P",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Pu[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Pu[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False]}], "+", 
   RowBox[{
    FractionBox["3", "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[CurlyPhi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][],
         Editable->False], "."],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xPand`\[CurlyPhi][
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[1]],
      Editable->False], "2"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[CurlyPhi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][],
        Editable->False], ".."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[CurlyPhi][
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[2]],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None]}], "+", 
   RowBox[{
    FractionBox["3", "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[CurlyPhi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][],
         Editable->False], "."],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xPand`\[CurlyPhi][
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[1]],
      Editable->False], "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None]}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{
  3.8090508175491824`*^9, 3.809054882584309*^9, 3.809060447140249*^9, 
   3.8090760898383627`*^9, 3.8090785056952553`*^9, 3.8090842471197214`*^9, 
   3.809086203160305*^9, 3.809088088767414*^9, 3.809141638268659*^9, 
   3.809146698176319*^9, 3.8091489400425696`*^9, 3.8091577558810945`*^9, 
   3.8091648654949455`*^9, 3.8091677999389105`*^9, 3.809171839934263*^9, 
   3.8093201152507706`*^9, 3.8093357946522474`*^9, 3.8093415590691013`*^9, 
   3.809347808347336*^9, 3.8095723752543964`*^9, 3.8095922051067433`*^9, 
   3.8095925797609367`*^9, 3.809593231424421*^9, 3.8095954344876614`*^9, 
   3.809615061691269*^9, {3.8097460601692605`*^9, 3.8097460664370737`*^9}, 
   3.8097461304722223`*^9, 3.8097507640781884`*^9, 3.809772847569378*^9, 
   3.809787161427353*^9, 3.809787544687709*^9, 3.809831014866585*^9, 
   3.8098393095181446`*^9, 3.809843534070053*^9, 3.809844353421838*^9, 
   3.8098634101799145`*^9, 3.8098673763358173`*^9}]
}, Open  ]],

Cell[TextData[{
 "For later, we solve for ",
 Cell[BoxData[
  FormBox["H", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["H", "."], TraditionalForm]]],
 "..."
}], "Text",
 CellChangeTimes->{{3.8090761162437363`*^9, 3.809076160443894*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"let", " ", "Q"}], " ", "=", " ", 
    SuperscriptBox["H", "2"]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"fes", "=", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"FE1", ",", "FE2"}], "}"}], "/.", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Hh", "[", 
            RowBox[{
             RowBox[{"LI", "[", "0", "]"}], ",", 
             RowBox[{"LI", "[", "0", "]"}]}], "]"}], "2"], "\[Rule]", "Q"}]}],
         ",", 
        RowBox[{"{", 
         RowBox[{"Q", ",", 
          RowBox[{"Hh", "[", 
           RowBox[{
            RowBox[{"LI", "[", "0", "]"}], ",", 
            RowBox[{"LI", "[", "1", "]"}]}], "]"}]}], "}"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"fes", "/.", "simp"}]}]}]], "Input",
 CellChangeTimes->{{3.80907616341378*^9, 3.8090762124025397`*^9}, {
  3.8090762424442296`*^9, 3.809076295729703*^9}, {3.809076363995025*^9, 
  3.809076446073715*^9}, {3.809141928604658*^9, 3.80914192944026*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Q", "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox["V",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`V,
        Editable->False], "-", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Rho]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Rho]u[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Rho]u[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "-", 
       RowBox[{"3", " ", 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], "3"], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None]}], "-", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], "2"], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["V",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`V,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None]}], "+", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], "2"], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None]}]}], 
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False]}]]}]}], ",", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], "."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["P",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Pu[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Pu[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "+", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Rho]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Rho]u[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Rho]u[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "+", 
       RowBox[{"3", " ", 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], "3"], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None]}], "-", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], "2"], " ", 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], ".."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[2]],
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None]}], "+", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], "2"], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["V",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`V,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], "2"], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None]}]}], 
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False]}]]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.8090764470649924`*^9, 3.809078511089322*^9, 
  3.8090842473691025`*^9, 3.8090862083603964`*^9, 3.809088088916005*^9, 
  3.8091416384087048`*^9, 3.8091419301024837`*^9, 3.8091466983838873`*^9, 
  3.8091489402440014`*^9, 3.80915775616199*^9, 3.8091648659742327`*^9, 
  3.809167800321801*^9, 3.8091718401432467`*^9, 3.8093201410240655`*^9, 
  3.8093357951463947`*^9, 3.8093415594287195`*^9, 3.8093478089553757`*^9, 
  3.8095723757544394`*^9, 3.8095922123457212`*^9, 3.809592579988577*^9, 
  3.8095932317565684`*^9, 3.8095954348281913`*^9, 3.809615068146905*^9, 
  3.8097461815031786`*^9, 3.8097507641419907`*^9, 3.8097728476853113`*^9, 
  3.809787161483409*^9, 3.8097875447360487`*^9, 3.809831014952487*^9, 
  3.8098393095658484`*^9, 3.8098435341197243`*^9, 3.809844353487504*^9, 
  3.8098634102434716`*^9, 3.809867376376771*^9}]
}, Open  ]],

Cell["\<\
These are the Friedmann equations of KGB.

The first-order perturbations of the Einstein equation provide the \
Hamiltonian and momentum constraints and the dynamical equation for the \
scalar perturbation. Let\[CloseCurlyQuote]s check it out...\
\>", "Text",
 CellChangeTimes->{{3.8090509426916513`*^9, 3.809051001670648*^9}, {
  3.809051149059119*^9, 3.8090511610703993`*^9}, {3.809051262619464*^9, 
  3.8090513281235185`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"EE1lhs", "=", 
   RowBox[{"ExtractOrder", "[", 
    RowBox[{"EElhs", ",", "1"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"EE1rhs", "=", 
    RowBox[{"ExtractOrder", "[", 
     RowBox[{"EErhs", ",", "1"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Hamiltonian", " ", "constraint"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Hconst", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"ExtractComponents", "[", 
          RowBox[{
           RowBox[{"EE1lhs", "-", "EE1rhs"}], ",", "h", ",", 
           RowBox[{"{", 
            RowBox[{"\"\<Time\>\"", ",", "\"\<Time\>\""}], "}"}]}], "]"}], "//",
          "ToCanonical"}], "//", "NoScalar"}], "//", "CollectXh"}], ")"}], 
     "\[Equal]", "0"}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Momentum", " ", "constraint"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Pconst", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"ExtractComponents", "[", 
            RowBox[{
             RowBox[{"EE1lhs", "-", "EE1rhs"}], ",", "h", ",", 
             RowBox[{"{", 
              RowBox[{"\"\<Time\>\"", ",", "\"\<Space\>\""}], "}"}]}], "]"}], 
           "/.", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"Hh", "[", 
              RowBox[{
               RowBox[{"LI", "[", "0", "]"}], ",", 
               RowBox[{"LI", "[", "0", "]"}]}], "]"}], "2"], "\[Rule]", 
            "Q"}]}], "/.", "fes"}], "//", "ToCanonical"}], "//", "NoScalar"}],
        "//", "CollectXh"}], ")"}], "\[Equal]", "0"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Hconst", "/.", "simp"}], "\[IndentingNewLine]", 
 RowBox[{"Pconst", "/.", "simp"}]}], "Input",
 CellChangeTimes->{{3.809051346873829*^9, 3.809051427266699*^9}, 
   3.809085042853823*^9, {3.8091419426576414`*^9, 3.8091419456844907`*^9}, {
   3.8093203173295355`*^9, 3.8093203316131096`*^9}, {3.809746211528309*^9, 
   3.809746266592097*^9}, {3.809746314200079*^9, 3.8097463647470956`*^9}, {
   3.809746615385559*^9, 3.809746615714219*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Rho]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Rho]u[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Rho]u[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}]}], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     InterpretationBox[
      StyleBox["\[Kappa]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Kappa],
      Editable->False], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox[
          OverscriptBox["D", "_"], "d"], 
         SuperscriptBox[
          OverscriptBox["D", "_"], "d"], 
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Psi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Psi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[-$CellContext`d][
        $CellContext`cd[$CellContext`d][
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]]],
       Editable->False], ")"}]}], 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox[
          OverscriptBox["D", "_"], "d"], 
         SuperscriptBox[
          OverscriptBox["D", "_"], "d"], 
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["B",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Bsh[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[-$CellContext`d][
        $CellContext`cd[$CellContext`d][
         $CellContext`Bsh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]]],
       Editable->False], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False]}], "+", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], "3"], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None]}]}], ")"}]}], 
    RowBox[{"2", " ", 
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False]}]], "+", 
   RowBox[{
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "6"}], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}], "+", 
      RowBox[{
       FractionBox["3", "2"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "3"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}]}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox["V",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`V,
        Editable->False]}], "-", 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Rho]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Rho]u[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Rho]u[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"6", " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["H",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Hh[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], "."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[1]],
           Editable->False], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None]}], "-", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["V",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`V,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "+", 
         RowBox[{"3", " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["H",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Hh[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[CurlyPhi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][],
               Editable->False], "."],
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[1]],
            Editable->False], "3"], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None]}], "+", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[CurlyPhi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][],
               Editable->False], "."],
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[1]],
            Editable->False], "2"], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["V",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`V,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None]}], "-", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[CurlyPhi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][],
               Editable->False], "."],
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[1]],
            Editable->False], "2"], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None]}]}], ")"}]}]}], ")"}]}]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{
  3.8090514285701604`*^9, 3.8090548993714466`*^9, 3.809060447662212*^9, 
   3.8090765603519526`*^9, 3.8090785167896476`*^9, 3.8090842521761646`*^9, 
   3.8090850471540785`*^9, 3.809086211617733*^9, 3.8090880896570306`*^9, 
   3.80914163899268*^9, 3.809141946700775*^9, 3.8091466988773117`*^9, 
   3.809148940753137*^9, 3.8091577566840754`*^9, 3.8091648870732007`*^9, 
   3.8091678012235785`*^9, 3.809171840863324*^9, 3.809320156185432*^9, {
   3.8093203195798054`*^9, 3.8093203330358477`*^9}, 3.809335795869598*^9, 
   3.8093415601602416`*^9, 3.8093478101577606`*^9, 3.8095723795250854`*^9, 
   3.8095922443396273`*^9, 3.809592580552537*^9, 3.809593232347807*^9, 
   3.809595435488764*^9, 3.8096150726016836`*^9, 3.8097463658722167`*^9, 
   3.809746621466079*^9, 3.8097470634469414`*^9, 3.8097472299523335`*^9, 
   3.8097507647243223`*^9, 3.8097871621915116`*^9, 3.8097875453163853`*^9, 
   3.8098310156173983`*^9, 3.809839310123982*^9, 3.80984353466212*^9, 
   3.809844354051753*^9, 3.8098634108264413`*^9, 3.809867376931612*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      RowBox[{"(", 
       RowBox[{
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["P",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Pu[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Pu[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "+", 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Rho]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Rho]u[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Rho]u[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "c"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["B",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Bsh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`c][
          $CellContext`Bsh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], "+", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "c"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["V",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Vshu[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`c][
          $CellContext`Vshu[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False]}], ")"}]}], "+", 
     RowBox[{"4", " ", 
      InterpretationBox[
       StyleBox["\[Kappa]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Kappa],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["H",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "c"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Phi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]h[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`c][
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]],
        Editable->False], ")"}]}], "+", 
     RowBox[{"4", " ", 
      InterpretationBox[
       StyleBox["\[Kappa]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Kappa],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "c"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Psi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Psi]h[],
            Editable->False], "."]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`c][
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]]],
        Editable->False], ")"}]}], "-", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], "3"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "c"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Phi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]h[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`c][
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]],
        Editable->False], ")"}], " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None]}]}], ")"}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{
  3.8090514285701604`*^9, 3.8090548993714466`*^9, 3.809060447662212*^9, 
   3.8090765603519526`*^9, 3.8090785167896476`*^9, 3.8090842521761646`*^9, 
   3.8090850471540785`*^9, 3.809086211617733*^9, 3.8090880896570306`*^9, 
   3.80914163899268*^9, 3.809141946700775*^9, 3.8091466988773117`*^9, 
   3.809148940753137*^9, 3.8091577566840754`*^9, 3.8091648870732007`*^9, 
   3.8091678012235785`*^9, 3.809171840863324*^9, 3.809320156185432*^9, {
   3.8093203195798054`*^9, 3.8093203330358477`*^9}, 3.809335795869598*^9, 
   3.8093415601602416`*^9, 3.8093478101577606`*^9, 3.8095723795250854`*^9, 
   3.8095922443396273`*^9, 3.809592580552537*^9, 3.809593232347807*^9, 
   3.809595435488764*^9, 3.8096150726016836`*^9, 3.8097463658722167`*^9, 
   3.809746621466079*^9, 3.8097470634469414`*^9, 3.8097472299523335`*^9, 
   3.8097507647243223`*^9, 3.8097871621915116`*^9, 3.8097875453163853`*^9, 
   3.8098310156173983`*^9, 3.809839310123982*^9, 3.80984353466212*^9, 
   3.809844354051753*^9, 3.8098634108264413`*^9, 3.809867376998184*^9}]
}, Open  ]],

Cell[TextData[{
 "We make use of these to eliminate the nondynamical ",
 Cell[BoxData[
  FormBox["\[Phi]", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox["B", TraditionalForm]]],
 " (which bring no time derivatives). \n\nIt is useful to notice that the \
momentum constraint is just a total derivative (in space). We could therefore \
integrate this by simply removing the covariant derivatives..."
}], "Text",
 CellChangeTimes->{{3.8090515481591797`*^9, 3.8090516571302676`*^9}, {
   3.8090520249654665`*^9, 3.8090520624259095`*^9}, {3.809054923964981*^9, 
   3.809054932916187*^9}, {3.809076970206087*^9, 3.8090770035090547`*^9}, {
   3.80907903587066*^9, 3.8090790602704554`*^9}, {3.8091578152635813`*^9, 
   3.809157821042635*^9}, {3.8091578723181734`*^9, 3.809157979565541*^9}, 
   3.809159337103632*^9, {3.8091648918672905`*^9, 3.809164909926404*^9}, {
   3.8097472470199337`*^9, 3.8097472643844028`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"DefProjectedTensor", "[", 
   RowBox[{
    RowBox[{"J", "[", "]"}], ",", "h"}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Pconst2", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"Pconst", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "-", 
       RowBox[{"J", "[", 
        RowBox[{
         RowBox[{"LI", "[", "0", "]"}], ",", 
         RowBox[{"LI", "[", "0", "]"}]}], "]"}]}], "/.", 
      RowBox[{
       RowBox[{
        RowBox[{"cd", "[", "x_", "]"}], "[", 
        RowBox[{"ph_", "[", 
         RowBox[{
          RowBox[{"LI", "[", "y_", "]"}], ",", 
          RowBox[{"LI", "[", "z_", "]"}]}], "]"}], "]"}], "\[Rule]", 
       RowBox[{"ph", "[", 
        RowBox[{
         RowBox[{"LI", "[", "y", "]"}], ",", 
         RowBox[{"LI", "[", "z", "]"}]}], "]"}]}]}], ")"}], "\[Equal]", 
    "0"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Pconst2", "/.", "simp"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "proof", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"cd", "[", 
        RowBox[{"-", "c"}], "]"}], "[", 
       RowBox[{"Pconst2", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "]"}], "\[Equal]", "0"}], "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"%", "Pconst"}], ",", 
        RowBox[{
         RowBox[{"cd", "[", 
          RowBox[{"-", "c"}], "]"}], "[", 
         RowBox[{"Bsh", "[", 
          RowBox[{
           RowBox[{"LI", "[", "1", "]"}], ",", 
           RowBox[{"LI", "[", "0", "]"}]}], "]"}], "]"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "/.", "Cosmic\[CurlyPhi]"}], ")"}], "//",
   "Simplify"}]}], "Input",
 CellChangeTimes->{{3.8097474792166367`*^9, 3.809747482826411*^9}, {
  3.809747683559243*^9, 3.8097476844348693`*^9}, {3.8097508119269457`*^9, 
  3.809750817726217*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"J", "[", 
    RowBox[{
     RowBox[{"LI", "[", "xAct`xPand`Private`p$35307", "]"}], ",", 
     RowBox[{"LI", "[", "xAct`xPand`Private`q$35307", "]"}]}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`J[
    xAct`xTensor`LI[xAct`xPand`Private`p$35307], 
    xAct`xTensor`LI[xAct`xPand`Private`q$35307]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.809747504442381*^9, 3.809747684793993*^9, 
  3.809750764858349*^9, 3.809750818676944*^9, 3.8097871623188243`*^9, 
  3.809787545427806*^9, 3.809831015752563*^9, 3.8098393102385855`*^9, 
  3.8098435347636623`*^9, 3.809844354156291*^9, 3.809863410935651*^9, 
  3.809867377090337*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["J",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`J[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`J[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           RowBox[{
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["B",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Bsh[],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]],
          Editable->False], "+", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["V",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Vshu[],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Vshu[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]],
          Editable->False]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["P",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Pu[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Pu[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False], "+", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Rho]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Rho]u[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Rho]u[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False]}], ")"}]}], "+", 
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], "+", 
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "."]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], "-", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "3"], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}]}], ")"}]}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.809747504457999*^9, 3.809747684809601*^9, 
  3.809750764862049*^9, 3.8097508186905556`*^9, 3.8097871623218613`*^9, 
  3.809787545442963*^9, 3.8098310157687864`*^9, 3.8098393102539296`*^9, 
  3.8098435347776365`*^9, 3.8098443541696496`*^9, 3.8098634109422827`*^9, 
  3.809867377101017*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.809747504457999*^9, 3.809747684809601*^9, 
  3.809750764862049*^9, 3.8097508186905556`*^9, 3.8097871623218613`*^9, 
  3.809787545442963*^9, 3.8098310157687864`*^9, 3.8098393102539296`*^9, 
  3.8098435347776365`*^9, 3.8098443541696496`*^9, 3.8098634109422827`*^9, 
  3.809867377124817*^9}]
}, Open  ]],

Cell[TextData[{
 "We solve ",
 Cell[BoxData[
  FormBox["B", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " from this and eliminate ",
 Cell[BoxData[
  FormBox["B", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " from the Hamiltonian constraint..."
}], "Text",
 CellChangeTimes->{{3.8097476007217216`*^9, 3.8097476182737865`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"B", " ", "=", " ", 
    RowBox[{"B", "[", 
     RowBox[{"\[Phi]", ",", "\[Psi]"}], "]"}]}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"DefProjectedTensor", "[", 
     RowBox[{
      RowBox[{"A", "[", "]"}], ",", "h"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Bsol", "=", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{"Pconst2", ",", 
        RowBox[{"Bsh", "[", 
         RowBox[{
          RowBox[{"LI", "[", "1", "]"}], ",", 
          RowBox[{"LI", "[", "0", "]"}]}], "]"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Bden", "=", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"Bsh", "[", 
          RowBox[{
           RowBox[{"LI", "[", "1", "]"}], ",", 
           RowBox[{"LI", "[", "0", "]"}]}], "]"}], "/.", "Bsol"}], "//", 
        "Denominator"}], 
       RowBox[{"ah", "[", 
        RowBox[{
         RowBox[{"LI", "[", "0", "]"}], ",", 
         RowBox[{"LI", "[", "0", "]"}]}], "]"}]], "\[Rule]", 
      RowBox[{"A", "[", 
       RowBox[{
        RowBox[{"LI", "[", "0", "]"}], ",", 
        RowBox[{"LI", "[", "0", "]"}]}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dB", "=", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"LieD", "[", 
         RowBox[{"n", "[", "l", "]"}], "]"}], "[", 
        RowBox[{"Bsh", "[", 
         RowBox[{
          RowBox[{"LI", "[", "1", "]"}], ",", 
          RowBox[{"LI", "[", "0", "]"}]}], "]"}], "]"}], 
       RowBox[{"ah", "[", 
        RowBox[{
         RowBox[{"LI", "[", "0", "]"}], ",", 
         RowBox[{"LI", "[", "0", "]"}]}], "]"}]], "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"LieD", "[", 
            RowBox[{"n", "[", "l", "]"}], "]"}], "[", 
           RowBox[{
            RowBox[{"Bsh", "[", 
             RowBox[{
              RowBox[{"LI", "[", "1", "]"}], ",", 
              RowBox[{"LI", "[", "0", "]"}]}], "]"}], "/.", 
            RowBox[{"(", 
             RowBox[{"Bsol", "/.", "Bden"}], ")"}]}], "]"}], 
          RowBox[{"ah", "[", 
           RowBox[{
            RowBox[{"LI", "[", "0", "]"}], ",", 
            RowBox[{"LI", "[", "0", "]"}]}], "]"}]], "//", "Simplification"}],
         "//", "NoScalar"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Bsol", "/.", "Bden"}], "/.", "simp"}]}]}]], "Input",
 CellChangeTimes->{{3.809157987074142*^9, 3.80915824914333*^9}, {
   3.8091583136935368`*^9, 3.809158315922925*^9}, {3.809158407336315*^9, 
   3.809158582684235*^9}, {3.809158658416439*^9, 3.8091586625421534`*^9}, {
   3.8091586940382056`*^9, 3.8091587259890113`*^9}, {3.8091588794626026`*^9, 
   3.8091589282081814`*^9}, {3.8091591181659956`*^9, 
   3.8091591350568476`*^9}, {3.809159232467801*^9, 3.8091593284333315`*^9}, {
   3.8091652504397216`*^9, 3.8091652824927835`*^9}, {3.8091677190305934`*^9, 
   3.809167723571283*^9}, {3.8095932370298457`*^9, 3.8095932407771397`*^9}, 
   3.8097458373973055`*^9, {3.8097472994733853`*^9, 3.809747467321703*^9}, {
   3.809747623150762*^9, 3.8097476232915173`*^9}, {3.8097476709466496`*^9, 
   3.8097476717745504`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"A", "[", 
    RowBox[{
     RowBox[{"LI", "[", "xAct`xPand`Private`p$35340", "]"}], ",", 
     RowBox[{"LI", "[", "xAct`xPand`Private`q$35340", "]"}]}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`A[
    xAct`xTensor`LI[xAct`xPand`Private`p$35340], 
    xAct`xTensor`LI[xAct`xPand`Private`q$35340]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8091649527610364`*^9, 3.809165283159692*^9, 3.809167817819989*^9, 
   3.8091718410129213`*^9, 3.809320354104927*^9, 3.8093357981015263`*^9, 
   3.809341560269085*^9, 3.8093478103703885`*^9, 3.809572424393863*^9, 
   3.809592580705902*^9, 3.8095932418444233`*^9, 3.8095954355823226`*^9, {
   3.8097476623499556`*^9, 3.809747692140356*^9}, 3.809750764945009*^9, 
   3.8097871623882847`*^9, 3.8097875455038652`*^9, 3.80983101584973*^9, 
   3.8098393103184223`*^9, 3.8098435348309298`*^9, 3.8098443542218175`*^9, 
   3.809863411017206*^9, 3.8098673771618605`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    StyleBox[
     RowBox[{
      OverscriptBox["\[Null]", 
       StyleBox[
        RowBox[{"(", "1", ")"}],
        FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
      OverscriptBox[
       InterpretationBox[
        StyleBox["B",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bsh[],
        Editable->False], ""]}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Bsh[
     xAct`xTensor`LI[1], 
     xAct`xTensor`LI[0]],
    Editable->False], "\[Rule]", 
   RowBox[{
    FractionBox["1", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["A",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`A[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`A[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["J",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`J[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`J[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["P",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Pu[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Pu[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["V",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Vshu[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Vshu[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["V",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Vshu[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Vshu[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Rho]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Rho]u[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Rho]u[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}], "-", 
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], "-", 
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "."]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "3"], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8091591360302477`*^9, {3.8091592884553723`*^9, 3.8091593006633987`*^9}, 
   3.809164952842998*^9, 3.809165283154332*^9, 3.809167817902343*^9, 
   3.8091718410617905`*^9, 3.8093203541837077`*^9, 3.809335798206786*^9, 
   3.809341560301518*^9, 3.809347810405983*^9, 3.8095724244409323`*^9, 
   3.8095925807526016`*^9, 3.809593241892104*^9, 3.809595435654121*^9, {
   3.8097476625998964`*^9, 3.809747692280943*^9}, 3.8097507652171807`*^9, 
   3.8097871627527056`*^9, 3.809787545787175*^9, 3.809831016144081*^9, 
   3.8098393105890756`*^9, 3.809843535092943*^9, 3.8098443544941325`*^9, 
   3.8098634112770796`*^9, 3.8098673774181304`*^9}]
}, Open  ]],

Cell["\<\
We substituting this into the Hamiltonian constraint to obtain...\
\>", "Text",
 CellChangeTimes->{{3.809165040648212*^9, 3.8091650511857347`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Hconst\[Phi]\[Psi]", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Hconst", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "-", 
             RowBox[{"Hconst", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "/.", 
            RowBox[{"(", 
             RowBox[{"Bsol", "/.", "Bden"}], ")"}]}], "/.", 
           "Cosmic\[CurlyPhi]"}], "//", "ToCanonical"}], "//", "NoScalar"}], 
        ")"}], "/.", 
       RowBox[{
        RowBox[{"Scalar", "[", 
         RowBox[{"A", "[", 
          RowBox[{"x_", ",", "y_"}], "]"}], "]"}], "\[RuleDelayed]", 
        RowBox[{"A", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}]}], "//", "CollectXh"}], ")"}], 
    "\[Equal]", "0"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Hconst\[Phi]\[Psi]", "/.", "simp"}]}], "Input",
 CellChangeTimes->{{3.8091653298753247`*^9, 3.8091653629347467`*^9}, {
   3.809165394302949*^9, 3.809165441503729*^9}, {3.809165541337634*^9, 
   3.809165553812508*^9}, {3.8091656372633953`*^9, 3.8091657307432466`*^9}, {
   3.8091679005398006`*^9, 3.809167901627582*^9}, {3.809171649521144*^9, 
   3.8091716549710245`*^9}, {3.8095724507461834`*^9, 3.809572455888645*^9}, 
   3.809745877379557*^9, {3.8097478083166604`*^9, 3.809747833496168*^9}, {
   3.8097479766960216`*^9, 3.8097480006886015`*^9}, {3.8097480347607985`*^9, 
   3.8097480370898724`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox[
    RowBox[{"2", " ", 
     InterpretationBox[
      StyleBox["\[Kappa]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Kappa],
      Editable->False], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox[
          OverscriptBox["D", "_"], "d"], 
         SuperscriptBox[
          OverscriptBox["D", "_"], "d"], 
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Psi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Psi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[-$CellContext`d][
        $CellContext`cd[$CellContext`d][
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]]],
       Editable->False], ")"}]}], 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     InterpretationBox[
      StyleBox["\[Kappa]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Kappa],
      Editable->False], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox[
          OverscriptBox["D", "_"], "d"], 
         SuperscriptBox[
          OverscriptBox["D", "_"], "d"], 
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Psi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Psi]h[],
           Editable->False], "."]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[-$CellContext`d][
        $CellContext`cd[$CellContext`d][
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]]]],
       Editable->False], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False]}], "-", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], "3"], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None]}]}], ")"}]}], 
    RowBox[{
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["A",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`A[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`A[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], "2"]}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox[
          OverscriptBox["D", "_"], "d"], 
         SuperscriptBox[
          OverscriptBox["D", "_"], "d"], 
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Phi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[-$CellContext`d][
        $CellContext`cd[$CellContext`d][
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]]],
       Editable->False], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "4"}], " ", 
         InterpretationBox[
          StyleBox["\[Kappa]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Kappa],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["H",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Hh[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False]}], "+", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], "."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[1]],
           Editable->False], "3"], " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None]}]}], ")"}], "2"]}], 
    RowBox[{"2", " ", 
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["A",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`A[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`A[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], "2"]}]], "+", 
   RowBox[{
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "6"}], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}], "+", 
      RowBox[{
       FractionBox["3", "2"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "3"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}]}], ")"}]}], "+", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["A",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`A[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`A[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Rho]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Rho]u[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Rho]u[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]],
        Editable->False], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["P",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Pu[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Pu[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "+", 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Rho]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Rho]u[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Rho]u[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False]}], ")"}], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "d"], 
          SuperscriptBox[
           OverscriptBox["D", "_"], "d"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["V",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Vshu[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`d][
         $CellContext`cd[$CellContext`d][
          $CellContext`Vshu[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]]],
        Editable->False], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"4", " ", 
         InterpretationBox[
          StyleBox["\[Kappa]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Kappa],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["H",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Hh[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False]}], "-", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], "."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[1]],
           Editable->False], "3"], " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None]}]}], ")"}]}]}], 
    RowBox[{"2", " ", 
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["A",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`A[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`A[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False]}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox["V",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`V,
        Editable->False]}], "-", 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Rho]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Rho]u[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Rho]u[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"6", " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["H",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Hh[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], "."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[1]],
           Editable->False], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None]}], "-", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["V",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`V,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "+", 
         RowBox[{"3", " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["H",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Hh[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[CurlyPhi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][],
               Editable->False], "."],
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[1]],
            Editable->False], "3"], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None]}], "+", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[CurlyPhi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][],
               Editable->False], "."],
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[1]],
            Editable->False], "2"], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["V",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`V,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None]}], "-", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[CurlyPhi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][],
               Editable->False], "."],
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[1]],
            Editable->False], "2"], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None]}]}], ")"}]}]}], ")"}]}]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{{3.8091653360762434`*^9, 3.8091653633812428`*^9}, {
   3.809165400242937*^9, 3.8091654421071887`*^9}, {3.8091655434604807`*^9, 
   3.8091655546143675`*^9}, 3.8091656411181564`*^9, 3.8091656736685066`*^9, 
   3.8091657323654227`*^9, {3.809167891436391*^9, 3.8091679062517443`*^9}, 
   3.8091716583224425`*^9, 3.8091718418716063`*^9, 3.8093204293001947`*^9, 
   3.809335803668536*^9, 3.809341560955217*^9, 3.8093478116273108`*^9, 
   3.80957245879554*^9, 3.80959258136333*^9, 3.8095932721815543`*^9, 
   3.809595436329358*^9, {3.809747990512912*^9, 3.8097480015631094`*^9}, 
   3.809748038090315*^9, 3.8097507654776883`*^9, 3.809787163071171*^9, 
   3.809787546045348*^9, 3.8098310164320164`*^9, 3.809839310875183*^9, 
   3.809843535351927*^9, 3.8098443547656584`*^9, 3.8098634115678577`*^9, 
   3.8098673776865845`*^9}]
}, Open  ]],

Cell[TextData[{
 "Let\[CloseCurlyQuote]s check out the ",
 StyleBox["space-space",
  FontSlant->"Italic"],
 " component..."
}], "Text",
 CellChangeTimes->{3.8090770006248426`*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Psi]eq", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"h", "[", 
             RowBox[{"b", ",", "c"}], "]"}], 
            RowBox[{"ExtractComponents", "[", 
             RowBox[{
              RowBox[{"EE1lhs", "-", "EE1rhs"}], ",", "h", ",", 
              RowBox[{"{", 
               RowBox[{"\"\<Space\>\"", ",", "\"\<Space\>\""}], "}"}]}], 
             "]"}]}], "/.", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"Hh", "[", 
              RowBox[{
               RowBox[{"LI", "[", "0", "]"}], ",", 
               RowBox[{"LI", "[", "0", "]"}]}], "]"}], "2"], "\[Rule]", 
            "Q"}]}], "/.", "fes"}], "//", "ToCanonical"}], "//", 
        "ContractMetric"}], "//", "NoScalar"}], "//", "CollectXh"}], ")"}], 
    "\[Equal]", "0"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"\[Psi]eq", "/.", "simp"}]}], "Input",
 CellChangeTimes->{{3.809052101128471*^9, 3.809052117619999*^9}, {
  3.8090522073026104`*^9, 3.8090522103630924`*^9}, {3.8090856779466567`*^9, 
  3.809085686195711*^9}, {3.809142114506631*^9, 3.8091421155304947`*^9}, {
  3.8097480741644616`*^9, 3.809748076649624*^9}, {3.8097481454827104`*^9, 
  3.8097481466085973`*^9}, {3.8097490631678295`*^9, 3.809749094498269*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["3", "2"]}], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["P",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Pu[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Pu[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"18", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ".."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[2]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`cd[$CellContext`b][
        $CellContext`Bsh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`cd[$CellContext`b][
        $CellContext`Bsh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1]]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`cd[$CellContext`b][
        $CellContext`\[Phi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`cd[$CellContext`b][
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "c"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "c"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`c][
       $CellContext`cd[$CellContext`c][
        $CellContext`Bsh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "c"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "c"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`c][
       $CellContext`cd[$CellContext`c][
        $CellContext`Bsh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1]]]],
      Editable->False], ")"}]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "c"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "c"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`c][
       $CellContext`cd[$CellContext`c][
        $CellContext`\[Phi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "c"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "c"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`c][
       $CellContext`cd[$CellContext`c][
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{
    FractionBox["3", "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}], "-", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "3"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}]}], ")"}]}], "-", 
   RowBox[{
    FractionBox["3", "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox["V",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`V,
        Editable->False]}], "+", 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["P",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Pu[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Pu[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["V",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`V,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None]}], "+", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], ".."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[2]],
           Editable->False], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox[
              InterpretationBox[
               StyleBox["G",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`G,
               Editable->False], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None]}], "+", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                OverscriptBox[
                 InterpretationBox[
                  StyleBox["\[CurlyPhi]",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  xAct`xPand`\[CurlyPhi][],
                  Editable->False], "."],
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][
                xAct`xTensor`LI[0], 
                xAct`xTensor`LI[1]],
               Editable->False], "2"], " ", 
             SuperscriptBox[
              InterpretationBox[
               StyleBox["G",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`G,
               Editable->False], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "2"}], ")"}],
               Derivative],
              MultilineFunction->None]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[CurlyPhi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][],
               Editable->False], "."],
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[1]],
            Editable->False], "2"], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None]}]}], ")"}]}]}], ")"}]}]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{
  3.809052211607357*^9, 3.8090549427424555`*^9, 3.809060448258111*^9, 
   3.8090855037311325`*^9, 3.8090856902906246`*^9, 3.8090868325985107`*^9, 
   3.809088092695898*^9, 3.8091416403730745`*^9, {3.8091421105550685`*^9, 
   3.8091421164229555`*^9}, 3.809142745432666*^9, 3.80914670006505*^9, 
   3.8091489419744425`*^9, 3.809157797888695*^9, 3.8091669597609406`*^9, 
   3.8091679574395247`*^9, 3.8091693347583675`*^9, 3.8091718467808356`*^9, 
   3.8091720818016343`*^9, 3.8093207577746468`*^9, 3.8093358224586473`*^9, 
   3.8093415662073298`*^9, 3.809347816328251*^9, 3.809592682480735*^9, 
   3.8095935891937675`*^9, 3.809595437019716*^9, 3.8097481480938244`*^9, {
   3.8097490721695113`*^9, 3.8097490954978943`*^9}, 3.809750766022461*^9, 
   3.8097871635593147`*^9, 3.809787546552605*^9, 3.8098310169502587`*^9, 
   3.8098393113671265`*^9, 3.8098435358217735`*^9, 3.8098443552532945`*^9, 
   3.8098634120595846`*^9, 3.8098673781770678`*^9}]
}, Open  ]],

Cell[TextData[{
 "Eliminating ",
 Cell[BoxData[
  FormBox["B", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " using the momentum constraint, we obtain..."
}], "Text",
 CellChangeTimes->{{3.8091681607197666`*^9, 3.8091681688360076`*^9}, {
  3.809168250199317*^9, 3.809168251568408*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"dd\[Psi]\[Phi]", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"\[Psi]eq", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "/.", 
            RowBox[{"(", 
             RowBox[{"Bsol", "/.", "Bden"}], ")"}]}], "/.", "dB"}], "//", 
          "ToCanonical"}], "//", "NoScalar"}], ")"}], "/.", 
       RowBox[{
        RowBox[{"Scalar", "[", 
         RowBox[{"A", "[", 
          RowBox[{"x_", ",", "y_"}], "]"}], "]"}], "\[RuleDelayed]", 
        RowBox[{"A", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}]}], "//", "CollectXh"}], ")"}], 
    "\[Equal]", "0"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"dd\[Psi]\[Phi]", "/.", "simp"}]}], "Input",
 CellChangeTimes->{{3.8091669950667553`*^9, 3.8091670866643124`*^9}, {
   3.8091672066206274`*^9, 3.809167215236781*^9}, {3.809167983169647*^9, 
   3.80916799044103*^9}, {3.809168171607869*^9, 3.809168193079508*^9}, {
   3.8091697500620356`*^9, 3.8091697625449314`*^9}, {3.8091714800489187`*^9, 
   3.8091715484752083`*^9}, {3.809172102505573*^9, 3.8091721031706705`*^9}, 
   3.8097491307293367`*^9, 3.809749183276529*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"18", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ".."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[2]],
      Editable->False], ")"}]}], "-", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["A",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`A[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`A[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]}]], 
    RowBox[{
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["A",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`A[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`A[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False], "2"], " ", 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["P",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Pu[],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Pu[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]],
          Editable->False], ")"}]}], "-", 
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["A",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`A[],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`A[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], " ", 
        RowBox[{"(", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["P",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Pu[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Pu[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], "+", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[Rho]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Rho]u[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Rho]u[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False]}], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox[
             OverscriptBox["D", "_"], "b"], 
            SuperscriptBox[
             OverscriptBox["D", "_"], "b"], 
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["V",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Vshu[],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`cd[-$CellContext`b][
           $CellContext`cd[$CellContext`b][
            $CellContext`Vshu[
             xAct`xTensor`LI[1], 
             xAct`xTensor`LI[0]]]],
          Editable->False], ")"}]}], "+", 
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["A",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`A[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`A[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["P",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Pu[],
               Editable->False], "."],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Pu[
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[1]],
            Editable->False], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox[
                OverscriptBox["D", "_"], "b"], 
               SuperscriptBox[
                OverscriptBox["D", "_"], "b"], 
               OverscriptBox["\[Null]", 
                StyleBox[
                 RowBox[{"(", "1", ")"}],
                 FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
               OverscriptBox[
                InterpretationBox[
                 StyleBox["V",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`Vshu[],
                 Editable->False], ""]}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`cd[-$CellContext`b][
              $CellContext`cd[$CellContext`b][
               $CellContext`Vshu[
                xAct`xTensor`LI[1], 
                xAct`xTensor`LI[0]]]],
             Editable->False], ")"}]}], "+", 
          RowBox[{"2", " ", 
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["H",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Hh[],
               Editable->False], ""],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[0]],
            Editable->False], " ", 
           RowBox[{"(", 
            RowBox[{
             InterpretationBox[
              StyleBox[
               OverscriptBox[
                InterpretationBox[
                 StyleBox["P",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`Pu[],
                 Editable->False], ""],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Pu[
               xAct`xTensor`LI[0], 
               xAct`xTensor`LI[0]],
              Editable->False], "+", 
             InterpretationBox[
              StyleBox[
               OverscriptBox[
                InterpretationBox[
                 StyleBox["\[Rho]",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`\[Rho]u[],
                 Editable->False], ""],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Rho]u[
               xAct`xTensor`LI[0], 
               xAct`xTensor`LI[0]],
              Editable->False]}], ")"}], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox[
                OverscriptBox["D", "_"], "b"], 
               SuperscriptBox[
                OverscriptBox["D", "_"], "b"], 
               OverscriptBox["\[Null]", 
                StyleBox[
                 RowBox[{"(", "1", ")"}],
                 FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
               OverscriptBox[
                InterpretationBox[
                 StyleBox["V",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`Vshu[],
                 Editable->False], ""]}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`cd[-$CellContext`b][
              $CellContext`cd[$CellContext`b][
               $CellContext`Vshu[
                xAct`xTensor`LI[1], 
                xAct`xTensor`LI[0]]]],
             Editable->False], ")"}]}], "+", 
          RowBox[{
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[Rho]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Rho]u[],
               Editable->False], "."],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Rho]u[
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[1]],
            Editable->False], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox[
                OverscriptBox["D", "_"], "b"], 
               SuperscriptBox[
                OverscriptBox["D", "_"], "b"], 
               OverscriptBox["\[Null]", 
                StyleBox[
                 RowBox[{"(", "1", ")"}],
                 FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
               OverscriptBox[
                InterpretationBox[
                 StyleBox["V",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`Vshu[],
                 Editable->False], ""]}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`cd[-$CellContext`b][
              $CellContext`cd[$CellContext`b][
               $CellContext`Vshu[
                xAct`xTensor`LI[1], 
                xAct`xTensor`LI[0]]]],
             Editable->False], ")"}]}], "+", 
          RowBox[{
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["P",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Pu[],
               Editable->False], ""],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Pu[
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[0]],
            Editable->False], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox[
                OverscriptBox["D", "_"], "b"], 
               SuperscriptBox[
                OverscriptBox["D", "_"], "b"], 
               OverscriptBox["\[Null]", 
                StyleBox[
                 RowBox[{"(", "1", ")"}],
                 FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
               OverscriptBox[
                InterpretationBox[
                 StyleBox["V",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`Vshu[],
                 Editable->False], "."]}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`cd[-$CellContext`b][
              $CellContext`cd[$CellContext`b][
               $CellContext`Vshu[
                xAct`xTensor`LI[1], 
                xAct`xTensor`LI[1]]]],
             Editable->False], ")"}]}], "+", 
          RowBox[{
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[Rho]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Rho]u[],
               Editable->False], ""],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Rho]u[
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[0]],
            Editable->False], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox[
                OverscriptBox["D", "_"], "b"], 
               SuperscriptBox[
                OverscriptBox["D", "_"], "b"], 
               OverscriptBox["\[Null]", 
                StyleBox[
                 RowBox[{"(", "1", ")"}],
                 FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
               OverscriptBox[
                InterpretationBox[
                 StyleBox["V",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`Vshu[],
                 Editable->False], "."]}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`cd[-$CellContext`b][
              $CellContext`cd[$CellContext`b][
               $CellContext`Vshu[
                xAct`xTensor`LI[1], 
                xAct`xTensor`LI[1]]]],
             Editable->False], ")"}]}]}], ")"}]}]}], ")"}]}]}], "-", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`cd[$CellContext`b][
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], "+", 
   FractionBox[
    RowBox[{"8", " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["\[Kappa]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Kappa],
       Editable->False], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["A",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`A[],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`A[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], "-", 
       RowBox[{
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["A",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`A[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`A[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False]}]}], ")"}], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox[
          OverscriptBox["D", "_"], "b"], 
         SuperscriptBox[
          OverscriptBox["D", "_"], "b"], 
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Psi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Psi]h[],
           Editable->False], "."]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[-$CellContext`b][
        $CellContext`cd[$CellContext`b][
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]]]],
       Editable->False], ")"}]}], 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["A",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`A[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`A[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]], "-", 
   FractionBox[
    RowBox[{"8", " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["\[Kappa]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Kappa],
       Editable->False], "2"], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox[
          OverscriptBox["D", "_"], "b"], 
         SuperscriptBox[
          OverscriptBox["D", "_"], "b"], 
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Psi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Psi]h[],
           Editable->False], ".."]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[-$CellContext`b][
        $CellContext`cd[$CellContext`b][
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[2]]]],
       Editable->False], ")"}]}], 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["A",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`A[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`A[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False]], "+", 
   RowBox[{
    FractionBox["3", "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}], "-", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "3"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}]}], ")"}]}], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     InterpretationBox[
      StyleBox["\[Kappa]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Kappa],
      Editable->False], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox[
          OverscriptBox["D", "_"], "b"], 
         SuperscriptBox[
          OverscriptBox["D", "_"], "b"], 
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Phi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]h[],
           Editable->False], "."]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[-$CellContext`b][
        $CellContext`cd[$CellContext`b][
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]]]],
       Editable->False], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False]}], "+", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], "3"], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None]}]}], ")"}]}], 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["A",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`A[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`A[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False]], "-", 
   RowBox[{
    FractionBox["3", "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox["V",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`V,
        Editable->False]}], "+", 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["P",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Pu[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Pu[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["V",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`V,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None]}], "+", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], ".."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[2]],
           Editable->False], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox[
              InterpretationBox[
               StyleBox["G",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`G,
               Editable->False], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None]}], "+", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                OverscriptBox[
                 InterpretationBox[
                  StyleBox["\[CurlyPhi]",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  xAct`xPand`\[CurlyPhi][],
                  Editable->False], "."],
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][
                xAct`xTensor`LI[0], 
                xAct`xTensor`LI[1]],
               Editable->False], "2"], " ", 
             SuperscriptBox[
              InterpretationBox[
               StyleBox["G",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`G,
               Editable->False], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "2"}], ")"}],
               Derivative],
              MultilineFunction->None]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[CurlyPhi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][],
               Editable->False], "."],
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[1]],
            Editable->False], "2"], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None]}]}], ")"}]}]}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["A",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`A[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`A[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], "2"]], 
    RowBox[{"2", " ", 
     InterpretationBox[
      StyleBox["\[Kappa]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Kappa],
      Editable->False], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox[
          OverscriptBox["D", "_"], "b"], 
         SuperscriptBox[
          OverscriptBox["D", "_"], "b"], 
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Phi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[-$CellContext`b][
        $CellContext`cd[$CellContext`b][
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]]],
       Editable->False], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["A",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`A[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`A[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], "+", 
       RowBox[{
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["A",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`A[],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`A[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["H",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Hh[],
               Editable->False], ""],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[0]],
            Editable->False]}], "-", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              OverscriptBox[
               InterpretationBox[
                StyleBox["\[CurlyPhi]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                xAct`xPand`\[CurlyPhi][],
                Editable->False], "."],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][
              xAct`xTensor`LI[0], 
              xAct`xTensor`LI[1]],
             Editable->False], "3"], " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None]}]}], ")"}]}], "+", 
       RowBox[{
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["A",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`A[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`A[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False], " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              OverscriptBox[
               InterpretationBox[
                StyleBox["H",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`Hh[],
                Editable->False], ""],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Hh[
              xAct`xTensor`LI[0], 
              xAct`xTensor`LI[0]],
             Editable->False], "2"]}], "-", 
          RowBox[{"4", " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["H",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Hh[],
               Editable->False], "."],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[1]],
            Editable->False]}], "+", 
          RowBox[{
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["H",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Hh[],
               Editable->False], ""],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[0]],
            Editable->False], " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              OverscriptBox[
               InterpretationBox[
                StyleBox["\[CurlyPhi]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                xAct`xPand`\[CurlyPhi][],
                Editable->False], "."],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][
              xAct`xTensor`LI[0], 
              xAct`xTensor`LI[1]],
             Editable->False], "3"], " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              OverscriptBox[
               InterpretationBox[
                StyleBox["\[CurlyPhi]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                xAct`xPand`\[CurlyPhi][],
                Editable->False], "."],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][
              xAct`xTensor`LI[0], 
              xAct`xTensor`LI[1]],
             Editable->False], "2"], " ", 
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[CurlyPhi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][],
               Editable->False], ".."],
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[2]],
            Editable->False], " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None]}], "+", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              OverscriptBox[
               InterpretationBox[
                StyleBox["\[CurlyPhi]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                xAct`xPand`\[CurlyPhi][],
                Editable->False], "."],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][
              xAct`xTensor`LI[0], 
              xAct`xTensor`LI[1]],
             Editable->False], "4"], " ", 
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[CurlyPhi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][],
               Editable->False], ".."],
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[2]],
            Editable->False], " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None]}], "+", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              OverscriptBox[
               InterpretationBox[
                StyleBox["\[CurlyPhi]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                xAct`xPand`\[CurlyPhi][],
                Editable->False], "."],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][
              xAct`xTensor`LI[0], 
              xAct`xTensor`LI[1]],
             Editable->False], "4"], " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None]}]}], ")"}]}]}], ")"}]}]}]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{{3.8091669968697042`*^9, 3.809167004000622*^9}, {
   3.8091670591697235`*^9, 3.809167088448028*^9}, 3.8091672163541155`*^9, 
   3.8091680018631754`*^9, 3.8091682413663836`*^9, 3.8091693609666023`*^9, 
   3.8091697665898247`*^9, 3.8091715535334063`*^9, 3.809171851652643*^9, 
   3.809172119385667*^9, 3.8093207742327228`*^9, 3.809335831069847*^9, 
   3.8093415743175335`*^9, 3.80934782100653*^9, 3.809592685914879*^9, 
   3.809593602909583*^9, 3.8095954403549075`*^9, 3.8097491906389422`*^9, 
   3.8097507693830414`*^9, 3.8097871670958824`*^9, 3.8097875499373255`*^9, 
   3.8098310203154693`*^9, 3.8098393145374327`*^9, 3.809843538922431*^9, 
   3.8098443584460773`*^9, 3.809863415366724*^9, 3.809867381353734*^9}]
}, Open  ]],

Cell[TextData[{
 "dd\[Psi]\[Phi] and ",
 StyleBox["Hconst",
  FontSlant->"Italic"],
 "\[Phi]\[Psi] are two equations for ",
 Cell[BoxData[
  FormBox["\[Phi]", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " and ",
 Cell[BoxData[
  FormBox["\[Psi]", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " with understanding that ",
 Cell[BoxData[
  FormBox["\[Psi]", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " is the dynamical variable. It should be possible to express this in terms \
of the single dynamical variable ",
 Cell[BoxData[
  FormBox["\[Psi]", TraditionalForm]]],
 " by using the constraints further. However, the dynamics is much simpler to \
understand at the level of the second-order action."
}], "Text",
 CellChangeTimes->{{3.8090549638577576`*^9, 3.809054980095358*^9}, {
  3.8090550164180064`*^9, 3.809055035239771*^9}, {3.809086952816188*^9, 
  3.809086962836561*^9}, {3.8095930606569586`*^9, 3.8095930655003614`*^9}, {
  3.809593612166283*^9, 3.809593678222372*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Scalar field equation", "Subsubsection",
 CellChangeTimes->{{3.8090550550721884`*^9, 3.8090550574653034`*^9}}],

Cell["\<\
Before dealing with the second-order action, we take a short look at the \
scalar field equation. Expanding it...\
\>", "Text",
 CellChangeTimes->{{3.8090550598983545`*^9, 3.8090550784866695`*^9}, {
  3.80905514580734*^9, 3.8090551774739394`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SFEO1", "=", 
   RowBox[{"MyToxPand", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"SFE", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "/.", 
      RowBox[{
       RowBox[{"\[Chi]", "[", "]"}], "\[Rule]", 
       RowBox[{"\[CurlyPhi]", "[", "]"}]}]}], ",", 
     "\"\<ScalarFieldComovingGauge\>\"", ",", "1"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8090551795233946`*^9, 3.80905520938614*^9}, {
  3.8090552575667486`*^9, 3.809055263022693*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The Splitting of \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[Del]", "s$42126"], 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`s$42126][
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SuperscriptBox["\[Del]", "s$42126"], 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[$CellContext`s$42126][
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[Del]", "s$42130"], 
         SuperscriptBox["\[Del]", "s$42130"], 
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`s$42130][
        $CellContext`CD[$CellContext`s$42130][
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]]]],
       Editable->False], " ", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        InterpretationBox[
         StyleBox[
          RowBox[{
           StyleBox["(",
            FontColor->RGBColor[1, 0, 0]], 
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[CurlyPhi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][],
               Editable->False], ""],
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[0]],
            Editable->False], 
           StyleBox[")",
            FontColor->RGBColor[1, 0, 0]]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xTensor`Scalar[
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]]],
         Editable->False], ",", 
        RowBox[{"-", 
         FractionBox[
          InterpretationBox[
           StyleBox[
            RowBox[{
             StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
             RowBox[{
              InterpretationBox[
               StyleBox[GridBox[{
                  {"g", 
                   StyleBox[GridBox[{
                    {" ", " "},
                    {"b", "c"}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                    FontSize->Rational[39, 4]]}
                 },
                 
                 GridBoxAlignment->{
                  "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`g[-$CellContext`b, -$CellContext`c],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "b"], 
                 OverscriptBox[
                  InterpretationBox[
                   StyleBox["\[CurlyPhi]",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                   xAct`xPand`\[CurlyPhi][],
                   Editable->False], ""]}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`b][
                xAct`xPand`\[CurlyPhi][
                 xAct`xTensor`LI[0], 
                 xAct`xTensor`LI[0]]],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["\[Del]", "c"], 
                 OverscriptBox[
                  InterpretationBox[
                   StyleBox["\[CurlyPhi]",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                   xAct`xPand`\[CurlyPhi][],
                   Editable->False], ""]}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[$CellContext`c][
                xAct`xPand`\[CurlyPhi][
                 xAct`xTensor`LI[0], 
                 xAct`xTensor`LI[0]]],
               Editable->False]}], 
             StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           
           xAct`xTensor`Scalar[$CellContext`g[-$CellContext`b, \
-$CellContext`c] $CellContext`CD[$CellContext`b][
              xAct`xPand`\[CurlyPhi][
               xAct`xTensor`LI[0], 
               xAct`xTensor`LI[0]]] $CellContext`CD[$CellContext`c][
              xAct`xPand`\[CurlyPhi][
               xAct`xTensor`LI[0], 
               xAct`xTensor`LI[0]]]],
           Editable->False], 
          RowBox[{"2", " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              RowBox[{
               StyleBox["(",
                FontColor->RGBColor[1, 0, 0]], 
               InterpretationBox[
                StyleBox[
                 OverscriptBox[
                  InterpretationBox[
                   StyleBox["a",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                   $CellContext`ah[],
                   Editable->False], ""],
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`ah[
                 xAct`xTensor`LI[0], 
                 xAct`xTensor`LI[0]],
                Editable->False], 
               StyleBox[")",
                FontColor->RGBColor[1, 0, 0]]}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xTensor`Scalar[
              $CellContext`ah[
               xAct`xTensor`LI[0], 
               xAct`xTensor`LI[0]]],
             Editable->False], "2"]}]]}]}], "]"}]}], 
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        RowBox[{
         StyleBox["(",
          FontColor->RGBColor[1, 0, 0]], 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False], 
         StyleBox[")",
          FontColor->RGBColor[1, 0, 0]]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       xAct`xTensor`Scalar[
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]]],
       Editable->False], "5"]]}], 
   "\[InvisibleSpace]", "\<\" +... was performed in \"\>", 
   "\[InvisibleSpace]", "30.1134126`", 
   "\[InvisibleSpace]", "\<\" seconds.\"\>"}],
  SequenceForm["The Splitting of ", -xAct`xTensor`Scalar[
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]]]^(-5) $CellContext`CD[-$CellContext`s$42126][
     xAct`xPand`\[CurlyPhi][
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]]] $CellContext`CD[$CellContext`s$42126][
     xAct`xPand`\[CurlyPhi][
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]]] $CellContext`CD[-$CellContext`s$42130][
     $CellContext`CD[$CellContext`s$42130][
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]]]] Derivative[0, 1][$CellContext`G][
     xAct`xTensor`Scalar[
      xAct`xPand`\[CurlyPhi][
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]]], Rational[-1, 2] xAct`xTensor`Scalar[
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]]]^(-2) 
     xAct`xTensor`Scalar[$CellContext`g[-$CellContext`b, -$CellContext`c] \
$CellContext`CD[$CellContext`b][
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]]] $CellContext`CD[$CellContext`c][
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]]]]], " +... was performed in ", 30.1134126, 
   " seconds."],
  Editable->False]], "Print",
 CellChangeTimes->{3.809055315604926*^9, 3.809087025863437*^9, 
  3.8095945794862485`*^9, 3.809750921119015*^9, 3.8097873719227276`*^9, 
  3.809787585896823*^9, 3.8098310539338856`*^9, 3.809839348999055*^9, 
  3.8098435729798975`*^9, 3.8098443931362386`*^9, 3.8098634502030764`*^9, 
  3.8098674160694184`*^9}]
}, Open  ]],

Cell["Extracting the background part...", "Text",
 CellChangeTimes->{{3.8090552729656773`*^9, 3.809055277510153*^9}, {
  3.8090553209835424`*^9, 3.8090553219632754`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"SFE0", "=", 
   RowBox[{
    RowBox[{"ExtractOrder", "[", 
     RowBox[{"SFEO1", ",", "0"}], "]"}], "\[Equal]", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"SFE0", "/.", "simp"}]}], "Input",
 CellChangeTimes->{{3.8090553239855022`*^9, 3.80905534583329*^9}, {
  3.8095945833884473`*^9, 3.8095945843931775`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"-", "9"}], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["H",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Hh[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[CurlyPhi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][],
         Editable->False], "."],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xPand`\[CurlyPhi][
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[1]],
      Editable->False], "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None]}], "-", 
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], "."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[CurlyPhi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][],
         Editable->False], "."],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xPand`\[CurlyPhi][
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[1]],
      Editable->False], "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None]}], "-", 
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[CurlyPhi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][],
        Editable->False], "."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[CurlyPhi][
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[CurlyPhi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][],
        Editable->False], ".."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[CurlyPhi][
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[2]],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None]}], "-", 
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[CurlyPhi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][],
        Editable->False], "."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[CurlyPhi][
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["V",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`V,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[CurlyPhi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][],
        Editable->False], ".."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[CurlyPhi][
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[2]],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["V",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`V,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None]}], "-", 
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[CurlyPhi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][],
         Editable->False], "."],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xPand`\[CurlyPhi][
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[1]],
      Editable->False], "3"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[CurlyPhi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][],
        Editable->False], ".."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[CurlyPhi][
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[2]],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None]}], "-", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[CurlyPhi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][],
         Editable->False], "."],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xPand`\[CurlyPhi][
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[1]],
      Editable->False], "2"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[CurlyPhi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][],
        Editable->False], ".."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[CurlyPhi][
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[2]],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["V",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`V,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None]}], "+", 
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[CurlyPhi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][],
        Editable->False], "."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[CurlyPhi][
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None]}], "+", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[CurlyPhi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][],
        Editable->False], ".."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[CurlyPhi][
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[2]],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None]}], "+", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox["V",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`V,
     Editable->False], 
    TagBox[
     RowBox[{"(", 
      RowBox[{"1", ",", "0"}], ")"}],
     Derivative],
    MultilineFunction->None], "-", 
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[CurlyPhi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][],
         Editable->False], "."],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xPand`\[CurlyPhi][
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[1]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None]}], "+", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[CurlyPhi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][],
         Editable->False], "."],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xPand`\[CurlyPhi][
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[1]],
      Editable->False], "2"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[CurlyPhi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][],
        Editable->False], ".."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[CurlyPhi][
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[2]],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None]}], "-", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[CurlyPhi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][],
         Editable->False], "."],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xPand`\[CurlyPhi][
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[1]],
      Editable->False], "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["V",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`V,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None]}], "+", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[CurlyPhi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][],
         Editable->False], "."],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xPand`\[CurlyPhi][
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[1]],
      Editable->False], "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None]}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.8090553463569107`*^9, 3.8090870431833773`*^9, 
  3.8095945852324505`*^9, 3.8097510053792596`*^9, 3.8097873724422307`*^9, 
  3.809787586312873*^9, 3.8098310543132358`*^9, 3.8098393494060655`*^9, 
  3.8098435733790236`*^9, 3.809844393531973*^9, 3.8098634506061354`*^9, 
  3.80986741646786*^9}]
}, Open  ]],

Cell["The linearized part is...", "Text",
 CellChangeTimes->{{3.80905542674015*^9, 3.809055446414049*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"SFE1", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"ExtractOrder", "[", 
           RowBox[{"SFEO1", ",", "1"}], "]"}], "/.", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"Hh", "[", 
             RowBox[{
              RowBox[{"LI", "[", "0", "]"}], ",", 
              RowBox[{"LI", "[", "0", "]"}]}], "]"}], "2"], "\[Rule]", 
           "Q"}]}], "/.", "fes"}], "//", "Simplification"}], "//", 
       "NoScalar"}], "//", "CollectXh"}], ")"}], "\[Equal]", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"SFE1", "/.", "simp"}]}], "Input",
 CellChangeTimes->{{3.8090554516700473`*^9, 3.8090554552521095`*^9}, {
  3.80908708299389*^9, 3.8090871198163996`*^9}, {3.809087149906087*^9, 
  3.809087152430193*^9}, {3.809594591236611*^9, 3.8095946079145155`*^9}, {
  3.809751013021001*^9, 3.809751019650914*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"3", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[CurlyPhi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][],
         Editable->False], "."],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xPand`\[CurlyPhi][
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[1]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ".."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[2]],
      Editable->False], ")"}], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None]}], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[CurlyPhi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][],
          Editable->False], "."],
        ShowAutoStyles->False,
        AutoSpacing->False],
       xAct`xPand`\[CurlyPhi][
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[1]],
       Editable->False], "2"], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox[
          OverscriptBox["D", "_"], "b"], 
         SuperscriptBox[
          OverscriptBox["D", "_"], "b"], 
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["B",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Bsh[],
           Editable->False], "."]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[-$CellContext`b][
        $CellContext`cd[$CellContext`b][
         $CellContext`Bsh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]]]],
       Editable->False], ")"}], " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None]}], 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[CurlyPhi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][],
          Editable->False], "."],
        ShowAutoStyles->False,
        AutoSpacing->False],
       xAct`xPand`\[CurlyPhi][
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[1]],
       Editable->False], "2"], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox[
          OverscriptBox["D", "_"], "b"], 
         SuperscriptBox[
          OverscriptBox["D", "_"], "b"], 
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Phi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[-$CellContext`b][
        $CellContext`cd[$CellContext`b][
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]]],
       Editable->False], ")"}], " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None]}], 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[CurlyPhi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][],
        Editable->False], "."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[CurlyPhi][
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox["V",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`V,
        Editable->False], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "+", 
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], "."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[1]],
           Editable->False], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None]}], "+", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[CurlyPhi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][],
               Editable->False], "."],
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[1]],
            Editable->False], "3"], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["V",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`V,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None]}], "-", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}]}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", 
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False]], 
    RowBox[{
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[CurlyPhi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][],
         Editable->False], "."],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xPand`\[CurlyPhi][
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[1]],
      Editable->False], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox[
          OverscriptBox["D", "_"], "b"], 
         SuperscriptBox[
          OverscriptBox["D", "_"], "b"], 
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["B",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Bsh[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[-$CellContext`b][
        $CellContext`cd[$CellContext`b][
         $CellContext`Bsh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]]],
       Editable->False], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"5", " ", 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None]}], "+", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["V",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`V,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "+", 
       RowBox[{
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], ".."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[2]],
         Editable->False], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None]}], "+", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              OverscriptBox[
               InterpretationBox[
                StyleBox["\[CurlyPhi]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                xAct`xPand`\[CurlyPhi][],
                Editable->False], "."],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][
              xAct`xTensor`LI[0], 
              xAct`xTensor`LI[1]],
             Editable->False], "2"], " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None]}]}], ")"}]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None]}], "+", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], "2"], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None]}]}], ")"}]}]}], "+", 
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[CurlyPhi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][],
        Editable->False], "."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[CurlyPhi][
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}], "+", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox["V",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`V,
        Editable->False], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], ".."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[2]],
        Editable->False], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None]}], "+", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[CurlyPhi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][],
               Editable->False], "."],
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[1]],
            Editable->False], "2"], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None]}]}], ")"}]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}]}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"4", " ", 
      InterpretationBox[
       StyleBox["\[Kappa]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Kappa],
       Editable->False]}]], 
    RowBox[{
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Phi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]],
       Editable->False], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "24"}], " ", 
        InterpretationBox[
         StyleBox["V",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`V,
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], "2"], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None]}], "+", 
       RowBox[{"12", " ", 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Rho]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Rho]u[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Rho]u[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], "2"], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None]}], "+", 
       RowBox[{"9", " ", 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], "7"], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], "6"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[CurlyPhi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][],
               Editable->False], ".."],
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[2]],
            Editable->False], " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None]}], "+", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["V",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`V,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None]}], ")"}], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None]}], "-", 
       RowBox[{"3", " ", 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["P",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Pu[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Pu[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None]}], "+", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              OverscriptBox[
               InterpretationBox[
                StyleBox["\[CurlyPhi]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                xAct`xPand`\[CurlyPhi][],
                Editable->False], "."],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][
              xAct`xTensor`LI[0], 
              xAct`xTensor`LI[1]],
             Editable->False], "2"], " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None]}]}], ")"}]}], "+", 
       RowBox[{"8", " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], ".."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[2]],
         Editable->False], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox["V",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`V,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None]}]}], ")"}]}], "+", 
       RowBox[{"24", " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", 
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[CurlyPhi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][],
               Editable->False], ".."],
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[2]],
            Editable->False], " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None]}], "+", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["V",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`V,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None]}]}], ")"}]}], "+", 
       RowBox[{"12", " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"8", " ", 
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[CurlyPhi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][],
               Editable->False], ".."],
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[2]],
            Editable->False], " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None]}], "+", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["V",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`V,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None]}]}], ")"}]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], "4"], " ", 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], ".."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[2]],
         Editable->False], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             SuperscriptBox[
              InterpretationBox[
               StyleBox["G",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`G,
               Editable->False], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], ")"}], "2"]}], "+", 
          RowBox[{
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox["V",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`V,
               Editable->False], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "3"}], ")"}],
               Derivative],
              MultilineFunction->None], "-", 
             SuperscriptBox[
              InterpretationBox[
               StyleBox["G",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`G,
               Editable->False], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "2"}], ")"}],
               Derivative],
              MultilineFunction->None]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"12", " ", 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], "5"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             SuperscriptBox[
              InterpretationBox[
               StyleBox["G",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`G,
               Editable->False], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], ")"}], "2"]}], "+", 
          RowBox[{
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              InterpretationBox[
               StyleBox[
                OverscriptBox[
                 InterpretationBox[
                  StyleBox["\[CurlyPhi]",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  xAct`xPand`\[CurlyPhi][],
                  Editable->False], ".."],
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][
                xAct`xTensor`LI[0], 
                xAct`xTensor`LI[2]],
               Editable->False], " ", 
              SuperscriptBox[
               InterpretationBox[
                StyleBox["G",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`G,
                Editable->False], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "3"}], ")"}],
                Derivative],
               MultilineFunction->None]}], "+", 
             SuperscriptBox[
              InterpretationBox[
               StyleBox["G",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`G,
               Editable->False], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "2"}], ")"}],
               Derivative],
              MultilineFunction->None]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[CurlyPhi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][],
               Editable->False], ".."],
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[2]],
            Editable->False], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"5", " ", 
              SuperscriptBox[
               InterpretationBox[
                StyleBox["V",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`V,
                Editable->False], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None]}], "-", 
             RowBox[{"6", " ", 
              SuperscriptBox[
               InterpretationBox[
                StyleBox["G",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`G,
                Editable->False], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None]}]}], ")"}]}], "+", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["V",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`V,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"12", " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["V",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`V,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None]}], "-", 
          RowBox[{"6", " ", 
           InterpretationBox[
            StyleBox["V",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`V,
            Editable->False], " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None]}], "+", 
          RowBox[{"3", " ", 
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[Rho]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Rho]u[],
               Editable->False], ""],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Rho]u[
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[0]],
            Editable->False], " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None]}], "+", 
          RowBox[{"4", " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False], " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["V",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`V,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None]}], "-", 
          RowBox[{"4", " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False], " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None]}]}], ")"}]}]}], ")"}]}]}]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{
  3.809055456818712*^9, 3.8090870504559255`*^9, 3.809087122140173*^9, 
   3.809087153482694*^9, {3.809594595654312*^9, 3.809594608846103*^9}, 
   3.8097510216421556`*^9, 3.8097873739740624`*^9, 3.8097875878221197`*^9, 
   3.8098310556998224`*^9, 3.8098393510389037`*^9, 3.809843574804538*^9, 
   3.809844394923156*^9, 3.8098634522245617`*^9, 3.8098674179242163`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Second-order action for ",
 StyleBox["k",
  FontSlant->"Italic"],
 "-essence"
}], "Subsubsection",
 CellChangeTimes->{{3.8090554888075686`*^9, 3.809055494781002*^9}, {
  3.8091485019558096`*^9, 3.8091485075155897`*^9}}],

Cell["\<\
To prepare for variational differentiation, we setup the simplifying rule and \
time differentiation...\
\>", "Text",
 CellChangeTimes->{{3.809755216738231*^9, 3.8097552392999477`*^9}, {
  3.8097634207020764`*^9, 3.8097634250526133`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"DeltaRule", "=", 
    RowBox[{
     RowBox[{"delta", "[", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"LI", "[", "x_", "]"}]}], ",", 
       RowBox[{"LI", "[", "y_", "]"}]}], "]"}], "\[RuleDelayed]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"x", "\[Equal]", "y"}], ",", "1", ",", "0"}], "]"}]}]}], ";"}],
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dt", "[", "expr_", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{"ah", "[", 
        RowBox[{
         RowBox[{"LI", "[", "0", "]"}], ",", 
         RowBox[{"LI", "[", "0", "]"}]}], "]"}]], 
      RowBox[{
       RowBox[{"LieD", "[", 
        RowBox[{"n", "[", "l", "]"}], "]"}], "[", "expr", "]"}]}], "//", 
     "ToCanonical"}], "//", "NoScalar"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CollectXh2", "[", "expr_", "]"}], ":=", 
  RowBox[{"Collect", "[", 
   RowBox[{"expr", ",", 
    RowBox[{"{", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}], "2"], ",", 
      RowBox[{
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], ",", 
      SuperscriptBox[
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}], "2"], ",", 
      RowBox[{
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "."]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], ",", 
      SuperscriptBox[
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "."]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}], "2"], ",", 
      RowBox[{
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "b"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["B",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Bsh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`b][
          $CellContext`Bsh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "b"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["B",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Bsh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`b][
          $CellContext`Bsh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], ",", 
      RowBox[{
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "b"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`b][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "b"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`b][
          $CellContext`\[Phi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], ",", 
      RowBox[{
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "b"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`b][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "b"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`b][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], ",", 
      RowBox[{
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "b"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`b][
          $CellContext`\[Phi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "b"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["B",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Bsh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`b][
          $CellContext`Bsh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], ",", 
      RowBox[{
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "b"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "."]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`b][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[1]]],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "b"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["B",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Bsh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`b][
          $CellContext`Bsh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}]}], "}"}], ",", "Simplify"}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.809755244548255*^9, 3.809755247542922*^9}, {
  3.809755310529524*^9, 3.809755341930318*^9}, {3.8097634294627843`*^9, 
  3.8097634688199186`*^9}, {3.8097665888986416`*^9, 3.8097665893453083`*^9}}],

Cell[TextData[{
 "To understand the derivation of the master equation for scalar \
perturbations, we look at the second-order action of ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]]],
 "-essence..."
}], "Text",
 CellChangeTimes->{{3.8090555115840797`*^9, 3.8090555434829226`*^9}, {
  3.809148547884301*^9, 3.809148582051625*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\"\<L\>\"", "\[Equal]", 
  RowBox[{"LEH", "+", "LK"}]}]], "Input",
 CellChangeTimes->{{3.809055544758816*^9, 3.8090555520845428`*^9}, {
  3.809148585280901*^9, 3.8091486118769684`*^9}, {3.8097876757006006`*^9, 
  3.809787676258851*^9}}],

Cell[BoxData[
 RowBox[{"\<\"L\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["R",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`RicciScalarCD[],
     Editable->False]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox["V",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`V,
     Editable->False], "[", 
    RowBox[{
     InterpretationBox[
      StyleBox["\[Chi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Chi][],
      Editable->False], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[Del]", "b"], "\[Chi]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`b][
        $CellContext`\[Chi][]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SuperscriptBox["\[Del]", "b"], "\[Chi]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[$CellContext`b][
        $CellContext`\[Chi][]],
       Editable->False]}]}], "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.809055552604018*^9, 3.8090871765306873`*^9, {3.8091485865864515`*^9, 
   3.8091486134552693`*^9}, 3.809148946570236*^9, 3.8093217843430653`*^9, 
   3.8093416287371335`*^9, 3.8093478828467875`*^9, 3.809572803745905*^9, 
   3.8095955128750944`*^9, 3.8095982196927257`*^9, 3.809615216410835*^9, 
   3.8097525895605993`*^9, 3.809753094482914*^9, 3.8097631464993367`*^9, 
   3.8097666383681726`*^9, 3.809772086092533*^9, 3.809783462659629*^9, 
   3.8097874225641003`*^9, 3.809787587916629*^9, 3.809831055797875*^9, 
   3.8098393511496167`*^9, 3.809843574892816*^9, 3.809844395000203*^9, 
   3.8098634523925457`*^9, 3.8098674180086803`*^9}]
}, Open  ]],

Cell["\<\
Just to check how variational differentiation works, let us derive the \
background field equations. First, here\[CloseCurlyQuote]s the total action \
expanded up to second order and its linear pieces...\
\>", "Text",
 CellChangeTimes->{{3.8097577668189745`*^9, 3.809757788162078*^9}, {
  3.8097632508563023`*^9, 3.8097632732630997`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SK012", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"MyToxPand", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            SqrtBox[
             RowBox[{"-", 
              RowBox[{"Detg", "[", "]"}]}]], 
            RowBox[{"(", 
             RowBox[{"LK", "+", "LEH"}], ")"}]}], "/.", 
           RowBox[{
            RowBox[{"\[Chi]", "[", "]"}], "\[Rule]", 
            RowBox[{"\[CurlyPhi]", "[", "]"}]}]}], ",", 
          "\"\<ScalarFieldComovingGauge\>\"", ",", "2"}], "]"}], "/.", 
        "kill2O"}], "/.", 
       RowBox[{
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"Detg", "[", "]"}]}], 
          SuperscriptBox[
           RowBox[{"Scalar", "[", 
            RowBox[{"ah", "[", "]"}], "]"}], "8"]}], "]"}], "\[Rule]", 
        SuperscriptBox[
         RowBox[{"ah", "[", 
          RowBox[{
           RowBox[{"LI", "[", "0", "]"}], ",", 
           RowBox[{"LI", "[", "0", "]"}]}], "]"}], "3"]}]}], "//", "Expand"}],
      "//", "org"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SK1", "=", 
    RowBox[{"ExtractOrder", "[", 
     RowBox[{"SK012", ",", "1"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
   "\"\<\!\(\*SuperscriptBox[\(S\), \((1)\)]\)\>\"", "\[Equal]", "SK1"}], "/.",
    "simpV"}], "//", "CollectXh"}]}], "Input",
 CellChangeTimes->{{3.8097577910178614`*^9, 3.809757822592157*^9}, {
  3.8097631612543287`*^9, 3.809763221292225*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The Splitting of \"\>", "\[InvisibleSpace]", 
   FractionBox[
    RowBox[{
     InterpretationBox[
      StyleBox["\[Kappa]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Kappa],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["R",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`RicciScalarCD[],
      Editable->False], " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"-", 
        InterpretationBox[
         StyleBox[
          OverscriptBox["g", 
           OverscriptBox[
            StyleBox["~",
             FontColor->RGBColor[0, 0, 0]], 
            StyleBox["~",
             FontColor->RGBColor[0, 0, 0]]]],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Detg[],
         Editable->False]}], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          RowBox[{
           StyleBox["(",
            FontColor->RGBColor[1, 0, 0]], 
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["a",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`ah[],
               Editable->False], ""],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[0]],
            Editable->False], 
           StyleBox[")",
            FontColor->RGBColor[1, 0, 0]]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xTensor`Scalar[
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]]],
         Editable->False], "8"]}]]}], 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       RowBox[{
        StyleBox["(",
         FontColor->RGBColor[1, 0, 0]], 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], 
        StyleBox[")",
         FontColor->RGBColor[1, 0, 0]]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xTensor`Scalar[
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]]],
      Editable->False], "2"]], 
   "\[InvisibleSpace]", "\<\" +... was performed in \"\>", 
   "\[InvisibleSpace]", "12.442575`", 
   "\[InvisibleSpace]", "\<\" seconds.\"\>"}],
  SequenceForm[
  "The Splitting of ", $CellContext`\[Kappa] $CellContext`RicciScalarCD[] 
   xAct`xTensor`Scalar[
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]]]^(-2) (-$CellContext`Detg[] xAct`xTensor`Scalar[
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]]]^8)^Rational[1, 2], " +... was performed in ", 
   12.442575, " seconds."],
  Editable->False]], "Print",
 CellChangeTimes->{3.809763237195521*^9, 3.809766657105226*^9, 
  3.8097721027960854`*^9, 3.809783488690648*^9, 3.8097874378437138`*^9, 
  3.8097876025725613`*^9, 3.8098310696026373`*^9, 3.8098393651270804`*^9, 
  3.809843588588395*^9, 3.8098444091398544`*^9, 3.8098634666583605`*^9, 
  3.8098674322126412`*^9}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SuperscriptBox[\\(S\\), \\((1)\\)]\\)\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "6"}], " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"3", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      InterpretationBox[
       StyleBox["V",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`V,
       Editable->False], "+", 
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"]}], "+", 
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False]}]}], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"24", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ".."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[2]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`cd[$CellContext`b][
        $CellContext`Bsh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`cd[$CellContext`b][
        $CellContext`Bsh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1]]]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`cd[$CellContext`b][
        $CellContext`\[Phi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"4", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`cd[$CellContext`b][
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      InterpretationBox[
       StyleBox["V",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`V,
       Editable->False], "-", 
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"]}], "-", 
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False]}], "-", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["V",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`V,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{{3.8097632131472516`*^9, 3.809763237775305*^9}, 
   3.8097666576628914`*^9, 3.809772103361807*^9, 3.8097834892614512`*^9, 
   3.8097874384201508`*^9, 3.8097876031235995`*^9, 3.8098310700219164`*^9, 
   3.809839365630506*^9, 3.8098435890892887`*^9, 3.8098444096434197`*^9, 
   3.8098634671576157`*^9, 3.809867432718094*^9}]
}, Open  ]],

Cell["\<\
What we want to do here is to place all of the time derivatives away from the \
perturbations by (manual) partial differentiation...\
\>", "Text",
 CellChangeTimes->{{3.8097632891255765`*^9, 3.809763337548018*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SK1final", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"SK1", "/.", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"ah", "[", 
            RowBox[{
             RowBox[{"LI", "[", "0", "]"}], ",", 
             RowBox[{"LI", "[", "0", "]"}]}], "]"}], "3"], 
          RowBox[{"\[Psi]h", "[", 
           RowBox[{
            RowBox[{"LI", "[", "1", "]"}], ",", 
            RowBox[{"LI", "[", "2", "]"}]}], "]"}]}], "\[Rule]", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"\[Psi]h", "[", 
            RowBox[{
             RowBox[{"LI", "[", "1", "]"}], ",", 
             RowBox[{"LI", "[", "1", "]"}]}], "]"}]}], 
          RowBox[{"dt", "[", 
           SuperscriptBox[
            RowBox[{"ah", "[", 
             RowBox[{
              RowBox[{"LI", "[", "0", "]"}], ",", 
              RowBox[{"LI", "[", "0", "]"}]}], "]"}], "3"], "]"}]}]}]}], "/.", 
       RowBox[{
        RowBox[{"expr_", " ", 
         RowBox[{"ph_", "[", 
          RowBox[{
           RowBox[{"LI", "[", "1", "]"}], ",", 
           RowBox[{"LI", "[", "1", "]"}]}], "]"}]}], "\[RuleDelayed]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"ph", "[", 
           RowBox[{
            RowBox[{"LI", "[", "1", "]"}], ",", 
            RowBox[{"LI", "[", "0", "]"}]}], "]"}]}], 
         RowBox[{"dt", "[", "expr", "]"}]}]}]}], "/.", 
      RowBox[{
       RowBox[{"expr_", " ", 
        RowBox[{
         RowBox[{"cd", "[", 
          RowBox[{"-", "x_"}], "]"}], "[", 
         RowBox[{
          RowBox[{"cd", "[", "x_", "]"}], "[", 
          RowBox[{"Bsh", "[", 
           RowBox[{
            RowBox[{"LI", "[", "1", "]"}], ",", 
            RowBox[{"LI", "[", "1", "]"}]}], "]"}], "]"}], "]"}]}], 
       "\[RuleDelayed]", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"cd", "[", 
           RowBox[{"-", "x"}], "]"}], "[", 
          RowBox[{
           RowBox[{"cd", "[", "x", "]"}], "[", 
           RowBox[{"Bsh", "[", 
            RowBox[{
             RowBox[{"LI", "[", "1", "]"}], ",", 
             RowBox[{"LI", "[", "0", "]"}]}], "]"}], "]"}], "]"}]}], 
        RowBox[{"dt", "[", "expr", "]"}]}]}]}], "//", "CollectXh"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "\"\<\!\(\*SuperscriptBox[\(S\), \((1)\)]\)\>\"", "\[Equal]", "SK1final"}], 
  "/.", "simpV"}]}], "Input",
 CellChangeTimes->{{3.8097633403099833`*^9, 3.8097633930891123`*^9}, {
  3.8097634874960256`*^9, 3.8097635381825476`*^9}, {3.8097636038573647`*^9, 
  3.80976365155377*^9}, {3.8097636976283026`*^9, 3.8097637220755973`*^9}, {
  3.809763811912569*^9, 3.8097638241750927`*^9}, {3.8097638698174934`*^9, 
  3.809763999095453*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SuperscriptBox[\\(S\\), \\((1)\\)]\\)\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "3"}], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      InterpretationBox[
       StyleBox["V",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`V,
       Editable->False], "+", 
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"]}], "+", 
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False]}]}], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`cd[$CellContext`b][
        $CellContext`Bsh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`cd[$CellContext`b][
        $CellContext`\[Phi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"4", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`cd[$CellContext`b][
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      InterpretationBox[
       StyleBox["V",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`V,
       Editable->False], "+", 
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"]}], "-", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["V",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`V,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{
  3.809763725148467*^9, {3.809763803458135*^9, 3.809763824507286*^9}, 
   3.8097639166331024`*^9, {3.809763950507886*^9, 3.8097639652587976`*^9}, 
   3.809763999448406*^9, 3.809766665617682*^9, 3.809772103546717*^9, 
   3.8097835764056225`*^9, 3.80978743860328*^9, 3.8097876033287606`*^9, 
   3.809831070214937*^9, 3.80983936581113*^9, 3.809843589258233*^9, 
   3.809844409847316*^9, 3.8098634673124585`*^9, 3.8098674328726683`*^9}]
}, Open  ]],

Cell[TextData[{
 "From this, it\[CloseCurlyQuote]s easy to just read out the Friedmann \
equations as the coefficients of ",
 Cell[BoxData[
  FormBox["\[Phi]", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " and ",
 Cell[BoxData[
  FormBox["\[Psi]", TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", but let\[CloseCurlyQuote]s use variational differentiation anyway..."
}], "Text",
 CellChangeTimes->{{3.8097640233388724`*^9, 3.809764065626289*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"fe1", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"VarD", "[", 
         RowBox[{
          RowBox[{"\[Phi]h", "[", 
           RowBox[{
            RowBox[{"LI", "[", "1", "]"}], ",", 
            RowBox[{"LI", "[", "0", "]"}]}], "]"}], ",", "cd"}], "]"}], "[", 
        "SK1final", "]"}], "/.", "DeltaRule"}], "//", "NoScalar"}], ")"}], 
    "\[Equal]", "0"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"fe2", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"VarD", "[", 
          RowBox[{
           RowBox[{"\[Psi]h", "[", 
            RowBox[{
             RowBox[{"LI", "[", "1", "]"}], ",", 
             RowBox[{"LI", "[", "0", "]"}]}], "]"}], ",", "cd"}], "]"}], "[", 
         "SK1final", "]"}], "/.", "DeltaRule"}], "//", "NoScalar"}], ")"}], 
     "\[Equal]", "0"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fesVar", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"fe1", ",", "fe2"}], "}"}], "/.", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Hh", "[", 
          RowBox[{
           RowBox[{"LI", "[", "0", "]"}], ",", 
           RowBox[{"LI", "[", "0", "]"}]}], "]"}], "2"], "\[Rule]", "Q"}]}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"Q", ",", 
        RowBox[{"Hh", "[", 
         RowBox[{
          RowBox[{"LI", "[", "0", "]"}], ",", 
          RowBox[{"LI", "[", "1", "]"}]}], "]"}]}], "}"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"fesVar", "/.", "simp"}]}], "Input",
 CellChangeTimes->{{3.80976407324883*^9, 3.809764267152145*^9}, {
  3.8097836309748583`*^9, 3.8097836371875763`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Q", "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox["V",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`V,
        Editable->False], "-", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], "2"], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["V",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`V,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None]}]}], 
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False]}]]}]}], ",", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], "."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["V",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`V,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}], 
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False]}]]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.809764103146325*^9, 3.809764156625451*^9}, 
   3.8097642676292477`*^9, 3.809766685839912*^9, 3.809772103658697*^9, {
   3.8097836203131084`*^9, 3.809783637566327*^9}, 3.8097874387221293`*^9, 
   3.809787603441684*^9, 3.8098310703558083`*^9, 3.809839365902954*^9, 
   3.809843589352688*^9, 3.809844409958501*^9, 3.809863467417389*^9, 
   3.809867432973278*^9}]
}, Open  ]],

Cell["\<\
These are of course the same background equations derived in the previous \
section.

We now extract the quadratic pieces of the action...\
\>", "Text",
 CellChangeTimes->{{3.8090555797174315`*^9, 3.8090556271344504`*^9}, {
  3.8090556618548145`*^9, 3.8090556705587587`*^9}, {3.809764307163412*^9, 
  3.8097643760449066`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SK2", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"ExtractOrder", "[", 
       RowBox[{"SK012", ",", "2"}], "]"}], "//", "ToCanonical"}], "//", 
     "NoScalar"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "\"\<\!\(\*SuperscriptBox[\(S\), \((2)\)]\)\>\"", "\[Equal]", "SK2"}], "/.",
   "simpV"}]}], "Input",
 CellChangeTimes->{{3.809056812396534*^9, 3.809056830130415*^9}, {
  3.809149145791281*^9, 3.8091491565059514`*^9}, {3.8095984358678875`*^9, 
  3.809598449900032*^9}, {3.809753210270579*^9, 3.8097532107469463`*^9}, {
  3.8097643888137736`*^9, 3.809764390401766*^9}, {3.8097644772146106`*^9, 
  3.809764484011561*^9}, {3.809764654371996*^9, 3.8097646555543633`*^9}, {
  3.8097647609776335`*^9, 3.8097647672539167`*^9}, {3.8097667028762445`*^9, 
  3.809766706086709*^9}, {3.809766791270018*^9, 3.809766791478506*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SuperscriptBox[\\(S\\), \\((2)\\)]\\)\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", 
    InterpretationBox[
     StyleBox["V",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`V,
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Phi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]],
       Editable->False], ")"}], "2"]}], "+", 
   RowBox[{"18", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["H",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Hh[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Phi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]],
       Editable->False], ")"}], "2"]}], "+", 
   RowBox[{"9", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], "."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Phi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]],
       Editable->False], ")"}], "2"]}], "+", 
   RowBox[{"18", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["V",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`V,
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"36", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["H",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Hh[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"18", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], "."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"18", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}]}], "+", 
   RowBox[{
    FractionBox["3", "2"], " ", 
    InterpretationBox[
     StyleBox["V",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`V,
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Psi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Psi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]],
       Editable->False], ")"}], "2"]}], "+", 
   RowBox[{"18", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["H",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Hh[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Psi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Psi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]],
       Editable->False], ")"}], "2"]}], "+", 
   RowBox[{"9", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], "."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Psi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Psi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]],
       Editable->False], ")"}], "2"]}], "+", 
   RowBox[{"24", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"24", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ".."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[2]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ".."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[2]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`cd[$CellContext`b][
        $CellContext`Bsh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`cd[$CellContext`b][
        $CellContext`Bsh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`cd[$CellContext`b][
        $CellContext`Bsh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"4", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`cd[$CellContext`b][
        $CellContext`Bsh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`cd[$CellContext`b][
        $CellContext`Bsh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1]]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`cd[$CellContext`b][
        $CellContext`Bsh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1]]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`cd[$CellContext`b][
        $CellContext`\[Phi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`cd[$CellContext`b][
        $CellContext`\[Phi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"4", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`cd[$CellContext`b][
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"4", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`cd[$CellContext`b][
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox["V",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`V,
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["H",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Hh[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], "."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[1]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"8", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[1]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[1]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`cd[$CellContext`b][
        $CellContext`Bsh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "c"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "c"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`c][
       $CellContext`cd[$CellContext`c][
        $CellContext`Bsh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "c"], 
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`c][
       $CellContext`cd[-$CellContext`b][
        $CellContext`Bsh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "c"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`c][
       $CellContext`cd[$CellContext`b][
        $CellContext`Bsh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[CurlyPhi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][],
         Editable->False], "."],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xPand`\[CurlyPhi][
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[1]],
      Editable->False], "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Phi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]],
       Editable->False], ")"}], "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["V",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`V,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None]}], "+", 
   RowBox[{"3", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[CurlyPhi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][],
         Editable->False], "."],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xPand`\[CurlyPhi][
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[1]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["V",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`V,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[CurlyPhi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][],
         Editable->False], "."],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xPand`\[CurlyPhi][
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[1]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["V",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`V,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[CurlyPhi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][],
         Editable->False], "."],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xPand`\[CurlyPhi][
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[1]],
      Editable->False], "4"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Phi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]],
       Editable->False], ")"}], "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["V",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`V,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None]}]}]}]], "Output",
 CellChangeTimes->{3.809056841211385*^9, 3.8091491688918357`*^9, 
  3.8093218031604357`*^9, 3.80934164412144*^9, 3.80934789805182*^9, 
  3.8095728218920374`*^9, 3.8095984613810215`*^9, 3.8096152881041665`*^9, 
  3.8097532303843718`*^9, 3.809764409086827*^9, 3.809764485391324*^9, 
  3.809764656328574*^9, 3.8097647681607175`*^9, 3.8097667074588785`*^9, 
  3.809766792505909*^9, 3.8097721041060762`*^9, 3.8097836693150024`*^9, 
  3.809787439157401*^9, 3.8097876038864965`*^9, 3.809831070823715*^9, 
  3.8098393663466797`*^9, 3.8098435897798986`*^9, 3.809844410392115*^9, 
  3.809863467908774*^9, 3.809867433404351*^9}]
}, Open  ]],

Cell["\<\
This looks so bad. But note that some of the terms above vanish after \
integration by parts (which we do manually using the rules below starting \
with)...\
\>", "Text",
 CellChangeTimes->{{3.809056864489047*^9, 3.8090569275977383`*^9}, {
  3.8091492796385574`*^9, 3.8091493356409426`*^9}, {3.8097644527024865`*^9, 
  3.809764471586789*^9}, {3.809783675003134*^9, 3.8097837137063117`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"IBP1", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"ph1_", "[", 
       RowBox[{
        RowBox[{"LI", "[", "1", "]"}], ",", 
        RowBox[{"LI", "[", "y_", "]"}]}], "]"}], " ", 
      RowBox[{
       RowBox[{"cd", "[", 
        RowBox[{"-", "x_"}], "]"}], "[", 
       RowBox[{
        RowBox[{"cd", "[", "x_", "]"}], "[", 
        RowBox[{"ph2_", "[", 
         RowBox[{
          RowBox[{"LI", "[", "1", "]"}], ",", 
          RowBox[{"LI", "[", "z_", "]"}]}], "]"}], "]"}], "]"}]}], 
     "\[RuleDelayed]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{"cd", "[", 
         RowBox[{"-", "x"}], "]"}], "[", 
        RowBox[{"ph1", "[", 
         RowBox[{
          RowBox[{"LI", "[", "1", "]"}], ",", 
          RowBox[{"LI", "[", "y", "]"}]}], "]"}], "]"}]}], 
      RowBox[{
       RowBox[{"cd", "[", "x", "]"}], "[", 
       RowBox[{"ph2", "[", 
        RowBox[{
         RowBox[{"LI", "[", "1", "]"}], ",", 
         RowBox[{"LI", "[", "z", "]"}]}], "]"}], "]"}]}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SK2ibp", "=", 
    RowBox[{"SK2", "/.", "IBP1"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "\"\<\!\(\*SuperscriptBox[\(S\), \((2)\)]\)\>\"", "\[Equal]", "SK2ibp"}], "/.",
   "simpV"}]}], "Input",
 CellChangeTimes->{{3.8091492461279697`*^9, 3.8091492596711206`*^9}, {
   3.809149309310923*^9, 3.80914931471371*^9}, {3.8091494965576086`*^9, 
   3.8091494967442584`*^9}, {3.8091495575244446`*^9, 
   3.8091495603002863`*^9}, {3.809150005987315*^9, 3.8091500219336824`*^9}, {
   3.8091500799151483`*^9, 3.8091501300912757`*^9}, {3.809150877483315*^9, 
   3.8091509129416943`*^9}, 3.809598668023769*^9, {3.809598721717903*^9, 
   3.8095987225658197`*^9}, {3.8097645066259794`*^9, 
   3.8097645222841635`*^9}, {3.8097647414200788`*^9, 3.809764748356377*^9}, 
   3.809764792682808*^9, {3.809766547462923*^9, 3.8097665487416754`*^9}, {
   3.8097667291704674`*^9, 3.809766731778784*^9}, 3.8097667864368443`*^9}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SuperscriptBox[\\(S\\), \\((2)\\)]\\)\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", 
    InterpretationBox[
     StyleBox["V",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`V,
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Phi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]],
       Editable->False], ")"}], "2"]}], "+", 
   RowBox[{"18", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["H",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Hh[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Phi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]],
       Editable->False], ")"}], "2"]}], "+", 
   RowBox[{"9", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], "."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Phi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]],
       Editable->False], ")"}], "2"]}], "+", 
   RowBox[{"18", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["V",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`V,
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"36", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["H",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Hh[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"18", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], "."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"18", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}]}], "+", 
   RowBox[{
    FractionBox["3", "2"], " ", 
    InterpretationBox[
     StyleBox["V",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`V,
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Psi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Psi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]],
       Editable->False], ")"}], "2"]}], "+", 
   RowBox[{"18", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["H",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Hh[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Psi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Psi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]],
       Editable->False], ")"}], "2"]}], "+", 
   RowBox[{"9", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], "."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Psi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Psi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]],
       Editable->False], ")"}], "2"]}], "+", 
   RowBox[{"24", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"24", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ".."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[2]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ".."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[2]],
      Editable->False], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    InterpretationBox[
     StyleBox["V",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`V,
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["H",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Hh[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], "."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[1]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[1]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"4", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[1]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[1]]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"4", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`cd[$CellContext`b][
        $CellContext`Bsh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "c"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "c"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`c][
       $CellContext`cd[$CellContext`c][
        $CellContext`Bsh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "c"], 
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`c][
       $CellContext`cd[-$CellContext`b][
        $CellContext`Bsh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "c"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`c][
       $CellContext`cd[$CellContext`b][
        $CellContext`Bsh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[CurlyPhi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][],
         Editable->False], "."],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xPand`\[CurlyPhi][
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[1]],
      Editable->False], "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Phi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]],
       Editable->False], ")"}], "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["V",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`V,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None]}], "+", 
   RowBox[{"3", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[CurlyPhi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][],
         Editable->False], "."],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xPand`\[CurlyPhi][
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[1]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["V",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`V,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[CurlyPhi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][],
         Editable->False], "."],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xPand`\[CurlyPhi][
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[1]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["V",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`V,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[CurlyPhi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][],
         Editable->False], "."],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xPand`\[CurlyPhi][
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[1]],
      Editable->False], "4"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Phi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]],
       Editable->False], ")"}], "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["V",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`V,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None]}]}]}]], "Output",
 CellChangeTimes->{
  3.809150913627161*^9, {3.8093218032984853`*^9, 3.8093218064425216`*^9}, 
   3.8093416442966733`*^9, 3.8093478983844614`*^9, 3.8095728222513294`*^9, 
   3.8095984980248756`*^9, 3.8095986700085607`*^9, 3.809598770258049*^9, 
   3.8096153467621417`*^9, 3.8097533343325634`*^9, 3.809764523486846*^9, {
   3.8097647443663006`*^9, 3.8097647493229885`*^9}, {3.8097647890050993`*^9, 
   3.809764795233306*^9}, 3.8097665500254393`*^9, 3.8097667324857273`*^9, 
   3.8097667996103287`*^9, 3.8097721044459724`*^9, 3.809783737904937*^9, 
   3.809787439474283*^9, 3.8097876041931396`*^9, 3.80983107115288*^9, 
   3.8098393664481044`*^9, 3.809843589967925*^9, 3.809844410684783*^9, 
   3.8098634680425634`*^9, 3.809867433516311*^9}]
}, Open  ]],

Cell[TextData[{
 "Notice that because the induced metric ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["h", "bc"], TraditionalForm]]],
 " is flat then the terms ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"(", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox[
        OverscriptBox["D", "_"], "b"], 
       SuperscriptBox[
        OverscriptBox["D", "_"], "b"], 
       OverscriptBox["\[Null]", 
        StyleBox[
         RowBox[{"(", "1", ")"}],
         FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
       OverscriptBox[
        InterpretationBox[
         StyleBox["B",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Bsh[],
         Editable->False], ""]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`cd[-$CellContext`b][
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]]],
     Editable->False], ")"}], " ", 
   RowBox[{"(", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox[
        OverscriptBox["D", "_"], "c"], 
       SuperscriptBox[
        OverscriptBox["D", "_"], "c"], 
       OverscriptBox["\[Null]", 
        StyleBox[
         RowBox[{"(", "1", ")"}],
         FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
       OverscriptBox[
        InterpretationBox[
         StyleBox["B",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Bsh[],
         Editable->False], ""]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`cd[-$CellContext`c][
      $CellContext`cd[$CellContext`c][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]]],
     Editable->False], ")"}]}]],
  CellChangeTimes->{
   3.809150913627161*^9, {3.8093218032984853`*^9, 3.8093218064425216`*^9}, 
    3.8093416442966733`*^9, 3.8093478983844614`*^9, 3.8095728222513294`*^9, 
    3.8095984980248756`*^9, 3.8095986700085607`*^9, 3.809598770258049*^9, 
    3.8096153467621417`*^9, 3.8097533343325634`*^9, 3.809764523486846*^9}],
 " and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"(", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox[
        OverscriptBox["D", "_"], "c"], 
       SubscriptBox[
        OverscriptBox["D", "_"], "b"], 
       OverscriptBox["\[Null]", 
        StyleBox[
         RowBox[{"(", "1", ")"}],
         FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
       OverscriptBox[
        InterpretationBox[
         StyleBox["B",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Bsh[],
         Editable->False], ""]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`cd[-$CellContext`c][
      $CellContext`cd[-$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]]],
     Editable->False], ")"}], " ", 
   RowBox[{"(", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox[
        OverscriptBox["D", "_"], "c"], 
       SuperscriptBox[
        OverscriptBox["D", "_"], "b"], 
       OverscriptBox["\[Null]", 
        StyleBox[
         RowBox[{"(", "1", ")"}],
         FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
       OverscriptBox[
        InterpretationBox[
         StyleBox["B",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Bsh[],
         Editable->False], ""]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`cd[$CellContext`c][
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]]],
     Editable->False], ")"}]}]],
  CellChangeTimes->{
   3.809150913627161*^9, {3.8093218032984853`*^9, 3.8093218064425216`*^9}, 
    3.8093416442966733`*^9, 3.8093478983844614`*^9, 3.8095728222513294`*^9, 
    3.8095984980248756`*^9, 3.8095986700085607`*^9, 3.809598770258049*^9, 
    3.8096153467621417`*^9, 3.8097533343325634`*^9, 3.809764523486846*^9}],
 " above also cancel out each other. It can also be checked via ",
 StyleBox["VarD[...]",
  FontSlant->"Italic"],
 " that this term does not contribute to the dynamics..."
}], "Text",
 CellChangeTimes->{
  3.8091524172728806`*^9, {3.809753598678944*^9, 3.809753656665141*^9}, {
   3.809753707762678*^9, 3.80975370844403*^9}, {3.809764588363102*^9, 
   3.809764623558999*^9}, {3.8097837575827684`*^9, 3.809783758126277*^9}, {
   3.8097837897197514`*^9, 3.8097837945777855`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "variations", " ", "wrt", " ", "\[Phi]", " ", "and", " ", "\[Psi]", " ", 
    "obvious"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Hold", "[", "\"\<\!\(\*FractionBox[SuperscriptBox[\"\[Delta]S\", 
RowBox[{\"(\", \"2\", \")\"}]], 
StyleBox[
RowBox[{\"\[Delta]\", 
StyleBox[\"B\",
FontSlant->\"Italic\"]}]]]\)\>\"", "]"}], "\[Equal]", 
   RowBox[{"SortCovDs", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"VarD", "[", 
        RowBox[{
         RowBox[{"Bsh", "[", 
          RowBox[{
           RowBox[{"LI", "[", "1", "]"}], ",", 
           RowBox[{"LI", "[", "0", "]"}]}], "]"}], ",", "cd"}], "]"}], "[", 
       RowBox[{
        RowBox[{
         InterpretationBox[
          StyleBox["\[Kappa]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Kappa],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False], " ", 
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             SubscriptBox[
              OverscriptBox["D", "_"], "b"], 
             SuperscriptBox[
              OverscriptBox["D", "_"], "b"], 
             OverscriptBox["\[Null]", 
              StyleBox[
               RowBox[{"(", "1", ")"}],
               FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
             OverscriptBox[
              InterpretationBox[
               StyleBox["B",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Bsh[],
               Editable->False], ""]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`cd[-$CellContext`b][
            $CellContext`cd[$CellContext`b][
             $CellContext`Bsh[
              xAct`xTensor`LI[1], 
              xAct`xTensor`LI[0]]]],
           Editable->False], ")"}], " ", 
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             SubscriptBox[
              OverscriptBox["D", "_"], "c"], 
             SuperscriptBox[
              OverscriptBox["D", "_"], "c"], 
             OverscriptBox["\[Null]", 
              StyleBox[
               RowBox[{"(", "1", ")"}],
               FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
             OverscriptBox[
              InterpretationBox[
               StyleBox["B",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Bsh[],
               Editable->False], ""]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`cd[-$CellContext`c][
            $CellContext`cd[$CellContext`c][
             $CellContext`Bsh[
              xAct`xTensor`LI[1], 
              xAct`xTensor`LI[0]]]],
           Editable->False], ")"}]}], "-", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Kappa]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Kappa],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False], " ", 
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             SubscriptBox[
              OverscriptBox["D", "_"], "c"], 
             SubscriptBox[
              OverscriptBox["D", "_"], "b"], 
             OverscriptBox["\[Null]", 
              StyleBox[
               RowBox[{"(", "1", ")"}],
               FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
             OverscriptBox[
              InterpretationBox[
               StyleBox["B",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Bsh[],
               Editable->False], ""]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`cd[-$CellContext`c][
            $CellContext`cd[-$CellContext`b][
             $CellContext`Bsh[
              xAct`xTensor`LI[1], 
              xAct`xTensor`LI[0]]]],
           Editable->False], ")"}], " ", 
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             SuperscriptBox[
              OverscriptBox["D", "_"], "c"], 
             SuperscriptBox[
              OverscriptBox["D", "_"], "b"], 
             OverscriptBox["\[Null]", 
              StyleBox[
               RowBox[{"(", "1", ")"}],
               FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
             OverscriptBox[
              InterpretationBox[
               StyleBox["B",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Bsh[],
               Editable->False], ""]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`cd[$CellContext`c][
            $CellContext`cd[$CellContext`b][
             $CellContext`Bsh[
              xAct`xTensor`LI[1], 
              xAct`xTensor`LI[0]]]],
           Editable->False], ")"}]}]}], "]"}], "//", "ToCanonical"}], ",", 
     "cd"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8097537094120035`*^9, 3.809753810493458*^9}, {
  3.809783799265194*^9, 3.809783820054414*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "Hold", "[", "\<\"\\!\\(\\*FractionBox[SuperscriptBox[\\\"\[Delta]S\\\", \
\\n  RowBox[{\\\"(\\\", \\\"2\\\", \\\")\\\"}]], \\n StyleBox[\\n  RowBox[{\\\
\"\[Delta]\\\", \\n   StyleBox[\\\"B\\\",\\nFontSlant->\\\"Italic\\\"]}]]]\\)\
\"\>", "]"}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{
  3.8097537243191185`*^9, {3.8097537743026*^9, 3.8097538114182334`*^9}, 
   3.809764634457596*^9, 3.809766808163491*^9, 3.8097721047738376`*^9, 
   3.8097838237315626`*^9, 3.8097874398427563`*^9, 3.809787604560009*^9, 
   3.8098310716339397`*^9, 3.8098393665904107`*^9, 3.809843590171832*^9, 
   3.8098444110108647`*^9, 3.809863468215764*^9, 3.809867433659157*^9}]
}, Open  ]],

Cell["We enforce this via the rule...", "Text",
 CellChangeTimes->{3.809753714606974*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"DDXDDXrule", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"cd", "[", 
       RowBox[{"-", "x_"}], "]"}], "[", 
      RowBox[{
       RowBox[{"cd", "[", "x_", "]"}], "[", 
       RowBox[{"xh_", "[", 
        RowBox[{
         RowBox[{"LI", "[", "1", "]"}], ",", 
         RowBox[{"LI", "[", "z_", "]"}]}], "]"}], "]"}], "]"}], 
     RowBox[{
      RowBox[{"cd", "[", 
       RowBox[{"-", "y_"}], "]"}], "[", 
      RowBox[{
       RowBox[{"cd", "[", "y_", "]"}], "[", 
       RowBox[{"xh_", "[", 
        RowBox[{
         RowBox[{"LI", "[", "1", "]"}], ",", 
         RowBox[{"LI", "[", "z_", "]"}]}], "]"}], "]"}], "]"}]}], 
    "\[RuleDelayed]", 
    RowBox[{
     RowBox[{
      RowBox[{"cd", "[", 
       RowBox[{"-", "x"}], "]"}], "[", 
      RowBox[{
       RowBox[{"cd", "[", 
        RowBox[{"-", "y"}], "]"}], "[", 
       RowBox[{"xh", "[", 
        RowBox[{
         RowBox[{"LI", "[", "1", "]"}], ",", 
         RowBox[{"LI", "[", "z", "]"}]}], "]"}], "]"}], "]"}], 
     RowBox[{
      RowBox[{"cd", "[", "x", "]"}], "[", 
      RowBox[{
       RowBox[{"cd", "[", "y", "]"}], "[", 
       RowBox[{"xh", "[", 
        RowBox[{
         RowBox[{"LI", "[", "1", "]"}], ",", 
         RowBox[{"LI", "[", "z", "]"}]}], "]"}], "]"}], "]"}]}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.809152435686799*^9, 3.809152583163631*^9}, {
  3.809152624343068*^9, 3.8091526413973637`*^9}, {3.8097647111707497`*^9, 
  3.8097647133813715`*^9}, {3.8097838486726227`*^9, 3.8097838498886924`*^9}}],

Cell["\<\
To simplify this further, we take note of several total time derivatives \
appearing in this expression...\
\>", "Text",
 CellChangeTimes->{{3.8091509958981705`*^9, 3.809151017214864*^9}, {
  3.8091522913118353`*^9, 3.8091523736662455`*^9}, {3.8091524046929245`*^9, 
  3.809152420309219*^9}, {3.809572855011524*^9, 3.809572855542642*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dotH\[Phi]\[Phi]", "=", 
   RowBox[{
    RowBox[{"Hold", "[", 
     RowBox[{"\"\<\!\(\*FractionBox[\(d\), \(dt\)]\)\>\"", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"ah", "[", 
          RowBox[{
           RowBox[{"LI", "[", "0", "]"}], ",", 
           RowBox[{"LI", "[", "0", "]"}]}], "]"}], "3"], 
        RowBox[{"Hh", "[", 
         RowBox[{
          RowBox[{"LI", "[", "0", "]"}], ",", 
          RowBox[{"LI", "[", "0", "]"}]}], "]"}], 
        SuperscriptBox[
         RowBox[{"\[Phi]h", "[", 
          RowBox[{
           RowBox[{"LI", "[", "1", "]"}], ",", 
           RowBox[{"LI", "[", "0", "]"}]}], "]"}], "2"]}], ")"}]}], "]"}], 
    "\[Equal]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"dt", "[", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"ah", "[", 
           RowBox[{
            RowBox[{"LI", "[", "0", "]"}], ",", 
            RowBox[{"LI", "[", "0", "]"}]}], "]"}], "3"], 
         RowBox[{"Hh", "[", 
          RowBox[{
           RowBox[{"LI", "[", "0", "]"}], ",", 
           RowBox[{"LI", "[", "0", "]"}]}], "]"}], 
         SuperscriptBox[
          RowBox[{"\[Phi]h", "[", 
           RowBox[{
            RowBox[{"LI", "[", "1", "]"}], ",", 
            RowBox[{"LI", "[", "0", "]"}]}], "]"}], "2"]}], "]"}], "//", 
       "ToCanonical"}], "//", "NoScalar"}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dotH\[Psi]\[Psi]", "=", 
   RowBox[{
    RowBox[{"Hold", "[", 
     RowBox[{"\"\<\!\(\*FractionBox[\(d\), \(dt\)]\)\>\"", "[", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"ah", "[", 
         RowBox[{
          RowBox[{"LI", "[", "0", "]"}], ",", 
          RowBox[{"LI", "[", "0", "]"}]}], "]"}], "3"], 
       RowBox[{"Hh", "[", 
        RowBox[{
         RowBox[{"LI", "[", "0", "]"}], ",", 
         RowBox[{"LI", "[", "0", "]"}]}], "]"}], 
       SuperscriptBox[
        RowBox[{"\[Psi]h", "[", 
         RowBox[{
          RowBox[{"LI", "[", "1", "]"}], ",", 
          RowBox[{"LI", "[", "0", "]"}]}], "]"}], "2"]}], "]"}], "]"}], 
    "\[Equal]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"dt", "[", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"ah", "[", 
           RowBox[{
            RowBox[{"LI", "[", "0", "]"}], ",", 
            RowBox[{"LI", "[", "0", "]"}]}], "]"}], "3"], 
         RowBox[{"Hh", "[", 
          RowBox[{
           RowBox[{"LI", "[", "0", "]"}], ",", 
           RowBox[{"LI", "[", "0", "]"}]}], "]"}], 
         SuperscriptBox[
          RowBox[{"\[Psi]h", "[", 
           RowBox[{
            RowBox[{"LI", "[", "1", "]"}], ",", 
            RowBox[{"LI", "[", "0", "]"}]}], "]"}], "2"]}], "]"}], "//", 
       "ToCanonical"}], "//", "NoScalar"}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dotH\[Phi]\[Psi]", "=", 
   RowBox[{
    RowBox[{"Hold", "[", 
     RowBox[{"\"\<\!\(\*FractionBox[\(d\), \(dt\)]\)\>\"", "[", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"ah", "[", 
         RowBox[{
          RowBox[{"LI", "[", "0", "]"}], ",", 
          RowBox[{"LI", "[", "0", "]"}]}], "]"}], "3"], 
       RowBox[{"Hh", "[", 
        RowBox[{
         RowBox[{"LI", "[", "0", "]"}], ",", 
         RowBox[{"LI", "[", "0", "]"}]}], "]"}], 
       RowBox[{"\[Phi]h", "[", 
        RowBox[{
         RowBox[{"LI", "[", "1", "]"}], ",", 
         RowBox[{"LI", "[", "0", "]"}]}], "]"}], 
       RowBox[{"\[Psi]h", "[", 
        RowBox[{
         RowBox[{"LI", "[", "1", "]"}], ",", 
         RowBox[{"LI", "[", "0", "]"}]}], "]"}]}], "]"}], "]"}], "\[Equal]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"dt", "[", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"ah", "[", 
           RowBox[{
            RowBox[{"LI", "[", "0", "]"}], ",", 
            RowBox[{"LI", "[", "0", "]"}]}], "]"}], "3"], 
         RowBox[{"Hh", "[", 
          RowBox[{
           RowBox[{"LI", "[", "0", "]"}], ",", 
           RowBox[{"LI", "[", "0", "]"}]}], "]"}], 
         RowBox[{"\[Phi]h", "[", 
          RowBox[{
           RowBox[{"LI", "[", "1", "]"}], ",", 
           RowBox[{"LI", "[", "0", "]"}]}], "]"}], 
         RowBox[{"\[Psi]h", "[", 
          RowBox[{
           RowBox[{"LI", "[", "1", "]"}], ",", 
           RowBox[{"LI", "[", "0", "]"}]}], "]"}]}], "]"}], "//", 
       "ToCanonical"}], "//", "NoScalar"}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dotHd\[Phi]d\[Psi]", "=", 
   RowBox[{
    RowBox[{"Hold", "[", 
     RowBox[{"\"\<\!\(\*FractionBox[\(d\), \(dt\)]\)\>\"", "[", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"ah", "[", 
         RowBox[{
          RowBox[{"LI", "[", "0", "]"}], ",", 
          RowBox[{"LI", "[", "0", "]"}]}], "]"}], "3"], 
       RowBox[{"\[Phi]h", "[", 
        RowBox[{
         RowBox[{"LI", "[", "1", "]"}], ",", 
         RowBox[{"LI", "[", "0", "]"}]}], "]"}], 
       RowBox[{"\[Psi]h", "[", 
        RowBox[{
         RowBox[{"LI", "[", "1", "]"}], ",", 
         RowBox[{"LI", "[", "1", "]"}]}], "]"}]}], "]"}], "]"}], "\[Equal]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"dt", "[", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"ah", "[", 
           RowBox[{
            RowBox[{"LI", "[", "0", "]"}], ",", 
            RowBox[{"LI", "[", "0", "]"}]}], "]"}], "3"], 
         RowBox[{"\[Phi]h", "[", 
          RowBox[{
           RowBox[{"LI", "[", "1", "]"}], ",", 
           RowBox[{"LI", "[", "0", "]"}]}], "]"}], 
         RowBox[{"\[Psi]h", "[", 
          RowBox[{
           RowBox[{"LI", "[", "1", "]"}], ",", 
           RowBox[{"LI", "[", "1", "]"}]}], "]"}]}], "]"}], "//", 
       "ToCanonical"}], "//", "NoScalar"}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dotHcdBcdB", "=", 
   RowBox[{
    RowBox[{"Hold", "[", 
     RowBox[{"\"\<\!\(\*FractionBox[\(d\), \(dt\)]\)\>\"", "[", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"ah", "[", 
         RowBox[{
          RowBox[{"LI", "[", "0", "]"}], ",", 
          RowBox[{"LI", "[", "0", "]"}]}], "]"}], "3"], 
       RowBox[{"Hh", "[", 
        RowBox[{
         RowBox[{"LI", "[", "0", "]"}], ",", 
         RowBox[{"LI", "[", "0", "]"}]}], "]"}], 
       RowBox[{
        RowBox[{"cd", "[", 
         RowBox[{"-", "b"}], "]"}], "[", 
        RowBox[{"Bsh", "[", 
         RowBox[{
          RowBox[{"LI", "[", "1", "]"}], ",", 
          RowBox[{"LI", "[", "0", "]"}]}], "]"}], "]"}], 
       RowBox[{
        RowBox[{"cd", "[", "b", "]"}], "[", 
        RowBox[{"Bsh", "[", 
         RowBox[{
          RowBox[{"LI", "[", "1", "]"}], ",", 
          RowBox[{"LI", "[", "0", "]"}]}], "]"}], "]"}]}], "]"}], "]"}], 
    "\[Equal]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"dt", "[", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"ah", "[", 
            RowBox[{
             RowBox[{"LI", "[", "0", "]"}], ",", 
             RowBox[{"LI", "[", "0", "]"}]}], "]"}], "3"], 
          RowBox[{"Hh", "[", 
           RowBox[{
            RowBox[{"LI", "[", "0", "]"}], ",", 
            RowBox[{"LI", "[", "0", "]"}]}], "]"}], 
          RowBox[{
           RowBox[{"cd", "[", 
            RowBox[{"-", "b"}], "]"}], "[", 
           RowBox[{"Bsh", "[", 
            RowBox[{
             RowBox[{"LI", "[", "1", "]"}], ",", 
             RowBox[{"LI", "[", "0", "]"}]}], "]"}], "]"}], 
          RowBox[{
           RowBox[{"cd", "[", "b", "]"}], "[", 
           RowBox[{"Bsh", "[", 
            RowBox[{
             RowBox[{"LI", "[", "1", "]"}], ",", 
             RowBox[{"LI", "[", "0", "]"}]}], "]"}], "]"}]}], "]"}], "//", 
        "ContractMetric"}], "//", "ToCanonical"}], "//", "NoScalar"}], 
     ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dotcd\[Phi]cdB", "=", 
   RowBox[{
    RowBox[{"Hold", "[", 
     RowBox[{"\"\<\!\(\*FractionBox[\(d\), \(dt\)]\)\>\"", "[", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"ah", "[", 
         RowBox[{
          RowBox[{"LI", "[", "0", "]"}], ",", 
          RowBox[{"LI", "[", "0", "]"}]}], "]"}], "2"], 
       RowBox[{
        RowBox[{"cd", "[", 
         RowBox[{"-", "b"}], "]"}], "[", 
        RowBox[{"\[Phi]h", "[", 
         RowBox[{
          RowBox[{"LI", "[", "1", "]"}], ",", 
          RowBox[{"LI", "[", "0", "]"}]}], "]"}], "]"}], 
       RowBox[{
        RowBox[{"cd", "[", "b", "]"}], "[", 
        RowBox[{"Bsh", "[", 
         RowBox[{
          RowBox[{"LI", "[", "1", "]"}], ",", 
          RowBox[{"LI", "[", "0", "]"}]}], "]"}], "]"}]}], "]"}], "]"}], 
    "\[Equal]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"dt", "[", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"ah", "[", 
            RowBox[{
             RowBox[{"LI", "[", "0", "]"}], ",", 
             RowBox[{"LI", "[", "0", "]"}]}], "]"}], "2"], 
          RowBox[{
           RowBox[{"cd", "[", 
            RowBox[{"-", "b"}], "]"}], "[", 
           RowBox[{"\[Phi]h", "[", 
            RowBox[{
             RowBox[{"LI", "[", "1", "]"}], ",", 
             RowBox[{"LI", "[", "0", "]"}]}], "]"}], "]"}], 
          RowBox[{
           RowBox[{"cd", "[", "b", "]"}], "[", 
           RowBox[{"Bsh", "[", 
            RowBox[{
             RowBox[{"LI", "[", "1", "]"}], ",", 
             RowBox[{"LI", "[", "0", "]"}]}], "]"}], "]"}]}], "]"}], "//", 
        "ContractMetric"}], "//", "ToCanonical"}], "//", "NoScalar"}], 
     ")"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.8096001140327067`*^9, 3.8096001530983577`*^9}, 
   3.8097540899770155`*^9, {3.8097650203619084`*^9, 3.8097650646897144`*^9}, {
   3.809765101325409*^9, 3.809765197712268*^9}}],

Cell[TextData[{
 "These total derivatives can be added to the action without changing the \
dynamical evolution. Therefore, we simplify ",
 StyleBox["SEH2",
  FontSlant->"Italic"],
 " further..."
}], "Text",
 CellChangeTimes->{{3.8091517164045324`*^9, 3.809151738517825*^9}, {
  3.8091527474537077`*^9, 3.8091527675453453`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SK2final", "=", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"(", "SK2ibp", ")"}], "-", 
                 RowBox[{"(", 
                  RowBox[{"9", "\[Kappa]", " ", 
                   RowBox[{"dotH\[Phi]\[Phi]", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "-", 
                 RowBox[{"(", 
                  RowBox[{"18", "\[Kappa]", " ", 
                   RowBox[{"dotH\[Phi]\[Psi]", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "-", 
                 RowBox[{"(", 
                  RowBox[{"6", "\[Kappa]", " ", 
                   RowBox[{"dotHd\[Phi]d\[Psi]", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "-", 
                 RowBox[{"(", 
                  RowBox[{"12", "\[Kappa]", " ", 
                   RowBox[{"dotH\[Psi]\[Psi]", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "+", 
                 RowBox[{"(", 
                  RowBox[{"3", "\[Kappa]", " ", 
                   RowBox[{"dotHcdBcdB", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "+", 
                 RowBox[{"(", 
                  RowBox[{"2", "\[Kappa]", " ", 
                   RowBox[{"dotcd\[Phi]cdB", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], ")"}]}], "//", 
                "ToCanonical"}], "//", "NoScalar"}], "//", "CollectXh2"}], 
             ")"}], "/.", "DDXDDXrule"}], "/.", 
           RowBox[{
            RowBox[{"expr_", " ", 
             RowBox[{"\[Psi]h", "[", 
              RowBox[{
               RowBox[{"LI", "[", "1", "]"}], ",", 
               RowBox[{"LI", "[", "2", "]"}]}], "]"}]}], "\[RuleDelayed]", 
            RowBox[{
             RowBox[{"-", 
              RowBox[{"\[Psi]h", "[", 
               RowBox[{
                RowBox[{"LI", "[", "1", "]"}], ",", 
                RowBox[{"LI", "[", "1", "]"}]}], "]"}]}], 
             RowBox[{"dt", "[", "expr", "]"}]}]}]}], ")"}], "+", 
         RowBox[{"(", 
          RowBox[{"9", "\[Kappa]", " ", 
           RowBox[{"dotH\[Psi]\[Psi]", "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], ")"}]}], "//", "ToCanonical"}], 
       "//", "NoScalar"}], "//", "CollectXh2"}], ")"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SuperscriptBox[\(S\), \((2)\)]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{"SK2final", "/.", "simpV"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.8091531681175785`*^9, 3.8091531695296545`*^9}, 
   3.809153234605311*^9, {3.809153530639943*^9, 3.809153544175867*^9}, {
   3.8091538107683015`*^9, 3.8091538972503853`*^9}, 3.8096007140939655`*^9, {
   3.8097649084928894`*^9, 3.8097649551729956`*^9}, {3.8097653792288895`*^9, 
   3.809765405161314*^9}, {3.809765451336215*^9, 3.8097654611794825`*^9}, 
   3.809765535971459*^9, {3.8097658845800686`*^9, 3.809765903727261*^9}, {
   3.809766011100991*^9, 3.8097660739608016`*^9}, {3.809766114942464*^9, 
   3.8097661645071363`*^9}, {3.8097665783554564`*^9, 3.809766580729581*^9}, {
   3.809843485534423*^9, 3.80984348893944*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SuperscriptBox[\\(S\\), \\((2)\\)]\\)\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{
    FractionBox["3", "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      InterpretationBox[
       StyleBox["V",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`V,
       Editable->False], "+", 
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"]}], "+", 
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False]}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Psi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Psi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]],
       Editable->False], ")"}], "2"]}], "-", 
   RowBox[{"12", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Psi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Psi]h[],
           Editable->False], "."]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[1]],
       Editable->False], ")"}], "2"]}], "+", 
   RowBox[{"4", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"4", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[1]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"4", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"3", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      InterpretationBox[
       StyleBox["V",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`V,
       Editable->False], "+", 
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"]}], "-", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["V",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`V,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}]}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      InterpretationBox[
       StyleBox["V",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`V,
       Editable->False], "+", 
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"]}], "-", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["V",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`V,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}]}], ")"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Phi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]],
       Editable->False], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      InterpretationBox[
       StyleBox["V",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`V,
       Editable->False], "+", 
      RowBox[{"18", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["V",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`V,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}], "-", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "4"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["V",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`V,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None]}]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{{3.809153880798731*^9, 3.809153898382336*^9}, 
   3.8093218263704443`*^9, 3.8093416447907996`*^9, 3.8093478988823457`*^9, 
   3.8095728740326214`*^9, 3.8096007166943035`*^9, 3.809615373161416*^9, 
   3.8097544007780857`*^9, 3.809764957135127*^9, 3.8097652739943476`*^9, 
   3.8097654079473124`*^9, {3.8097655122151175`*^9, 3.809765537302682*^9}, {
   3.8097658856309757`*^9, 3.8097659065835876`*^9}, 3.809766015849244*^9, 
   3.809766076133328*^9, {3.8097661168605013`*^9, 3.80976617129425*^9}, 
   3.8097668179210167`*^9, 3.809772105285025*^9, 3.8097840511172166`*^9, 
   3.809787440375429*^9, 3.8097876050643387`*^9, 3.8098310722272205`*^9, 
   3.8098393671299825`*^9, 3.8098434915012736`*^9, 3.8098435908341627`*^9, 
   3.809844411628665*^9, 3.8098634689332485`*^9, 3.809867434326769*^9}]
}, Open  ]],

Cell[TextData[{
 "A very useful trick at this stage is to make use of the background \
equations. This comes from the observation that the combination ",
 Cell[BoxData[
  RowBox[{
   InterpretationBox[
    StyleBox["V",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`V,
    Editable->False], "+", 
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["H",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Hh[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}], "-", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[CurlyPhi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][],
         Editable->False], "."],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xPand`\[CurlyPhi][
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[1]],
      Editable->False], "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["V",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`V,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None]}]}]],
  CellChangeTimes->{{3.809153880798731*^9, 3.809153898382336*^9}, 
    3.8093218263704443`*^9, 3.8093416447907996`*^9, 3.8093478988823457`*^9, 
    3.8095728740326214`*^9, 3.8096007166943035`*^9, 3.809615373161416*^9, 
    3.8097544007780857`*^9, 3.809764957135127*^9, 3.8097652739943476`*^9, 
    3.8097654079473124`*^9, {3.8097655122151175`*^9, 3.809765537302682*^9}, {
    3.8097658856309757`*^9, 3.8097659065835876`*^9}, 3.809766015849244*^9, 
    3.809766076133328*^9, {3.8097661168605013`*^9, 3.80976617129425*^9}, 
    3.8097668179210167`*^9, 3.809772105285025*^9, 3.8097840511172166`*^9}],
 " is actually the Friedmann constraint. Hence, after using the background \
field equations, we obtain..."
}], "Text",
 CellChangeTimes->{{3.8097858334442234`*^9, 3.809785919072195*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SK2Final", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"SK2final", "/.", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Hh", "[", 
          RowBox[{
           RowBox[{"LI", "[", "0", "]"}], ",", 
           RowBox[{"LI", "[", "0", "]"}]}], "]"}], "2"], "\[Rule]", "Q"}]}], "/.",
       "fesVar"}], "//", "CollectXh2"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SuperscriptBox[\(S\), \((2)\)]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{"SK2Final", "/.", "simpV"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.809785958966486*^9, 3.8097859949314146`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SuperscriptBox[\\(S\\), \\((2)\\)]\\)\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "12"}], " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Psi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Psi]h[],
           Editable->False], "."]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[1]],
       Editable->False], ")"}], "2"]}], "+", 
   RowBox[{"4", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"4", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[1]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"4", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Phi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]],
       Editable->False], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox["V",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`V,
        Editable->False]}], "-", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["V",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`V,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "4"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["V",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`V,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None]}]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{3.809785995409624*^9, 3.809787440470728*^9, 
  3.8097876051576753`*^9, 3.809831072337332*^9, 3.8098393672052574`*^9, 
  3.809843590897151*^9, 3.8098444117932663`*^9, 3.8098634689947615`*^9, 
  3.809867434388898*^9}]
}, Open  ]],

Cell[TextData[{
 "Noting that this is linear in ",
 Cell[BoxData[
  FormBox["B", TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", we further perform an integration by parts so we can easily just read off \
the constraint..."
}], "Text",
 CellChangeTimes->{{3.8097860455619097`*^9, 3.8097860859322944`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SK2Final2", "=", 
    RowBox[{"Collect", "[", 
     RowBox[{
      RowBox[{"SK2Final", "/.", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"cd", "[", 
           RowBox[{"-", "x_"}], "]"}], "[", 
          RowBox[{"ph_", "[", 
           RowBox[{"y_", ",", "z_"}], "]"}], "]"}], 
         RowBox[{
          RowBox[{"cd", "[", "x_", "]"}], "[", 
          RowBox[{"Bsh", "[", 
           RowBox[{
            RowBox[{"LI", "[", "1", "]"}], ",", 
            RowBox[{"LI", "[", "0", "]"}]}], "]"}], "]"}]}], "\[RuleDelayed]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"cd", "[", 
            RowBox[{"-", "x"}], "]"}], "[", 
           RowBox[{
            RowBox[{"cd", "[", "x", "]"}], "[", 
            RowBox[{"ph", "[", 
             RowBox[{"y", ",", "z"}], "]"}], "]"}], "]"}]}], 
         RowBox[{"Bsh", "[", 
          RowBox[{
           RowBox[{"LI", "[", "1", "]"}], ",", 
           RowBox[{"LI", "[", "0", "]"}]}], "]"}]}]}]}], ",", 
      RowBox[{"{", 
       RowBox[{"Bsh", "[", 
        RowBox[{
         RowBox[{"LI", "[", "1", "]"}], ",", 
         RowBox[{"LI", "[", "0", "]"}]}], "]"}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SuperscriptBox[\(S\), \((2)\)]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{"SK2Final2", "/.", "simpV"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.809786104715619*^9, 3.8097861254202*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SuperscriptBox[\\(S\\), \\((2)\\)]\\)\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "12"}], " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Psi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Psi]h[],
           Editable->False], "."]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[1]],
       Editable->False], ")"}], "2"]}], "+", 
   RowBox[{
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Bsh[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "b"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "b"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`b][
          $CellContext`cd[$CellContext`b][
           $CellContext`\[Phi]h[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], "-", 
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "b"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "b"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "."]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`b][
          $CellContext`cd[$CellContext`b][
           $CellContext`\[Psi]h[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[1]]]],
         Editable->False], ")"}]}]}], ")"}]}], "-", 
   RowBox[{"4", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Phi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]],
       Editable->False], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox["V",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`V,
        Editable->False]}], "-", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["V",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`V,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "4"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["V",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`V,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None]}]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{3.809786125978718*^9, 3.809787440551813*^9, 
  3.8097876052390633`*^9, 3.8098310724594135`*^9, 3.809839367253084*^9, 
  3.809843590954008*^9, 3.8098444118991323`*^9, 3.8098634690448027`*^9, 
  3.8098674344369926`*^9}]
}, Open  ]],

Cell[TextData[{
 "The constraint on ",
 Cell[BoxData[
  FormBox["B", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " drastically simplifies everything else..."
}], "Text",
 CellChangeTimes->{{3.8097861810337057`*^9, 3.809786192675545*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ConstraintB", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"VarD", "[", 
         RowBox[{
          RowBox[{"Bsh", "[", 
           RowBox[{
            RowBox[{"LI", "[", "1", "]"}], ",", 
            RowBox[{"LI", "[", "0", "]"}]}], "]"}], ",", "cd"}], "]"}], "[", 
        "SK2Final2", "]"}], "/.", "DeltaRule"}], "//", "NoScalar"}], ")"}], 
    "\[Equal]", "0"}]}], ";", "ConstraintB"}]], "Input",
 CellChangeTimes->{{3.8097862025483227`*^9, 3.809786211770505*^9}, {
  3.8097874841284375`*^9, 3.8097874883005323`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"-", "4"}], " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`cd[$CellContext`b][
        $CellContext`\[Phi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"4", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`cd[$CellContext`b][
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1]]]],
      Editable->False], ")"}]}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.809786212203849*^9, 3.8097874406108932`*^9, 
  3.8097874891209717`*^9, 3.8097876053387527`*^9, 3.809831072560939*^9, 
  3.8098393673186073`*^9, 3.8098435910377636`*^9, 3.8098444119980335`*^9, 
  3.8098634691201153`*^9, 3.809867434516833*^9}]
}, Open  ]],

Cell["\<\
The exact solution to this can of course be obtained simply by removing the \
Laplacian...\
\>", "Text",
 CellChangeTimes->{{3.8097862174965954`*^9, 3.809786280685547*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ConstraintB2", "=", 
   RowBox[{"ConstraintB", "/.", 
    RowBox[{
     RowBox[{
      RowBox[{"cd", "[", 
       RowBox[{"-", "x_"}], "]"}], "[", 
      RowBox[{
       RowBox[{"cd", "[", "x_", "]"}], "[", "expr_", "]"}], "]"}], 
     "\[RuleDelayed]", "expr"}]}]}], ";", "ConstraintB2"}]], "Input",
 CellChangeTimes->{{3.809786284384799*^9, 3.809786304794548*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"-", "4"}], " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"4", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}]}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.8097863052209687`*^9, 3.8097874406423693`*^9, 
  3.809787492956724*^9, 3.809787605396065*^9, 3.809831072585756*^9, 
  3.8098393673466806`*^9, 3.809843591063918*^9, 3.8098444120213814`*^9, 
  3.8098634691569686`*^9, 3.8098674345507135`*^9}]
}, Open  ]],

Cell[TextData[{
 "Using this constraint, we eliminate ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Phi]", " "}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " from the action..."
}], "Text",
 CellChangeTimes->{{3.8097863287846746`*^9, 3.8097863452180233`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SK2Final3", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"SK2Final2", "/.", 
        RowBox[{
         RowBox[{"Solve", "[", 
          RowBox[{"ConstraintB2", ",", 
           RowBox[{"\[Phi]h", "[", 
            RowBox[{
             RowBox[{"LI", "[", "1", "]"}], ",", 
             RowBox[{"LI", "[", "0", "]"}]}], "]"}]}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], "//", "ToCanonical"}], "//", 
      "NoScalar"}], "//", "CollectXh2"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SuperscriptBox[\(S\), \((2)\)]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{"SK2Final3", "/.", "simpV"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.8097863535046687`*^9, 3.809786395775483*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SuperscriptBox[\\(S\\), \\((2)\\)]\\)\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "+", 
   FractionBox[
    RowBox[{"4", " ", 
     InterpretationBox[
      StyleBox["\[Kappa]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Kappa],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox[
          OverscriptBox["D", "_"], "b"], 
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Psi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Psi]h[],
           Editable->False], "."]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[-$CellContext`b][
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1]]],
       Editable->False], ")"}], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SuperscriptBox[
          OverscriptBox["D", "_"], "b"], 
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Psi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Psi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[$CellContext`b][
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]],
       Editable->False], ")"}]}], 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], "3"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Psi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Psi]h[],
            Editable->False], "."]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1]],
        Editable->False], ")"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        InterpretationBox[
         StyleBox["V",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`V,
         Editable->False]}], "+", 
       RowBox[{"12", " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["H",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Hh[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False], "2"]}], "-", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], "2"], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["V",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`V,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None]}], "+", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], "4"], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["V",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`V,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None]}]}], ")"}]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["H",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], "2"]}]]}]}]], "Output",
 CellChangeTimes->{{3.8097863707136908`*^9, 3.809786396276075*^9}, 
   3.8097874412886124`*^9, 3.809787495221594*^9, 3.8097876055620856`*^9, 
   3.8098310726729207`*^9, 3.8098393674334745`*^9, 3.8098435912050967`*^9, 
   3.809844412104167*^9, 3.809863469245822*^9, 3.8098674346420627`*^9}]
}, Open  ]],

Cell["\<\
Last step is to perform an IBP over the term with a single time derivative...\
\>", "Text",
 CellChangeTimes->{{3.809786400743673*^9, 3.8097864204755173`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"aHcd\[Psi]cd\[Psi]", "=", 
    RowBox[{
     RowBox[{"Hold", "[", 
      RowBox[{"\"\<\!\(\*FractionBox[\(d\), \(dt\)]\)\>\"", 
       RowBox[{"Hold", "[", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"ah", "[", 
            RowBox[{
             RowBox[{"LI", "[", "0", "]"}], ",", 
             RowBox[{"LI", "[", "0", "]"}]}], "]"}], 
           RowBox[{"Hh", "[", 
            RowBox[{
             RowBox[{"LI", "[", "0", "]"}], ",", 
             RowBox[{"LI", "[", "0", "]"}]}], "]"}]], 
          RowBox[{
           RowBox[{"cd", "[", 
            RowBox[{"-", "b"}], "]"}], "[", 
           RowBox[{"\[Psi]h", "[", 
            RowBox[{
             RowBox[{"LI", "[", "1", "]"}], ",", 
             RowBox[{"LI", "[", "0", "]"}]}], "]"}], "]"}], 
          RowBox[{
           RowBox[{"cd", "[", "b", "]"}], "[", 
           RowBox[{"\[Psi]h", "[", 
            RowBox[{
             RowBox[{"LI", "[", "1", "]"}], ",", 
             RowBox[{"LI", "[", "0", "]"}]}], "]"}], "]"}]}], ")"}], "]"}]}], 
      "]"}], "\[Equal]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"dt", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"ah", "[", 
             RowBox[{
              RowBox[{"LI", "[", "0", "]"}], ",", 
              RowBox[{"LI", "[", "0", "]"}]}], "]"}], 
            RowBox[{"Hh", "[", 
             RowBox[{
              RowBox[{"LI", "[", "0", "]"}], ",", 
              RowBox[{"LI", "[", "0", "]"}]}], "]"}]], 
           RowBox[{
            RowBox[{"cd", "[", 
             RowBox[{"-", "b"}], "]"}], "[", 
            RowBox[{"\[Psi]h", "[", 
             RowBox[{
              RowBox[{"LI", "[", "1", "]"}], ",", 
              RowBox[{"LI", "[", "0", "]"}]}], "]"}], "]"}], 
           RowBox[{
            RowBox[{"cd", "[", "b", "]"}], "[", 
            RowBox[{"\[Psi]h", "[", 
             RowBox[{
              RowBox[{"LI", "[", "1", "]"}], ",", 
              RowBox[{"LI", "[", "0", "]"}]}], "]"}], "]"}]}], "]"}], "//", 
         "ContractMetric"}], "//", "ToCanonical"}], "//", "NoScalar"}], 
      ")"}]}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SKquad", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"SK2Final3", "-", 
              RowBox[{"(", 
               RowBox[{"2", "\[Kappa]", " ", 
                RowBox[{"aHcd\[Psi]cd\[Psi]", "[", 
                 RowBox[{"[", "2", "]"}], "]"}]}], ")"}]}], "//", 
             "ToCanonical"}], "//", "NoScalar"}], "//", "CollectXh2"}], ")"}],
          "/.", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Hh", "[", 
            RowBox[{
             RowBox[{"LI", "[", "0", "]"}], ",", 
             RowBox[{"LI", "[", "0", "]"}]}], "]"}], "2"], "\[Rule]", "Q"}]}],
         "/.", "fesVar"}], "//", "ToCanonical"}], "//", "NoScalar"}], "//", 
     "CollectXh2"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SuperscriptBox[\(S\), \((2)\)]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{"SKquad", "/.", "simpV"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.809786435423665*^9, 3.8097865277860985`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SuperscriptBox[\\(S\\), \\((2)\\)]\\)\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "b"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Psi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Psi]h[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`b][
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]],
        Editable->False], ")"}], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox[
           OverscriptBox["D", "_"], "b"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Psi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Psi]h[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[$CellContext`b][
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]],
        Editable->False], ")"}], " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox["V",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`V,
        Editable->False], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None]}], 
     RowBox[{"2", " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]}]]}], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], "3"], " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[CurlyPhi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][],
          Editable->False], "."],
        ShowAutoStyles->False,
        AutoSpacing->False],
       xAct`xPand`\[CurlyPhi][
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[1]],
       Editable->False], "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Psi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Psi]h[],
            Editable->False], "."]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1]],
        Editable->False], ")"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["V",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`V,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "+", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], "2"], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["V",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`V,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None]}]}], ")"}]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["H",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], "2"]}]]}]}]], "Output",
 CellChangeTimes->{3.8097865284142427`*^9, 3.809787442090006*^9, 
  3.8097874992900105`*^9, 3.809787605751544*^9, 3.809831072862719*^9, 
  3.809839367598569*^9, 3.8098435914298563`*^9, 3.809844412277425*^9, 
  3.809863469450491*^9, 3.8098674348103037`*^9}]
}, Open  ]],

Cell["\<\
This is the second-order action for quintessence. Stability conditions can be \
read from this...\
\>", "Text",
 CellChangeTimes->{{3.8097865446362505`*^9, 3.809786575889507*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"$Assumptions", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"ah", "[", 
       RowBox[{
        RowBox[{"LI", "[", "0", "]"}], ",", 
        RowBox[{"LI", "[", "0", "]"}]}], "]"}], ">", "0"}], "&&", 
     RowBox[{
      RowBox[{"Hh", "[", 
       RowBox[{
        RowBox[{"LI", "[", "0", "]"}], ",", 
        RowBox[{"LI", "[", "0", "]"}]}], "]"}], ">", "0"}], "&&", 
     RowBox[{
      RowBox[{"\[CurlyPhi]", "[", 
       RowBox[{
        RowBox[{"LI", "[", "0", "]"}], ",", 
        RowBox[{"LI", "[", "1", "]"}]}], "]"}], ">", "0"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"SKquad", "/.", "simpV"}], ",", 
     SuperscriptBox[
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Psi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Psi]h[],
            Editable->False], "."]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1]],
        Editable->False], ")"}], "2"]}], "]"}], ">", "0"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    RowBox[{"Coefficient", "[", 
     RowBox[{
      RowBox[{"SKquad", "/.", "simpV"}], ",", 
      RowBox[{
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "b"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`b][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "b"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`b][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}]}], "]"}]}], ">", "0"}], "//", 
  "Simplify"}]}], "Input",
 CellChangeTimes->{{3.8097865880641513`*^9, 3.809786629894213*^9}, {
  3.8097867195898848`*^9, 3.8097867995473557`*^9}, {3.809786832737085*^9, 
  3.809786927998188*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox[
    InterpretationBox[
     StyleBox["V",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`V,
     Editable->False], 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "1"}], ")"}],
     Derivative],
    MultilineFunction->None], "+", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[CurlyPhi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][],
         Editable->False], "."],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xPand`\[CurlyPhi][
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[1]],
      Editable->False], "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["V",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`V,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None]}]}], ">", "0"}]], "Output",
 CellChangeTimes->{3.8097869286563334`*^9, 3.8097874422592764`*^9, 
  3.8097875025443597`*^9, 3.809787605806296*^9, 3.809831072914238*^9, 
  3.809839367645757*^9, 3.8098435914725733`*^9, 3.809844412325247*^9, 
  3.809863469501379*^9, 3.809867434848625*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox[
   InterpretationBox[
    StyleBox["V",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`V,
    Editable->False], 
   TagBox[
    RowBox[{"(", 
     RowBox[{"0", ",", "1"}], ")"}],
    Derivative],
   MultilineFunction->None], ">", "0"}]], "Output",
 CellChangeTimes->{3.8097869286563334`*^9, 3.8097874422592764`*^9, 
  3.8097875025443597`*^9, 3.809787605806296*^9, 3.809831072914238*^9, 
  3.809839367645757*^9, 3.8098435914725733`*^9, 3.809844412325247*^9, 
  3.809863469501379*^9, 3.8098674348623104`*^9}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["III. Second-order action for ",
  FontColor->RGBColor[1, 0.5, 0.5]],
 StyleBox["scalar",
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0.5, 0.5]],
 StyleBox[" perturbations of KGB",
  FontColor->RGBColor[1, 0.5, 0.5]]
}], "Subsection",
 CellChangeTimes->{{3.809786958135058*^9, 3.8097869688624525`*^9}, {
  3.8098632378737793`*^9, 3.8098632417296515`*^9}}],

Cell[TextData[{
 "In this section, we derive the second-order action of KGB. Since we\
\[CloseCurlyQuote]ve already dealt with ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]]],
 "-essence, we have to just bother about the braiding terms.\n\nWe start with \
the full perturbed action..."
}], "Text",
 CellChangeTimes->{{3.8097869946803226`*^9, 3.809787060669959*^9}, {
  3.8097876948223515`*^9, 3.809787708052204*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SKG012", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"MyToxPand", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SqrtBox[
            RowBox[{"-", 
             RowBox[{"Detg", "[", "]"}]}]], 
           RowBox[{"(", 
            RowBox[{"LK", "+", "LG", "+", "LEH"}], ")"}]}], "/.", 
          RowBox[{
           RowBox[{"\[Chi]", "[", "]"}], "\[Rule]", 
           RowBox[{"\[CurlyPhi]", "[", "]"}]}]}], ",", 
         "\"\<ScalarFieldComovingGauge\>\"", ",", "2"}], "]"}], "/.", 
       "kill2O"}], "/.", 
      RowBox[{
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Detg", "[", "]"}]}], 
         SuperscriptBox[
          RowBox[{"Scalar", "[", 
           RowBox[{"ah", "[", "]"}], "]"}], "8"]}], "]"}], "\[Rule]", 
       SuperscriptBox[
        RowBox[{"ah", "[", 
         RowBox[{
          RowBox[{"LI", "[", "0", "]"}], ",", 
          RowBox[{"LI", "[", "0", "]"}]}], "]"}], "3"]}]}], "//", "Expand"}], 
    "//", "org"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8097877380399914`*^9, 3.8097877387193904`*^9}, 
   3.8097878145615826`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The Splitting of \"\>", "\[InvisibleSpace]", 
   FractionBox[
    RowBox[{
     InterpretationBox[
      StyleBox["\[Kappa]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Kappa],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["R",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`RicciScalarCD[],
      Editable->False], " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"-", 
        InterpretationBox[
         StyleBox[
          OverscriptBox["g", 
           OverscriptBox[
            StyleBox["~",
             FontColor->RGBColor[0, 0, 0]], 
            StyleBox["~",
             FontColor->RGBColor[0, 0, 0]]]],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Detg[],
         Editable->False]}], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          RowBox[{
           StyleBox["(",
            FontColor->RGBColor[1, 0, 0]], 
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["a",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`ah[],
               Editable->False], ""],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[0]],
            Editable->False], 
           StyleBox[")",
            FontColor->RGBColor[1, 0, 0]]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xTensor`Scalar[
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]]],
         Editable->False], "8"]}]]}], 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       RowBox[{
        StyleBox["(",
         FontColor->RGBColor[1, 0, 0]], 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], 
        StyleBox[")",
         FontColor->RGBColor[1, 0, 0]]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xTensor`Scalar[
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]]],
      Editable->False], "2"]], 
   "\[InvisibleSpace]", "\<\" +... was performed in \"\>", 
   "\[InvisibleSpace]", "69.8072758`", 
   "\[InvisibleSpace]", "\<\" seconds.\"\>"}],
  SequenceForm[
  "The Splitting of ", $CellContext`\[Kappa] $CellContext`RicciScalarCD[] 
   xAct`xTensor`Scalar[
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]]]^(-2) (-$CellContext`Detg[] xAct`xTensor`Scalar[
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]]]^8)^Rational[1, 2], " +... was performed in ", 
   69.8072758, " seconds."],
  Editable->False]], "Print",
 CellChangeTimes->{3.809787894736183*^9, 3.8098313361725936`*^9, 
  3.809840027621643*^9, 3.8098436623073263`*^9, 3.8098444841073747`*^9, 
  3.809863546964428*^9, 3.809867506751679*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Background solutions", "Subsubsection",
 CellChangeTimes->{{3.8097877487831383`*^9, 3.809787755363824*^9}}],

Cell[TextData[{
 "As with ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]]],
 "-essence, we first derive the background field equations because these will \
drastically simplify the analysis of the second-order action later. So, \
extracting the first order terms from ",
 StyleBox["SKG012",
  FontSlant->"Italic"],
 "..."
}], "Text",
 CellChangeTimes->{{3.8097877572329454`*^9, 3.8097878347250357`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SKG1", "=", 
    RowBox[{"ExtractOrder", "[", 
     RowBox[{"SKG012", ",", "1"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
   "\"\<\!\(\*SuperscriptBox[\(S\), \((1)\)]\)\>\"", "\[Equal]", "SKG1"}], "/.",
    "simp"}], "//", "CollectXh"}]}], "Input",
 CellChangeTimes->{{3.809787852419359*^9, 3.80978786172756*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SuperscriptBox[\\(S\\), \\((1)\\)]\\)\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], "3"]}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False]}]}], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"3", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      InterpretationBox[
       StyleBox["V",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`V,
       Editable->False], "+", 
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"]}], "+", 
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False]}], "+", 
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], ".."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[2]],
        Editable->False]}]}], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"3", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"8", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False]}]}], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ".."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[2]],
      Editable->False], ")"}]}], "-", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False]}]}], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "i"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "i"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`i][
       $CellContext`cd[$CellContext`i][
        $CellContext`Bsh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "i"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "i"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`i][
       $CellContext`cd[$CellContext`i][
        $CellContext`Bsh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1]]]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "i"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "i"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`i][
       $CellContext`cd[$CellContext`i][
        $CellContext`\[Phi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"4", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "i"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "i"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`i][
       $CellContext`cd[$CellContext`i][
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      InterpretationBox[
       StyleBox["V",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`V,
       Editable->False], "-", 
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"]}], "-", 
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], ".."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[2]],
        Editable->False]}], "-", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], ".."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[2]],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}], "-", 
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       RowBox[{"(", 
        RowBox[{
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], "+", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[CurlyPhi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][],
               Editable->False], "."],
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[1]],
            Editable->False], "2"], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None]}]}], ")"}]}], "-", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["V",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`V,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{3.8097879679598446`*^9, 3.809831354322298*^9, 
  3.809840028907219*^9, 3.809843663458932*^9, 3.8098444853063774`*^9, 
  3.809863548964084*^9, 3.809867507913785*^9}]
}, Open  ]],

Cell[TextData[{
 "Performing partial integration (recall that ",
 StyleBox["dt[...]",
  FontSlant->"Italic"],
 " is the time derivative)..."
}], "Text",
 CellChangeTimes->{{3.809788021147944*^9, 3.809788027711901*^9}, {
  3.8098313319671507`*^9, 3.8098313505393085`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SKG1final", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"SKG1", "/.", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"ah", "[", 
            RowBox[{
             RowBox[{"LI", "[", "0", "]"}], ",", 
             RowBox[{"LI", "[", "0", "]"}]}], "]"}], "3"], 
          RowBox[{"\[Psi]h", "[", 
           RowBox[{
            RowBox[{"LI", "[", "1", "]"}], ",", 
            RowBox[{"LI", "[", "2", "]"}]}], "]"}]}], "\[Rule]", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"\[Psi]h", "[", 
            RowBox[{
             RowBox[{"LI", "[", "1", "]"}], ",", 
             RowBox[{"LI", "[", "1", "]"}]}], "]"}]}], 
          RowBox[{"dt", "[", 
           SuperscriptBox[
            RowBox[{"ah", "[", 
             RowBox[{
              RowBox[{"LI", "[", "0", "]"}], ",", 
              RowBox[{"LI", "[", "0", "]"}]}], "]"}], "3"], "]"}]}]}]}], "/.", 
       RowBox[{
        RowBox[{"expr_", " ", 
         RowBox[{"ph_", "[", 
          RowBox[{
           RowBox[{"LI", "[", "1", "]"}], ",", 
           RowBox[{"LI", "[", "1", "]"}]}], "]"}]}], "\[RuleDelayed]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"ph", "[", 
           RowBox[{
            RowBox[{"LI", "[", "1", "]"}], ",", 
            RowBox[{"LI", "[", "0", "]"}]}], "]"}]}], 
         RowBox[{"dt", "[", "expr", "]"}]}]}]}], "/.", 
      RowBox[{
       RowBox[{"expr_", " ", 
        RowBox[{
         RowBox[{"cd", "[", 
          RowBox[{"-", "x_"}], "]"}], "[", 
         RowBox[{
          RowBox[{"cd", "[", "x_", "]"}], "[", 
          RowBox[{"Bsh", "[", 
           RowBox[{
            RowBox[{"LI", "[", "1", "]"}], ",", 
            RowBox[{"LI", "[", "1", "]"}]}], "]"}], "]"}], "]"}]}], 
       "\[RuleDelayed]", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"cd", "[", 
           RowBox[{"-", "x"}], "]"}], "[", 
          RowBox[{
           RowBox[{"cd", "[", "x", "]"}], "[", 
           RowBox[{"Bsh", "[", 
            RowBox[{
             RowBox[{"LI", "[", "1", "]"}], ",", 
             RowBox[{"LI", "[", "0", "]"}]}], "]"}], "]"}], "]"}]}], 
        RowBox[{"dt", "[", "expr", "]"}]}]}]}], "//", "CollectXh"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "\"\<\!\(\*SuperscriptBox[\(S\), \((1)\)]\)\>\"", "\[Equal]", "SKG1final"}],
   "/.", "simp"}]}], "Input",
 CellChangeTimes->{{3.8097880334172955`*^9, 3.8097880850749187`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SuperscriptBox[\\(S\\), \\((1)\\)]\\)\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], "2"]}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False]}]}], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "i"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "i"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`i][
       $CellContext`cd[$CellContext`i][
        $CellContext`Bsh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "i"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "i"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`i][
       $CellContext`cd[$CellContext`i][
        $CellContext`\[Phi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"4", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "i"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "i"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`i][
       $CellContext`cd[$CellContext`i][
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"3", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      InterpretationBox[
       StyleBox["V",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`V,
       Editable->False], "+", 
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"]}], "+", 
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False]}], "-", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], ".."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[2]],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}], "-", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None]}]}], ")"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      InterpretationBox[
       StyleBox["V",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`V,
       Editable->False], "+", 
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"]}], "-", 
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "3"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["V",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`V,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None]}], "+", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None]}], ")"}]}]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{{3.80978807061703*^9, 3.8097880867625265`*^9}, 
   3.809831361634941*^9, 3.809840029133957*^9, 3.809843663610383*^9, 
   3.80984448546929*^9, 3.809863549132907*^9, 3.809867508075647*^9}]
}, Open  ]],

Cell[TextData[{
 "The terms with Laplacians vanish by partial differentiation because they \
are besides purely time-dependent terms only. The constraints, or rather, the \
background equations, can therefore be read off from the coefficients of ",
 Cell[BoxData[
  FormBox["\[Phi]", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox["\[Psi]", TraditionalForm]]],
 "..."
}], "Text",
 CellChangeTimes->{{3.809788112067374*^9, 3.8097881612388*^9}, {
  3.8098313740155597`*^9, 3.8098313851984653`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"fe1", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"VarD", "[", 
         RowBox[{
          RowBox[{"\[Phi]h", "[", 
           RowBox[{
            RowBox[{"LI", "[", "1", "]"}], ",", 
            RowBox[{"LI", "[", "0", "]"}]}], "]"}], ",", "cd"}], "]"}], "[", 
        "SKG1final", "]"}], "/.", "DeltaRule"}], "//", "NoScalar"}], ")"}], 
    "\[Equal]", "0"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"fe2", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"VarD", "[", 
          RowBox[{
           RowBox[{"\[Psi]h", "[", 
            RowBox[{
             RowBox[{"LI", "[", "1", "]"}], ",", 
             RowBox[{"LI", "[", "0", "]"}]}], "]"}], ",", "cd"}], "]"}], "[", 
         "SKG1final", "]"}], "/.", "DeltaRule"}], "//", "NoScalar"}], ")"}], 
     "\[Equal]", "0"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fesVar", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"fe1", ",", "fe2"}], "}"}], "/.", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Hh", "[", 
          RowBox[{
           RowBox[{"LI", "[", "0", "]"}], ",", 
           RowBox[{"LI", "[", "0", "]"}]}], "]"}], "2"], "\[Rule]", "Q"}]}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"Q", ",", 
        RowBox[{"Hh", "[", 
         RowBox[{
          RowBox[{"LI", "[", "0", "]"}], ",", 
          RowBox[{"LI", "[", "1", "]"}]}], "]"}]}], "}"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"fesVar", "/.", "simp"}]}], "Input",
 CellChangeTimes->{{3.809788199094146*^9, 3.8097882007511578`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Q", "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox["V",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`V,
        Editable->False], "-", 
       RowBox[{"3", " ", 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], "3"], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None]}], "-", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], "2"], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["V",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`V,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None]}], "+", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], "2"], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None]}]}], 
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False]}]]}]}], ",", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], "."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{"3", " ", 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], "3"], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None]}], "-", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], "2"], " ", 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], ".."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[2]],
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None]}], "+", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], "2"], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["V",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`V,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], "2"], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None]}]}], 
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False]}]]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.8097882104566917`*^9, 3.809831414046654*^9, 
  3.809840029305916*^9, 3.809843663775447*^9, 3.8098444856433306`*^9, 
  3.809863549301361*^9, 3.8098675082368712`*^9}]
}, Open  ]],

Cell["These are the background field equations.", "Text",
 CellChangeTimes->{{3.8097882993277917`*^9, 3.8097883067216787`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Quadratic action", "Subsubsection",
 CellChangeTimes->{{3.8097883106433554`*^9, 3.809788312722613*^9}}],

Cell["Extracting the second-order pieces of the full action...", "Text",
 CellChangeTimes->{{3.8097883224440184`*^9, 3.8097883358856816`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SKG2", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"ExtractOrder", "[", 
      RowBox[{"SKG012", ",", "2"}], "]"}], "//", "ToCanonical"}], "//", 
    "NoScalar"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8097883384177866`*^9, 3.8097883625656786`*^9}}],

Cell[TextData[{
 "We are expecting this to already look so bad and don\[CloseCurlyQuote]t \
want to look at it. So, we first perform the partial differentiations done \
previously in ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]]],
 "-essence..."
}], "Text",
 CellChangeTimes->{{3.8097883681625223`*^9, 3.8097884018742867`*^9}, {
  3.809831444867076*^9, 3.8098314500937243`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SKG2ibp", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"SKG2", "/.", "IBP1"}], "/.", "DDXDDXrule"}], "//", 
       "ToCanonical"}], "//", "NoScalar"}], "//", "CollectXh2"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "\"\<\!\(\*SuperscriptBox[\(S\), \((2)\)]\)\>\"", "\[Equal]", "SKG2ibp"}], "/.",
   "simp"}]}], "Input",
 CellChangeTimes->{{3.809788426866411*^9, 3.8097885186771317`*^9}, 
   3.809838022077753*^9, 3.8098381178897343`*^9}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SuperscriptBox[\\(S\\), \\((2)\\)]\\)\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{
    FractionBox["3", "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      InterpretationBox[
       StyleBox["V",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`V,
       Editable->False], "+", 
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"]}], "+", 
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False]}], "+", 
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], ".."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[2]],
        Editable->False]}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Psi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Psi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]],
       Editable->False], ")"}], "2"]}], "+", 
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"8", " ", 
          InterpretationBox[
           StyleBox["\[Kappa]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Kappa],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["H",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Hh[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False]}], "+", 
         RowBox[{
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], "."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[1]],
           Editable->False]}]}], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "."]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"6", " ", 
          InterpretationBox[
           StyleBox["\[Kappa]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Kappa],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["H",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Hh[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              OverscriptBox["\[Null]", 
               StyleBox[
                RowBox[{"(", "1", ")"}],
                FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
              OverscriptBox[
               InterpretationBox[
                StyleBox["\[Phi]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Phi]h[],
                Editable->False], "."]}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]h[
             xAct`xTensor`LI[1], 
             xAct`xTensor`LI[1]],
            Editable->False], ")"}]}], "+", 
         RowBox[{
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], "."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[1]],
           Editable->False], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              OverscriptBox["\[Null]", 
               StyleBox[
                RowBox[{"(", "1", ")"}],
                FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
              OverscriptBox[
               InterpretationBox[
                StyleBox["\[Phi]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Phi]h[],
                Editable->False], "."]}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]h[
             xAct`xTensor`LI[1], 
             xAct`xTensor`LI[1]],
            Editable->False], ")"}]}], "+", 
         RowBox[{"2", " ", 
          InterpretationBox[
           StyleBox["\[Kappa]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Kappa],
           Editable->False], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              OverscriptBox["\[Null]", 
               StyleBox[
                RowBox[{"(", "1", ")"}],
                FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
              OverscriptBox[
               InterpretationBox[
                StyleBox["\[Psi]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Psi]h[],
                Editable->False], ".."]}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Psi]h[
             xAct`xTensor`LI[1], 
             xAct`xTensor`LI[2]],
            Editable->False], ")"}]}]}], ")"}]}]}], ")"}]}], "+", 
   RowBox[{"4", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[1]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "-", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"6", " ", 
          InterpretationBox[
           StyleBox["\[Kappa]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Kappa],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["H",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Hh[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False]}], "+", 
         RowBox[{
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], "."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[1]],
           Editable->False]}]}], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "b"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["B",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Bsh[],
             Editable->False], "."]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`b][
          $CellContext`Bsh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[1]]],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "b"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["B",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Bsh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`b][
          $CellContext`Bsh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], "+", 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox[
               OverscriptBox["D", "_"], "b"], 
              OverscriptBox["\[Null]", 
               StyleBox[
                RowBox[{"(", "1", ")"}],
                FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
              OverscriptBox[
               InterpretationBox[
                StyleBox["\[Phi]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Phi]h[],
                Editable->False], "."]}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`cd[-$CellContext`b][
             $CellContext`\[Phi]h[
              xAct`xTensor`LI[1], 
              xAct`xTensor`LI[1]]],
            Editable->False], ")"}], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox[
               OverscriptBox["D", "_"], "b"], 
              OverscriptBox["\[Null]", 
               StyleBox[
                RowBox[{"(", "1", ")"}],
                FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
              OverscriptBox[
               InterpretationBox[
                StyleBox["B",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`Bsh[],
                Editable->False], ""]}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`cd[$CellContext`b][
             $CellContext`Bsh[
              xAct`xTensor`LI[1], 
              xAct`xTensor`LI[0]]],
            Editable->False], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox[
               OverscriptBox["D", "_"], "b"], 
              OverscriptBox["\[Null]", 
               StyleBox[
                RowBox[{"(", "1", ")"}],
                FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
              OverscriptBox[
               InterpretationBox[
                StyleBox["\[Phi]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Phi]h[],
                Editable->False], ""]}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`cd[-$CellContext`b][
             $CellContext`\[Phi]h[
              xAct`xTensor`LI[1], 
              xAct`xTensor`LI[0]]],
            Editable->False], ")"}], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox[
               OverscriptBox["D", "_"], "b"], 
              OverscriptBox["\[Null]", 
               StyleBox[
                RowBox[{"(", "1", ")"}],
                FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
              OverscriptBox[
               InterpretationBox[
                StyleBox["B",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`Bsh[],
                Editable->False], "."]}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`cd[$CellContext`b][
             $CellContext`Bsh[
              xAct`xTensor`LI[1], 
              xAct`xTensor`LI[1]]],
            Editable->False], ")"}]}]}], ")"}]}]}], ")"}]}], "-", 
   RowBox[{"4", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "-", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[CurlyPhi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][],
         Editable->False], "."],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xPand`\[CurlyPhi][
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[1]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None]}], "+", 
   RowBox[{"3", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"8", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "3"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}]}], ")"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"18", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], "."]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], "+", 
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], "."]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], "+", 
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ".."]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[2]],
         Editable->False], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "3"], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], "."]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}]}], ")"}]}], "+", 
   RowBox[{"3", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       InterpretationBox[
        StyleBox["V",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`V,
        Editable->False]}], "+", 
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"]}], "+", 
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], ".."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[2]],
        Editable->False]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], ".."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[2]],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}], "+", 
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       RowBox[{"(", 
        RowBox[{
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], "+", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[CurlyPhi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][],
               Editable->False], "."],
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[1]],
            Editable->False], "2"], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["V",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`V,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}]}], ")"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       InterpretationBox[
        StyleBox["V",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`V,
        Editable->False]}], "+", 
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"]}], "+", 
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], ".."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[2]],
        Editable->False]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], ".."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[2]],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}], "+", 
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       RowBox[{"(", 
        RowBox[{
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], "+", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[CurlyPhi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][],
               Editable->False], "."],
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[1]],
            Editable->False], "2"], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["V",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`V,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}]}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Phi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]],
       Editable->False], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       InterpretationBox[
        StyleBox["V",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`V,
        Editable->False]}], "+", 
      RowBox[{"36", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"]}], "+", 
      RowBox[{"18", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False]}], "+", 
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], ".."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[2]],
        Editable->False]}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], ".."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[2]],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["V",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`V,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "4"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], ".."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[2]],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None]}], "+", 
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], "."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[1]],
           Editable->False]}], "+", 
         RowBox[{"6", " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[CurlyPhi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][],
               Editable->False], "."],
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[1]],
            Editable->False], "3"], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None]}], "+", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[CurlyPhi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][],
               Editable->False], "."],
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[1]],
            Editable->False], "5"], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "4"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["V",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`V,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None]}]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{3.809788519786922*^9, 3.8098315732383223`*^9, 
  3.8098380242310686`*^9, 3.809838125468527*^9, 3.8098400479802027`*^9, 
  3.809843664997118*^9, 3.809844486827475*^9, 3.8098635505954847`*^9, 
  3.8098675095124063`*^9}]
}, Open  ]],

Cell["Performing partial differentiations with respect to time...", "Text",
 CellChangeTimes->{{3.8097885636129823`*^9, 3.8097885736165514`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"CollectXXX", "[", "expr_", "]"}], ":=", 
   RowBox[{"Collect", "[", 
    RowBox[{"expr", ",", 
     RowBox[{"{", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[Psi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Psi]h[],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]],
          Editable->False], ")"}], "2"], ",", 
       SuperscriptBox[
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[Psi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Psi]h[],
              Editable->False], "."]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[1]],
          Editable->False], ")"}], "2"], ",", 
       RowBox[{
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox[
             OverscriptBox["D", "_"], "b"], 
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[Psi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Psi]h[],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`cd[-$CellContext`b][
           $CellContext`\[Psi]h[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SuperscriptBox[
             OverscriptBox["D", "_"], "b"], 
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[Psi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Psi]h[],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`cd[$CellContext`b][
           $CellContext`\[Psi]h[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]],
          Editable->False], ")"}]}], ",", 
       RowBox[{
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[Phi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]h[],
              Editable->False], "."]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[1]],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[Psi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Psi]h[],
              Editable->False], "."]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[1]],
          Editable->False], ")"}]}], ",", 
       RowBox[{
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[Psi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Psi]h[],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]],
          Editable->False], ")"}], 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[Phi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]h[],
              Editable->False], "."]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[1]],
          Editable->False], ")"}]}], ",", 
       RowBox[{
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[Psi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Psi]h[],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]],
          Editable->False], ")"}], 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[Psi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Psi]h[],
              Editable->False], "."]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[1]],
          Editable->False], ")"}]}], ",", 
       RowBox[{
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox[
             OverscriptBox["D", "_"], "b"], 
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["B",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Bsh[],
              Editable->False], "."]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`cd[-$CellContext`b][
           $CellContext`Bsh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[1]]],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SuperscriptBox[
             OverscriptBox["D", "_"], "b"], 
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["B",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Bsh[],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`cd[$CellContext`b][
           $CellContext`Bsh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]],
          Editable->False], ")"}]}], ",", 
       RowBox[{
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox[
             OverscriptBox["D", "_"], "b"], 
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[Psi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Psi]h[],
              Editable->False], "."]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`cd[-$CellContext`b][
           $CellContext`\[Psi]h[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[1]]],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SuperscriptBox[
             OverscriptBox["D", "_"], "b"], 
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["B",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Bsh[],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`cd[$CellContext`b][
           $CellContext`Bsh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]],
          Editable->False], ")"}]}], ",", 
       RowBox[{
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox[
             OverscriptBox["D", "_"], "b"], 
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[Psi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Psi]h[],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`cd[-$CellContext`b][
           $CellContext`\[Psi]h[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SuperscriptBox[
             OverscriptBox["D", "_"], "b"], 
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[Phi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]h[],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`cd[$CellContext`b][
           $CellContext`\[Phi]h[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]],
          Editable->False], ")"}]}], ",", 
       RowBox[{
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[Phi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]h[],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[Phi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]h[],
              Editable->False], "."]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[1]],
          Editable->False], ")"}]}], ",", 
       RowBox[{
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox[
             OverscriptBox["D", "_"], "b"], 
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[Phi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]h[],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`cd[-$CellContext`b][
           $CellContext`\[Phi]h[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SuperscriptBox[
             OverscriptBox["D", "_"], "b"], 
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["B",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Bsh[],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`cd[$CellContext`b][
           $CellContext`Bsh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]],
          Editable->False], ")"}]}], ",", 
       RowBox[{
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[Phi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]h[],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[Psi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Psi]h[],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]],
          Editable->False], ")"}]}], ",", 
       SuperscriptBox[
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[Phi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]h[],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]],
          Editable->False], ")"}], "2"], ",", 
       RowBox[{
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox[
             OverscriptBox["D", "_"], "b"], 
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["B",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Bsh[],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`cd[-$CellContext`b][
           $CellContext`Bsh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SuperscriptBox[
             OverscriptBox["D", "_"], "b"], 
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["B",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Bsh[],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`cd[$CellContext`b][
           $CellContext`Bsh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]],
          Editable->False], ")"}]}]}], "}"}], ",", "Simplify"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SKG2final", "=", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"(", "SKG2ibp", ")"}], "-", 
                RowBox[{"(", 
                 RowBox[{"9", "\[Kappa]", " ", 
                  RowBox[{"dotH\[Phi]\[Phi]", "[", 
                   RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "-", 
                RowBox[{"(", 
                 RowBox[{"18", "\[Kappa]", " ", 
                  RowBox[{"dotH\[Phi]\[Psi]", "[", 
                   RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "-", 
                RowBox[{"(", 
                 RowBox[{"6", "\[Kappa]", " ", 
                  RowBox[{"dotHd\[Phi]d\[Psi]", "[", 
                   RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "-", 
                RowBox[{"(", 
                 RowBox[{"12", "\[Kappa]", " ", 
                  RowBox[{"dotH\[Psi]\[Psi]", "[", 
                   RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "+", 
                RowBox[{"(", 
                 RowBox[{"3", "\[Kappa]", " ", 
                  RowBox[{"dotHcdBcdB", "[", 
                   RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "+", 
                RowBox[{"(", 
                 RowBox[{"2", "\[Kappa]", " ", 
                  RowBox[{"dotcd\[Phi]cdB", "[", 
                   RowBox[{"[", "2", "]"}], "]"}]}], ")"}]}], "//", 
               "ToCanonical"}], "//", "NoScalar"}], "//", "CollectXXX"}], 
            ")"}], "/.", 
           RowBox[{
            RowBox[{"expr_", " ", 
             RowBox[{"\[Psi]h", "[", 
              RowBox[{
               RowBox[{"LI", "[", "1", "]"}], ",", 
               RowBox[{"LI", "[", "2", "]"}]}], "]"}]}], "\[RuleDelayed]", 
            RowBox[{
             RowBox[{"-", 
              RowBox[{"\[Psi]h", "[", 
               RowBox[{
                RowBox[{"LI", "[", "1", "]"}], ",", 
                RowBox[{"LI", "[", "1", "]"}]}], "]"}]}], 
             RowBox[{"dt", "[", "expr", "]"}]}]}]}], ")"}], "+", 
         RowBox[{"(", 
          RowBox[{"9", "\[Kappa]", " ", 
           RowBox[{"dotH\[Psi]\[Psi]", "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], ")"}]}], "//", "ToCanonical"}], 
       "//", "NoScalar"}], "//", "CollectXXX"}], ")"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SuperscriptBox[\(S\), \((2)\)]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{"SKG2final", "/.", "simp"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.8097885834000964`*^9, 3.809788617287236*^9}, {
   3.809788761143653*^9, 3.8097887639263678`*^9}, {3.8097888173332634`*^9, 
   3.8097889092203927`*^9}, {3.8097889938237953`*^9, 3.80978902830424*^9}, {
   3.809789060141114*^9, 3.8097891472624865`*^9}, {3.809790191759133*^9, 
   3.809790210514838*^9}, 3.809838049145543*^9, 3.809838112606476*^9, {
   3.8098401766952844`*^9, 3.8098401797603316`*^9}, {3.8098402766483297`*^9, 
   3.809840279124109*^9}, {3.8098408233734083`*^9, 3.8098408501523013`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SuperscriptBox[\\(S\\), \\((2)\\)]\\)\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["G",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`G,
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[CurlyPhi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][],
        Editable->False], "."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[CurlyPhi][
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}]}], "+", 
   RowBox[{
    FractionBox["3", "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      InterpretationBox[
       StyleBox["V",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`V,
       Editable->False], "+", 
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"]}], "+", 
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False]}], "+", 
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], ".."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[2]],
        Editable->False]}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Psi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Psi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]],
       Editable->False], ")"}], "2"]}], "+", 
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["G",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`G,
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[CurlyPhi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][],
        Editable->False], "."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[CurlyPhi][
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Psi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Psi]h[],
           Editable->False], "."]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[1]],
       Editable->False], ")"}], "2"]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox["G",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`G,
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[CurlyPhi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][],
        Editable->False], "."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[CurlyPhi][
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[1]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"4", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[1]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"4", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[CurlyPhi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][],
        Editable->False], "."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[CurlyPhi][
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}]}], ")"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}], "-", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "3"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}]}], ")"}]}], "+", 
   RowBox[{"3", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "3"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}]}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      InterpretationBox[
       StyleBox["V",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`V,
       Editable->False], "+", 
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], ".."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[2]],
        Editable->False]}], "-", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], ".."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[2]],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}], "-", 
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       RowBox[{"(", 
        RowBox[{
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], "+", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[CurlyPhi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][],
               Editable->False], "."],
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[1]],
            Editable->False], "2"], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None]}]}], ")"}]}], "-", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["V",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`V,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}]}], ")"}]}], "+", 
   RowBox[{"3", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       InterpretationBox[
        StyleBox["V",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`V,
        Editable->False]}], "-", 
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], ".."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[2]],
        Editable->False]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], ".."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[2]],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}], "+", 
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       RowBox[{"(", 
        RowBox[{
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], "+", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[CurlyPhi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][],
               Editable->False], "."],
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[1]],
            Editable->False], "2"], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["V",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`V,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}]}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Phi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]],
       Editable->False], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       InterpretationBox[
        StyleBox["V",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`V,
        Editable->False]}], "-", 
      RowBox[{"18", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"]}], "+", 
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], ".."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[2]],
        Editable->False]}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], ".."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[2]],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["V",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`V,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "4"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], ".."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[2]],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None]}], "+", 
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], "."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[1]],
           Editable->False]}], "+", 
         RowBox[{"6", " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[CurlyPhi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][],
               Editable->False], "."],
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[1]],
            Editable->False], "3"], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None]}], "+", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[CurlyPhi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][],
               Editable->False], "."],
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[1]],
            Editable->False], "5"], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "4"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["V",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`V,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None]}]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{
  3.8097886402624273`*^9, 3.8097891489361706`*^9, 3.809790217595467*^9, 
   3.809831719571204*^9, 3.809838052431121*^9, 3.8098381305018415`*^9, 
   3.8098401848121767`*^9, 3.809840307284523*^9, {3.809840839510375*^9, 
   3.809840852212661*^9}, 3.809843665861469*^9, 3.80984448782796*^9, 
   3.8098635516380315`*^9, 3.8098675103798475`*^9}]
}, Open  ]],

Cell[TextData[{
 "*The set of IBPs performed above are for the Einstein-Hilbert part of the \
theory (i.e., just a Ricci scalar), and should not be different whether it be \
for pure ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]],
  FormatType->"TraditionalForm"],
 "-essence or KGB.\n\nWe perform more IBPs since we want to put all of the \
time derivative to the dynamical variable ",
 Cell[BoxData[
  FormBox["\[Psi]", TraditionalForm]]],
 "..."
}], "Text",
 CellChangeTimes->{{3.809788663941616*^9, 3.809788688075837*^9}, {
  3.8097891821180973`*^9, 3.8097892118455515`*^9}, {3.809831644827424*^9, 
  3.8098317102701216`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SKG2final2", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"SKG2final", "/.", 
        RowBox[{
         RowBox[{"expr_", " ", 
          RowBox[{"\[Phi]h", "[", 
           RowBox[{
            RowBox[{"LI", "[", "1", "]"}], ",", 
            RowBox[{"LI", "[", "1", "]"}]}], "]"}]}], "\[RuleDelayed]", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"\[Phi]h", "[", 
            RowBox[{
             RowBox[{"LI", "[", "1", "]"}], ",", 
             RowBox[{"LI", "[", "0", "]"}]}], "]"}]}], 
          RowBox[{"dt", "[", "expr", "]"}]}]}]}], "//", "ToCanonical"}], "//",
       "NoScalar"}], "//", "CollectXXX"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SuperscriptBox[\(S\), \((2)\)]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{"SKG2final2", "/.", "simp"}], 
   ")"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.8097892286787095`*^9, 3.809789327679983*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SuperscriptBox[\\(S\\), \\((2)\\)]\\)\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{
    FractionBox["3", "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      InterpretationBox[
       StyleBox["V",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`V,
       Editable->False], "+", 
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"]}], "+", 
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False]}], "+", 
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], ".."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[2]],
        Editable->False]}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Psi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Psi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]],
       Editable->False], ")"}], "2"]}], "+", 
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["G",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`G,
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[CurlyPhi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][],
        Editable->False], "."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[CurlyPhi][
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Psi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Psi]h[],
           Editable->False], "."]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[1]],
       Editable->False], ")"}], "2"]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox["G",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`G,
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[CurlyPhi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][],
        Editable->False], "."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[CurlyPhi][
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[1]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"4", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[1]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"4", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "-", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[CurlyPhi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][],
        Editable->False], "."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[CurlyPhi][
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}]}], ")"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}], "-", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "3"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}]}], ")"}]}], "+", 
   RowBox[{"3", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "3"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}]}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      InterpretationBox[
       StyleBox["V",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`V,
       Editable->False], "+", 
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], ".."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[2]],
        Editable->False]}], "-", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], ".."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[2]],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}], "-", 
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       RowBox[{"(", 
        RowBox[{
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], "+", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[CurlyPhi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][],
               Editable->False], "."],
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[1]],
            Editable->False], "2"], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None]}]}], ")"}]}], "-", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["V",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`V,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}]}], ")"}]}], "-", 
   RowBox[{"3", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      InterpretationBox[
       StyleBox["V",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`V,
       Editable->False], "+", 
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"]}], "-", 
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "3"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["V",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`V,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None]}], "+", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None]}], ")"}]}]}], ")"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Phi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]],
       Editable->False], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      InterpretationBox[
       StyleBox["V",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`V,
       Editable->False], "+", 
      RowBox[{"18", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"]}], "+", 
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], ".."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[2]],
        Editable->False]}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], ".."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[2]],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["V",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`V,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "4"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], ".."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[2]],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None]}], "+", 
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], "."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[1]],
           Editable->False]}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[CurlyPhi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][],
               Editable->False], "."],
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[1]],
            Editable->False], "3"], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None]}], "-", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[CurlyPhi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][],
               Editable->False], "."],
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[1]],
            Editable->False], "5"], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None]}]}], ")"}]}], "-", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "4"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["V",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`V,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None]}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "4"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{3.80978932875837*^9, 3.809790222769097*^9, 
  3.809831782264867*^9, 3.8098409046261253`*^9, 3.809843666461055*^9, 
  3.8098444886225667`*^9, 3.809863552251775*^9, 3.8098675109803295`*^9}]
}, Open  ]],

Cell[TextData[{
 "Just a few more terms to deal with, specifically, the terms ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"(", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       OverscriptBox["\[Null]", 
        StyleBox[
         RowBox[{"(", "1", ")"}],
         FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[Phi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[],
         Editable->False], ""]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Phi]h[
      xAct`xTensor`LI[1], 
      xAct`xTensor`LI[0]],
     Editable->False], ")"}], " ", 
   RowBox[{
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}], "~", 
    FractionBox["d", "dt"]}], 
   SuperscriptBox[
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], "2"]}]],
  CellChangeTimes->{3.80978932875837*^9, 3.809790222769097*^9, 
   3.809831782264867*^9}],
 " and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"(", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox[
        OverscriptBox["D", "_"], "b"], 
       OverscriptBox["\[Null]", 
        StyleBox[
         RowBox[{"(", "1", ")"}],
         FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
       OverscriptBox[
        InterpretationBox[
         StyleBox["B",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Bsh[],
         Editable->False], "."]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`cd[-$CellContext`b][
      $CellContext`Bsh[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]]],
     Editable->False], ")"}], " ", 
   RowBox[{
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], "~", 
    FractionBox["d", "dt"]}], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox[
          OverscriptBox["D", "_"], "b"], 
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["B",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Bsh[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[-$CellContext`b][
        $CellContext`Bsh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]],
       Editable->False], ")"}], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SuperscriptBox[
          OverscriptBox["D", "_"], "b"], 
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["B",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Bsh[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[$CellContext`b][
        $CellContext`Bsh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]],
       Editable->False], ")"}]}], ")"}]}]],
  CellChangeTimes->{3.80978932875837*^9, 3.809790222769097*^9, 
   3.809831782264867*^9}],
 ". Consider the total derivatives..."
}], "Text",
 CellChangeTimes->{{3.8097893543132057`*^9, 3.8097893715850515`*^9}, {
  3.8098318363965206`*^9, 3.8098318918026457`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"G\[Phi]\[Phi]", "=", 
    RowBox[{
     RowBox[{"Hold", "[", 
      RowBox[{"\"\<\!\(\*FractionBox[\(d\), \(dt\)]\)\>\"", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["a",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`ah[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], "3"], " ", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              OverscriptBox["\[Null]", 
               StyleBox[
                RowBox[{"(", "1", ")"}],
                FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
              OverscriptBox[
               InterpretationBox[
                StyleBox["\[Phi]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Phi]h[],
                Editable->False], ""]}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]h[
             xAct`xTensor`LI[1], 
             xAct`xTensor`LI[0]],
            Editable->False], ")"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False]}], "+", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               OverscriptBox[
                InterpretationBox[
                 StyleBox["\[CurlyPhi]",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 xAct`xPand`\[CurlyPhi][],
                 Editable->False], "."],
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][
               xAct`xTensor`LI[0], 
               xAct`xTensor`LI[1]],
              Editable->False], "2"], " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["G",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`G,
              Editable->False], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None]}]}], ")"}]}], ")"}]}], "]"}], 
     "\[Equal]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"dt", "[", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["a",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`ah[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], "3"], " ", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            RowBox[{
             InterpretationBox[
              StyleBox["G",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`G,
              Editable->False], "[", 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 StyleBox["(",
                  FontColor->RGBColor[1, 0, 0]], 
                 InterpretationBox[
                  StyleBox[
                   OverscriptBox[
                    InterpretationBox[
                    StyleBox["\[CurlyPhi]",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    xAct`xPand`\[CurlyPhi][],
                    Editable->False], ""],
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  xAct`xPand`\[CurlyPhi][
                   xAct`xTensor`LI[0], 
                   xAct`xTensor`LI[0]],
                  Editable->False], 
                 StyleBox[")",
                  FontColor->RGBColor[1, 0, 0]]}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xTensor`Scalar[
                xAct`xPand`\[CurlyPhi][
                 xAct`xTensor`LI[0], 
                 xAct`xTensor`LI[0]]],
               Editable->False], ",", 
              FractionBox[
               SuperscriptBox[
                InterpretationBox[
                 StyleBox[
                  RowBox[{
                   StyleBox["(",
                    FontColor->RGBColor[1, 0, 0]], 
                   InterpretationBox[
                    StyleBox[
                    OverscriptBox[
                    InterpretationBox[
                    StyleBox["\[CurlyPhi]",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    xAct`xPand`\[CurlyPhi][],
                    Editable->False], "."],
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    xAct`xPand`\[CurlyPhi][
                    xAct`xTensor`LI[0], 
                    xAct`xTensor`LI[1]],
                    Editable->False], 
                   StyleBox[")",
                    FontColor->RGBColor[1, 0, 0]]}],
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 xAct`xTensor`Scalar[
                  xAct`xPand`\[CurlyPhi][
                   xAct`xTensor`LI[0], 
                   xAct`xTensor`LI[1]]],
                 Editable->False], "2"], "2"]}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               OverscriptBox[
                InterpretationBox[
                 StyleBox["\[CurlyPhi]",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 xAct`xPand`\[CurlyPhi][],
                 Editable->False], "."],
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][
               xAct`xTensor`LI[0], 
               xAct`xTensor`LI[1]],
              Editable->False], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox["G",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`G,
               Editable->False], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              InterpretationBox[
               StyleBox[
                RowBox[{
                 StyleBox["(",
                  FontColor->RGBColor[1, 0, 0]], 
                 InterpretationBox[
                  StyleBox[
                   OverscriptBox[
                    InterpretationBox[
                    StyleBox["\[CurlyPhi]",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    xAct`xPand`\[CurlyPhi][],
                    Editable->False], ""],
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  xAct`xPand`\[CurlyPhi][
                   xAct`xTensor`LI[0], 
                   xAct`xTensor`LI[0]],
                  Editable->False], 
                 StyleBox[")",
                  FontColor->RGBColor[1, 0, 0]]}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xTensor`Scalar[
                xAct`xPand`\[CurlyPhi][
                 xAct`xTensor`LI[0], 
                 xAct`xTensor`LI[0]]],
               Editable->False], ",", 
              FractionBox[
               SuperscriptBox[
                InterpretationBox[
                 StyleBox[
                  RowBox[{
                   StyleBox["(",
                    FontColor->RGBColor[1, 0, 0]], 
                   InterpretationBox[
                    StyleBox[
                    OverscriptBox[
                    InterpretationBox[
                    StyleBox["\[CurlyPhi]",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    xAct`xPand`\[CurlyPhi][],
                    Editable->False], "."],
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    xAct`xPand`\[CurlyPhi][
                    xAct`xTensor`LI[0], 
                    xAct`xTensor`LI[1]],
                    Editable->False], 
                   StyleBox[")",
                    FontColor->RGBColor[1, 0, 0]]}],
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 xAct`xTensor`Scalar[
                  xAct`xPand`\[CurlyPhi][
                   xAct`xTensor`LI[0], 
                   xAct`xTensor`LI[1]]],
                 Editable->False], "2"], "2"]}], "]"}]}]}], ")"}], 
         SuperscriptBox[
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              OverscriptBox["\[Null]", 
               StyleBox[
                RowBox[{"(", "1", ")"}],
                FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
              OverscriptBox[
               InterpretationBox[
                StyleBox["\[Phi]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Phi]h[],
                Editable->False], ""]}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]h[
             xAct`xTensor`LI[1], 
             xAct`xTensor`LI[0]],
            Editable->False], ")"}], "2"]}], "]"}], "//", "CollectXXX"}], 
      ")"}]}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"GBB", "=", 
    RowBox[{
     RowBox[{"Hold", "[", 
      RowBox[{"\"\<\!\(\*FractionBox[\(d\), \(dt\)]\)\>\"", 
       RowBox[{"(", 
        RowBox[{
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["a",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`ah[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], "3"], " ", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], " ", 
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             SubscriptBox[
              OverscriptBox["D", "_"], "b"], 
             OverscriptBox["\[Null]", 
              StyleBox[
               RowBox[{"(", "1", ")"}],
               FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
             OverscriptBox[
              InterpretationBox[
               StyleBox["B",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Bsh[],
               Editable->False], ""]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`cd[-$CellContext`b][
            $CellContext`Bsh[
             xAct`xTensor`LI[1], 
             xAct`xTensor`LI[0]]],
           Editable->False], ")"}], " ", 
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             SuperscriptBox[
              OverscriptBox["D", "_"], "b"], 
             OverscriptBox["\[Null]", 
              StyleBox[
               RowBox[{"(", "1", ")"}],
               FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
             OverscriptBox[
              InterpretationBox[
               StyleBox["B",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Bsh[],
               Editable->False], ""]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`cd[$CellContext`b][
            $CellContext`Bsh[
             xAct`xTensor`LI[1], 
             xAct`xTensor`LI[0]]],
           Editable->False], ")"}]}], ")"}]}], "]"}], "\[Equal]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"dt", "[", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["a",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`ah[],
               Editable->False], ""],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[0]],
            Editable->False], "3"], " ", 
          RowBox[{
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], "[", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              RowBox[{
               StyleBox["(",
                FontColor->RGBColor[1, 0, 0]], 
               InterpretationBox[
                StyleBox[
                 OverscriptBox[
                  InterpretationBox[
                   StyleBox["\[CurlyPhi]",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                   xAct`xPand`\[CurlyPhi][],
                   Editable->False], ""],
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                xAct`xPand`\[CurlyPhi][
                 xAct`xTensor`LI[0], 
                 xAct`xTensor`LI[0]],
                Editable->False], 
               StyleBox[")",
                FontColor->RGBColor[1, 0, 0]]}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xTensor`Scalar[
              xAct`xPand`\[CurlyPhi][
               xAct`xTensor`LI[0], 
               xAct`xTensor`LI[0]]],
             Editable->False], ",", 
            FractionBox[
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                RowBox[{
                 StyleBox["(",
                  FontColor->RGBColor[1, 0, 0]], 
                 InterpretationBox[
                  StyleBox[
                   OverscriptBox[
                    InterpretationBox[
                    StyleBox["\[CurlyPhi]",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    xAct`xPand`\[CurlyPhi][],
                    Editable->False], "."],
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  xAct`xPand`\[CurlyPhi][
                   xAct`xTensor`LI[0], 
                   xAct`xTensor`LI[1]],
                  Editable->False], 
                 StyleBox[")",
                  FontColor->RGBColor[1, 0, 0]]}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xTensor`Scalar[
                xAct`xPand`\[CurlyPhi][
                 xAct`xTensor`LI[0], 
                 xAct`xTensor`LI[1]]],
               Editable->False], "2"], "2"]}], "]"}], " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], "."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[1]],
           Editable->False], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox[
               OverscriptBox["D", "_"], "b"], 
              OverscriptBox["\[Null]", 
               StyleBox[
                RowBox[{"(", "1", ")"}],
                FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
              OverscriptBox[
               InterpretationBox[
                StyleBox["B",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`Bsh[],
                Editable->False], ""]}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`cd[-$CellContext`b][
             $CellContext`Bsh[
              xAct`xTensor`LI[1], 
              xAct`xTensor`LI[0]]],
            Editable->False], ")"}], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox[
               OverscriptBox["D", "_"], "b"], 
              OverscriptBox["\[Null]", 
               StyleBox[
                RowBox[{"(", "1", ")"}],
                FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
              OverscriptBox[
               InterpretationBox[
                StyleBox["B",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`Bsh[],
                Editable->False], ""]}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`cd[$CellContext`b][
             $CellContext`Bsh[
              xAct`xTensor`LI[1], 
              xAct`xTensor`LI[0]]],
            Editable->False], ")"}]}], "]"}], "//", "ContractMetric"}], "//", 
       "CollectXXX"}], ")"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"G\[Phi]\[Phi]", "/.", "simp"}], "\[IndentingNewLine]", 
 RowBox[{"GBB", "/.", "simp"}]}], "Input",
 CellChangeTimes->{{3.8097895736623936`*^9, 3.8097897707090693`*^9}, {
  3.809790356967659*^9, 3.809790360343669*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Hold", "[", 
   RowBox[{"\<\"\\!\\(\\*FractionBox[\\(d\\), \\(dt\\)]\\)\"\>", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "3"], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[CurlyPhi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][],
          Editable->False], "."],
        ShowAutoStyles->False,
        AutoSpacing->False],
       xAct`xPand`\[CurlyPhi][
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[1]],
       Editable->False], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False]}], "+", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], "."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[1]],
           Editable->False], "2"], " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None]}]}], ")"}]}], ")"}]}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[CurlyPhi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][],
        Editable->False], "."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[CurlyPhi][
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}]}], ")"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Phi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]],
       Editable->False], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["H",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Hh[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], "."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[1]],
           Editable->False]}], "+", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], ".."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[2]],
          Editable->False]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["H",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Hh[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], "."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[1]],
           Editable->False], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None]}], "+", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], ".."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[2]],
           Editable->False], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"6", " ", 
             SuperscriptBox[
              InterpretationBox[
               StyleBox["G",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`G,
               Editable->False], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None]}], "+", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                OverscriptBox[
                 InterpretationBox[
                  StyleBox["\[CurlyPhi]",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  xAct`xPand`\[CurlyPhi][],
                  Editable->False], "."],
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][
                xAct`xTensor`LI[0], 
                xAct`xTensor`LI[1]],
               Editable->False], "2"], " ", 
             SuperscriptBox[
              InterpretationBox[
               StyleBox["G",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`G,
               Editable->False], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "2"}], ")"}],
               Derivative],
              MultilineFunction->None]}]}], ")"}]}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None]}], "+", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[CurlyPhi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][],
               Editable->False], "."],
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[1]],
            Editable->False], "2"], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None]}]}], ")"}]}]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{
  3.809789568599161*^9, {3.8097897563596945`*^9, 3.8097897713181124`*^9}, 
   3.809790228067783*^9, 3.8097903610002747`*^9, 3.8098319281689057`*^9, 
   3.8098410452897606`*^9, 3.809843666693657*^9, 3.8098444889728756`*^9, 
   3.8098635525229163`*^9, 3.8098675112310457`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Hold", "[", 
   RowBox[{"\<\"\\!\\(\\*FractionBox[\\(d\\), \\(dt\\)]\\)\"\>", " ", 
    RowBox[{"(", 
     RowBox[{
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "3"], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[CurlyPhi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][],
          Editable->False], "."],
        ShowAutoStyles->False,
        AutoSpacing->False],
       xAct`xPand`\[CurlyPhi][
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[1]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "b"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["B",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bsh[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`b][
         $CellContext`Bsh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]],
        Editable->False], ")"}], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox[
           OverscriptBox["D", "_"], "b"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["B",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bsh[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[$CellContext`b][
         $CellContext`Bsh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]],
        Editable->False], ")"}]}], ")"}]}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["G",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`G,
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[CurlyPhi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][],
        Editable->False], "."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[CurlyPhi][
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[1]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["H",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Hh[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], "."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[1]],
           Editable->False]}], "+", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], ".."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[2]],
          Editable->False]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], ".."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[2]],
           Editable->False], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None]}], "+", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None]}], ")"}]}]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{
  3.809789568599161*^9, {3.8097897563596945`*^9, 3.8097897713181124`*^9}, 
   3.809790228067783*^9, 3.8097903610002747`*^9, 3.8098319281689057`*^9, 
   3.8098410452897606`*^9, 3.809843666693657*^9, 3.8098444889728756`*^9, 
   3.8098635525229163`*^9, 3.8098675112482777`*^9}]
}, Open  ]],

Cell["\<\
Performing the IBP with the above total derivatives, we end up with...\
\>", "Text",
 CellChangeTimes->{{3.809789792011688*^9, 3.8097898225200596`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SKG2final3", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"SKG2final2", "+", 
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", "2"], 
           RowBox[{"G\[Phi]\[Phi]", "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "+", 
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", "2"], 
           RowBox[{"GBB", "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], ")"}]}], ")"}], "//", 
       "ToCanonical"}], "//", "NoScalar"}], "//", "CollectXXX"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SuperscriptBox[\(S\), \((2)\)]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{"SKG2final3", "/.", "simp"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.8097898445895414`*^9, 3.809789866706645*^9}, {
  3.8097899020140066`*^9, 3.809789955921274*^9}, {3.80979008264694*^9, 
  3.809790085398862*^9}, {3.8097903328045897`*^9, 3.8097903542636933`*^9}, {
  3.8097905008395443`*^9, 3.8097905063415384`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SuperscriptBox[\\(S\\), \\((2)\\)]\\)\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{
    FractionBox["3", "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      InterpretationBox[
       StyleBox["V",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`V,
       Editable->False], "+", 
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"]}], "+", 
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False]}], "+", 
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], ".."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[2]],
        Editable->False]}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Psi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Psi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]],
       Editable->False], ")"}], "2"]}], "+", 
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["G",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`G,
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[CurlyPhi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][],
        Editable->False], "."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[CurlyPhi][
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Psi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Psi]h[],
           Editable->False], "."]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[1]],
       Editable->False], ")"}], "2"]}], "+", 
   RowBox[{"4", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[1]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"4", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}], "-", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "3"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}]}], ")"}]}], "+", 
   RowBox[{"3", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "3"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}]}], ")"}]}], "-", 
   RowBox[{"3", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      InterpretationBox[
       StyleBox["V",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`V,
       Editable->False], "+", 
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"]}], "-", 
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "3"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["V",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`V,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None]}], "+", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None]}], ")"}]}]}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      InterpretationBox[
       StyleBox["V",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`V,
       Editable->False], "+", 
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"]}], "-", 
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "3"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["V",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`V,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None]}], "+", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None]}], ")"}]}]}], ")"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Phi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]],
       Editable->False], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      InterpretationBox[
       StyleBox["V",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`V,
       Editable->False], "+", 
      RowBox[{"18", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"]}], "-", 
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"5", " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[CurlyPhi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][],
               Editable->False], "."],
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[1]],
            Editable->False], "3"], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None]}], "+", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[CurlyPhi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][],
               Editable->False], "."],
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[1]],
            Editable->False], "5"], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["V",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`V,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None]}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None]}], "+", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[CurlyPhi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][],
               Editable->False], "."],
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[1]],
            Editable->False], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox[
              InterpretationBox[
               StyleBox["V",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`V,
               Editable->False], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "2"}], ")"}],
               Derivative],
              MultilineFunction->None]}], "+", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["G",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`G,
              Editable->False], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None]}], ")"}]}]}], ")"}]}]}], 
     ")"}]}]}]}]], "Output",
 CellChangeTimes->{3.809789958640174*^9, 3.8097900865247135`*^9, 
  3.8097902323814054`*^9, 3.8097903680023966`*^9, 3.8097905072790537`*^9, 
  3.8098320729470644`*^9, 3.809841057781636*^9, 3.8098436670551662`*^9, 
  3.8098444894718294`*^9, 3.809863552918116*^9, 3.8098675115950108`*^9}]
}, Open  ]],

Cell[TextData[{
 "It is at this point that we appeal to the background equations. Applying \
them simplifies the action to [",
 StyleBox["resulting expression does not reduce to ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox["k", TraditionalForm]],
  FormatType->"TraditionalForm",
  FontSlant->"Italic"],
 StyleBox["-essence limit",
  FontSlant->"Italic"],
 "]..."
}], "Text",
 CellChangeTimes->{{3.8097899930887594`*^9, 3.8097900192997627`*^9}, {
  3.809790247495389*^9, 3.8097902494491343`*^9}, {3.80983480876433*^9, 
  3.8098348288114967`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SKG2Final", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"SKG2final3", "/.", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Hh", "[", 
          RowBox[{
           RowBox[{"LI", "[", "0", "]"}], ",", 
           RowBox[{"LI", "[", "0", "]"}]}], "]"}], "2"], "\[Rule]", "Q"}]}], "/.",
       "fesVar"}], "//", "CollectXXX"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SuperscriptBox[\(S\), \((2)\)]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{"SKG2Final", "/.", "simp"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.809790137382389*^9, 3.80979015165276*^9}, {
  3.8097902594362555`*^9, 3.809790265533876*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SuperscriptBox[\\(S\\), \\((2)\\)]\\)\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["G",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`G,
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[CurlyPhi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][],
        Editable->False], "."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[CurlyPhi][
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Psi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Psi]h[],
           Editable->False], "."]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[1]],
       Editable->False], ")"}], "2"]}], "+", 
   RowBox[{"4", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[1]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"4", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`Bsh[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}], "-", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "3"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}]}], ")"}]}], "+", 
   RowBox[{"3", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "3"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}]}], ")"}]}], "+", 
   RowBox[{
    FractionBox["3", "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Psi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Psi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]],
       Editable->False], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["H",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Hh[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], "."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[1]],
           Editable->False]}], "+", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], ".."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[2]],
          Editable->False]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], ".."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[2]],
           Editable->False], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None]}], "+", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None]}], ")"}]}]}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Phi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]],
       Editable->False], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox["V",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`V,
        Editable->False]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["V",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`V,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None]}], "+", 
         RowBox[{"3", " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["H",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Hh[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             InterpretationBox[
              StyleBox[
               OverscriptBox[
                InterpretationBox[
                 StyleBox["\[CurlyPhi]",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 xAct`xPand`\[CurlyPhi][],
                 Editable->False], "."],
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][
               xAct`xTensor`LI[0], 
               xAct`xTensor`LI[1]],
              Editable->False], " ", 
             SuperscriptBox[
              InterpretationBox[
               StyleBox["G",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`G,
               Editable->False], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None]}], "+", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                OverscriptBox[
                 InterpretationBox[
                  StyleBox["\[CurlyPhi]",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  xAct`xPand`\[CurlyPhi][],
                  Editable->False], "."],
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][
                xAct`xTensor`LI[0], 
                xAct`xTensor`LI[1]],
               Editable->False], "3"], " ", 
             SuperscriptBox[
              InterpretationBox[
               StyleBox["G",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`G,
               Editable->False], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "2"}], ")"}],
               Derivative],
              MultilineFunction->None]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[CurlyPhi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][],
               Editable->False], "."],
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[1]],
            Editable->False], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox["V",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`V,
              Editable->False], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "-", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["G",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`G,
              Editable->False], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None]}], ")"}]}]}], ")"}]}]}], 
     ")"}]}]}]}]], "Output",
 CellChangeTimes->{{3.8097902604523*^9, 3.8097902668464518`*^9}, 
   3.809790378474194*^9, 3.809790519828574*^9, 3.8098320982984867`*^9, 
   3.809841072061818*^9, 3.8098436671932545`*^9, 3.8098444896619263`*^9, 
   3.8098635530384808`*^9, 3.809867511731868*^9}]
}, Open  ]],

Cell[TextData[{
 "Performing an IBP to further reveal the Lagrange multiplier ",
 Cell[BoxData[
  FormBox["B", TraditionalForm]],
  FormatType->"TraditionalForm"],
 "..."
}], "Text",
 CellChangeTimes->{{3.809790658169129*^9, 3.809790674220684*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SKG2Final2", "=", 
    RowBox[{"Collect", "[", 
     RowBox[{
      RowBox[{"SKG2Final", "/.", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"cd", "[", 
           RowBox[{"-", "x_"}], "]"}], "[", 
          RowBox[{"ph_", "[", 
           RowBox[{"y_", ",", "z_"}], "]"}], "]"}], 
         RowBox[{
          RowBox[{"cd", "[", "x_", "]"}], "[", 
          RowBox[{"Bsh", "[", 
           RowBox[{
            RowBox[{"LI", "[", "1", "]"}], ",", 
            RowBox[{"LI", "[", "0", "]"}]}], "]"}], "]"}]}], "\[RuleDelayed]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"cd", "[", 
            RowBox[{"-", "x"}], "]"}], "[", 
           RowBox[{
            RowBox[{"cd", "[", "x", "]"}], "[", 
            RowBox[{"ph", "[", 
             RowBox[{"y", ",", "z"}], "]"}], "]"}], "]"}]}], 
         RowBox[{"Bsh", "[", 
          RowBox[{
           RowBox[{"LI", "[", "1", "]"}], ",", 
           RowBox[{"LI", "[", "0", "]"}]}], "]"}]}]}]}], ",", 
      RowBox[{"{", 
       RowBox[{"Bsh", "[", 
        RowBox[{
         RowBox[{"LI", "[", "1", "]"}], ",", 
         RowBox[{"LI", "[", "0", "]"}]}], "]"}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SuperscriptBox[\(S\), \((2)\)]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{"SKG2Final2", "/.", "simp"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.8097906863187227`*^9, 3.809790715749271*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SuperscriptBox[\\(S\\), \\((2)\\)]\\)\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["G",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`G,
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[CurlyPhi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][],
        Editable->False], "."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[CurlyPhi][
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Psi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Psi]h[],
           Editable->False], "."]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[1]],
       Editable->False], ")"}], "2"]}], "-", 
   RowBox[{"4", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"3", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "3"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}]}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Bsh[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "b"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "b"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "."]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`b][
          $CellContext`cd[$CellContext`b][
           $CellContext`\[Psi]h[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[1]]]],
         Editable->False], ")"}]}], "-", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "b"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "b"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`b][
          $CellContext`cd[$CellContext`b][
           $CellContext`\[Phi]h[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", 
          InterpretationBox[
           StyleBox["\[Kappa]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Kappa],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["H",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Hh[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False]}], "-", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[CurlyPhi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][],
               Editable->False], "."],
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[1]],
            Editable->False], "3"], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None]}]}], ")"}]}]}], ")"}]}], "+", 
   RowBox[{
    FractionBox["3", "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Psi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Psi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]],
       Editable->False], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["H",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Hh[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], "."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[1]],
           Editable->False]}], "+", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], ".."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[2]],
          Editable->False]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], ".."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[2]],
           Editable->False], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None]}], "+", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None]}], ")"}]}]}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Phi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]],
       Editable->False], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox["V",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`V,
        Editable->False]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["V",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`V,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None]}], "+", 
         RowBox[{"3", " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["H",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Hh[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             InterpretationBox[
              StyleBox[
               OverscriptBox[
                InterpretationBox[
                 StyleBox["\[CurlyPhi]",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 xAct`xPand`\[CurlyPhi][],
                 Editable->False], "."],
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][
               xAct`xTensor`LI[0], 
               xAct`xTensor`LI[1]],
              Editable->False], " ", 
             SuperscriptBox[
              InterpretationBox[
               StyleBox["G",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`G,
               Editable->False], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None]}], "+", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                OverscriptBox[
                 InterpretationBox[
                  StyleBox["\[CurlyPhi]",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  xAct`xPand`\[CurlyPhi][],
                  Editable->False], "."],
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][
                xAct`xTensor`LI[0], 
                xAct`xTensor`LI[1]],
               Editable->False], "3"], " ", 
             SuperscriptBox[
              InterpretationBox[
               StyleBox["G",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`G,
               Editable->False], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "2"}], ")"}],
               Derivative],
              MultilineFunction->None]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[CurlyPhi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][],
               Editable->False], "."],
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[1]],
            Editable->False], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox["V",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`V,
              Editable->False], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "-", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["G",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`G,
              Editable->False], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None]}], ")"}]}]}], ")"}]}]}], 
     ")"}]}]}]}]], "Output",
 CellChangeTimes->{3.809790718687414*^9, 3.809832174004647*^9, 
  3.8098410799795227`*^9, 3.8098436672602463`*^9, 3.809844489779106*^9, 
  3.8098635531209784`*^9, 3.8098675117854896`*^9}]
}, Open  ]],

Cell[TextData[{
 "Thus, we see again that this expression is linear in ",
 Cell[BoxData[
  FormBox["B", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " and so varying it with respect to ",
 Cell[BoxData[
  FormBox["B", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " should yield a functional ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"F", "[", 
     RowBox[{"\[Phi]", ",", "\[Psi]"}], "]"}], "=", "0"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "..."
}], "Text",
 CellChangeTimes->{{3.8097905455253563`*^9, 3.809790594383713*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ConstraintB", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"VarD", "[", 
          RowBox[{
           RowBox[{"Bsh", "[", 
            RowBox[{
             RowBox[{"LI", "[", "1", "]"}], ",", 
             RowBox[{"LI", "[", "0", "]"}]}], "]"}], ",", "cd"}], "]"}], "[", 
         "SKG2Final2", "]"}], "/.", "DeltaRule"}], "//", "NoScalar"}], ")"}], 
     "\[Equal]", "0"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"ConstraintB", "/.", "simp"}]}], "Input",
 CellChangeTimes->{
  3.809790615578066*^9, {3.8097907659835863`*^9, 3.8097907741737213`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"-", "4"}], " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`cd[$CellContext`b][
        $CellContext`\[Phi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"4", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`cd[$CellContext`b][
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1]]]],
      Editable->False], ")"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[CurlyPhi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][],
         Editable->False], "."],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xPand`\[CurlyPhi][
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[1]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`cd[$CellContext`b][
        $CellContext`\[Phi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None]}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{{3.8097907629195857`*^9, 3.809790774876571*^9}, 
   3.8098322045389795`*^9, 3.8098410831425533`*^9, 3.8098436673779087`*^9, 
   3.8098444900091496`*^9, 3.8098635532301435`*^9, 3.809867511910822*^9}]
}, Open  ]],

Cell["The exact solution is (check by inspection)...", "Text",
 CellChangeTimes->{{3.8097907858796663`*^9, 3.809790789802739*^9}, {
  3.809841096269642*^9, 3.8098411092481265`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ConstraintB2", "=", 
    RowBox[{"ConstraintB", "/.", 
     RowBox[{
      RowBox[{
       RowBox[{"cd", "[", 
        RowBox[{"-", "x_"}], "]"}], "[", 
       RowBox[{
        RowBox[{"cd", "[", "x_", "]"}], "[", "expr_", "]"}], "]"}], 
      "\[RuleDelayed]", "expr"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"ConstraintB2", "/.", "simp"}]}], "Input",
 CellChangeTimes->{{3.809790800322014*^9, 3.809790807558841*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"-", "4"}], " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"4", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[CurlyPhi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][],
         Editable->False], "."],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xPand`\[CurlyPhi][
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[1]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Phi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None]}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{{3.809790796680148*^9, 3.8097908080745745`*^9}, 
   3.809832206561943*^9, 3.809841088428482*^9, 3.8098436674119167`*^9, 
   3.8098444900456257`*^9, 3.809863553264324*^9, 3.8098675119468064`*^9}]
}, Open  ]],

Cell[TextData[{
 "Finally, we can eliminate ",
 Cell[BoxData[
  FormBox["\[Phi]", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " from the second-order action using this..."
}], "Text",
 CellChangeTimes->{{3.8097908181249747`*^9, 3.8097908341294355`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SKG2Final3", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"SKG2Final2", "/.", 
           RowBox[{
            RowBox[{"Solve", "[", 
             RowBox[{"ConstraintB2", ",", 
              RowBox[{"\[Phi]h", "[", 
               RowBox[{
                RowBox[{"LI", "[", "1", "]"}], ",", 
                RowBox[{"LI", "[", "0", "]"}]}], "]"}]}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], "//", "ToCanonical"}], "//", 
         "NoScalar"}], ")"}], "/.", "ScalarHa"}], "/.", 
      RowBox[{
       RowBox[{"Scalar", "[", 
        RowBox[{"\[CurlyPhi]", "[", 
         RowBox[{"x_", ",", "y_"}], "]"}], "]"}], "\[RuleDelayed]", 
       RowBox[{"\[CurlyPhi]", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}], "//", "CollectXXX"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SuperscriptBox[\(S\), \((2)\)]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{"SKG2Final3", "/.", "simp"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.8097908534945893`*^9, 3.809790916779487*^9}, {
  3.809790976704109*^9, 3.809791015888672*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SuperscriptBox[\\(S\\), \\((2)\\)]\\)\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["G",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`G,
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[CurlyPhi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][],
        Editable->False], "."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[CurlyPhi][
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], "+", 
   FractionBox[
    RowBox[{"16", " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["\[Kappa]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Kappa],
       Editable->False], "2"], " ", 
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox[
          OverscriptBox["D", "_"], "b"], 
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Psi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Psi]h[],
           Editable->False], "."]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[-$CellContext`b][
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1]]],
       Editable->False], ")"}], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SuperscriptBox[
          OverscriptBox["D", "_"], "b"], 
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Psi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Psi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[$CellContext`b][
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]],
       Editable->False], ")"}]}], 
    RowBox[{
     RowBox[{"4", " ", 
      InterpretationBox[
       StyleBox["\[Kappa]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Kappa],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["H",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]}], "-", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], "3"], " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None]}]}]], "+", 
   RowBox[{
    FractionBox["3", "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Psi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Psi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]],
       Editable->False], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["H",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Hh[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], "."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[1]],
           Editable->False]}], "+", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], ".."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[2]],
          Editable->False]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], ".."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[2]],
           Editable->False], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None]}], "+", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None]}], ")"}]}]}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox["\[Kappa]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Kappa],
       Editable->False], " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "3"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "."]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"8", " ", 
         InterpretationBox[
          StyleBox["V",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`V,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Kappa]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Kappa],
          Editable->False]}], "+", 
        RowBox[{"48", " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["\[Kappa]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Kappa],
           Editable->False], "2"], " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["H",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Hh[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], "."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[1]],
           Editable->False], "6"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], ")"}], "2"]}], "-", 
        RowBox[{"4", " ", 
         InterpretationBox[
          StyleBox["\[Kappa]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Kappa],
          Editable->False], " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], "."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[1]],
           Editable->False], "2"], " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["V",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`V,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None]}], "+", 
        RowBox[{"12", " ", 
         InterpretationBox[
          StyleBox["\[Kappa]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Kappa],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["H",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Hh[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False], " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], "."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[1]],
           Editable->False], "5"], " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None]}], "+", 
        RowBox[{"4", " ", 
         InterpretationBox[
          StyleBox["\[Kappa]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Kappa],
          Editable->False], " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], "."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[1]],
           Editable->False], "4"], " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["V",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`V,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None]}], "-", 
        RowBox[{"4", " ", 
         InterpretationBox[
          StyleBox["\[Kappa]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Kappa],
          Editable->False], " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], "."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[1]],
           Editable->False], "4"], " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None]}]}], ")"}]}], ")"}], "/", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False]}], "+", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], "3"], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None]}]}], ")"}], "2"]}]}]}]], "Output",
 CellChangeTimes->{3.8097908844414463`*^9, 3.809790918170741*^9, 
  3.809791017310298*^9, 3.80983241130225*^9, 3.809841123022719*^9, 
  3.8098436684418373`*^9, 3.809844491184575*^9, 3.8098635546313176`*^9, 
  3.8098675129716854`*^9}]
}, Open  ]],

Cell[TextData[{
 "At this point, a few more total derivatives must be added to the action to \
rewrite the terms ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"(", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       OverscriptBox["\[Null]", 
        StyleBox[
         RowBox[{"(", "1", ")"}],
         FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[Psi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[],
         Editable->False], ""]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Psi]h[
      xAct`xTensor`LI[1], 
      xAct`xTensor`LI[0]],
     Editable->False], ")"}], " ", 
   RowBox[{
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}], "~", 
    FractionBox["d", "dt"]}], 
   SuperscriptBox[
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], "2"]}]],
  CellChangeTimes->{3.8097908844414463`*^9, 3.809790918170741*^9, 
   3.809791017310298*^9, 3.80983241130225*^9}],
 ", and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"(", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox[
        OverscriptBox["D", "_"], "b"], 
       OverscriptBox["\[Null]", 
        StyleBox[
         RowBox[{"(", "1", ")"}],
         FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[Psi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[],
         Editable->False], "."]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`cd[-$CellContext`b][
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]]],
     Editable->False], ")"}], " ", 
   RowBox[{
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "b"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`b][
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], "~", 
    FractionBox["d", "dt"]}], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox[
          OverscriptBox["D", "_"], "b"], 
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Psi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Psi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[-$CellContext`b][
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]],
       Editable->False], ")"}], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SuperscriptBox[
          OverscriptBox["D", "_"], "b"], 
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Psi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Psi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[$CellContext`b][
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]],
       Editable->False], ")"}]}], ")"}]}]],
  CellChangeTimes->{3.8097908844414463`*^9, 3.809790918170741*^9, 
   3.809791017310298*^9, 3.80983241130225*^9}],
 "..."
}], "Text",
 CellChangeTimes->{{3.8097910814704165`*^9, 3.809791094739784*^9}, {
  3.8098324246930227`*^9, 3.809832518184364*^9}, {3.8098411612087703`*^9, 
  3.8098411624263105`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aHG\[Psi]\[Psi]", "=", 
   RowBox[{
    RowBox[{"Hold", "[", 
     RowBox[{"\"\<\!\(\*FractionBox[\(d\), \(dt\)]\)\>\"", 
      RowBox[{"(", 
       RowBox[{"3", " ", 
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False], "3"], " ", 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             OverscriptBox["\[Null]", 
              StyleBox[
               RowBox[{"(", "1", ")"}],
               FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[Psi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Psi]h[],
               Editable->False], ""]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Psi]h[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]],
           Editable->False], ")"}], "2"]}], ")"}]}], "]"}], "\[Equal]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"dt", "[", 
         RowBox[{"3", " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["a",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`ah[],
               Editable->False], ""],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[0]],
            Editable->False], "3"], " ", 
          RowBox[{
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], "[", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              OverscriptBox[
               InterpretationBox[
                StyleBox["\[CurlyPhi]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                xAct`xPand`\[CurlyPhi][],
                Editable->False], ""],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][
              xAct`xTensor`LI[0], 
              xAct`xTensor`LI[0]],
             Editable->False], ",", 
            FractionBox[
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                OverscriptBox[
                 InterpretationBox[
                  StyleBox["\[CurlyPhi]",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  xAct`xPand`\[CurlyPhi][],
                  Editable->False], "."],
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][
                xAct`xTensor`LI[0], 
                xAct`xTensor`LI[1]],
               Editable->False], "2"], "2"]}], "]"}], " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], "."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[1]],
           Editable->False], 
          SuperscriptBox[
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               OverscriptBox["\[Null]", 
                StyleBox[
                 RowBox[{"(", "1", ")"}],
                 FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
               OverscriptBox[
                InterpretationBox[
                 StyleBox["\[Psi]",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`\[Psi]h[],
                 Editable->False], ""]}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[
              xAct`xTensor`LI[1], 
              xAct`xTensor`LI[0]],
             Editable->False], ")"}], "2"]}], "]"}], "/.", "ScalarHa"}], "/.", 
       RowBox[{
        RowBox[{"Scalar", "[", 
         RowBox[{"\[CurlyPhi]", "[", 
          RowBox[{"x_", ",", "y_"}], "]"}], "]"}], "\[RuleDelayed]", 
        RowBox[{"\[CurlyPhi]", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}]}], "//", "CollectXXX"}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"aHGcd\[Psi]cd\[Psi]", "=", 
    RowBox[{
     RowBox[{"Hold", "[", 
      RowBox[{"\"\<\!\(\*FractionBox[\(d\), \(dt\)]\)\>\"", 
       RowBox[{"Hold", "[", 
        FractionBox[
         RowBox[{"16", " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False], "2"], " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["a",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`ah[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox[
               OverscriptBox["D", "_"], "b"], 
              OverscriptBox["\[Null]", 
               StyleBox[
                RowBox[{"(", "1", ")"}],
                FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
              OverscriptBox[
               InterpretationBox[
                StyleBox["\[Psi]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Psi]h[],
                Editable->False], ""]}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`cd[-$CellContext`b][
             $CellContext`\[Psi]h[
              xAct`xTensor`LI[1], 
              xAct`xTensor`LI[0]]],
            Editable->False], ")"}], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox[
               OverscriptBox["D", "_"], "b"], 
              OverscriptBox["\[Null]", 
               StyleBox[
                RowBox[{"(", "1", ")"}],
                FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
              OverscriptBox[
               InterpretationBox[
                StyleBox["\[Psi]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Psi]h[],
                Editable->False], ""]}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`cd[$CellContext`b][
             $CellContext`\[Psi]h[
              xAct`xTensor`LI[1], 
              xAct`xTensor`LI[0]]],
            Editable->False], ")"}]}], 
         RowBox[{
          RowBox[{"4", " ", 
           InterpretationBox[
            StyleBox["\[Kappa]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Kappa],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["H",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Hh[],
               Editable->False], ""],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[0]],
            Editable->False]}], "-", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              OverscriptBox[
               InterpretationBox[
                StyleBox["\[CurlyPhi]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                xAct`xPand`\[CurlyPhi][],
                Editable->False], "."],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][
              xAct`xTensor`LI[0], 
              xAct`xTensor`LI[1]],
             Editable->False], "3"], " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None]}]}]], "]"}]}], "]"}], "\[Equal]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"dt", "[", 
           FractionBox[
            RowBox[{"16", " ", 
             SuperscriptBox[
              InterpretationBox[
               StyleBox["\[Kappa]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Kappa],
               Editable->False], "2"], " ", 
             InterpretationBox[
              StyleBox[
               OverscriptBox[
                InterpretationBox[
                 StyleBox["a",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`ah[],
                 Editable->False], ""],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`ah[
               xAct`xTensor`LI[0], 
               xAct`xTensor`LI[0]],
              Editable->False], " ", 
             RowBox[{"(", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox[
                  OverscriptBox["D", "_"], "b"], 
                 OverscriptBox["\[Null]", 
                  StyleBox[
                   RowBox[{"(", "1", ")"}],
                   FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
                 OverscriptBox[
                  InterpretationBox[
                   StyleBox["\[Psi]",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                   $CellContext`\[Psi]h[],
                   Editable->False], ""]}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`cd[-$CellContext`b][
                $CellContext`\[Psi]h[
                 xAct`xTensor`LI[1], 
                 xAct`xTensor`LI[0]]],
               Editable->False], ")"}], " ", 
             RowBox[{"(", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox[
                  OverscriptBox["D", "_"], "b"], 
                 OverscriptBox["\[Null]", 
                  StyleBox[
                   RowBox[{"(", "1", ")"}],
                   FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
                 OverscriptBox[
                  InterpretationBox[
                   StyleBox["\[Psi]",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                   $CellContext`\[Psi]h[],
                   Editable->False], ""]}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`cd[$CellContext`b][
                $CellContext`\[Psi]h[
                 xAct`xTensor`LI[1], 
                 xAct`xTensor`LI[0]]],
               Editable->False], ")"}]}], 
            RowBox[{
             RowBox[{"4", " ", 
              InterpretationBox[
               StyleBox["\[Kappa]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Kappa],
               Editable->False], " ", 
              InterpretationBox[
               StyleBox[
                OverscriptBox[
                 InterpretationBox[
                  StyleBox["H",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`Hh[],
                  Editable->False], ""],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Hh[
                xAct`xTensor`LI[0], 
                xAct`xTensor`LI[0]],
               Editable->False]}], "-", 
             RowBox[{
              SuperscriptBox[
               InterpretationBox[
                StyleBox[
                 OverscriptBox[
                  InterpretationBox[
                   StyleBox["\[CurlyPhi]",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                   xAct`xPand`\[CurlyPhi][],
                   Editable->False], "."],
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                xAct`xPand`\[CurlyPhi][
                 xAct`xTensor`LI[0], 
                 xAct`xTensor`LI[1]],
                Editable->False], "3"], " ", 
              RowBox[{
               SuperscriptBox[
                InterpretationBox[
                 StyleBox["G",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`G,
                 Editable->False], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{
                InterpretationBox[
                 StyleBox[
                  OverscriptBox[
                   InterpretationBox[
                    StyleBox["\[CurlyPhi]",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    xAct`xPand`\[CurlyPhi][],
                    Editable->False], ""],
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 xAct`xPand`\[CurlyPhi][
                  xAct`xTensor`LI[0], 
                  xAct`xTensor`LI[0]],
                 Editable->False], ",", 
                FractionBox[
                 SuperscriptBox[
                  InterpretationBox[
                   StyleBox[
                    OverscriptBox[
                    InterpretationBox[
                    StyleBox["\[CurlyPhi]",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    xAct`xPand`\[CurlyPhi][],
                    Editable->False], "."],
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                   xAct`xPand`\[CurlyPhi][
                    xAct`xTensor`LI[0], 
                    xAct`xTensor`LI[1]],
                   Editable->False], "2"], "2"]}], "]"}]}]}]], "]"}], "/.", 
          "ScalarHa"}], "/.", 
         RowBox[{
          RowBox[{"Scalar", "[", 
           RowBox[{"\[CurlyPhi]", "[", 
            RowBox[{"x_", ",", "y_"}], "]"}], "]"}], "\[RuleDelayed]", 
          RowBox[{"\[CurlyPhi]", "[", 
           RowBox[{"x", ",", "y"}], "]"}]}]}], "//", "ContractMetric"}], "//",
        "CollectXXX"}], ")"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"aHG\[Psi]\[Psi]", "/.", "simp"}], "\[IndentingNewLine]", 
 RowBox[{"aHGcd\[Psi]cd\[Psi]", "/.", "simp"}]}], "Input",
 CellChangeTimes->{{3.8097911360502906`*^9, 3.8097912352375646`*^9}, {
  3.8097912684498196`*^9, 3.809791367198432*^9}, {3.809791435908268*^9, 
  3.8097915993354893`*^9}, {3.8098411736480527`*^9, 3.809841178868391*^9}, {
  3.8098412916259727`*^9, 3.809841329427213*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Hold", "[", 
   RowBox[{"\<\"\\!\\(\\*FractionBox[\\(d\\), \\(dt\\)]\\)\"\>", " ", 
    RowBox[{"(", 
     RowBox[{"3", " ", 
      InterpretationBox[
       StyleBox["G",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G,
       Editable->False], " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "3"], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[CurlyPhi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][],
          Editable->False], "."],
        ShowAutoStyles->False,
        AutoSpacing->False],
       xAct`xPand`\[CurlyPhi][
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[1]],
       Editable->False], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}], "2"]}], ")"}]}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox["G",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`G,
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[CurlyPhi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][],
        Editable->False], "."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[CurlyPhi][
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Psi]h[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"3", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Psi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Psi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]],
       Editable->False], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["H",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Hh[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], "."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[1]],
           Editable->False]}], "+", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], ".."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[2]],
          Editable->False]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], ".."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[2]],
           Editable->False], " ", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None]}], "+", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None]}], ")"}]}]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{{3.8097912047420745`*^9, 3.809791235659337*^9}, 
   3.809791367823106*^9, 3.8097915274077563`*^9, {3.8097915593701363`*^9, 
   3.8097915800480022`*^9}, 3.809832788429384*^9, 3.809841182345278*^9, 
   3.8098413348592634`*^9, 3.809843668727151*^9, 3.809844491531145*^9, 
   3.809863554922244*^9, 3.8098675132508397`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Hold", "[", 
   RowBox[{"\<\"\\!\\(\\*FractionBox[\\(d\\), \\(dt\\)]\\)\"\>", " ", 
    RowBox[{"Hold", "[", 
     FractionBox[
      RowBox[{"16", " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "b"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`b][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "b"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`b][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      RowBox[{
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False]}], "-", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], "3"], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None]}]}]], "]"}]}], "]"}], "\[Equal]", 
  RowBox[{
   FractionBox[
    RowBox[{"32", " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["\[Kappa]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Kappa],
       Editable->False], "2"], " ", 
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox[
          OverscriptBox["D", "_"], "b"], 
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Psi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Psi]h[],
           Editable->False], "."]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[-$CellContext`b][
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1]]],
       Editable->False], ")"}], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SuperscriptBox[
          OverscriptBox["D", "_"], "b"], 
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Psi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Psi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[$CellContext`b][
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]],
       Editable->False], ")"}]}], 
    RowBox[{
     RowBox[{"4", " ", 
      InterpretationBox[
       StyleBox["\[Kappa]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Kappa],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["H",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]}], "-", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], "3"], " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None]}]}]], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"16", " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], "2"], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "b"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Psi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Psi]h[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`b][
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]],
        Editable->False], ")"}], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox[
           OverscriptBox["D", "_"], "b"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Psi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Psi]h[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[$CellContext`b][
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]],
        Editable->False], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"4", " ", 
         InterpretationBox[
          StyleBox["\[Kappa]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Kappa],
          Editable->False], " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["H",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Hh[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], "2"]}], "-", 
        RowBox[{"4", " ", 
         InterpretationBox[
          StyleBox["\[Kappa]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Kappa],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["H",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Hh[],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False]}], "-", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["H",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Hh[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False], " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], "."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[1]],
           Editable->False], "3"], " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], "."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[1]],
           Editable->False], "2"], " ", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], ".."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[2]],
          Editable->False], " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None]}], "+", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], "."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[1]],
           Editable->False], "4"], " ", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], ".."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[2]],
          Editable->False], " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None]}], "+", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], "."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[1]],
           Editable->False], "4"], " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None]}]}], ")"}]}], ")"}], "/", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False]}], "+", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], "3"], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None]}]}], ")"}], "2"]}]}]}]], "Output",
 CellChangeTimes->{{3.8097912047420745`*^9, 3.809791235659337*^9}, 
   3.809791367823106*^9, 3.8097915274077563`*^9, {3.8097915593701363`*^9, 
   3.8097915800480022`*^9}, 3.809832788429384*^9, 3.809841182345278*^9, 
   3.8098413348592634`*^9, 3.809843668727151*^9, 3.809844491531145*^9, 
   3.809863554922244*^9, 3.8098675132676077`*^9}]
}, Open  ]],

Cell["\<\
Adding appropriate amounts of these total derivative terms into the action \
finally leads to...\
\>", "Text",
 CellChangeTimes->{{3.809791603305499*^9, 3.8097916229203243`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SKGquad", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"SKG2Final3", "-", 
                    RowBox[{"(", 
                    RowBox[{
                    FractionBox["1", "2"], 
                    RowBox[{"aHG\[Psi]\[Psi]", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "-", 
                    RowBox[{"(", 
                    RowBox[{
                    FractionBox["1", "2"], 
                    RowBox[{"aHGcd\[Psi]cd\[Psi]", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], ")"}]}], ")"}], "//", 
                  "ToCanonical"}], "//", "NoScalar"}], "//", "CollectXh2"}], 
               ")"}], "/.", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"Hh", "[", 
                 RowBox[{
                  RowBox[{"LI", "[", "0", "]"}], ",", 
                  RowBox[{"LI", "[", "0", "]"}]}], "]"}], "2"], "\[Rule]", 
               "Q"}]}], "/.", "fesVar"}], "//", "ToCanonical"}], "//", 
           "NoScalar"}], ")"}], "/.", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Hh", "[", 
            RowBox[{
             RowBox[{"LI", "[", "0", "]"}], ",", 
             RowBox[{"LI", "[", "0", "]"}]}], "]"}], "2"], "\[Rule]", "Q"}]}],
         "/.", "fesVar"}], "/.", "ScalarHa"}], "/.", 
      RowBox[{
       RowBox[{"Scalar", "[", 
        RowBox[{"\[CurlyPhi]", "[", 
         RowBox[{"x_", ",", "y_"}], "]"}], "]"}], "\[RuleDelayed]", 
       RowBox[{"\[CurlyPhi]", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}], "//", "CollectXXX"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SuperscriptBox[\(S\), \((2)\)]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{"SKGquad", "/.", "simp"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.809791643333308*^9, 3.809791659853724*^9}, {
   3.8097917190901966`*^9, 3.8097918147605324`*^9}, {3.809791854413663*^9, 
   3.8097918788112693`*^9}, 3.809832977959004*^9, 3.8098413590959945`*^9}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SuperscriptBox[\\(S\\), \\((2)\\)]\\)\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox["\[Kappa]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Kappa],
       Editable->False], " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "3"], " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "."]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], "."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[1]],
           Editable->False], "4"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], ")"}], "2"]}], "+", 
        RowBox[{"12", " ", 
         InterpretationBox[
          StyleBox["\[Kappa]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Kappa],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["H",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Hh[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["G",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`G,
              Editable->False], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None]}], "+", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               OverscriptBox[
                InterpretationBox[
                 StyleBox["\[CurlyPhi]",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 xAct`xPand`\[CurlyPhi][],
                 Editable->False], "."],
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][
               xAct`xTensor`LI[0], 
               xAct`xTensor`LI[1]],
              Editable->False], "2"], " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["G",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`G,
              Editable->False], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None]}]}], ")"}]}], "+", 
        RowBox[{"4", " ", 
         InterpretationBox[
          StyleBox["\[Kappa]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Kappa],
          Editable->False], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox["V",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`V,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["G",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`G,
              Editable->False], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None]}]}], ")"}]}], "+", 
        RowBox[{"4", " ", 
         InterpretationBox[
          StyleBox["\[Kappa]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Kappa],
          Editable->False], " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], "."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[1]],
           Editable->False], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox["V",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`V,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "-", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None]}], ")"}]}]}], ")"}]}], ")"}], "/", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False]}], "+", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], "3"], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None]}]}], ")"}], "2"]}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox["\[Kappa]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Kappa],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "b"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Psi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Psi]h[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`b][
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]],
        Editable->False], ")"}], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox[
           OverscriptBox["D", "_"], "b"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Psi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Psi]h[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[$CellContext`b][
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]],
        Editable->False], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"16", " ", 
         InterpretationBox[
          StyleBox["\[Kappa]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Kappa],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["H",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Hh[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None]}], "-", 
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], "."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[1]],
           Editable->False], "4"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], ")"}], "2"]}], "+", 
        RowBox[{"4", " ", 
         InterpretationBox[
          StyleBox["\[Kappa]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Kappa],
          Editable->False], " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["V",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`V,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None]}], "+", 
        RowBox[{"4", " ", 
         InterpretationBox[
          StyleBox["\[Kappa]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Kappa],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], ".."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[2]],
          Editable->False], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["G",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`G,
              Editable->False], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None]}], "+", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox[
               OverscriptBox[
                InterpretationBox[
                 StyleBox["\[CurlyPhi]",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 xAct`xPand`\[CurlyPhi][],
                 Editable->False], "."],
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][
               xAct`xTensor`LI[0], 
               xAct`xTensor`LI[1]],
              Editable->False], "2"], " ", 
            SuperscriptBox[
             InterpretationBox[
              StyleBox["G",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`G,
              Editable->False], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None]}]}], ")"}]}], "-", 
        RowBox[{"8", " ", 
         InterpretationBox[
          StyleBox["\[Kappa]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Kappa],
          Editable->False], " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None]}], "+", 
        RowBox[{"4", " ", 
         InterpretationBox[
          StyleBox["\[Kappa]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Kappa],
          Editable->False], " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], "."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[1]],
           Editable->False], "2"], " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["G",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`G,
           Editable->False], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None]}]}], ")"}]}], ")"}], "/", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False]}], "+", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], "3"], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None]}]}], ")"}], "2"]}]}]}]], "Output",
 CellChangeTimes->{{3.8097918077744436`*^9, 3.809791817057869*^9}, {
   3.8097918574617167`*^9, 3.8097918800626297`*^9}, 3.8098329836227136`*^9, 
   3.8098413914782066`*^9, 3.8098436694164*^9, 3.809844492279724*^9, 
   3.809863555689468*^9, 3.8098675139598637`*^9}]
}, Open  ]],

Cell["We simplify this further by defining...", "Text",
 CellChangeTimes->{{3.809833600033968*^9, 3.809833607810872*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"DefProjectedTensor", "[", 
  RowBox[{
   RowBox[{"Z", "[", "]"}], ",", "h"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Zdef", "=", 
    RowBox[{
     FractionBox["1", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "4"}], " ", 
          InterpretationBox[
           StyleBox["\[Kappa]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Kappa],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["H",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Hh[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False]}], "+", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[CurlyPhi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][],
               Editable->False], "."],
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[1]],
            Editable->False], "3"], " ", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              OverscriptBox[
               InterpretationBox[
                StyleBox["\[CurlyPhi]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                xAct`xPand`\[CurlyPhi][],
                Editable->False], ""],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][
              xAct`xTensor`LI[0], 
              xAct`xTensor`LI[0]],
             Editable->False], ",", 
            FractionBox[
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                OverscriptBox[
                 InterpretationBox[
                  StyleBox["\[CurlyPhi]",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  xAct`xPand`\[CurlyPhi][],
                  Editable->False], "."],
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xPand`\[CurlyPhi][
                xAct`xTensor`LI[0], 
                xAct`xTensor`LI[1]],
               Editable->False], "2"], "2"]}], "]"}]}]}], ")"}], "2"]], 
     "\[Rule]", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"Z", "[", 
        RowBox[{
         RowBox[{"LI", "[", "0", "]"}], ",", 
         RowBox[{"LI", "[", "0", "]"}]}], "]"}], "2"], 
      RowBox[{"16", " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], "2"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"]}]]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SKGquadFinal", "=", 
    RowBox[{"SKGquad", "/.", "Zdef"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SuperscriptBox[\(S\), \((2)\)]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{"SKGquadFinal", "/.", "simp"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.809833619252922*^9, 3.8098336802038164`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"Z", "[", 
    RowBox[{
     RowBox[{"LI", "[", "xAct`xPand`Private`p$175202", "]"}], ",", 
     RowBox[{"LI", "[", "xAct`xPand`Private`q$175202", "]"}]}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`Z[
    xAct`xTensor`LI[xAct`xPand`Private`p$175202], 
    xAct`xTensor`LI[xAct`xPand`Private`q$175202]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.809833680500969*^9, 3.8098414736107864`*^9, 
  3.8098436694485025`*^9, 3.8098444923846855`*^9, 3.809863555750551*^9, 
  3.809867514001092*^9}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SuperscriptBox[\\(S\\), \\((2)\\)]\\)\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{
    FractionBox["1", 
     RowBox[{"8", " ", 
      InterpretationBox[
       StyleBox["\[Kappa]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Kappa],
       Editable->False]}]], 
    RowBox[{
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["Z",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Z[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Z[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Psi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Psi]h[],
            Editable->False], "."]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1]],
        Editable->False], ")"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], "4"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], ")"}], "2"]}], "+", 
       RowBox[{"12", " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None]}], "+", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              OverscriptBox[
               InterpretationBox[
                StyleBox["\[CurlyPhi]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                xAct`xPand`\[CurlyPhi][],
                Editable->False], "."],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][
              xAct`xTensor`LI[0], 
              xAct`xTensor`LI[1]],
             Editable->False], "2"], " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None]}]}], ")"}]}], "+", 
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox["V",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`V,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None]}]}], ")"}]}], "+", 
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           InterpretationBox[
            StyleBox["V",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`V,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None], "-", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None]}], ")"}]}]}], ")"}]}]}], "-", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"8", " ", 
      InterpretationBox[
       StyleBox["\[Kappa]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Kappa],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]}]], 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["Z",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Z[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Z[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], "2"], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox[
          OverscriptBox["D", "_"], "b"], 
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Psi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Psi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[-$CellContext`b][
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]],
       Editable->False], ")"}], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SuperscriptBox[
          OverscriptBox["D", "_"], "b"], 
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Psi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Psi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[$CellContext`b][
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]],
       Editable->False], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"16", " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None]}], "-", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], "4"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          SuperscriptBox[
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], ")"}], "2"]}], "+", 
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["V",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`V,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None]}], "+", 
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], ".."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[2]],
         Editable->False], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None]}], "+", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox[
              OverscriptBox[
               InterpretationBox[
                StyleBox["\[CurlyPhi]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                xAct`xPand`\[CurlyPhi][],
                Editable->False], "."],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][
              xAct`xTensor`LI[0], 
              xAct`xTensor`LI[1]],
             Editable->False], "2"], " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None]}]}], ")"}]}], "-", 
       RowBox[{"8", " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None]}], "+", 
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], "2"], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None]}]}], ")"}]}]}]}]}]], "Output",
 CellChangeTimes->{3.809833680516918*^9, 3.8098414736246634`*^9, 
  3.809843669461543*^9, 3.809844492400133*^9, 3.8098635557682905`*^9, 
  3.8098675140143166`*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["This is the second-order action of KGB",
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0.5, 0.5]],
 StyleBox[".",
  FontColor->RGBColor[1, 0.5, 0.5]],
 " This is Eq. (17) in arXiv:1008.0603 (expressed in conformal time) and Eq. \
(A.8) in arXiv:1008.0048.\n\nThe stability conditions are therefore..."
}], "Text",
 CellChangeTimes->{{3.809833683388405*^9, 3.8098337132663975`*^9}, {
  3.80984140391108*^9, 3.8098414458071346`*^9}, {3.8098441008398104`*^9, 
  3.8098441766158113`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[ScriptCapitalG]", "=", 
   RowBox[{
    RowBox[{
     FractionBox["2", 
      RowBox[{
       RowBox[{"ah", "[", 
        RowBox[{
         RowBox[{"LI", "[", "0", "]"}], ",", 
         RowBox[{"LI", "[", "0", "]"}]}], "]"}], 
       SuperscriptBox[
        RowBox[{"Z", "[", 
         RowBox[{
          RowBox[{"LI", "[", "0", "]"}], ",", 
          RowBox[{"LI", "[", "0", "]"}]}], "]"}], "2"]}]], 
     RowBox[{"Coefficient", "[", 
      RowBox[{"SKGquadFinal", ",", 
       SuperscriptBox[
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[Psi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Psi]h[],
              Editable->False], "."]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[1]],
          Editable->False], ")"}], "2"]}], "]"}]}], "//", "Expand"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[ScriptCapitalF]", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", 
         RowBox[{"ah", "[", 
          RowBox[{
           RowBox[{"LI", "[", "0", "]"}], ",", 
           RowBox[{"LI", "[", "0", "]"}]}], "]"}]}], 
        SuperscriptBox[
         RowBox[{"Z", "[", 
          RowBox[{
           RowBox[{"LI", "[", "0", "]"}], ",", 
           RowBox[{"LI", "[", "0", "]"}]}], "]"}], "2"]]}], 
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"SKGquadFinal", "/.", "simpV"}], ",", 
        RowBox[{
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             SubscriptBox[
              OverscriptBox["D", "_"], "b"], 
             OverscriptBox["\[Null]", 
              StyleBox[
               RowBox[{"(", "1", ")"}],
               FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[Psi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Psi]h[],
               Editable->False], ""]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`cd[-$CellContext`b][
            $CellContext`\[Psi]h[
             xAct`xTensor`LI[1], 
             xAct`xTensor`LI[0]]],
           Editable->False], ")"}], " ", 
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             SuperscriptBox[
              OverscriptBox["D", "_"], "b"], 
             OverscriptBox["\[Null]", 
              StyleBox[
               RowBox[{"(", "1", ")"}],
               FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[Psi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Psi]h[],
               Editable->False], ""]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`cd[$CellContext`b][
            $CellContext`\[Psi]h[
             xAct`xTensor`LI[1], 
             xAct`xTensor`LI[0]]],
           Editable->False], ")"}]}]}], "]"}]}], "//", "Simplify"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"\[ScriptCapitalF]", "/.", "simp"}], ")"}], ">", 
  "0"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"\[ScriptCapitalG]", "/.", "simp"}], ")"}], ">", "0"}]}], "Input",
 CellChangeTimes->{{3.8098417411059513`*^9, 3.809841862063773*^9}, {
  3.8098419345968533`*^9, 3.8098419853278294`*^9}, {3.8098421664891987`*^9, 
  3.8098422978504457`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"4", " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[CurlyPhi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][],
        Editable->False], "."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[CurlyPhi][
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None]}], "+", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[CurlyPhi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][],
        Editable->False], ".."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[CurlyPhi][
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[2]],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None]}], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[CurlyPhi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][],
          Editable->False], "."],
        ShowAutoStyles->False,
        AutoSpacing->False],
       xAct`xPand`\[CurlyPhi][
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[1]],
       Editable->False], "4"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], ")"}], "2"]}], 
    RowBox[{"4", " ", 
     InterpretationBox[
      StyleBox["\[Kappa]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Kappa],
      Editable->False]}]], "+", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox["V",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`V,
     Editable->False], 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "1"}], ")"}],
     Derivative],
    MultilineFunction->None], "+", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[CurlyPhi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][],
         Editable->False], "."],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xPand`\[CurlyPhi][
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[1]],
      Editable->False], "2"], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[CurlyPhi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][],
        Editable->False], ".."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[CurlyPhi][
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[2]],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None]}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None]}], "+", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[CurlyPhi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][],
         Editable->False], "."],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xPand`\[CurlyPhi][
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[1]],
      Editable->False], "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None]}]}], ">", "0"}]], "Output",
 CellChangeTimes->{{3.8098417517459445`*^9, 3.809841862409455*^9}, {
   3.809841952452691*^9, 3.8098419865129027`*^9}, {3.8098422714403687`*^9, 
   3.809842298278366*^9}, 3.809843669511024*^9, 3.8098444925033216`*^9, 
   3.8098635558370314`*^9, 3.809867514098521*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[CurlyPhi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][],
        Editable->False], "."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[CurlyPhi][
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None]}], "+", 
   FractionBox[
    RowBox[{"3", " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[CurlyPhi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][],
          Editable->False], "."],
        ShowAutoStyles->False,
        AutoSpacing->False],
       xAct`xPand`\[CurlyPhi][
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[1]],
       Editable->False], "4"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], ")"}], "2"]}], 
    RowBox[{"4", " ", 
     InterpretationBox[
      StyleBox["\[Kappa]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Kappa],
      Editable->False]}]], "+", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox["V",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`V,
     Editable->False], 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "1"}], ")"}],
     Derivative],
    MultilineFunction->None], "+", 
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[CurlyPhi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][],
         Editable->False], "."],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xPand`\[CurlyPhi][
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[1]],
      Editable->False], "3"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None]}], "+", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[CurlyPhi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][],
         Editable->False], "."],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xPand`\[CurlyPhi][
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[1]],
      Editable->False], "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["V",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`V,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None]}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None]}], "-", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[CurlyPhi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][],
         Editable->False], "."],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xPand`\[CurlyPhi][
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[1]],
      Editable->False], "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None]}]}], ">", "0"}]], "Output",
 CellChangeTimes->{{3.8098417517459445`*^9, 3.809841862409455*^9}, {
   3.809841952452691*^9, 3.8098419865129027`*^9}, {3.8098422714403687`*^9, 
   3.809842298278366*^9}, 3.809843669511024*^9, 3.8098444925033216`*^9, 
   3.8098635558370314`*^9, 3.8098675141113896`*^9}]
}, Open  ]],

Cell[TextData[{
 "This can be compared with the established results in arXiv:1008.0603 and \
arXiv:1008.0048 by using ",
 Cell[BoxData[
  FormBox[
   RowBox[{"X", "=", 
    RowBox[{
     SuperscriptBox[
      OverscriptBox["\[CurlyPhi]", "."], "2"], "/", "2"}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Kappa]", "=", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox["M", "Pl"], "2"], "/", "2"}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "..."
}], "Text",
 CellChangeTimes->{{3.809842142422*^9, 3.809842147031484*^9}, {
  3.809842326585451*^9, 3.809842328218566*^9}, {3.8098423649228554`*^9, 
  3.8098423865900793`*^9}, {3.809842508739354*^9, 3.8098425715737677`*^9}, {
  3.8098429492507906`*^9, 3.8098429535887756`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"DefConstantSymbol", "[", 
   RowBox[{"Mpl", ",", 
    RowBox[{"PrintAs", "\[Rule]", "\"\<\!\(\*SubscriptBox[
StyleBox[\"M\",
FontSlant->\"Italic\"], \"Pl\"]\)\>\""}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"DefProjectedTensor", "[", 
    RowBox[{
     RowBox[{"Xb", "[", "]"}], ",", "h", ",", 
     RowBox[{"PrintAs", "\[Rule]", "\"\<X\>\""}]}], "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"\[ScriptCapitalF]", "/.", "simp"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"\[CurlyPhi]", "[", 
          RowBox[{
           RowBox[{"LI", "[", "0", "]"}], ",", 
           RowBox[{"LI", "[", "1", "]"}]}], "]"}], "2"], "\[Rule]", 
        RowBox[{"2", 
         RowBox[{"Xb", "[", 
          RowBox[{
           RowBox[{"LI", "[", "0", "]"}], ",", 
           RowBox[{"LI", "[", "0", "]"}]}], "]"}]}]}], ",", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"\[CurlyPhi]", "[", 
          RowBox[{
           RowBox[{"LI", "[", "0", "]"}], ",", 
           RowBox[{"LI", "[", "1", "]"}]}], "]"}], "3"], "\[Rule]", 
        RowBox[{"2", 
         RowBox[{"Xb", "[", 
          RowBox[{
           RowBox[{"LI", "[", "0", "]"}], ",", 
           RowBox[{"LI", "[", "0", "]"}]}], "]"}], 
         RowBox[{"\[CurlyPhi]", "[", 
          RowBox[{
           RowBox[{"LI", "[", "0", "]"}], ",", 
           RowBox[{"LI", "[", "1", "]"}]}], "]"}]}]}], ",", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"\[CurlyPhi]", "[", 
          RowBox[{
           RowBox[{"LI", "[", "0", "]"}], ",", 
           RowBox[{"LI", "[", "1", "]"}]}], "]"}], "4"], "\[Rule]", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"2", 
           RowBox[{"Xb", "[", 
            RowBox[{
             RowBox[{"LI", "[", "0", "]"}], ",", 
             RowBox[{"LI", "[", "0", "]"}]}], "]"}]}], ")"}], "2"]}], ",", 
       RowBox[{"\[Kappa]", "\[Rule]", 
        RowBox[{
         SuperscriptBox["Mpl", "2"], "/", "2"}]}]}], "}"}]}], "//", 
    "Expand"}], ")"}], ">", "0"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"\[ScriptCapitalG]", "/.", "simp"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"\[CurlyPhi]", "[", 
          RowBox[{
           RowBox[{"LI", "[", "0", "]"}], ",", 
           RowBox[{"LI", "[", "1", "]"}]}], "]"}], "2"], "\[Rule]", 
        RowBox[{"2", 
         RowBox[{"Xb", "[", 
          RowBox[{
           RowBox[{"LI", "[", "0", "]"}], ",", 
           RowBox[{"LI", "[", "0", "]"}]}], "]"}]}]}], ",", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"\[CurlyPhi]", "[", 
          RowBox[{
           RowBox[{"LI", "[", "0", "]"}], ",", 
           RowBox[{"LI", "[", "1", "]"}]}], "]"}], "3"], "\[Rule]", 
        RowBox[{"2", 
         RowBox[{"Xb", "[", 
          RowBox[{
           RowBox[{"LI", "[", "0", "]"}], ",", 
           RowBox[{"LI", "[", "0", "]"}]}], "]"}], 
         RowBox[{"\[CurlyPhi]", "[", 
          RowBox[{
           RowBox[{"LI", "[", "0", "]"}], ",", 
           RowBox[{"LI", "[", "1", "]"}]}], "]"}]}]}], ",", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"\[CurlyPhi]", "[", 
          RowBox[{
           RowBox[{"LI", "[", "0", "]"}], ",", 
           RowBox[{"LI", "[", "1", "]"}]}], "]"}], "4"], "\[Rule]", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"2", 
           RowBox[{"Xb", "[", 
            RowBox[{
             RowBox[{"LI", "[", "0", "]"}], ",", 
             RowBox[{"LI", "[", "0", "]"}]}], "]"}]}], ")"}], "2"]}], ",", 
       RowBox[{"\[Kappa]", "\[Rule]", 
        RowBox[{
         SuperscriptBox["Mpl", "2"], "/", "2"}]}]}], "}"}]}], "//", 
    "Expand"}], ")"}], ">", "0"}]}], "Input",
 CellChangeTimes->{{3.809842592182892*^9, 3.809842625312416*^9}, {
  3.8098426567791395`*^9, 3.809842757448981*^9}, {3.8098428166531096`*^9, 
  3.809842871901247*^9}, {3.809843328040345*^9, 3.8098433582378054`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefConstantSymbol", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"constant symbol \"\>", "\[InvisibleSpace]", 
   "Mpl", "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefConstantSymbol, ": Defining ", 
   "constant symbol ", $CellContext`Mpl, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.8098428642219586`*^9, 3.809842872459484*^9}, 
   3.8098433597329855`*^9, 3.8098436696027813`*^9, 3.8098444925467567`*^9, 
   3.8098635558936434`*^9, 3.8098675141486435`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"Xb", "[", 
    RowBox[{
     RowBox[{"LI", "[", "xAct`xPand`Private`p$175238", "]"}], ",", 
     RowBox[{"LI", "[", "xAct`xPand`Private`q$175238", "]"}]}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`Xb[
    xAct`xTensor`LI[xAct`xPand`Private`p$175238], 
    xAct`xTensor`LI[xAct`xPand`Private`q$175238]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{{3.8098428642219586`*^9, 3.809842872459484*^9}, 
   3.8098433597329855`*^9, 3.8098436696027813`*^9, 3.8098444925467567`*^9, 
   3.8098635558936434`*^9, 3.8098675141542983`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"4", " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[CurlyPhi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][],
        Editable->False], "."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[CurlyPhi][
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None]}], "+", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[CurlyPhi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][],
        Editable->False], ".."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[CurlyPhi][
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[2]],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None]}], "-", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["X",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Xb[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Xb[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], ")"}], "2"]}], 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       SubscriptBox[
        StyleBox["M",
         FontSlant->"Italic"], "Pl"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Mpl,
      Editable->False], "2"]], "+", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox["V",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`V,
     Editable->False], 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "1"}], ")"}],
     Derivative],
    MultilineFunction->None], "+", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["X",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Xb[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Xb[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[CurlyPhi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][],
        Editable->False], ".."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[CurlyPhi][
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[2]],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None]}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None]}], "+", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["X",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Xb[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Xb[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None]}]}], ">", "0"}]], "Output",
 CellChangeTimes->{{3.8098428642308035`*^9, 3.809842872466776*^9}, 
   3.8098433597430205`*^9, 3.809843669620884*^9, 3.809844492568267*^9, 
   3.809863555915347*^9, 3.809867514171256*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[CurlyPhi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][],
        Editable->False], "."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[CurlyPhi][
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None]}], "+", 
   FractionBox[
    RowBox[{"6", " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["X",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Xb[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Xb[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], ")"}], "2"]}], 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       SubscriptBox[
        StyleBox["M",
         FontSlant->"Italic"], "Pl"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Mpl,
      Editable->False], "2"]], "+", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox["V",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`V,
     Editable->False], 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "1"}], ")"}],
     Derivative],
    MultilineFunction->None], "+", 
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["X",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Xb[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Xb[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[CurlyPhi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][],
        Editable->False], "."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[CurlyPhi][
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None]}], "+", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["X",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Xb[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Xb[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["V",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`V,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None]}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None]}], "-", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["X",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Xb[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Xb[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["G",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`G,
      Editable->False], 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None]}]}], ">", "0"}]], "Output",
 CellChangeTimes->{{3.8098428642308035`*^9, 3.809842872466776*^9}, 
   3.8098433597430205`*^9, 3.809843669620884*^9, 3.809844492568267*^9, 
   3.809863555915347*^9, 3.8098675141966367`*^9}]
}, Open  ]],

Cell[TextData[{
 "These are Eqs. (18) and (19) in arXiv:1008.0603 and Eqs. (A.10) and (A.12) \
in arXiv:1008.0048.",
 StyleBox["\n\nEnd of notebook.",
  FontSlant->"Italic"]
}], "Text",
 CellChangeTimes->{{3.809843115510867*^9, 3.8098431204089956`*^9}, {
  3.8098431784452143`*^9, 3.809843186640032*^9}, {3.809843944879945*^9, 
  3.809843955670539*^9}, {3.809844038661748*^9, 3.809844090968302*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["[",
  FontColor->RGBColor[1, 0.5, 0.5]],
 StyleBox["Bonus",
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0.5, 0.5]],
 StyleBox["] Second-order action for ",
  FontColor->RGBColor[1, 0.5, 0.5]],
 StyleBox["tensor",
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0.5, 0.5]],
 StyleBox[" perturbations of KGB",
  FontColor->RGBColor[1, 0.5, 0.5]]
}], "Subsection",
 CellChangeTimes->{{3.8098632567006893`*^9, 3.8098632728054895`*^9}}],

Cell["\<\
In this section, we derive the second-order action for the tensor \
fluctuations in KGB. This is a much more straightforward derivation that what \
was considered previously in the case of scalar perturbations. Let\
\[CloseCurlyQuote]s get straight to it.

First, we put back the tensor perturbations and kill off the scalar \
perturbations in the metric (valid since there\[CloseCurlyQuote]s no expected \
coupling between scalar and tensor modes)...\
\>", "Text",
 CellChangeTimes->{{3.809863306460202*^9, 3.809863382353632*^9}, {
  3.809863585901428*^9, 3.809863657784792*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"$FirstOrderTensorPerturbations", "=", "True"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"killScalar", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Phi]h", "[", 
        RowBox[{"_", ",", "_"}], "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"\[Psi]h", "[", 
        RowBox[{"_", ",", "_"}], "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"Bsh", "[", 
        RowBox[{"_", ",", "_"}], "]"}], "\[Rule]", "0"}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SubscriptBox[\(g\), \(bc\)]\)\>\"", "\[Equal]", 
  RowBox[{"VisualizeTensor", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"MyToxPand", "[", 
      RowBox[{
       RowBox[{"g", "[", 
        RowBox[{
         RowBox[{"-", "b"}], ",", 
         RowBox[{"-", "c"}]}], "]"}], ",", "\"\<ScalarFieldComovingGauge\>\"",
        ",", "1"}], "]"}], "/.", "killScalar"}], ",", "h"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\[Chi]\>\"", "\[Equal]", 
  RowBox[{"MyToxPand", "[", 
   RowBox[{
    RowBox[{"\[CurlyPhi]", "[", "]"}], ",", 
    "\"\<ScalarFieldComovingGauge\>\"", ",", "1"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.8098636001345663`*^9, 3.809863636965444*^9}, {
  3.8098637147802615`*^9, 3.80986380731861*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The Splitting of \"\>", "\[InvisibleSpace]", 
   RowBox[{
    StyleBox["\[Epsilon]",
     FontColor->RGBColor[0., 1., 0.]], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]g", 
         StyleBox[GridBox[{
            {"1", " ", " "},
            {" ", "b", "c"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dg[
      xAct`xTensor`LI[1], -$CellContext`b, -$CellContext`c],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       RowBox[{
        StyleBox["(",
         FontColor->RGBColor[1, 0, 0]], 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], 
        StyleBox[")",
         FontColor->RGBColor[1, 0, 0]]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xTensor`Scalar[
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]]],
      Editable->False], "2"]}], 
   "\[InvisibleSpace]", "\<\" +... was performed in \"\>", 
   "\[InvisibleSpace]", "0.1985425`", 
   "\[InvisibleSpace]", "\<\" seconds.\"\>"}],
  SequenceForm["The Splitting of ", xAct`xPand`\[Epsilon] $CellContext`dg[
     xAct`xTensor`LI[1], -$CellContext`b, -$CellContext`c] xAct`xTensor`Scalar[
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]]]^2, " +... was performed in ", 0.1985425, 
   " seconds."],
  Editable->False]], "Print",
 CellChangeTimes->{3.809863814596115*^9, 3.8098675145641756`*^9}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(g\\), \\(bc\\)]\\)\"\>", "\[Equal]", 
  TagBox[GridBox[{
     {"", "n", "h"},
     {"n", 
      RowBox[{"-", "1"}], "0"},
     {"h", "0", 
      RowBox[{
       RowBox[{"2", " ", 
        StyleBox["\[Epsilon]",
         FontColor->RGBColor[0., 1., 0.]], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False], "2"], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox[GridBox[{
                 {"E", 
                  StyleBox[GridBox[{
                    {" ", " "},
                    {"b", "c"}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                   FontSize->Rational[39, 4]]}
                },
                
                GridBoxAlignment->{
                 "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Eth[-$CellContext`b, -$CellContext`c],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0], -$CellContext`b, -$CellContext`c],
          Editable->False], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False], "2"], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {
             OverscriptBox["h", "-"], 
             StyleBox[GridBox[{
                {" ", " "},
                {"b", "c"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`h[-$CellContext`b, -$CellContext`c],
         Editable->False]}]}]}
    },
    AutoDelete->False,
    GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"]}]], "Output",
 CellChangeTimes->{3.8098638146575675`*^9, 3.809867514596603*^9}],

Cell[BoxData[
 TemplateBox[{
  "ToCanonical","noident",
   "\"Unknown expression not canonicalized: \\!\\(\\*RowBox[{\\\"LI\\\", \
\\\"[\\\", \\\"0\\\", \\\"]\\\"}]\\) .\"",2,199,3,16722567384493544385,
   "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8098638148341136`*^9, 3.809867514760624*^9}],

Cell[BoxData[
 TemplateBox[{
  "ToCanonical","noident",
   "\"Unknown expression not canonicalized: \\!\\(\\*RowBox[{\\\"LI\\\", \
\\\"[\\\", \\\"0\\\", \\\"]\\\"}]\\) .\"",2,199,4,16722567384493544385,
   "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8098638148341136`*^9, 3.8098675147951784`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The Splitting of \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox["\[CurlyPhi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       xAct`xPand`\[CurlyPhi][],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    xAct`xPand`\[CurlyPhi][
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0]],
    Editable->False], "\[InvisibleSpace]", "\<\" +... was performed in \"\>", 
   "\[InvisibleSpace]", "0.0537358`", 
   "\[InvisibleSpace]", "\<\" seconds.\"\>"}],
  SequenceForm["The Splitting of ", 
   xAct`xPand`\[CurlyPhi][
    xAct`xTensor`LI[0], 
    xAct`xTensor`LI[0]], " +... was performed in ", 0.0537358, " seconds."],
  Editable->False]], "Print",
 CellChangeTimes->{3.809863814596115*^9, 3.8098675148194714`*^9}],

Cell[BoxData[
 RowBox[{"\<\"\[Chi]\"\>", "\[Equal]", 
  InterpretationBox[
   StyleBox[
    OverscriptBox[
     InterpretationBox[
      StyleBox["\[CurlyPhi]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xPand`\[CurlyPhi][],
      Editable->False], ""],
    ShowAutoStyles->False,
    AutoSpacing->False],
   xAct`xPand`\[CurlyPhi][
    xAct`xTensor`LI[0], 
    xAct`xTensor`LI[0]],
   Editable->False]}]], "Output",
 CellChangeTimes->{3.8098638146575675`*^9, 3.80986751482248*^9}]
}, Open  ]],

Cell["The action expanded up to second-order is given by...", "Text",
 CellChangeTimes->{{3.8098638503379955`*^9, 3.8098638658709755`*^9}, {
  3.80986396453046*^9, 3.809863967915431*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SKG012Tensor", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"MyToxPand", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SqrtBox[
              RowBox[{"-", 
               RowBox[{"Detg", "[", "]"}]}]], 
             RowBox[{"(", 
              RowBox[{"LK", "+", "LG", "+", "LEH"}], ")"}]}], "/.", 
            RowBox[{
             RowBox[{"\[Chi]", "[", "]"}], "\[Rule]", 
             RowBox[{"\[CurlyPhi]", "[", "]"}]}]}], ",", 
           "\"\<ScalarFieldComovingGauge\>\"", ",", "2"}], "]"}], "/.", 
         "killScalar"}], "/.", "kill2O"}], "/.", 
       RowBox[{
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"Detg", "[", "]"}]}], 
          SuperscriptBox[
           RowBox[{"Scalar", "[", 
            RowBox[{"ah", "[", "]"}], "]"}], "8"]}], "]"}], "\[Rule]", 
        SuperscriptBox[
         RowBox[{"ah", "[", 
          RowBox[{
           RowBox[{"LI", "[", "0", "]"}], ",", 
           RowBox[{"LI", "[", "0", "]"}]}], "]"}], "3"]}]}], "//", "Expand"}],
      "//", "org"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SKG1Tensor", "=", 
   RowBox[{"ExtractOrder", "[", 
    RowBox[{"SKG012Tensor", ",", "1"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SKG2Tensor", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"ExtractOrder", "[", 
       RowBox[{"SKG012Tensor", ",", "2"}], "]"}], "//", "ToCanonical"}], "//",
      "NoScalar"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "Hold", "[", "\"\<\!\(\*SuperscriptBox[\(S\), \((1)\)]\)\>\"", "]"}], 
  "\[Equal]", "SKG1Tensor"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SuperscriptBox[\(S\), \((2)\)]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{"SKG2Tensor", "/.", "simp"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.8098639180491676`*^9, 3.8098639483868895`*^9}, {
   3.8098639861524005`*^9, 3.8098640519307146`*^9}, {3.80986415867106*^9, 
   3.8098641643269243`*^9}, 3.8098642302759275`*^9, {3.8098644613433104`*^9, 
   3.80986446954377*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The Splitting of \"\>", "\[InvisibleSpace]", 
   FractionBox[
    RowBox[{
     InterpretationBox[
      StyleBox["\[Kappa]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Kappa],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["R",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`RicciScalarCD[],
      Editable->False], " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"-", 
        InterpretationBox[
         StyleBox[
          OverscriptBox["g", 
           OverscriptBox[
            StyleBox["~",
             FontColor->RGBColor[0, 0, 0]], 
            StyleBox["~",
             FontColor->RGBColor[0, 0, 0]]]],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Detg[],
         Editable->False]}], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          RowBox[{
           StyleBox["(",
            FontColor->RGBColor[1, 0, 0]], 
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox["a",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`ah[],
               Editable->False], ""],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[0]],
            Editable->False], 
           StyleBox[")",
            FontColor->RGBColor[1, 0, 0]]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xTensor`Scalar[
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]]],
         Editable->False], "8"]}]]}], 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       RowBox[{
        StyleBox["(",
         FontColor->RGBColor[1, 0, 0]], 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], 
        StyleBox[")",
         FontColor->RGBColor[1, 0, 0]]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xTensor`Scalar[
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]]],
      Editable->False], "2"]], 
   "\[InvisibleSpace]", "\<\" +... was performed in \"\>", 
   "\[InvisibleSpace]", "70.900161`", 
   "\[InvisibleSpace]", "\<\" seconds.\"\>"}],
  SequenceForm[
  "The Splitting of ", $CellContext`\[Kappa] $CellContext`RicciScalarCD[] 
   xAct`xTensor`Scalar[
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]]]^(-2) (-$CellContext`Detg[] xAct`xTensor`Scalar[
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]]]^8)^Rational[1, 2], " +... was performed in ", 
   70.900161, " seconds."],
  Editable->False]], "Print",
 CellChangeTimes->{3.8098641253323584`*^9, 3.8098643076678724`*^9, 
  3.8098645484821243`*^9, 3.8098675878469305`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "Hold", "[", "\<\"\\!\\(\\*SuperscriptBox[\\(S\\), \\((1)\\)]\\)\"\>", 
   "]"}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.8098641256414905`*^9, 3.809864307976175*^9, 
  3.8098645493519683`*^9, 3.809867588233802*^9}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SuperscriptBox[\\(S\\), \\((2)\\)]\\)\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     InterpretationBox[
      StyleBox["V",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`V,
      Editable->False]}], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"b", "c"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[-$CellContext`b, -$CellContext`c],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Eth[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0], -$CellContext`b, -$CellContext`c],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {"b", "c"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[$CellContext`b, $CellContext`c],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Eth[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0], $CellContext`b, $CellContext`c],
      Editable->False], ")"}]}], "-", 
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"b", "c"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[-$CellContext`b, -$CellContext`c],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Eth[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1], -$CellContext`b, -$CellContext`c],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {"b", "c"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[$CellContext`b, $CellContext`c],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Eth[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1], $CellContext`b, $CellContext`c],
      Editable->False], ")"}]}], "-", 
   RowBox[{"4", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {"b", "c"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[$CellContext`b, $CellContext`c],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Eth[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0], $CellContext`b, $CellContext`c],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"b", "c"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[-$CellContext`b, -$CellContext`c],
          Editable->False], ".."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Eth[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[2], -$CellContext`b, -$CellContext`c],
      Editable->False], ")"}]}], "-", 
   RowBox[{"16", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {"b", "c"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[$CellContext`b, $CellContext`c],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Eth[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0], $CellContext`b, $CellContext`c],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"b", "c"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[-$CellContext`b, -$CellContext`c],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Eth[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1], -$CellContext`b, -$CellContext`c],
      Editable->False], ")"}], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False]}], "-", 
   RowBox[{"12", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"b", "c"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[-$CellContext`b, -$CellContext`c],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Eth[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0], -$CellContext`b, -$CellContext`c],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {"b", "c"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[$CellContext`b, $CellContext`c],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Eth[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0], $CellContext`b, $CellContext`c],
      Editable->False], ")"}], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["H",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Hh[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}], "-", 
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"b", "c"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[-$CellContext`b, -$CellContext`c],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Eth[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0], -$CellContext`b, -$CellContext`c],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {"b", "c"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[$CellContext`b, $CellContext`c],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Eth[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0], $CellContext`b, $CellContext`c],
      Editable->False], ")"}], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], "."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False]}], "-", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["G",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`G,
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {"b", "c"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[$CellContext`b, $CellContext`c],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Eth[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0], $CellContext`b, $CellContext`c],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"b", "c"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[-$CellContext`b, -$CellContext`c],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Eth[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1], -$CellContext`b, -$CellContext`c],
      Editable->False], ")"}], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[CurlyPhi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][],
        Editable->False], "."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[CurlyPhi][
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False]}], "-", 
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["G",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`G,
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"b", "c"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[-$CellContext`b, -$CellContext`c],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Eth[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0], -$CellContext`b, -$CellContext`c],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {"b", "c"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[$CellContext`b, $CellContext`c],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Eth[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0], $CellContext`b, $CellContext`c],
      Editable->False], ")"}], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["H",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[CurlyPhi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][],
        Editable->False], "."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[CurlyPhi][
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox["G",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`G,
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"b", "c"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[-$CellContext`b, -$CellContext`c],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Eth[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0], -$CellContext`b, -$CellContext`c],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {"b", "c"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[$CellContext`b, $CellContext`c],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Eth[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0], $CellContext`b, $CellContext`c],
      Editable->False], ")"}], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[CurlyPhi]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][],
        Editable->False], ".."],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[CurlyPhi][
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[2]],
     Editable->False]}], "+", 
   RowBox[{"4", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {"b", "c"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[$CellContext`b, $CellContext`c],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Eth[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0], $CellContext`b, $CellContext`c],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "i"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "i"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"b", "c"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[-$CellContext`b, -$CellContext`c],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`i][
       $CellContext`cd[$CellContext`i][
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`b, -$CellContext`c]]],
      Editable->False], ")"}]}], "-", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "c"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"b", "i"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[-$CellContext`b, -$CellContext`i],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`c][
       $CellContext`Eth[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0], -$CellContext`b, -$CellContext`i]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "i"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {"b", "c"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[$CellContext`b, $CellContext`c],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`i][
       $CellContext`Eth[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0], $CellContext`b, $CellContext`c]],
      Editable->False], ")"}]}], "+", 
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "i"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"b", "c"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[-$CellContext`b, -$CellContext`c],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`i][
       $CellContext`Eth[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0], -$CellContext`b, -$CellContext`c]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "i"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {"b", "c"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[$CellContext`b, $CellContext`c],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`i][
       $CellContext`Eth[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0], $CellContext`b, $CellContext`c]],
      Editable->False], ")"}]}]}]}]], "Output",
 CellChangeTimes->{3.8098641256414905`*^9, 3.809864307976175*^9, 
  3.8098645493519683`*^9, 3.8098675883217044`*^9}]
}, Open  ]],

Cell["\<\
So, we see that the tensor fluctuations doesn\[CloseCurlyQuote]t add to the \
background dynamics. Rather, it appears at second-order as gravitational waves.

We massage the quadratic action as we did previously for scalar \
perturbations. Let\[CloseCurlyQuote]s start with the easier IBPs \
(specifically those with second-derivative)...\
\>", "Text",
 CellChangeTimes->{{3.8098642467518396`*^9, 3.809864317600565*^9}, {
  3.8098643704218335`*^9, 3.8098644000546474`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"CollectEt", "[", "expr_", "]"}], ":=", 
   RowBox[{"Collect", "[", 
    RowBox[{"expr", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox[GridBox[{
                 {"E", 
                  StyleBox[GridBox[{
                    {" ", " "},
                    {"b", "c"}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                   FontSize->Rational[39, 4]]}
                },
                
                GridBoxAlignment->{
                 "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Eth[-$CellContext`b, -$CellContext`c],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0], -$CellContext`b, -$CellContext`c],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox[GridBox[{
                 {"E", 
                  StyleBox[GridBox[{
                    {"b", "c"},
                    {" ", " "}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                   FontSize->Rational[39, 4]]}
                },
                
                GridBoxAlignment->{
                 "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Eth[$CellContext`b, $CellContext`c],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0], $CellContext`b, $CellContext`c],
          Editable->False], ")"}]}], ",", 
       RowBox[{
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox[GridBox[{
                 {"E", 
                  StyleBox[GridBox[{
                    {" ", " "},
                    {"b", "c"}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                   FontSize->Rational[39, 4]]}
                },
                
                GridBoxAlignment->{
                 "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Eth[-$CellContext`b, -$CellContext`c],
              Editable->False], "."]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[1], -$CellContext`b, -$CellContext`c],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox[GridBox[{
                 {"E", 
                  StyleBox[GridBox[{
                    {"b", "c"},
                    {" ", " "}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                   FontSize->Rational[39, 4]]}
                },
                
                GridBoxAlignment->{
                 "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Eth[$CellContext`b, $CellContext`c],
              Editable->False], "."]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[1], $CellContext`b, $CellContext`c],
          Editable->False], ")"}]}], ",", 
       RowBox[{
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox[GridBox[{
                 {"E", 
                  StyleBox[GridBox[{
                    {"b", "c"},
                    {" ", " "}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                   FontSize->Rational[39, 4]]}
                },
                
                GridBoxAlignment->{
                 "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Eth[$CellContext`b, $CellContext`c],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0], $CellContext`b, $CellContext`c],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox[GridBox[{
                 {"E", 
                  StyleBox[GridBox[{
                    {" ", " "},
                    {"b", "c"}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                   FontSize->Rational[39, 4]]}
                },
                
                GridBoxAlignment->{
                 "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Eth[-$CellContext`b, -$CellContext`c],
              Editable->False], "."]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[1], -$CellContext`b, -$CellContext`c],
          Editable->False], ")"}]}], ",", 
       RowBox[{
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox[
             OverscriptBox["D", "_"], "i"], 
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox[GridBox[{
                 {"E", 
                  StyleBox[GridBox[{
                    {" ", " "},
                    {"b", "c"}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                   FontSize->Rational[39, 4]]}
                },
                
                GridBoxAlignment->{
                 "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Eth[-$CellContext`b, -$CellContext`c],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`cd[-$CellContext`i][
           $CellContext`Eth[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0], -$CellContext`b, -$CellContext`c]],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SuperscriptBox[
             OverscriptBox["D", "_"], "i"], 
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox[GridBox[{
                 {"E", 
                  StyleBox[GridBox[{
                    {"b", "c"},
                    {" ", " "}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                   FontSize->Rational[39, 4]]}
                },
                
                GridBoxAlignment->{
                 "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Eth[$CellContext`b, $CellContext`c],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`cd[$CellContext`i][
           $CellContext`Eth[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0], $CellContext`b, $CellContext`c]],
          Editable->False], ")"}]}]}], "}"}], ",", "Simplify"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SKG2Tensor2", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"SKG2Tensor", "/.", 
          RowBox[{
           RowBox[{"expr_", " ", 
            RowBox[{"Eth", "[", 
             RowBox[{
              RowBox[{"LI", "[", "1", "]"}], ",", 
              RowBox[{"LI", "[", "2", "]"}], ",", 
              RowBox[{"-", "x_"}], ",", 
              RowBox[{"-", "y_"}]}], "]"}]}], "\[RuleDelayed]", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"Eth", "[", 
              RowBox[{
               RowBox[{"LI", "[", "1", "]"}], ",", 
               RowBox[{"LI", "[", "1", "]"}], ",", 
               RowBox[{"-", "x"}], ",", 
               RowBox[{"-", "y"}]}], "]"}]}], 
            RowBox[{"dt", "[", "expr", "]"}]}]}]}], "/.", 
         RowBox[{
          RowBox[{"expr_", " ", 
           RowBox[{
            RowBox[{"cd", "[", 
             RowBox[{"-", "x_"}], "]"}], "[", 
            RowBox[{
             RowBox[{"cd", "[", "x_", "]"}], "[", 
             RowBox[{"Eth", "[", 
              RowBox[{
               RowBox[{"LI", "[", "1", "]"}], ",", 
               RowBox[{"LI", "[", "0", "]"}], ",", "u_", ",", "v_"}], "]"}], 
             "]"}], "]"}]}], "\[RuleDelayed]", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{
             RowBox[{"cd", "[", 
              RowBox[{"-", "x"}], "]"}], "[", "expr", "]"}]}], 
           RowBox[{
            RowBox[{"cd", "[", "x", "]"}], "[", 
            RowBox[{"Eth", "[", 
             RowBox[{
              RowBox[{"LI", "[", "1", "]"}], ",", 
              RowBox[{"LI", "[", "0", "]"}], ",", "u", ",", "v"}], "]"}], 
            "]"}]}]}]}], "//", "ContractMetric"}], "//", "ToCanonical"}], "//",
       "NoScalar"}], "//", "CollectEt"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SuperscriptBox[\(S\), \((2)\)]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{"SKG2Tensor2", "/.", "simp"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.809864417831538*^9, 3.8098644300211067`*^9}, {
  3.809864508942033*^9, 3.8098645471776843`*^9}, {3.8098645841845694`*^9, 
  3.8098647020722127`*^9}, {3.8098647397677827`*^9, 3.809864741618783*^9}, {
  3.8098647733683014`*^9, 3.809864776344718*^9}, {3.809865042414466*^9, 
  3.809865043905678*^9}, {3.8098652581827745`*^9, 3.8098652888983593`*^9}, {
  3.80986534180077*^9, 3.8098654066640525`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SuperscriptBox[\\(S\\), \\((2)\\)]\\)\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"b", "c"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[-$CellContext`b, -$CellContext`c],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Eth[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1], -$CellContext`b, -$CellContext`c],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {"b", "c"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[$CellContext`b, $CellContext`c],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Eth[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1], $CellContext`b, $CellContext`c],
      Editable->False], ")"}]}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {"b", "c"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[$CellContext`b, $CellContext`c],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Eth[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0], $CellContext`b, $CellContext`c],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"b", "c"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[-$CellContext`b, -$CellContext`c],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Eth[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1], -$CellContext`b, -$CellContext`c],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False]}]}], ")"}]}], "-", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"b", "c"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[-$CellContext`b, -$CellContext`c],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Eth[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0], -$CellContext`b, -$CellContext`c],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {"b", "c"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[$CellContext`b, $CellContext`c],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Eth[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0], $CellContext`b, $CellContext`c],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      InterpretationBox[
       StyleBox["V",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`V,
       Editable->False], "+", 
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"]}], "+", 
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False]}], "+", 
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], ".."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[2]],
        Editable->False]}]}], ")"}]}], "-", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "c"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"b", "i"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[-$CellContext`b, -$CellContext`i],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`c][
       $CellContext`Eth[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0], -$CellContext`b, -$CellContext`i]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "i"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {"b", "c"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[$CellContext`b, $CellContext`c],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`i][
       $CellContext`Eth[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0], $CellContext`b, $CellContext`c]],
      Editable->False], ")"}]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "i"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"b", "c"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[-$CellContext`b, -$CellContext`c],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`i][
       $CellContext`Eth[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0], -$CellContext`b, -$CellContext`c]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "i"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {"b", "c"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[$CellContext`b, $CellContext`c],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`i][
       $CellContext`Eth[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0], $CellContext`b, $CellContext`c]],
      Editable->False], ")"}]}]}]}]], "Output",
 CellChangeTimes->{
  3.809864704968501*^9, 3.809865046515685*^9, {3.8098652612838154`*^9, 
   3.809865290181299*^9}, {3.8098653962953954`*^9, 3.8098654073934116`*^9}, 
   3.8098675887540216`*^9}]
}, Open  ]],

Cell[TextData[{
 "It should be reminded that the tensor ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["E", "ab"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " is divergenceless by construction (SVT decomposition). The term ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"(", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox[
        OverscriptBox["D", "_"], "c"], 
       OverscriptBox["\[Null]", 
        StyleBox[
         RowBox[{"(", "1", ")"}],
         FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
       OverscriptBox[
        InterpretationBox[
         StyleBox[GridBox[{
            {"E", 
             StyleBox[GridBox[{
                {" ", " "},
                {"b", "i"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Eth[-$CellContext`b, -$CellContext`i],
         Editable->False], ""]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`cd[-$CellContext`c][
      $CellContext`Eth[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0], -$CellContext`b, -$CellContext`i]],
     Editable->False], ")"}], " ", 
   RowBox[{"(", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox[
        OverscriptBox["D", "_"], "i"], 
       OverscriptBox["\[Null]", 
        StyleBox[
         RowBox[{"(", "1", ")"}],
         FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
       OverscriptBox[
        InterpretationBox[
         StyleBox[GridBox[{
            {"E", 
             StyleBox[GridBox[{
                {"b", "c"},
                {" ", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Eth[$CellContext`b, $CellContext`c],
         Editable->False], ""]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`cd[$CellContext`i][
      $CellContext`Eth[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0], $CellContext`b, $CellContext`c]],
     Editable->False], ")"}]}]],
  CellChangeTimes->{
   3.809864704968501*^9, 3.809865046515685*^9, {3.8098652612838154`*^9, 
    3.809865290181299*^9}, {3.8098653962953954`*^9, 3.8098654073934116`*^9}}],
 " can therefore be eliminated by IBP..."
}], "Text",
 CellChangeTimes->{{3.8098654399596972`*^9, 3.8098654946830363`*^9}, {
  3.8098655558931065`*^9, 3.8098655560319824`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Hold", "[", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "c"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"b", "i"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[-$CellContext`b, -$CellContext`i],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`c][
       $CellContext`Eth[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0], -$CellContext`b, -$CellContext`i]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "i"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {"b", "c"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[$CellContext`b, $CellContext`c],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`i][
       $CellContext`Eth[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0], $CellContext`b, $CellContext`c]],
      Editable->False], ")"}]}], "]"}], "\[Equal]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      InterpretationBox[
       StyleBox["\[Kappa]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Kappa],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "c"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {" ", " "},
                   {"b", "i"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[-$CellContext`b, -$CellContext`i],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`c][
         $CellContext`Eth[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], -$CellContext`b, -$CellContext`i]],
        Editable->False], ")"}], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox[
           OverscriptBox["D", "_"], "i"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {"b", "c"},
                   {" ", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[$CellContext`b, $CellContext`c],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[$CellContext`i][
         $CellContext`Eth[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], $CellContext`b, $CellContext`c]],
        Editable->False], ")"}]}], "/.", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"cd", "[", 
         RowBox[{"-", "x_"}], "]"}], "[", 
        RowBox[{"Eth", "[", 
         RowBox[{
          RowBox[{"LI", "[", "1", "]"}], ",", 
          RowBox[{"LI", "[", "0", "]"}], ",", 
          RowBox[{"-", "y_"}], ",", 
          RowBox[{"-", "z_"}]}], "]"}], "]"}], 
       RowBox[{
        RowBox[{"cd", "[", "z_", "]"}], "[", 
        RowBox[{"Eth", "[", 
         RowBox[{
          RowBox[{"LI", "[", "1", "]"}], ",", 
          RowBox[{"LI", "[", "0", "]"}], ",", "y_", ",", "x_"}], "]"}], 
        "]"}]}], "\[RuleDelayed]", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Eth", "[", 
         RowBox[{
          RowBox[{"LI", "[", "1", "]"}], ",", 
          RowBox[{"LI", "[", "0", "]"}], ",", 
          RowBox[{"-", "y"}], ",", 
          RowBox[{"-", "z"}]}], "]"}]}], 
       RowBox[{
        RowBox[{"cd", "[", 
         RowBox[{"-", "x"}], "]"}], "[", 
        RowBox[{
         RowBox[{"cd", "[", "z", "]"}], "[", 
         RowBox[{"Eth", "[", 
          RowBox[{
           RowBox[{"LI", "[", "1", "]"}], ",", 
           RowBox[{"LI", "[", "0", "]"}], ",", "y", ",", "x"}], "]"}], "]"}], 
        "]"}]}]}]}], "//", "ToCanonical"}], ")"}], "\[Equal]", 
  RowBox[{"CommuteCovDs", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "c"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"E", 
                 StyleBox[GridBox[{
                    {" ", " "},
                    {"b", "i"}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Eth[-$CellContext`b, -$CellContext`i],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`c][
          $CellContext`Eth[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0], -$CellContext`b, -$CellContext`i]],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "i"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"E", 
                 StyleBox[GridBox[{
                    {"b", "c"},
                    {" ", " "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Eth[$CellContext`b, $CellContext`c],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`i][
          $CellContext`Eth[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0], $CellContext`b, $CellContext`c]],
         Editable->False], ")"}]}], "/.", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"cd", "[", 
          RowBox[{"-", "x_"}], "]"}], "[", 
         RowBox[{"Eth", "[", 
          RowBox[{
           RowBox[{"LI", "[", "1", "]"}], ",", 
           RowBox[{"LI", "[", "0", "]"}], ",", 
           RowBox[{"-", "y_"}], ",", 
           RowBox[{"-", "z_"}]}], "]"}], "]"}], 
        RowBox[{
         RowBox[{"cd", "[", "z_", "]"}], "[", 
         RowBox[{"Eth", "[", 
          RowBox[{
           RowBox[{"LI", "[", "1", "]"}], ",", 
           RowBox[{"LI", "[", "0", "]"}], ",", "y_", ",", "x_"}], "]"}], 
         "]"}]}], "\[RuleDelayed]", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Eth", "[", 
          RowBox[{
           RowBox[{"LI", "[", "1", "]"}], ",", 
           RowBox[{"LI", "[", "0", "]"}], ",", 
           RowBox[{"-", "y"}], ",", 
           RowBox[{"-", "z"}]}], "]"}]}], 
        RowBox[{
         RowBox[{"cd", "[", 
          RowBox[{"-", "x"}], "]"}], "[", 
         RowBox[{
          RowBox[{"cd", "[", "z", "]"}], "[", 
          RowBox[{"Eth", "[", 
           RowBox[{
            RowBox[{"LI", "[", "1", "]"}], ",", 
            RowBox[{"LI", "[", "0", "]"}], ",", "y", ",", "x"}], "]"}], "]"}],
          "]"}]}]}]}], "//", "ToCanonical"}], ",", "cd", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "c"}], ",", 
      RowBox[{"-", "i"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8098655702774916`*^9, 3.809865570353844*^9}, {
  3.8098656145243444`*^9, 3.8098658298259363`*^9}, {3.809865934151517*^9, 
  3.8098660661454353`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Hold", "[", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "c"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"b", "i"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[-$CellContext`b, -$CellContext`i],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`c][
       $CellContext`Eth[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0], -$CellContext`b, -$CellContext`i]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "i"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {"b", "c"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[$CellContext`b, $CellContext`c],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`i][
       $CellContext`Eth[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0], $CellContext`b, $CellContext`c]],
      Editable->False], ")"}]}], "]"}], "\[Equal]", 
  RowBox[{"2", " ", 
   InterpretationBox[
    StyleBox["\[Kappa]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Kappa],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`ah[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0]],
    Editable->False], " ", 
   RowBox[{"(", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       OverscriptBox["\[Null]", 
        StyleBox[
         RowBox[{"(", "1", ")"}],
         FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
       OverscriptBox[
        InterpretationBox[
         StyleBox[GridBox[{
            {"E", 
             StyleBox[GridBox[{
                {"b", "c"},
                {" ", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Eth[$CellContext`b, $CellContext`c],
         Editable->False], ""]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Eth[
      xAct`xTensor`LI[1], 
      xAct`xTensor`LI[0], $CellContext`b, $CellContext`c],
     Editable->False], ")"}], " ", 
   RowBox[{"(", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox[
        OverscriptBox["D", "_"], "i"], 
       SubscriptBox[
        OverscriptBox["D", "_"], "c"], 
       OverscriptBox["\[Null]", 
        StyleBox[
         RowBox[{"(", "1", ")"}],
         FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
       OverscriptBox[
        InterpretationBox[
         StyleBox[GridBox[{
            {"E", 
             StyleBox[GridBox[{
                {" ", "i"},
                {"b", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Eth[-$CellContext`b, $CellContext`i],
         Editable->False], ""]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`cd[-$CellContext`i][
      $CellContext`cd[-$CellContext`c][
       $CellContext`Eth[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0], -$CellContext`b, $CellContext`i]]],
     Editable->False], ")"}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{{3.8098657471587896`*^9, 3.809865830766123*^9}, {
   3.809865952899021*^9, 3.8098660679683046`*^9}, 3.8098666584334946`*^9, 
   3.8098675888600054`*^9}]
}, Open  ]],

Cell["Also consider the total derivative term...", "Text",
 CellChangeTimes->{{3.8098661194222527`*^9, 3.809866129293106*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"GEE", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Hold", "[", 
      RowBox[{"\"\<\!\(\*FractionBox[\(d\), \(dt\)]\)\>\"", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["a",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`ah[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], "3"], " ", 
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             OverscriptBox["\[Null]", 
              StyleBox[
               RowBox[{"(", "1", ")"}],
               FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
             OverscriptBox[
              InterpretationBox[
               StyleBox[GridBox[{
                  {"E", 
                   StyleBox[GridBox[{
                    {" ", " "},
                    {"b", "c"}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                    FontSize->Rational[39, 4]]}
                 },
                 
                 GridBoxAlignment->{
                  "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Eth[-$CellContext`b, -$CellContext`c],
               Editable->False], ""]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Eth[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0], -$CellContext`b, -$CellContext`c],
           Editable->False], ")"}], " ", 
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             OverscriptBox["\[Null]", 
              StyleBox[
               RowBox[{"(", "1", ")"}],
               FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
             OverscriptBox[
              InterpretationBox[
               StyleBox[GridBox[{
                  {"E", 
                   StyleBox[GridBox[{
                    {"b", "c"},
                    {" ", " "}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                    FontSize->Rational[39, 4]]}
                 },
                 
                 GridBoxAlignment->{
                  "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Eth[$CellContext`b, $CellContext`c],
               Editable->False], ""]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Eth[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0], $CellContext`b, $CellContext`c],
           Editable->False], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            InterpretationBox[
             StyleBox["\[Kappa]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Kappa],
             Editable->False], " ", 
            InterpretationBox[
             StyleBox[
              OverscriptBox[
               InterpretationBox[
                StyleBox["H",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`Hh[],
                Editable->False], ""],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Hh[
              xAct`xTensor`LI[0], 
              xAct`xTensor`LI[0]],
             Editable->False]}], "+", 
           RowBox[{
            InterpretationBox[
             StyleBox["G",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`G,
             Editable->False], " ", 
            InterpretationBox[
             StyleBox[
              OverscriptBox[
               InterpretationBox[
                StyleBox["\[CurlyPhi]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                xAct`xPand`\[CurlyPhi][],
                Editable->False], "."],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][
              xAct`xTensor`LI[0], 
              xAct`xTensor`LI[1]],
             Editable->False]}]}], ")"}]}], ")"}]}], "]"}], "\[Equal]", 
     RowBox[{"dt", "[", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "3"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          InterpretationBox[
           StyleBox["\[Kappa]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Kappa],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["H",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Hh[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False]}], "+", 
         RowBox[{
          RowBox[{
           InterpretationBox[
            StyleBox["G",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`G,
            Editable->False], "[", 
           RowBox[{
            InterpretationBox[
             StyleBox[
              RowBox[{
               StyleBox["(",
                FontColor->RGBColor[1, 0, 0]], 
               InterpretationBox[
                StyleBox[
                 OverscriptBox[
                  InterpretationBox[
                   StyleBox["\[CurlyPhi]",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                   xAct`xPand`\[CurlyPhi][],
                   Editable->False], ""],
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                xAct`xPand`\[CurlyPhi][
                 xAct`xTensor`LI[0], 
                 xAct`xTensor`LI[0]],
                Editable->False], 
               StyleBox[")",
                FontColor->RGBColor[1, 0, 0]]}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xTensor`Scalar[
              xAct`xPand`\[CurlyPhi][
               xAct`xTensor`LI[0], 
               xAct`xTensor`LI[0]]],
             Editable->False], ",", 
            FractionBox[
             SuperscriptBox[
              InterpretationBox[
               StyleBox[
                RowBox[{
                 StyleBox["(",
                  FontColor->RGBColor[1, 0, 0]], 
                 InterpretationBox[
                  StyleBox[
                   OverscriptBox[
                    InterpretationBox[
                    StyleBox["\[CurlyPhi]",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    xAct`xPand`\[CurlyPhi][],
                    Editable->False], "."],
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  xAct`xPand`\[CurlyPhi][
                   xAct`xTensor`LI[0], 
                   xAct`xTensor`LI[1]],
                  Editable->False], 
                 StyleBox[")",
                  FontColor->RGBColor[1, 0, 0]]}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               xAct`xTensor`Scalar[
                xAct`xPand`\[CurlyPhi][
                 xAct`xTensor`LI[0], 
                 xAct`xTensor`LI[1]]],
               Editable->False], "2"], "2"]}], "]"}], " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], "."],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[1]],
           Editable->False]}]}], ")"}], 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"E", 
                 StyleBox[GridBox[{
                    {" ", " "},
                    {"b", "c"}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Eth[-$CellContext`b, -$CellContext`c],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Eth[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], -$CellContext`b, -$CellContext`c],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"E", 
                 StyleBox[GridBox[{
                    {"b", "c"},
                    {" ", " "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Eth[$CellContext`b, $CellContext`c],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Eth[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], $CellContext`b, $CellContext`c],
         Editable->False], ")"}]}], "]"}]}], "//", "CollectEt"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"GEE", "/.", "simp"}]}], "Input",
 CellChangeTimes->{{3.809866133425876*^9, 3.809866140084134*^9}, {
  3.809866176099759*^9, 3.8098662464317145`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Hold", "[", 
   RowBox[{"\<\"\\!\\(\\*FractionBox[\\(d\\), \\(dt\\)]\\)\"\>", " ", 
    RowBox[{"(", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         InterpretationBox[
          StyleBox["\[Kappa]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Kappa],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["H",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Hh[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False]}], "+", 
        RowBox[{
         InterpretationBox[
          StyleBox["G",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`G,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[CurlyPhi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             xAct`xPand`\[CurlyPhi][],
             Editable->False], "."],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox[GridBox[{
                 {"E", 
                  StyleBox[GridBox[{
                    {" ", " "},
                    {"b", "c"}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                   FontSize->Rational[39, 4]]}
                },
                
                GridBoxAlignment->{
                 "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Eth[-$CellContext`b, -$CellContext`c],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0], -$CellContext`b, -$CellContext`c],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox[GridBox[{
                 {"E", 
                  StyleBox[GridBox[{
                    {"b", "c"},
                    {" ", " "}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                   FontSize->Rational[39, 4]]}
                },
                
                GridBoxAlignment->{
                 "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Eth[$CellContext`b, $CellContext`c],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0], $CellContext`b, $CellContext`c],
          Editable->False], ")"}]}], ")"}]}], ")"}]}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"4", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {"b", "c"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[$CellContext`b, $CellContext`c],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Eth[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0], $CellContext`b, $CellContext`c],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"b", "c"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[-$CellContext`b, -$CellContext`c],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Eth[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1], -$CellContext`b, -$CellContext`c],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False]}]}], ")"}]}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"b", "c"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[-$CellContext`b, -$CellContext`c],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Eth[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0], -$CellContext`b, -$CellContext`c],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {"b", "c"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[$CellContext`b, $CellContext`c],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Eth[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0], $CellContext`b, $CellContext`c],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"]}], "+", 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False]}], "+", 
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox["G",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], ".."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[2]],
        Editable->False]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], ".."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[2]],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None]}]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{{3.8098662324468765`*^9, 3.8098662468619504`*^9}, 
   3.809867589048376*^9}]
}, Open  ]],

Cell["The second-order action for tensor perturbations become...", "Text",
 CellChangeTimes->{{3.809866257037635*^9, 3.809866268476026*^9}, 
   3.8098669247842207`*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SKG2Tensor3", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"CommuteCovDs", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"SKG2Tensor2", "/.", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"cd", "[", 
                  RowBox[{"-", "x_"}], "]"}], "[", 
                 RowBox[{"Eth", "[", 
                  RowBox[{
                   RowBox[{"LI", "[", "1", "]"}], ",", 
                   RowBox[{"LI", "[", "0", "]"}], ",", 
                   RowBox[{"-", "y_"}], ",", 
                   RowBox[{"-", "z_"}]}], "]"}], "]"}], 
                RowBox[{
                 RowBox[{"cd", "[", "z_", "]"}], "[", 
                 RowBox[{"Eth", "[", 
                  RowBox[{
                   RowBox[{"LI", "[", "1", "]"}], ",", 
                   RowBox[{"LI", "[", "0", "]"}], ",", "y_", ",", "x_"}], 
                  "]"}], "]"}]}], "\[RuleDelayed]", 
               RowBox[{
                RowBox[{"-", 
                 RowBox[{"Eth", "[", 
                  RowBox[{
                   RowBox[{"LI", "[", "1", "]"}], ",", 
                   RowBox[{"LI", "[", "0", "]"}], ",", 
                   RowBox[{"-", "y"}], ",", 
                   RowBox[{"-", "z"}]}], "]"}]}], 
                RowBox[{
                 RowBox[{"cd", "[", 
                  RowBox[{"-", "x"}], "]"}], "[", 
                 RowBox[{
                  RowBox[{"cd", "[", "z", "]"}], "[", 
                  RowBox[{"Eth", "[", 
                   RowBox[{
                    RowBox[{"LI", "[", "1", "]"}], ",", 
                    RowBox[{"LI", "[", "0", "]"}], ",", "y", ",", "x"}], 
                   "]"}], "]"}], "]"}]}]}]}], ")"}], "//", "ToCanonical"}], "//",
            "NoScalar"}], ",", "cd", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "c"}], ",", 
            RowBox[{"-", "i"}]}], "}"}]}], "]"}], "+", 
        RowBox[{"(", 
         RowBox[{
          FractionBox["1", "2"], 
          RowBox[{"GEE", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], ")"}]}], "//", "ToCanonical"}], "//",
       "NoScalar"}], "//", "CollectEt"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SuperscriptBox[\(S\), \((2)\)]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{"SKG2Tensor3", "/.", "simp"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.809866288183901*^9, 3.8098663425115175`*^9}, {
  3.809866382559901*^9, 3.8098664097091155`*^9}, {3.8098668490679026`*^9, 
  3.8098668604790483`*^9}, {3.8098669107429795`*^9, 3.8098669119308357`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SuperscriptBox[\\(S\\), \\((2)\\)]\\)\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"b", "c"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[-$CellContext`b, -$CellContext`c],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Eth[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1], -$CellContext`b, -$CellContext`c],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {"b", "c"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[$CellContext`b, $CellContext`c],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Eth[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1], $CellContext`b, $CellContext`c],
      Editable->False], ")"}]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "i"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"b", "c"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[-$CellContext`b, -$CellContext`c],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`i][
       $CellContext`Eth[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0], -$CellContext`b, -$CellContext`c]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "i"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {"b", "c"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[$CellContext`b, $CellContext`c],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`i][
       $CellContext`Eth[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0], $CellContext`b, $CellContext`c]],
      Editable->False], ")"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"b", "c"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[-$CellContext`b, -$CellContext`c],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Eth[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0], -$CellContext`b, -$CellContext`c],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {"b", "c"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[$CellContext`b, $CellContext`c],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Eth[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0], $CellContext`b, $CellContext`c],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       InterpretationBox[
        StyleBox["V",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`V,
        Editable->False]}], "-", 
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["H",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"]}], "-", 
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox["\[Kappa]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Kappa],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["H",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], ".."],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[2]],
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None]}], "+", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], "."],
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["G",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`G,
         Editable->False], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None]}]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{3.8098664108215947`*^9, 3.809866861480326*^9, 
  3.809866912605727*^9, 3.8098675892707562`*^9}]
}, Open  ]],

Cell["Finally, using the background field equations...", "Text",
 CellChangeTimes->{{3.809866950896584*^9, 3.8098669584362054`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SKGquadTensor", "=", 
    RowBox[{
     RowBox[{"SKG2Tensor3", "/.", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Hh", "[", 
         RowBox[{
          RowBox[{"LI", "[", "0", "]"}], ",", 
          RowBox[{"LI", "[", "0", "]"}]}], "]"}], "2"], "\[Rule]", "Q"}]}], "/.",
      "fesVar"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SuperscriptBox[\(S\), \((2)\)]\)\>\"", "\[Equal]", 
  "SKGquadTensor"}]}], "Input",
 CellChangeTimes->{{3.809866964019082*^9, 3.8098670607194495`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SuperscriptBox[\\(S\\), \\((2)\\)]\\)\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "3"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"b", "c"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[-$CellContext`b, -$CellContext`c],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Eth[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1], -$CellContext`b, -$CellContext`c],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {"b", "c"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[$CellContext`b, $CellContext`c],
          Editable->False], "."]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Eth[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1], $CellContext`b, $CellContext`c],
      Editable->False], ")"}]}], "-", 
   RowBox[{
    InterpretationBox[
     StyleBox["\[Kappa]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Kappa],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "i"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"b", "c"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[-$CellContext`b, -$CellContext`c],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`i][
       $CellContext`Eth[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0], -$CellContext`b, -$CellContext`c]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "i"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {"b", "c"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[$CellContext`b, $CellContext`c],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`i][
       $CellContext`Eth[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0], $CellContext`b, $CellContext`c]],
      Editable->False], ")"}]}]}]}]], "Output",
 CellChangeTimes->{{3.8098669988417797`*^9, 3.8098670094099894`*^9}, {
   3.8098670538265347`*^9, 3.8098670612994337`*^9}, 3.809867589342807*^9}]
}, Open  ]],

Cell[TextData[{
 "Obviously, the tensor modes travel at the speed of light in KGB. This is \
expected since there\[CloseCurlyQuote]s no direct coupling between the scalar \
field and the curvature tensors, e.g., terms in the action like ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["S", 
       RowBox[{"(", "2", ")"}]], "~", 
      RowBox[{"f", "(", "\[Phi]", ")"}]}], "R"}], ",", 
    RowBox[{
     RowBox[{"\[Eta]", "(", 
      RowBox[{
       SubscriptBox["\[Del]", "a"], "\[Phi]"}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Del]", "b"], "\[Phi]"}], ")"}], " ", 
     SuperscriptBox["G", "ab"]}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "."
}], "Text",
 CellChangeTimes->{{3.8098670743427258`*^9, 3.8098670875509415`*^9}, {
  3.809867124702339*^9, 3.8098672307347417`*^9}, {3.8098672729445114`*^9, 
  3.809867300186248*^9}, {3.8098678359582515`*^9, 3.8098678411121297`*^9}}]
}, Closed]]
}, Open  ]]
},
WindowSize->{765, 930},
WindowMargins->{{Automatic, 1183}, {Automatic, 42}},
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (September 21, 2016)",
StyleDefinitions->"ReverseColor.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 120, 1, 70, "Section"],
Cell[703, 25, 1008, 27, 125, "Text"],
Cell[CellGroupData[{
Cell[1736, 56, 206, 3, 49, "Subsection"],
Cell[1945, 61, 111, 1, 67, "Text"],
Cell[CellGroupData[{
Cell[2081, 66, 1890, 57, 670, "Input"],
Cell[CellGroupData[{
Cell[3996, 127, 1717, 24, 91, "Print"],
Cell[5716, 153, 1986, 31, 50, "Print"],
Cell[7705, 186, 1740, 24, 91, "Print"],
Cell[9448, 212, 1699, 23, 50, "Print"],
Cell[11150, 237, 1680, 23, 50, "Print"],
Cell[12833, 262, 1719, 24, 91, "Print"],
Cell[14555, 288, 1992, 32, 50, "Print"],
Cell[16550, 322, 1738, 24, 91, "Print"],
Cell[18291, 348, 1719, 24, 91, "Print"],
Cell[20013, 374, 1986, 31, 50, "Print"],
Cell[22002, 407, 1786, 25, 131, "Print"],
Cell[23791, 434, 1961, 31, 50, "Print"],
Cell[25755, 467, 2043, 32, 50, "Print"],
Cell[27801, 501, 2146, 32, 91, "Print"],
Cell[29950, 535, 2101, 32, 50, "Print"],
Cell[32054, 569, 2122, 32, 91, "Print"],
Cell[34179, 603, 1717, 24, 91, "Print"],
Cell[35899, 629, 1986, 31, 50, "Print"],
Cell[37888, 662, 1758, 24, 91, "Print"],
Cell[39649, 688, 1717, 24, 91, "Print"],
Cell[41369, 714, 1872, 26, 171, "Print"],
Cell[43244, 742, 1719, 24, 91, "Print"],
Cell[44966, 768, 2051, 32, 50, "Print"],
Cell[47020, 802, 2059, 32, 50, "Print"],
Cell[49082, 836, 2211, 37, 50, "Print"],
Cell[51296, 875, 2311, 39, 91, "Print"],
Cell[53610, 916, 2288, 38, 50, "Print"],
Cell[55901, 956, 2304, 38, 50, "Print"],
Cell[58208, 996, 2135, 34, 50, "Print"],
Cell[60346, 1032, 2257, 38, 91, "Print"],
Cell[62606, 1072, 2275, 39, 91, "Print"],
Cell[64884, 1113, 2301, 39, 91, "Print"],
Cell[67188, 1154, 2218, 37, 50, "Print"],
Cell[69409, 1193, 1728, 24, 91, "Print"],
Cell[71140, 1219, 2100, 32, 50, "Print"],
Cell[73243, 1253, 1730, 24, 91, "Print"],
Cell[74976, 1279, 2231, 37, 91, "Print"],
Cell[77210, 1318, 2288, 38, 50, "Print"],
Cell[79501, 1358, 2229, 37, 91, "Print"],
Cell[81733, 1397, 2117, 33, 50, "Print"],
Cell[83853, 1432, 1863, 28, 50, "Print"],
Cell[85719, 1462, 1853, 28, 50, "Print"],
Cell[87575, 1492, 1865, 28, 50, "Print"],
Cell[89443, 1522, 2121, 33, 50, "Print"]
}, Open  ]]
}, Open  ]],
Cell[91591, 1559, 762, 17, 369, "Text"],
Cell[CellGroupData[{
Cell[92378, 1580, 980, 25, 319, "Input"],
Cell[CellGroupData[{
Cell[93383, 1609, 2085, 32, 50, "Print"],
Cell[95471, 1643, 2221, 37, 91, "Print"],
Cell[97695, 1682, 2257, 38, 91, "Print"],
Cell[99955, 1722, 2276, 38, 50, "Print"],
Cell[102234, 1762, 2294, 38, 50, "Print"],
Cell[104531, 1802, 2135, 34, 50, "Print"],
Cell[106669, 1838, 2247, 38, 91, "Print"],
Cell[108919, 1878, 2267, 39, 91, "Print"],
Cell[111189, 1919, 2293, 39, 91, "Print"],
Cell[113485, 1960, 2209, 37, 50, "Print"],
Cell[115697, 1999, 1718, 24, 91, "Print"],
Cell[117418, 2025, 2092, 32, 50, "Print"],
Cell[119513, 2059, 1722, 24, 91, "Print"],
Cell[121238, 2085, 2223, 37, 91, "Print"],
Cell[123464, 2124, 2299, 39, 91, "Print"],
Cell[125766, 2165, 2219, 37, 91, "Print"],
Cell[127988, 2204, 2107, 33, 50, "Print"],
Cell[130098, 2239, 1851, 28, 50, "Print"],
Cell[131952, 2269, 1845, 28, 50, "Print"],
Cell[133800, 2299, 1855, 28, 50, "Print"],
Cell[135658, 2329, 2109, 33, 50, "Print"],
Cell[137770, 2364, 2229, 36, 91, "Print"],
Cell[140002, 2402, 2176, 34, 91, "Print"],
Cell[142181, 2438, 2087, 33, 50, "Print"],
Cell[144271, 2473, 2125, 35, 91, "Print"],
Cell[146399, 2510, 2123, 35, 91, "Print"],
Cell[148525, 2547, 2034, 33, 50, "Print"],
Cell[150562, 2582, 2060, 33, 50, "Print"],
Cell[152625, 2617, 2123, 35, 91, "Print"],
Cell[154751, 2654, 2330, 37, 131, "Print"],
Cell[157084, 2693, 2111, 32, 50, "Print"],
Cell[159198, 2727, 2130, 33, 50, "Print"],
Cell[161331, 2762, 2231, 36, 50, "Print"],
Cell[163565, 2800, 2294, 37, 91, "Print"],
Cell[165862, 2839, 2294, 37, 91, "Print"],
Cell[168159, 2878, 2225, 37, 91, "Print"],
Cell[170387, 2917, 2223, 36, 91, "Print"],
Cell[172613, 2955, 2307, 39, 91, "Print"],
Cell[174923, 2996, 2282, 38, 50, "Print"],
Cell[177208, 3036, 2300, 38, 50, "Print"],
Cell[179511, 3076, 2138, 34, 50, "Print"],
Cell[181652, 3112, 2251, 38, 91, "Print"],
Cell[183906, 3152, 2271, 39, 91, "Print"],
Cell[186180, 3193, 2307, 39, 91, "Print"],
Cell[188490, 3234, 2353, 39, 131, "Print"],
Cell[190846, 3275, 2217, 37, 91, "Print"],
Cell[193066, 3314, 1716, 24, 91, "Print"],
Cell[194785, 3340, 2098, 32, 50, "Print"],
Cell[196886, 3374, 1722, 24, 91, "Print"],
Cell[198611, 3400, 2229, 37, 91, "Print"],
Cell[200843, 3439, 1705, 24, 50, "Print"],
Cell[202551, 3465, 2282, 38, 50, "Print"],
Cell[204836, 3505, 2223, 37, 91, "Print"],
Cell[207062, 3544, 2110, 33, 50, "Print"],
Cell[209175, 3579, 1853, 28, 50, "Print"],
Cell[211031, 3609, 1854, 28, 50, "Print"],
Cell[212888, 3639, 2115, 33, 91, "Print"],
Cell[215006, 3674, 2123, 35, 91, "Print"],
Cell[217132, 3711, 2002, 31, 50, "Print"],
Cell[219137, 3744, 2258, 37, 91, "Print"],
Cell[221398, 3783, 2242, 37, 50, "Print"],
Cell[223643, 3822, 2182, 35, 50, "Print"],
Cell[225828, 3859, 2110, 33, 50, "Print"],
Cell[227941, 3894, 2064, 33, 50, "Print"],
Cell[230008, 3929, 2421, 41, 91, "Print"],
Cell[232432, 3972, 2065, 33, 50, "Print"],
Cell[234500, 4007, 2245, 37, 50, "Print"],
Cell[236748, 4046, 2306, 37, 91, "Print"],
Cell[239057, 4085, 2296, 37, 131, "Print"],
Cell[241356, 4124, 2346, 38, 131, "Print"],
Cell[243705, 4164, 2306, 37, 91, "Print"],
Cell[246014, 4203, 2296, 37, 131, "Print"],
Cell[248313, 4242, 2344, 38, 131, "Print"],
Cell[250660, 4282, 2397, 40, 131, "Print"],
Cell[253060, 4324, 2296, 37, 91, "Print"],
Cell[255359, 4363, 2298, 37, 131, "Print"],
Cell[257660, 4402, 2346, 38, 131, "Print"],
Cell[260009, 4442, 2312, 37, 91, "Print"],
Cell[262324, 4481, 2306, 37, 91, "Print"],
Cell[264633, 4520, 2294, 37, 91, "Print"],
Cell[266930, 4559, 2354, 38, 131, "Print"],
Cell[269287, 4599, 2298, 37, 131, "Print"],
Cell[271588, 4638, 2298, 37, 131, "Print"],
Cell[273889, 4677, 2348, 38, 131, "Print"],
Cell[276240, 4717, 2073, 32, 50, "Print"],
Cell[278316, 4751, 2177, 35, 50, "Print"]
}, Open  ]]
}, Open  ]],
Cell[280520, 4790, 199, 2, 67, "Text"],
Cell[280722, 4794, 1747, 44, 612, "Input"],
Cell[282472, 4840, 277, 6, 110, "Text"],
Cell[282752, 4848, 392, 9, 139, "Input"],
Cell[283147, 4859, 118, 1, 67, "Text"],
Cell[283268, 4862, 16940, 426, 5473, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[300245, 5293, 170, 2, 41, "Subsection"],
Cell[300418, 5297, 118, 1, 67, "Text"],
Cell[CellGroupData[{
Cell[300561, 5302, 1970, 58, 479, "Input"],
Cell[CellGroupData[{
Cell[302556, 5364, 1679, 26, 50, "Print"],
Cell[304238, 5392, 1679, 26, 50, "Print"],
Cell[305920, 5420, 1697, 27, 50, "Print"],
Cell[307620, 5449, 1676, 26, 50, "Print"]
}, Open  ]],
Cell[309311, 5478, 4105, 116, 118, "Output"]
}, Open  ]],
Cell[313431, 5597, 154, 2, 67, "Text"],
Cell[CellGroupData[{
Cell[313610, 5603, 1195, 33, 268, "Input"],
Cell[314808, 5638, 6377, 175, 163, "Output"],
Cell[321188, 5815, 18357, 568, 463, "Output"]
}, Open  ]],
Cell[339560, 6386, 122, 1, 67, "Text"],
Cell[CellGroupData[{
Cell[339707, 6391, 1104, 33, 265, "Input"],
Cell[340814, 6426, 952, 18, 50, "Print"],
Cell[341769, 6446, 28876, 834, 615, "Output"]
}, Open  ]],
Cell[370660, 7283, 124, 1, 67, "Text"],
Cell[CellGroupData[{
Cell[370809, 7288, 586, 16, 225, "Input"],
Cell[371398, 7306, 33056, 1063, 877, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[404503, 8375, 235, 3, 41, "Subsection"],
Cell[404741, 8380, 341, 6, 110, "Text"],
Cell[CellGroupData[{
Cell[405107, 8390, 173, 2, 87, "Subsubsection"],
Cell[405283, 8394, 167, 5, 68, "Text"],
Cell[CellGroupData[{
Cell[405475, 8403, 573, 14, 182, "Input"],
Cell[CellGroupData[{
Cell[406073, 8421, 1819, 31, 50, "Print"],
Cell[407895, 8454, 3774, 92, 98, "Print"]
}, Open  ]],
Cell[411684, 8549, 23735, 624, 551, "Output"]
}, Open  ]],
Cell[435434, 9176, 767, 18, 238, "Text"],
Cell[CellGroupData[{
Cell[436226, 9198, 1190, 27, 311, "Input"],
Cell[437419, 9227, 3848, 92, 98, "Print"],
Cell[441270, 9321, 9304, 256, 259, "Output"],
Cell[450577, 9579, 1366, 21, 53, "Message"],
Cell[451946, 9602, 1366, 21, 53, "Message"],
Cell[453315, 9625, 2106, 42, 50, "Print"],
Cell[455424, 9669, 1707, 34, 95, "Output"]
}, Open  ]],
Cell[457146, 9706, 254, 5, 153, "Text"],
Cell[457403, 9713, 1918, 54, 527, "Input"],
Cell[459324, 9769, 157, 2, 67, "Text"],
Cell[CellGroupData[{
Cell[459506, 9775, 647, 17, 225, "Input"],
Cell[460156, 9794, 4018, 105, 98, "Print"],
Cell[464177, 9901, 23640, 668, 487, "Output"]
}, Open  ]],
Cell[487832, 10572, 190, 4, 110, "Text"],
Cell[488025, 10578, 1123, 30, 139, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[489185, 10613, 161, 2, 68, "Subsubsection"],
Cell[489349, 10617, 154, 3, 67, "Text"],
Cell[489506, 10622, 3920, 116, 741, "Input"],
Cell[493429, 10740, 328, 4, 67, "Text"],
Cell[CellGroupData[{
Cell[493782, 10748, 1063, 29, 311, "Input"],
Cell[CellGroupData[{
Cell[494870, 10781, 2620, 59, 57, "Print"],
Cell[497493, 10842, 3884, 105, 116, "Print"]
}, Open  ]]
}, Open  ]],
Cell[501404, 10951, 210, 4, 110, "Text"],
Cell[CellGroupData[{
Cell[501639, 10959, 1480, 41, 526, "Input"],
Cell[503122, 11002, 5005, 167, 121, "Output"],
Cell[508130, 11171, 7438, 258, 187, "Output"]
}, Open  ]],
Cell[515583, 11432, 265, 10, 73, "Text"],
Cell[CellGroupData[{
Cell[515873, 11446, 1159, 32, 238, "Input"],
Cell[517035, 11480, 10918, 350, 210, "Output"]
}, Open  ]],
Cell[527968, 11833, 439, 9, 238, "Text"],
Cell[CellGroupData[{
Cell[528432, 11846, 2320, 62, 755, "Input"],
Cell[530755, 11910, 15455, 493, 414, "Output"],
Cell[546213, 12405, 8132, 246, 203, "Output"]
}, Open  ]],
Cell[554360, 12654, 919, 17, 282, "Text"],
Cell[CellGroupData[{
Cell[555304, 12675, 1989, 59, 526, "Input"],
Cell[557296, 12736, 987, 19, 91, "Print"],
Cell[558286, 12757, 7453, 238, 203, "Output"],
Cell[565742, 12997, 341, 5, 95, "Output"]
}, Open  ]],
Cell[566098, 13005, 346, 11, 111, "Text"],
Cell[CellGroupData[{
Cell[566469, 13020, 3355, 90, 664, "Input"],
Cell[569827, 13112, 1269, 23, 91, "Print"],
Cell[571099, 13137, 9551, 308, 206, "Output"]
}, Open  ]],
Cell[580665, 13448, 157, 3, 67, "Text"],
Cell[CellGroupData[{
Cell[580847, 13455, 1520, 36, 268, "Input"],
Cell[582370, 13493, 24514, 802, 543, "Output"]
}, Open  ]],
Cell[606899, 14298, 179, 6, 68, "Text"],
Cell[CellGroupData[{
Cell[607103, 14308, 1389, 34, 325, "Input"],
Cell[608495, 14344, 23853, 799, 412, "Output"]
}, Open  ]],
Cell[632363, 15146, 294, 8, 68, "Text"],
Cell[CellGroupData[{
Cell[632682, 15158, 1244, 30, 268, "Input"],
Cell[633929, 15190, 47080, 1488, 1063, "Output"]
}, Open  ]],
Cell[681024, 16681, 1009, 26, 239, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[682070, 16712, 116, 1, 68, "Subsubsection"],
Cell[682189, 16715, 257, 5, 1181, "Text"],
Cell[CellGroupData[{
Cell[682471, 16724, 491, 13, 1498, "Input"],
Cell[682965, 16739, 10359, 292, 70, "Print"]
}, Open  ]],
Cell[693339, 17034, 170, 2, 717, "Text"],
Cell[CellGroupData[{
Cell[693534, 17040, 354, 9, 1498, "Input"],
Cell[693891, 17051, 14914, 558, 70, "Output"]
}, Open  ]],
Cell[708820, 17612, 106, 1, 717, "Text"],
Cell[CellGroupData[{
Cell[708951, 17617, 957, 25, 2542, "Input"],
Cell[709911, 17644, 54328, 1769, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[764288, 19419, 237, 7, 68, "Subsubsection"],
Cell[764528, 19428, 248, 5, 110, "Text"],
Cell[764779, 19435, 14354, 436, 697, "Input"],
Cell[779136, 19873, 334, 8, 111, "Text"],
Cell[CellGroupData[{
Cell[779495, 19885, 260, 5, 95, "Input"],
Cell[779758, 19892, 2034, 60, 118, "Output"]
}, Open  ]],
Cell[781807, 19955, 348, 6, 153, "Text"],
Cell[CellGroupData[{
Cell[782180, 19965, 1619, 48, 485, "Input"],
Cell[783802, 20015, 3559, 110, 150, "Print"],
Cell[787364, 20127, 17142, 594, 359, "Output"]
}, Open  ]],
Cell[804521, 20724, 224, 4, 110, "Text"],
Cell[CellGroupData[{
Cell[804770, 20732, 2792, 77, 447, "Input"],
Cell[807565, 20811, 10661, 362, 281, "Output"]
}, Open  ]],
Cell[818241, 21176, 464, 12, 153, "Text"],
Cell[CellGroupData[{
Cell[818730, 21192, 1855, 57, 496, "Input"],
Cell[820588, 21251, 3272, 108, 126, "Output"]
}, Open  ]],
Cell[823875, 21362, 336, 8, 196, "Text"],
Cell[CellGroupData[{
Cell[824236, 21374, 913, 19, 182, "Input"],
Cell[825152, 21395, 90498, 3146, 1613, "Output"]
}, Open  ]],
Cell[915665, 24544, 400, 7, 153, "Text"],
Cell[CellGroupData[{
Cell[916090, 24555, 2088, 54, 397, "Input"],
Cell[918181, 24611, 64367, 2241, 1145, "Output"]
}, Open  ]],
Cell[982563, 26855, 4554, 138, 224, "Text"],
Cell[CellGroupData[{
Cell[987142, 26997, 6099, 178, 448, "Input"],
Cell[993244, 27177, 698, 12, 125, "Output"]
}, Open  ]],
Cell[993957, 27192, 89, 1, 67, "Text"],
Cell[994049, 27195, 1542, 46, 268, "Input"],
Cell[995594, 27243, 348, 6, 110, "Text"],
Cell[995945, 27251, 9779, 284, 2015, "Input"],
Cell[1005727, 27537, 328, 8, 111, "Text"],
Cell[CellGroupData[{
Cell[1006080, 27549, 3338, 74, 526, "Input"],
Cell[1009421, 27625, 26599, 902, 596, "Output"]
}, Open  ]],
Cell[1036035, 28530, 2484, 74, 201, "Text"],
Cell[CellGroupData[{
Cell[1038544, 28608, 661, 18, 225, "Input"],
Cell[1039208, 28628, 15610, 536, 361, "Output"]
}, Open  ]],
Cell[1054833, 29167, 314, 8, 111, "Text"],
Cell[CellGroupData[{
Cell[1055172, 29179, 1505, 42, 397, "Input"],
Cell[1056680, 29223, 15424, 519, 361, "Output"]
}, Open  ]],
Cell[1072119, 29745, 247, 7, 68, "Text"],
Cell[CellGroupData[{
Cell[1072391, 29756, 610, 17, 225, "Input"],
Cell[1073004, 29775, 3646, 122, 125, "Output"]
}, Open  ]],
Cell[1076665, 29900, 182, 4, 110, "Text"],
Cell[CellGroupData[{
Cell[1076872, 29908, 401, 11, 139, "Input"],
Cell[1077276, 29921, 3212, 110, 125, "Output"]
}, Open  ]],
Cell[1080503, 30034, 268, 8, 67, "Text"],
Cell[CellGroupData[{
Cell[1080796, 30046, 799, 21, 268, "Input"],
Cell[1081598, 30069, 9307, 309, 286, "Output"]
}, Open  ]],
Cell[1090920, 30381, 169, 3, 110, "Text"],
Cell[CellGroupData[{
Cell[1091114, 30388, 3384, 93, 946, "Input"],
Cell[1094501, 30483, 7058, 233, 215, "Output"]
}, Open  ]],
Cell[1101574, 30719, 189, 4, 110, "Text"],
Cell[CellGroupData[{
Cell[1101788, 30727, 3501, 107, 382, "Input"],
Cell[1105292, 30836, 1360, 47, 95, "Output"],
Cell[1106655, 30885, 572, 17, 95, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[1107288, 30909, 385, 10, 41, "Subsection"],
Cell[1107676, 30921, 420, 9, 106, "Text"],
Cell[CellGroupData[{
Cell[1108121, 30934, 1185, 36, 127, "Input"],
Cell[1109309, 30972, 3435, 108, 66, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1112781, 31085, 113, 1, 38, "Subsubsection"],
Cell[1112897, 31088, 406, 11, 747, "Text"],
Cell[CellGroupData[{
Cell[1113328, 31103, 422, 12, 895, "Input"],
Cell[1113753, 31117, 25056, 860, 70, "Output"]
}, Open  ]],
Cell[1138824, 31980, 271, 7, 326, "Text"],
Cell[CellGroupData[{
Cell[1139120, 31991, 2539, 73, 2207, "Input"],
Cell[1141662, 32066, 15115, 515, 70, "Output"]
}, Open  ]],
Cell[1156792, 32584, 504, 12, 940, "Text"],
Cell[CellGroupData[{
Cell[1157321, 32600, 1807, 56, 2450, "Input"],
Cell[1159131, 32658, 8927, 296, 70, "Output"]
}, Open  ]],
Cell[1168073, 32957, 127, 1, 321, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[1168237, 32963, 109, 1, 30, "Subsubsection"],
Cell[1168349, 32966, 142, 1, 30, "Text"],
Cell[1168494, 32969, 287, 8, 30, "Input"],
Cell[1168784, 32979, 383, 9, 68, "Text"],
Cell[CellGroupData[{
Cell[1169192, 32992, 563, 16, 107, "Input"],
Cell[1169758, 33010, 68391, 2261, 508, "Output"]
}, Open  ]],
Cell[1238164, 35274, 145, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[1238334, 35279, 22774, 654, 427, "Input"],
Cell[1261111, 35935, 55190, 1879, 439, "Output"]
}, Open  ]],
Cell[1316316, 37817, 634, 15, 125, "Text"],
Cell[CellGroupData[{
Cell[1316975, 37836, 1001, 27, 145, "Input"],
Cell[1317979, 37865, 51522, 1755, 392, "Output"]
}, Open  ]],
Cell[1369516, 39623, 5407, 180, 111, "Text"],
Cell[CellGroupData[{
Cell[1374948, 39807, 20047, 571, 335, "Input"],
Cell[1394998, 40380, 14700, 474, 137, "Output"],
Cell[1409701, 40856, 11018, 363, 78, "Output"]
}, Open  ]],
Cell[1420734, 41222, 162, 3, 49, "Text"],
Cell[CellGroupData[{
Cell[1420921, 41229, 1067, 27, 124, "Input"],
Cell[1421991, 41258, 39092, 1326, 737, "Output"]
}, Open  ]],
Cell[1461098, 42587, 553, 15, 155, "Text"],
Cell[CellGroupData[{
Cell[1461676, 42606, 712, 19, 225, "Input"],
Cell[1462391, 42627, 27842, 929, 617, "Output"]
}, Open  ]],
Cell[1490248, 43559, 248, 7, 68, "Text"],
Cell[CellGroupData[{
Cell[1490521, 43570, 1511, 42, 397, "Input"],
Cell[1492035, 43614, 27676, 911, 539, "Output"]
}, Open  ]],
Cell[1519726, 44528, 571, 18, 112, "Text"],
Cell[CellGroupData[{
Cell[1520322, 44550, 689, 20, 268, "Input"],
Cell[1521014, 44572, 5637, 193, 203, "Output"]
}, Open  ]],
Cell[1526666, 44768, 181, 2, 67, "Text"],
Cell[CellGroupData[{
Cell[1526872, 44774, 500, 14, 225, "Input"],
Cell[1527375, 44790, 4985, 175, 125, "Output"]
}, Open  ]],
Cell[1532375, 44968, 263, 7, 110, "Text"],
Cell[CellGroupData[{
Cell[1532663, 44979, 1202, 31, 126, "Input"],
Cell[1533868, 45012, 23189, 763, 224, "Output"]
}, Open  ]],
Cell[1557072, 45778, 5560, 182, 92, "Text"],
Cell[CellGroupData[{
Cell[1562657, 45964, 17130, 482, 424, "Input"],
Cell[1579790, 46448, 9304, 305, 79, "Output"],
Cell[1589097, 46755, 18442, 594, 188, "Output"]
}, Open  ]],
Cell[1607554, 47352, 188, 4, 110, "Text"],
Cell[CellGroupData[{
Cell[1607767, 47360, 2316, 59, 504, "Input"],
Cell[1610086, 47421, 21626, 685, 505, "Output"]
}, Open  ]],
Cell[1631727, 48109, 121, 1, 67, "Text"],
Cell[CellGroupData[{
Cell[1631873, 48114, 5028, 154, 398, "Input"],
Cell[1636904, 48270, 853, 17, 58, "Print"],
Cell[1637760, 48289, 17636, 575, 154, "Output"]
}, Open  ]],
Cell[1655411, 48867, 513, 11, 106, "Text"],
Cell[CellGroupData[{
Cell[1655949, 48882, 4102, 120, 259, "Input"],
Cell[1660054, 49004, 5805, 214, 67, "Output"],
Cell[1665862, 49220, 5831, 215, 68, "Output"]
}, Open  ]],
Cell[1671708, 49438, 804, 23, 73, "Text"],
Cell[CellGroupData[{
Cell[1672537, 49465, 4150, 117, 233, "Input"],
Cell[CellGroupData[{
Cell[1676712, 49586, 654, 12, 22, "Print"],
Cell[1677369, 49600, 887, 17, 58, "Print"]
}, Open  ]],
Cell[1678271, 49620, 5664, 214, 73, "Output"],
Cell[1683938, 49836, 6027, 229, 73, "Output"]
}, Open  ]],
Cell[1689980, 50068, 399, 8, 88, "Text"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1690428, 50082, 462, 14, 41, "Subsection"],
Cell[1690893, 50098, 590, 11, 367, "Text"],
Cell[CellGroupData[{
Cell[1691508, 50113, 1341, 37, 354, "Input"],
Cell[1692852, 50152, 2630, 75, 98, "Print"],
Cell[1695485, 50229, 4574, 124, 223, "Output"],
Cell[1700062, 50355, 322, 7, 53, "Message"],
Cell[1700387, 50364, 324, 7, 53, "Message"],
Cell[1700714, 50373, 890, 25, 50, "Print"],
Cell[1701607, 50400, 507, 17, 95, "Output"]
}, Open  ]],
Cell[1702129, 50420, 187, 2, 67, "Text"],
Cell[CellGroupData[{
Cell[1702341, 50426, 2202, 59, 621, "Input"],
Cell[1704546, 50487, 3366, 107, 150, "Print"],
Cell[1707915, 50596, 263, 6, 100, "Output"],
Cell[1708181, 50604, 50272, 1457, 515, "Output"]
}, Open  ]],
Cell[1758468, 52064, 483, 9, 324, "Text"],
Cell[CellGroupData[{
Cell[1758976, 52077, 17550, 439, 638, "Input"],
Cell[1776529, 52518, 24357, 717, 281, "Output"]
}, Open  ]],
Cell[1800901, 53238, 4013, 109, 207, "Text"],
Cell[CellGroupData[{
Cell[1804939, 53351, 15884, 443, 825, "Input"],
Cell[1820826, 53796, 8301, 238, 203, "Output"]
}, Open  ]],
Cell[1829142, 54037, 126, 1, 67, "Text"],
Cell[CellGroupData[{
Cell[1829293, 54042, 14029, 380, 321, "Input"],
Cell[1843325, 54424, 19895, 597, 266, "Output"]
}, Open  ]],
Cell[1863235, 55024, 168, 2, 67, "Text"],
Cell[CellGroupData[{
Cell[1863428, 55030, 2704, 67, 565, "Input"],
Cell[1866135, 55099, 15614, 463, 203, "Output"]
}, Open  ]],
Cell[1881764, 55565, 132, 1, 67, "Text"],
Cell[CellGroupData[{
Cell[1881921, 55570, 578, 15, 225, "Input"],
Cell[1882502, 55587, 8205, 231, 125, "Output"]
}, Open  ]],
Cell[1890722, 55821, 962, 25, 199, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)

