(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   1761618,      36991]
NotebookOptionsPosition[   1735089,      36218]
NotebookOutlinePosition[   1735442,      36233]
CellTagsIndexPosition[   1735399,      36230]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Self-tuning kinetic gravity braiding: Cosmological dynamics, shift symmetry, \
and the tadpole\
\>", "Section",
 CellChangeTimes->{{3.798082327605251*^9, 3.798082337449258*^9}, {
  3.8187619711393805`*^9, 3.8187619842038884`*^9}}],

Cell[TextData[{
 "This notebook serves as a supplement to the paper \
\[OpenCurlyDoubleQuote]Self-tuning kinetic gravity braiding\
\[CloseCurlyDoubleQuote] (",
 ButtonBox["arXiv:2101.00965",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://arxiv.org/abs/2101.00965"], None},
  ButtonNote->"https://arxiv.org/abs/2101.00965"],
 ") and presents all of the calculations down to the last detail.\n\nAuthor: \
Reginald Christian Bernardo"
}], "Text",
 CellChangeTimes->{{3.798082339665019*^9, 3.7980823928721313`*^9}, {
   3.8187619977379503`*^9, 3.818762012851894*^9}, 3.818804478423292*^9, {
   3.8188045090448446`*^9, 3.8188045090513277`*^9}}],

Cell[BoxData[
 RowBox[{"Quit", "[", "]"}]], "Input",
 CellChangeTimes->{{3.7977738597501464`*^9, 3.797773860404518*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Section 2. Field equations of KGB",
 FontColor->RGBColor[1, 0.5, 0.5]]], "Subsection",
 CellChangeTimes->{{3.7980824491511693`*^9, 3.798082487925877*^9}}],

Cell[TextData[{
 "For ",
 Cell[BoxData[
  FormBox[
   RowBox[{"c", "=", "1"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox[
     SubscriptBox["M", "P"], "2"], "=", "1"}], TraditionalForm]]],
 ", the field equations of KGB are given by (see ",
 StyleBox["kgb_cosmology.nb",
  FontSlant->"Italic"],
 " for a derivation using xAct and xCoba)..."
}], "Text",
 CellChangeTimes->{{3.7980827129711723`*^9, 3.798082746127043*^9}, {
  3.8187626950567217`*^9, 3.8187626965938005`*^9}, {3.8187628404395275`*^9, 
  3.8187628580969677`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Get", "[", "\"\<friedmann_kgb.m\>\"", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FE1", "=", 
   RowBox[{"FE1H", "/.", 
    RowBox[{"\[Phi]0", "\[Rule]", 
     RowBox[{"Function", "[", 
      RowBox[{"t", ",", 
       RowBox[{"\[Phi]", "[", "t", "]"}]}], "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FE2", "=", 
   RowBox[{"FE2H", "/.", 
    RowBox[{"\[Phi]0", "\[Rule]", 
     RowBox[{"Function", "[", 
      RowBox[{"t", ",", 
       RowBox[{"\[Phi]", "[", "t", "]"}]}], "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SFE", "=", 
    RowBox[{"SFEH", "/.", 
     RowBox[{"\[Phi]0", "\[Rule]", 
      RowBox[{"Function", "[", 
       RowBox[{"t", ",", 
        RowBox[{"\[Phi]", "[", "t", "]"}]}], "]"}]}]}]}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Friedmann", " ", "constraint"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Feq", "=", "FE1"}], ";", "Feq"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Hubble", " ", "equation"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Heq", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Rho]", "[", "t", "]"}], "+", 
          RowBox[{"P", "[", "t", "]"}]}], "/.", 
         RowBox[{
          RowBox[{"Solve", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"FE1", ",", "FE2"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"\[Rho]", "[", "t", "]"}], ",", 
              RowBox[{"P", "[", "t", "]"}]}], "}"}]}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ")"}]}], "+", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Rho]", "[", "t", "]"}], "+", 
        RowBox[{"P", "[", "t", "]"}]}], ")"}]}], "\[Equal]", "0"}]}], ";", 
   "Heq"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Scalar", " ", "field", " ", "equation"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Seq", "=", "SFE"}], ";", "Seq"}]}], "Input",
 CellChangeTimes->{{3.798082781853357*^9, 3.798082819917704*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Rho]", "[", "t", "]"}], "+", 
   RowBox[{
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["G", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"\[Phi]", "[", "t", "]"}], ",", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], 
      "+", 
      RowBox[{
       SuperscriptBox["K", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"\[Phi]", "[", "t", "]"}], ",", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Phi]", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], 
     ")"}]}]}], "\[Equal]", 
  RowBox[{
   RowBox[{"3", " ", 
    SuperscriptBox[
     RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
   RowBox[{"K", "[", 
    RowBox[{
     RowBox[{"\[Phi]", "[", "t", "]"}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}], "+", 
   RowBox[{
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox["G", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{"\[Phi]", "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], 
     "]"}]}]}]}]], "Output",
 CellChangeTimes->{
  3.798082822093648*^9, 3.798281947770321*^9, 3.7984285329319797`*^9, 
   3.7984576032136707`*^9, 3.7984601938601804`*^9, 3.798563040297413*^9, 
   3.7985633601256*^9, 3.7985636412618704`*^9, 3.7985639142708035`*^9, 
   3.798564074978855*^9, 3.798573126178254*^9, 3.7985795356038275`*^9, 
   3.798607077190304*^9, 3.7986959971409445`*^9, 3.7986975830188036`*^9, 
   3.7987000263310575`*^9, 3.7987142429520807`*^9, 3.798714290242756*^9, 
   3.798714323657859*^9, 3.7987144371612844`*^9, 3.798718544650573*^9, 
   3.798938900775635*^9, 3.7992325761400824`*^9, 3.79923293826549*^9, 
   3.7992357907779074`*^9, 3.799238229369277*^9, 3.7992387423327355`*^9, {
   3.800267606522028*^9, 3.8002676242651086`*^9}, 3.800334255799772*^9, 
   3.8003348342921133`*^9, 3.801015944040773*^9, 3.801016250314133*^9, 
   3.80102404713793*^9, 3.8010244652788115`*^9, {3.8010246390927896`*^9, 
   3.8010246630006847`*^9}, 3.8010250028235874`*^9, 3.8010335853605585`*^9, 
   3.8147839094680915`*^9, 3.818762685556262*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"P", "[", "t", "]"}], "+", 
   RowBox[{"\[Rho]", "[", "t", "]"}], "+", 
   RowBox[{"2", " ", 
    RowBox[{
     SuperscriptBox["H", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}], "+", 
   RowBox[{"3", " ", 
    RowBox[{"H", "[", "t", "]"}], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
    RowBox[{
     SuperscriptBox["G", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{"\[Phi]", "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], "-", 
   RowBox[{
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{
     SuperscriptBox["G", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{"\[Phi]", "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox["K", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{"\[Phi]", "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox["G", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{"\[Phi]", "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}]}], 
  "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{
  3.798082822093648*^9, 3.798281947770321*^9, 3.7984285329319797`*^9, 
   3.7984576032136707`*^9, 3.7984601938601804`*^9, 3.798563040297413*^9, 
   3.7985633601256*^9, 3.7985636412618704`*^9, 3.7985639142708035`*^9, 
   3.798564074978855*^9, 3.798573126178254*^9, 3.7985795356038275`*^9, 
   3.798607077190304*^9, 3.7986959971409445`*^9, 3.7986975830188036`*^9, 
   3.7987000263310575`*^9, 3.7987142429520807`*^9, 3.798714290242756*^9, 
   3.798714323657859*^9, 3.7987144371612844`*^9, 3.798718544650573*^9, 
   3.798938900775635*^9, 3.7992325761400824`*^9, 3.79923293826549*^9, 
   3.7992357907779074`*^9, 3.799238229369277*^9, 3.7992387423327355`*^9, {
   3.800267606522028*^9, 3.8002676242651086`*^9}, 3.800334255799772*^9, 
   3.8003348342921133`*^9, 3.801015944040773*^9, 3.801016250314133*^9, 
   3.80102404713793*^9, 3.8010244652788115`*^9, {3.8010246390927896`*^9, 
   3.8010246630006847`*^9}, 3.8010250028235874`*^9, 3.8010335853605585`*^9, 
   3.8147839094680915`*^9, 3.818762685580222*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox["K", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{
     RowBox[{"\[Phi]", "[", "t", "]"}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox["G", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"\[Phi]", "[", "t", "]"}], ",", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], 
      "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["G", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"\[Phi]", "[", "t", "]"}], ",", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}]}], 
     ")"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox["G", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{"\[Phi]", "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}]}], 
  "\[Equal]", 
  RowBox[{
   RowBox[{"9", " ", 
    SuperscriptBox[
     RowBox[{"H", "[", "t", "]"}], "2"], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox["G", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{"\[Phi]", "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], "+", 
   RowBox[{"3", " ", 
    RowBox[{
     SuperscriptBox["H", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox["G", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{"\[Phi]", "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{
     SuperscriptBox["K", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{"\[Phi]", "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{
     SuperscriptBox["K", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{"\[Phi]", "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], "+", 
   RowBox[{"3", " ", 
    RowBox[{"H", "[", "t", "]"}], " ", 
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["K", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"\[Phi]", "[", "t", "]"}], ",", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Phi]", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{
           SuperscriptBox["G", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            RowBox[{"\[Phi]", "[", "t", "]"}], ",", 
            RowBox[{
             FractionBox["1", "2"], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["\[Phi]", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], 
         "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox["G", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{
            RowBox[{"\[Phi]", "[", "t", "]"}], ",", 
            RowBox[{
             FractionBox["1", "2"], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["\[Phi]", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "2"]}]}], 
           "]"}]}]}], ")"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox["G", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"\[Phi]", "[", "t", "]"}], ",", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}], 
      "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["G", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         RowBox[{"\[Phi]", "[", "t", "]"}], ",", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}]}], "]"}]}]}], 
     ")"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox["K", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{
      RowBox[{"\[Phi]", "[", "t", "]"}], ",", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], 
     "]"}]}]}]}]], "Output",
 CellChangeTimes->{
  3.798082822093648*^9, 3.798281947770321*^9, 3.7984285329319797`*^9, 
   3.7984576032136707`*^9, 3.7984601938601804`*^9, 3.798563040297413*^9, 
   3.7985633601256*^9, 3.7985636412618704`*^9, 3.7985639142708035`*^9, 
   3.798564074978855*^9, 3.798573126178254*^9, 3.7985795356038275`*^9, 
   3.798607077190304*^9, 3.7986959971409445`*^9, 3.7986975830188036`*^9, 
   3.7987000263310575`*^9, 3.7987142429520807`*^9, 3.798714290242756*^9, 
   3.798714323657859*^9, 3.7987144371612844`*^9, 3.798718544650573*^9, 
   3.798938900775635*^9, 3.7992325761400824`*^9, 3.79923293826549*^9, 
   3.7992357907779074`*^9, 3.799238229369277*^9, 3.7992387423327355`*^9, {
   3.800267606522028*^9, 3.8002676242651086`*^9}, 3.800334255799772*^9, 
   3.8003348342921133`*^9, 3.801015944040773*^9, 3.801016250314133*^9, 
   3.80102404713793*^9, 3.8010244652788115`*^9, {3.8010246390927896`*^9, 
   3.8010246630006847`*^9}, 3.8010250028235874`*^9, 3.8010335853605585`*^9, 
   3.8147839094680915`*^9, 3.8187626855953217`*^9}]
}, Open  ]],

Cell["\<\
To approach the tadpole-driven shift symmetric KGB, we use the rule...\
\>", "Text",
 CellChangeTimes->{{3.7980828597276196`*^9, 3.798082874215072*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tadpole", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"K", "\[Rule]", 
      RowBox[{"Function", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"a", ",", "b"}], "}"}], ",", 
        RowBox[{
         RowBox[{"a", " ", "l"}], "+", 
         RowBox[{"A", "[", "b", "]"}]}]}], "]"}]}], ",", 
     RowBox[{"G", "\[Rule]", 
      RowBox[{"Function", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"a", ",", "b"}], "}"}], ",", 
        RowBox[{"B", "[", "b", "]"}]}], "]"}]}]}], "}"}]}], ";"}]], "Input"],

Cell["...in which case the field equations become...", "Text",
 CellChangeTimes->{{3.798082903886747*^9, 3.7980829155373125`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"FeqTP", "=", 
   RowBox[{"Feq", "/.", "tadpole"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"HeqTP", "=", 
   RowBox[{"Heq", "/.", "tadpole"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SeqTP", "=", 
    RowBox[{"Seq", "/.", "tadpole"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "FeqTP", "\
\[IndentingNewLine]", "HeqTP", "\[IndentingNewLine]", "SeqTP"}], "Input",
 CellChangeTimes->{{3.798082938744261*^9, 3.798082988867464*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Rho]", "[", "t", "]"}], "+", 
   RowBox[{
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["A", "\[Prime]",
        MultilineFunction->None], "[", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Phi]", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["B", "\[Prime]",
         MultilineFunction->None], "[", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Phi]", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], "\[Equal]", 
  RowBox[{
   RowBox[{"A", "[", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], "+", 
   RowBox[{"3", " ", 
    SuperscriptBox[
     RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
   RowBox[{"l", " ", 
    RowBox[{"\[Phi]", "[", "t", "]"}]}]}]}]], "Output",
 CellChangeTimes->{
  3.798082989308025*^9, 3.798281947880031*^9, 3.7984285330821095`*^9, 
   3.798457603329554*^9, 3.7984601940237474`*^9, 3.7985630404669566`*^9, 
   3.798563360241021*^9, 3.7985636413724337`*^9, 3.7985639143848047`*^9, 
   3.7985640751131787`*^9, 3.7985731263134766`*^9, 3.7985795357509923`*^9, 
   3.7986070774257956`*^9, 3.798695997327216*^9, 3.7986975831200066`*^9, 
   3.798700026438365*^9, 3.7987142431284847`*^9, 3.798714290345949*^9, 
   3.798714323765938*^9, 3.7987144372642136`*^9, 3.798718544864569*^9, 
   3.7989389009318504`*^9, 3.799232576241282*^9, 3.79923293837329*^9, 
   3.7992357909428124`*^9, 3.7992382294876423`*^9, 3.7992387424484816`*^9, {
   3.8002676066455493`*^9, 3.8002676244054804`*^9}, 3.8003342559061737`*^9, 
   3.8003348345122037`*^9, 3.801015944181364*^9, 3.801016250423487*^9, 
   3.8010240472539062`*^9, 3.801024465394326*^9, {3.8010246392066507`*^9, 
   3.801024663118174*^9}, 3.801025002982321*^9, 3.801033585501898*^9, 
   3.8147839095837812`*^9, 3.8187628774587846`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"P", "[", "t", "]"}], "+", 
   RowBox[{"\[Rho]", "[", "t", "]"}], "+", 
   RowBox[{"2", " ", 
    RowBox[{
     SuperscriptBox["H", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox["A", "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
   RowBox[{"3", " ", 
    RowBox[{"H", "[", "t", "]"}], " ", 
    RowBox[{
     SuperscriptBox["B", "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
   RowBox[{
    RowBox[{
     SuperscriptBox["B", "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{
  3.798082989308025*^9, 3.798281947880031*^9, 3.7984285330821095`*^9, 
   3.798457603329554*^9, 3.7984601940237474`*^9, 3.7985630404669566`*^9, 
   3.798563360241021*^9, 3.7985636413724337`*^9, 3.7985639143848047`*^9, 
   3.7985640751131787`*^9, 3.7985731263134766`*^9, 3.7985795357509923`*^9, 
   3.7986070774257956`*^9, 3.798695997327216*^9, 3.7986975831200066`*^9, 
   3.798700026438365*^9, 3.7987142431284847`*^9, 3.798714290345949*^9, 
   3.798714323765938*^9, 3.7987144372642136`*^9, 3.798718544864569*^9, 
   3.7989389009318504`*^9, 3.799232576241282*^9, 3.79923293837329*^9, 
   3.7992357909428124`*^9, 3.7992382294876423`*^9, 3.7992387424484816`*^9, {
   3.8002676066455493`*^9, 3.8002676244054804`*^9}, 3.8003342559061737`*^9, 
   3.8003348345122037`*^9, 3.801015944181364*^9, 3.801016250423487*^9, 
   3.8010240472539062`*^9, 3.801024465394326*^9, {3.8010246392066507`*^9, 
   3.801024663118174*^9}, 3.801025002982321*^9, 3.801033585501898*^9, 
   3.8147839095837812`*^9, 3.81876287746931*^9}],

Cell[BoxData[
 RowBox[{"l", "\[Equal]", 
  RowBox[{
   RowBox[{"9", " ", 
    SuperscriptBox[
     RowBox[{"H", "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox["B", "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
   RowBox[{"3", " ", 
    RowBox[{
     SuperscriptBox["B", "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
    RowBox[{
     SuperscriptBox["H", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox["A", "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox["A", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}], "+", 
   RowBox[{"3", " ", 
    RowBox[{"H", "[", "t", "]"}], " ", 
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["A", "\[Prime]",
        MultilineFunction->None], "[", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Phi]", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{
           SuperscriptBox["B", "\[Prime]",
            MultilineFunction->None], "[", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Phi]", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}]}], 
         "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox["B", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Phi]", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}]}]}], 
        ")"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{
  3.798082989308025*^9, 3.798281947880031*^9, 3.7984285330821095`*^9, 
   3.798457603329554*^9, 3.7984601940237474`*^9, 3.7985630404669566`*^9, 
   3.798563360241021*^9, 3.7985636413724337`*^9, 3.7985639143848047`*^9, 
   3.7985640751131787`*^9, 3.7985731263134766`*^9, 3.7985795357509923`*^9, 
   3.7986070774257956`*^9, 3.798695997327216*^9, 3.7986975831200066`*^9, 
   3.798700026438365*^9, 3.7987142431284847`*^9, 3.798714290345949*^9, 
   3.798714323765938*^9, 3.7987144372642136`*^9, 3.798718544864569*^9, 
   3.7989389009318504`*^9, 3.799232576241282*^9, 3.79923293837329*^9, 
   3.7992357909428124`*^9, 3.7992382294876423`*^9, 3.7992387424484816`*^9, {
   3.8002676066455493`*^9, 3.8002676244054804`*^9}, 3.8003342559061737`*^9, 
   3.8003348345122037`*^9, 3.801015944181364*^9, 3.801016250423487*^9, 
   3.8010240472539062`*^9, 3.801024465394326*^9, {3.8010246392066507`*^9, 
   3.801024663118174*^9}, 3.801025002982321*^9, 3.801033585501898*^9, 
   3.8147839095837812`*^9, 3.81876287747956*^9}]
}, Open  ]],

Cell["\<\
Then, lastly before moving on to self-tuning, we setup the following rules... \
\>", "Text",
 CellChangeTimes->{{3.798083020326744*^9, 3.7980830603770356`*^9}, {
  3.8187628945616984`*^9, 3.8187628957935047`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ds", "=", 
   RowBox[{"H", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{"t", ",", "h"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pf", "=", 
   RowBox[{"P", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{"t", ",", 
      RowBox[{"w", " ", 
       RowBox[{"\[Rho]", "[", "t", "]"}]}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vac", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"w", "\[Rule]", 
      RowBox[{"-", "1"}]}], ",", 
     RowBox[{"\[Rho]", "\[Rule]", 
      RowBox[{"Function", "[", 
       RowBox[{"t", ",", "\[Rho]\[CapitalLambda]"}], "]"}]}]}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7980830937440777`*^9, 3.798083145389851*^9}}],

Cell[TextData[{
 "...to approach the de Sitter limit (",
 StyleBox["ds",
  FontSlant->"Italic"],
 "), impose a barotropic perfect fluid with equation of state ",
 Cell[BoxData[
  FormBox["w", TraditionalForm]]],
 " (",
 StyleBox["pf",
  FontSlant->"Italic"],
 "), and fill the background with vacuum-energy (",
 StyleBox["vac",
  FontSlant->"Italic"],
 "). "
}], "Text",
 CellChangeTimes->{{3.798083148843488*^9, 3.7980833007563567`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Section 3. Self-tuning KGB",
 FontColor->RGBColor[1, 0.5, 0.5]]], "Subsection",
 CellChangeTimes->{{3.798082466606784*^9, 3.798082491660494*^9}, {
  3.818763110107163*^9, 3.8187631103208904`*^9}}],

Cell[CellGroupData[{

Cell["3.1 Well-tempered KGB", "Subsubsection",
 CellChangeTimes->{{3.7980824959953265`*^9, 3.7980825027265453`*^9}}],

Cell[TextData[{
 "To obtain the well-tempered theory, we first take the field equations\
\[CloseCurlyQuote] de Sitter limit, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"H", "(", "t", ")"}], "=", "h"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ",..."
}], "Text",
 CellChangeTimes->{{3.79808335908565*^9, 3.798083373896699*^9}, {
  3.8187631651320257`*^9, 3.8187631779641514`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"FeqTPds", "=", 
   RowBox[{"FeqTP", "/.", "ds"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"HeqTPds", "=", 
   RowBox[{
    RowBox[{"HeqTP", "/.", "pf"}], "/.", "ds"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SeqTPds", "=", 
    RowBox[{"SeqTP", "/.", "ds"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "FeqTPds", "\
\[IndentingNewLine]", "HeqTPds", "\[IndentingNewLine]", "SeqTPds"}], "Input",
 CellChangeTimes->{{3.7980833816851816`*^9, 3.798083448618869*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Rho]", "[", "t", "]"}], "+", 
   RowBox[{
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["A", "\[Prime]",
        MultilineFunction->None], "[", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Phi]", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], "+", 
      RowBox[{"3", " ", "h", " ", 
       RowBox[{
        SuperscriptBox["B", "\[Prime]",
         MultilineFunction->None], "[", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Phi]", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], "\[Equal]", 
  RowBox[{
   RowBox[{"3", " ", 
    SuperscriptBox["h", "2"]}], "+", 
   RowBox[{"A", "[", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], "+", 
   RowBox[{"l", " ", 
    RowBox[{"\[Phi]", "[", "t", "]"}]}]}]}]], "Output",
 CellChangeTimes->{
  3.7980834494266133`*^9, 3.79828195706981*^9, 3.798428549207354*^9, 
   3.7984576133415947`*^9, 3.798460196987745*^9, 3.798563054343701*^9, 
   3.798563362912448*^9, 3.798563644036407*^9, 3.798563916826193*^9, 
   3.7985640773314753`*^9, 3.798573129031686*^9, 3.7985795405270653`*^9, 
   3.798607084298379*^9, 3.798696002934725*^9, 3.7986975853314104`*^9, 
   3.798700031768696*^9, 3.7987142477671213`*^9, 3.798714293183092*^9, 
   3.7987143280947137`*^9, 3.798714439948035*^9, 3.798718547647401*^9, 
   3.7989389115195446`*^9, 3.799232942023244*^9, 3.799235806538395*^9, 
   3.7992382342096853`*^9, 3.7992387461011033`*^9, 3.800267626336805*^9, 
   3.8003342631539545`*^9, 3.8003348433807507`*^9, 3.8010159472900543`*^9, 
   3.801016253250943*^9, 3.801024069035329*^9, {3.801024645923888*^9, 
   3.8010246662540793`*^9}, 3.8010250061644955`*^9, 3.8010335932217855`*^9, 
   3.81478391586998*^9, 3.8187631365510225`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Rho]", "[", "t", "]"}], "+", 
   RowBox[{"w", " ", 
    RowBox[{"\[Rho]", "[", "t", "]"}]}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox["A", "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
   RowBox[{"3", " ", "h", " ", 
    RowBox[{
     SuperscriptBox["B", "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
   RowBox[{
    RowBox[{
     SuperscriptBox["B", "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{
  3.7980834494266133`*^9, 3.79828195706981*^9, 3.798428549207354*^9, 
   3.7984576133415947`*^9, 3.798460196987745*^9, 3.798563054343701*^9, 
   3.798563362912448*^9, 3.798563644036407*^9, 3.798563916826193*^9, 
   3.7985640773314753`*^9, 3.798573129031686*^9, 3.7985795405270653`*^9, 
   3.798607084298379*^9, 3.798696002934725*^9, 3.7986975853314104`*^9, 
   3.798700031768696*^9, 3.7987142477671213`*^9, 3.798714293183092*^9, 
   3.7987143280947137`*^9, 3.798714439948035*^9, 3.798718547647401*^9, 
   3.7989389115195446`*^9, 3.799232942023244*^9, 3.799235806538395*^9, 
   3.7992382342096853`*^9, 3.7992387461011033`*^9, 3.800267626336805*^9, 
   3.8003342631539545`*^9, 3.8003348433807507`*^9, 3.8010159472900543`*^9, 
   3.801016253250943*^9, 3.801024069035329*^9, {3.801024645923888*^9, 
   3.8010246662540793`*^9}, 3.8010250061644955`*^9, 3.8010335932217855`*^9, 
   3.81478391586998*^9, 3.8187631365596495`*^9}],

Cell[BoxData[
 RowBox[{"l", "\[Equal]", 
  RowBox[{
   RowBox[{"9", " ", 
    SuperscriptBox["h", "2"], " ", 
    RowBox[{
     SuperscriptBox["B", "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox["A", "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox["A", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}], "+", 
   RowBox[{"3", " ", "h", " ", 
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["A", "\[Prime]",
        MultilineFunction->None], "[", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Phi]", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{
           SuperscriptBox["B", "\[Prime]",
            MultilineFunction->None], "[", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Phi]", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}]}], 
         "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox["B", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Phi]", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}]}]}], 
        ")"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{
  3.7980834494266133`*^9, 3.79828195706981*^9, 3.798428549207354*^9, 
   3.7984576133415947`*^9, 3.798460196987745*^9, 3.798563054343701*^9, 
   3.798563362912448*^9, 3.798563644036407*^9, 3.798563916826193*^9, 
   3.7985640773314753`*^9, 3.798573129031686*^9, 3.7985795405270653`*^9, 
   3.798607084298379*^9, 3.798696002934725*^9, 3.7986975853314104`*^9, 
   3.798700031768696*^9, 3.7987142477671213`*^9, 3.798714293183092*^9, 
   3.7987143280947137`*^9, 3.798714439948035*^9, 3.798718547647401*^9, 
   3.7989389115195446`*^9, 3.799232942023244*^9, 3.799235806538395*^9, 
   3.7992382342096853`*^9, 3.7992387461011033`*^9, 3.800267626336805*^9, 
   3.8003342631539545`*^9, 3.8003348433807507`*^9, 3.8010159472900543`*^9, 
   3.801016253250943*^9, 3.801024069035329*^9, {3.801024645923888*^9, 
   3.8010246662540793`*^9}, 3.8010250061644955`*^9, 3.8010335932217855`*^9, 
   3.81478391586998*^9, 3.8187631365690403`*^9}]
}, Open  ]],

Cell[TextData[{
 "Well-tempering can be achieved when the Hubble and scalar field equations \
become the same equation on the de Sitter vacuum. This can be satisfied with ",
 Cell[BoxData[
  FormBox[
   RowBox[{"w", "=", 
    RowBox[{"-", "1"}]}], TraditionalForm]]],
 " and so protects the de Sitter state only from vacuum energy. The field \
equations then become..."
}], "Text",
 CellChangeTimes->{{3.7980835043803806`*^9, 3.798083561355463*^9}, {
  3.7980836156941214`*^9, 3.7980837194072437`*^9}, {3.798083756146364*^9, 
  3.7980838533936663`*^9}, {3.798083895429134*^9, 3.7980839483270197`*^9}, {
  3.7980839920630713`*^9, 3.798084019737487*^9}, {3.8187632145362673`*^9, 
  3.818763377931747*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"FeqTPdsvac", "=", 
   RowBox[{"FeqTPds", "/.", "vac"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"HeqTPdsvac", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"HeqTPds", "/.", "vac"}], ",", 
     RowBox[{
      RowBox[{"\[Phi]", "''"}], "[", "t", "]"}], ",", "Simplify"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SeqTPdsvac", "=", 
    RowBox[{
     RowBox[{"Collect", "[", 
      RowBox[{
       RowBox[{"l", "-", 
        RowBox[{"(", 
         RowBox[{"l", "/.", 
          RowBox[{
           RowBox[{"Solve", "[", 
            RowBox[{
             RowBox[{"SeqTPds", "/.", "vac"}], ",", "l"}], "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], ")"}]}], ",", 
       RowBox[{
        RowBox[{"\[Phi]", "''"}], "[", "t", "]"}], ",", "Simplify"}], "]"}], 
     "\[Equal]", "0"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "FeqTPdsvac", "\
\[IndentingNewLine]", "HeqTPdsvac", "\[IndentingNewLine]", "SeqTPdsvac"}], \
"Input",
 CellChangeTimes->{{3.798083952348693*^9, 3.7980839883931527`*^9}, {
  3.798084170102634*^9, 3.7980842427947826`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Rho]\[CapitalLambda]", "+", 
   RowBox[{
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["A", "\[Prime]",
        MultilineFunction->None], "[", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Phi]", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], "+", 
      RowBox[{"3", " ", "h", " ", 
       RowBox[{
        SuperscriptBox["B", "\[Prime]",
         MultilineFunction->None], "[", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Phi]", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], "\[Equal]", 
  RowBox[{
   RowBox[{"3", " ", 
    SuperscriptBox["h", "2"]}], "+", 
   RowBox[{"A", "[", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], "+", 
   RowBox[{"l", " ", 
    RowBox[{"\[Phi]", "[", "t", "]"}]}]}]}]], "Output",
 CellChangeTimes->{
  3.7980840212822666`*^9, 3.7980841939624505`*^9, 3.7980842434719453`*^9, 
   3.7982819572452345`*^9, 3.798428549521609*^9, 3.798457613494852*^9, 
   3.798460197204666*^9, 3.798563054609624*^9, 3.7985633632561426`*^9, 
   3.7985636443086896`*^9, 3.798563917208426*^9, 3.798564077517376*^9, 
   3.7985731292928886`*^9, 3.798579540696111*^9, 3.798607084884984*^9, 
   3.7986960035076933`*^9, 3.798697585740855*^9, 3.7987000320933447`*^9, 
   3.798714247963987*^9, 3.798714293445239*^9, 3.7987143283045053`*^9, 
   3.798714440176503*^9, 3.798718547935352*^9, 3.798938911722616*^9, 
   3.799232942315216*^9, 3.7992358067789125`*^9, 3.7992382343967533`*^9, 
   3.799238746337859*^9, 3.8002676265249357`*^9, 3.8003342633537917`*^9, 
   3.8003348435785503`*^9, 3.8010159474774995`*^9, 3.801016253407156*^9, 
   3.801024069142602*^9, {3.8010246461099906`*^9, 3.80102466644821*^9}, 
   3.8010250063229375`*^9, 3.801033593417195*^9, 3.8147839161113343`*^9, 
   3.8187633849553337`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["A", "\[Prime]",
        MultilineFunction->None], "[", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Phi]", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], "+", 
      RowBox[{"3", " ", "h", " ", 
       RowBox[{
        SuperscriptBox["B", "\[Prime]",
         MultilineFunction->None], "[", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Phi]", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], "-", 
   RowBox[{
    RowBox[{
     SuperscriptBox["B", "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{
  3.7980840212822666`*^9, 3.7980841939624505`*^9, 3.7980842434719453`*^9, 
   3.7982819572452345`*^9, 3.798428549521609*^9, 3.798457613494852*^9, 
   3.798460197204666*^9, 3.798563054609624*^9, 3.7985633632561426`*^9, 
   3.7985636443086896`*^9, 3.798563917208426*^9, 3.798564077517376*^9, 
   3.7985731292928886`*^9, 3.798579540696111*^9, 3.798607084884984*^9, 
   3.7986960035076933`*^9, 3.798697585740855*^9, 3.7987000320933447`*^9, 
   3.798714247963987*^9, 3.798714293445239*^9, 3.7987143283045053`*^9, 
   3.798714440176503*^9, 3.798718547935352*^9, 3.798938911722616*^9, 
   3.799232942315216*^9, 3.7992358067789125`*^9, 3.7992382343967533`*^9, 
   3.799238746337859*^9, 3.8002676265249357`*^9, 3.8003342633537917`*^9, 
   3.8003348435785503`*^9, 3.8010159474774995`*^9, 3.801016253407156*^9, 
   3.801024069142602*^9, {3.8010246461099906`*^9, 3.80102466644821*^9}, 
   3.8010250063229375`*^9, 3.801033593417195*^9, 3.8147839161113343`*^9, 
   3.818763384971547*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"l", "-", 
   RowBox[{"3", " ", "h", " ", 
    RowBox[{
     SuperscriptBox["A", "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}], "-", 
   RowBox[{"9", " ", 
    SuperscriptBox["h", "2"], " ", 
    RowBox[{
     SuperscriptBox["B", "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        SuperscriptBox["A", "\[Prime]",
         MultilineFunction->None], "[", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Phi]", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}]}], "-", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"6", " ", "h", " ", 
          RowBox[{
           SuperscriptBox["B", "\[Prime]",
            MultilineFunction->None], "[", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Phi]", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox["\[Phi]", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["A", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", 
             RowBox[{
              FractionBox["1", "2"], " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["\[Phi]", "\[Prime]",
                 MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], 
            "+", 
            RowBox[{"3", " ", "h", " ", 
             RowBox[{
              SuperscriptBox["\[Phi]", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], " ", 
             RowBox[{
              SuperscriptBox["B", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", 
              RowBox[{
               FractionBox["1", "2"], " ", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox["\[Phi]", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], "2"]}], 
              "]"}]}]}], ")"}]}]}], ")"}]}]}], ")"}], " ", 
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{
  3.7980840212822666`*^9, 3.7980841939624505`*^9, 3.7980842434719453`*^9, 
   3.7982819572452345`*^9, 3.798428549521609*^9, 3.798457613494852*^9, 
   3.798460197204666*^9, 3.798563054609624*^9, 3.7985633632561426`*^9, 
   3.7985636443086896`*^9, 3.798563917208426*^9, 3.798564077517376*^9, 
   3.7985731292928886`*^9, 3.798579540696111*^9, 3.798607084884984*^9, 
   3.7986960035076933`*^9, 3.798697585740855*^9, 3.7987000320933447`*^9, 
   3.798714247963987*^9, 3.798714293445239*^9, 3.7987143283045053`*^9, 
   3.798714440176503*^9, 3.798718547935352*^9, 3.798938911722616*^9, 
   3.799232942315216*^9, 3.7992358067789125`*^9, 3.7992382343967533`*^9, 
   3.799238746337859*^9, 3.8002676265249357`*^9, 3.8003342633537917`*^9, 
   3.8003348435785503`*^9, 3.8010159474774995`*^9, 3.801016253407156*^9, 
   3.801024069142602*^9, {3.8010246461099906`*^9, 3.80102466644821*^9}, 
   3.8010250063229375`*^9, 3.801033593417195*^9, 3.8147839161113343`*^9, 
   3.818763385005316*^9}]
}, Open  ]],

Cell[TextData[{
 "We focus on the Hubble and scalar field equations and find their shared \
theory space by equating the terms proportional to ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Phi]", "''"}], 
    RowBox[{"(", "t", ")"}]}], TraditionalForm]]],
 ". We do this as follows..."
}], "Text",
 CellChangeTimes->{{3.7980840692124815`*^9, 3.7980841222211037`*^9}, {
  3.7980842841243258`*^9, 3.798084316740511*^9}, {3.7980844337028313`*^9, 
  3.798084443512967*^9}, {3.818763398209293*^9, 3.8187634073715754`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"EnH", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"HeqTPdsvac", "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{"\[Phi]", "''"}], "[", "t", "]"}], ",", "0"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"EdH", "=", 
    RowBox[{"-", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"HeqTPdsvac", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"\[Phi]", "''"}], "[", "t", "]"}], ",", "1"}], "]"}]}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"En\[Phi]", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"SeqTPdsvac", "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{"\[Phi]", "''"}], "[", "t", "]"}], ",", "0"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ed\[Phi]", "=", 
    RowBox[{"-", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"SeqTPdsvac", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"\[Phi]", "''"}], "[", "t", "]"}], ",", "1"}], "]"}]}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"HSeq1", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{
       RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "]"}], "EdH"}], "\[Equal]", 
    "Ed\[Phi]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"HSeq2", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"f", "[", 
       RowBox[{
        RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "]"}], "EnH"}], "\[Equal]", 
     "En\[Phi]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "HSeq1", "\
\[IndentingNewLine]", "HSeq2"}], "Input",
 CellChangeTimes->{{3.798084318301315*^9, 3.7980843265599327`*^9}, {
  3.7980844534252615`*^9, 3.7980846030454655`*^9}, {3.7980846518195915`*^9, 
  3.79808470939856*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["B", "\[Prime]",
     MultilineFunction->None], "[", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}], "\[Equal]", 
  RowBox[{
   RowBox[{
    SuperscriptBox["A", "\[Prime]",
     MultilineFunction->None], "[", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"6", " ", "h", " ", 
       RowBox[{
        SuperscriptBox["B", "\[Prime]",
         MultilineFunction->None], "[", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Phi]", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["A", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], "+", 
         RowBox[{"3", " ", "h", " ", 
          RowBox[{
           SuperscriptBox["\[Phi]", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], " ", 
          RowBox[{
           SuperscriptBox["B", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Phi]", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}]}]}], 
        ")"}]}]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{{3.798084518168144*^9, 3.798084523137416*^9}, 
   3.7980847111781826`*^9, 3.798281957282128*^9, 3.798428549576258*^9, 
   3.7984576135417137`*^9, 3.7984601972330813`*^9, 3.798563054660946*^9, 
   3.798563363285142*^9, 3.7985636443525667`*^9, 3.798563917253612*^9, 
   3.798564077553359*^9, 3.7985731293313804`*^9, 3.7985795407273226`*^9, 
   3.7986070850320816`*^9, 3.7986960035722265`*^9, 3.7986975857747335`*^9, 
   3.798700032144206*^9, 3.798714247997192*^9, 3.7987142934750032`*^9, 
   3.7987143283309336`*^9, 3.798714440211542*^9, 3.7987185479893627`*^9, 
   3.7989389117694826`*^9, 3.7992329423567123`*^9, 3.7992358068114*^9, 
   3.7992382344401765`*^9, 3.799238746387806*^9, 3.800267626579116*^9, 
   3.8003342633919697`*^9, 3.800334843616283*^9, 3.801015947524375*^9, 
   3.801016253454056*^9, 3.8010240691919403`*^9, {3.801024646147607*^9, 
   3.8010246664791007`*^9}, 3.8010250063646936`*^9, 3.8010335934517765`*^9, 
   3.81478391615023*^9, 3.8187634251017942`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["A", "\[Prime]",
       MultilineFunction->None], "[", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], "+", 
     RowBox[{"3", " ", "h", " ", 
      RowBox[{
       SuperscriptBox["B", "\[Prime]",
        MultilineFunction->None], "[", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Phi]", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], "\[Equal]", 
  RowBox[{"l", "-", 
   RowBox[{"3", " ", "h", " ", 
    RowBox[{
     SuperscriptBox["A", "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}], "-", 
   RowBox[{"9", " ", 
    SuperscriptBox["h", "2"], " ", 
    RowBox[{
     SuperscriptBox["B", "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"]}]}]}]], "Output",
 CellChangeTimes->{{3.798084518168144*^9, 3.798084523137416*^9}, 
   3.7980847111781826`*^9, 3.798281957282128*^9, 3.798428549576258*^9, 
   3.7984576135417137`*^9, 3.7984601972330813`*^9, 3.798563054660946*^9, 
   3.798563363285142*^9, 3.7985636443525667`*^9, 3.798563917253612*^9, 
   3.798564077553359*^9, 3.7985731293313804`*^9, 3.7985795407273226`*^9, 
   3.7986070850320816`*^9, 3.7986960035722265`*^9, 3.7986975857747335`*^9, 
   3.798700032144206*^9, 3.798714247997192*^9, 3.7987142934750032`*^9, 
   3.7987143283309336`*^9, 3.798714440211542*^9, 3.7987185479893627`*^9, 
   3.7989389117694826`*^9, 3.7992329423567123`*^9, 3.7992358068114*^9, 
   3.7992382344401765`*^9, 3.799238746387806*^9, 3.800267626579116*^9, 
   3.8003342633919697`*^9, 3.800334843616283*^9, 3.801015947524375*^9, 
   3.801016253454056*^9, 3.8010240691919403`*^9, {3.801024646147607*^9, 
   3.8010246664791007`*^9}, 3.8010250063646936`*^9, 3.8010335934517765`*^9, 
   3.81478391615023*^9, 3.8187634251174097`*^9}]
}, Open  ]],

Cell[TextData[{
 "These are Eqs. (3.11) and (3.12) in the text. From this, we can obtain the \
well-tempered theory, by expressing this in terms of the kinetic density ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"X", "(", "t", ")"}], "=", 
    RowBox[{
     RowBox[{"\[Phi]", "'"}], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", "t", ")"}], "2"], "/", "2"}]}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "..."
}], "Text",
 CellChangeTimes->{{3.798084717466251*^9, 3.798084797778619*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"$Assumptions", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "\[GreaterEqual]", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Phi]tox", "=", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"X", "[", "t", "]"}], "\[Equal]", 
          FractionBox[
           SuperscriptBox[
            RowBox[{
             RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "2"], "2"]}], ",", 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"X", "[", "t", "]"}], "\[Equal]", 
            FractionBox[
             SuperscriptBox[
              RowBox[{
               RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "2"], "2"]}], ",", 
           "t"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], ",", 
         RowBox[{
          RowBox[{"\[Phi]", "''"}], "[", "t", "]"}]}], "}"}]}], "]"}], "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"HSeq1X", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"HSeq1", "/.", "\[Phi]tox"}], "/.", 
      RowBox[{
       RowBox[{"X", "[", "t", "]"}], "\[Rule]", "X"}]}], "/.", 
     RowBox[{"f", "\[Rule]", 
      RowBox[{"Function", "[", 
       RowBox[{"X", ",", 
        FractionBox[
         RowBox[{"q", "[", 
          RowBox[{
           SuperscriptBox["X", "2"], "/", "2"}], "]"}], "X"]}], "]"}]}]}], "//",
     "FullSimplify"}]}], ";", "HSeq1X"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"HSeq2X", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"HSeq2", "/.", "\[Phi]tox"}], "/.", 
      RowBox[{
       RowBox[{"X", "[", "t", "]"}], "\[Rule]", "X"}]}], "/.", 
     RowBox[{"f", "\[Rule]", 
      RowBox[{"Function", "[", 
       RowBox[{"X", ",", 
        FractionBox[
         RowBox[{"q", "[", 
          RowBox[{
           SuperscriptBox["X", "2"], "/", "2"}], "]"}], "X"]}], "]"}]}]}], "//",
     "FullSimplify"}]}], ";", "HSeq2X"}]}], "Input",
 CellChangeTimes->{{3.798084800422897*^9, 3.79808507561582*^9}, 
   3.7980851319366503`*^9, {3.7980851709865103`*^9, 3.7980851971009207`*^9}, {
   3.7980863140506215`*^9, 3.7980863206740847`*^9}, {3.798086971781973*^9, 
   3.79808697194803*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox["A", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}], "+", 
   RowBox[{
    SqrtBox["2"], " ", 
    SqrtBox["X"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"6", " ", "h"}], "-", 
      RowBox[{"q", "[", "X", "]"}]}], ")"}], " ", 
    RowBox[{
     SuperscriptBox["B", "\[Prime]",
      MultilineFunction->None], "[", "X", "]"}]}], "+", 
   RowBox[{"2", " ", "X", " ", 
    RowBox[{
     SuperscriptBox["A", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "X", "]"}]}], "+", 
   RowBox[{"6", " ", 
    SqrtBox["2"], " ", "h", " ", 
    SuperscriptBox["X", 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{
     SuperscriptBox["B", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "X", "]"}]}]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{{3.7980849498421574`*^9, 3.7980849667875443`*^9}, 
   3.7980850304469776`*^9, 3.798085079928013*^9, {3.798085187212039*^9, 
   3.7980851976193156`*^9}, 3.7980863211285954`*^9, 3.798086972876764*^9, 
   3.798281957505765*^9, 3.7984285502773013`*^9, 3.7984576137801666`*^9, 
   3.7984601974577775`*^9, 3.798563055432892*^9, 3.798563363540944*^9, 
   3.798563644753353*^9, 3.798563917542983*^9, 3.7985640777656918`*^9, 
   3.7985731295757027`*^9, 3.798579541081487*^9, 3.7986070859274917`*^9, 
   3.7986960040306745`*^9, 3.798697585988846*^9, 3.798700032384652*^9, 
   3.7987142482630157`*^9, 3.7987142936875763`*^9, 3.7987143285422316`*^9, 
   3.7987144404112797`*^9, 3.7987185483186707`*^9, 3.7989389121131535`*^9, 
   3.7992329427596226`*^9, 3.7992358070176773`*^9, 3.7992382346764607`*^9, 
   3.7992387466060286`*^9, 3.8002676268451385`*^9, 3.8003342639546523`*^9, 
   3.800334843842651*^9, 3.801015947993002*^9, 3.8010162536570983`*^9, 
   3.8010240694085493`*^9, {3.801024646434457*^9, 3.801024666696789*^9}, 
   3.801025006583005*^9, 3.8010335936626997`*^9, 3.8147839165322123`*^9, 
   3.8187634534581084`*^9}],

Cell[BoxData[
 RowBox[{"l", "\[Equal]", 
  RowBox[{
   SqrtBox["X"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", "h"}], "+", 
     RowBox[{"q", "[", "X", "]"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SqrtBox["2"], " ", 
      RowBox[{
       SuperscriptBox["A", "\[Prime]",
        MultilineFunction->None], "[", "X", "]"}]}], "+", 
     RowBox[{"6", " ", "h", " ", 
      SqrtBox["X"], " ", 
      RowBox[{
       SuperscriptBox["B", "\[Prime]",
        MultilineFunction->None], "[", "X", "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.7980849498421574`*^9, 3.7980849667875443`*^9}, 
   3.7980850304469776`*^9, 3.798085079928013*^9, {3.798085187212039*^9, 
   3.7980851976193156`*^9}, 3.7980863211285954`*^9, 3.798086972876764*^9, 
   3.798281957505765*^9, 3.7984285502773013`*^9, 3.7984576137801666`*^9, 
   3.7984601974577775`*^9, 3.798563055432892*^9, 3.798563363540944*^9, 
   3.798563644753353*^9, 3.798563917542983*^9, 3.7985640777656918`*^9, 
   3.7985731295757027`*^9, 3.798579541081487*^9, 3.7986070859274917`*^9, 
   3.7986960040306745`*^9, 3.798697585988846*^9, 3.798700032384652*^9, 
   3.7987142482630157`*^9, 3.7987142936875763`*^9, 3.7987143285422316`*^9, 
   3.7987144404112797`*^9, 3.7987185483186707`*^9, 3.7989389121131535`*^9, 
   3.7992329427596226`*^9, 3.7992358070176773`*^9, 3.7992382346764607`*^9, 
   3.7992387466060286`*^9, 3.8002676268451385`*^9, 3.8003342639546523`*^9, 
   3.800334843842651*^9, 3.801015947993002*^9, 3.8010162536570983`*^9, 
   3.8010240694085493`*^9, {3.801024646434457*^9, 3.801024666696789*^9}, 
   3.801025006583005*^9, 3.8010335936626997`*^9, 3.8147839165322123`*^9, 
   3.8187634536086235`*^9}]
}, Open  ]],

Cell[TextData[{
 "These are Eqs. (3.13) and (3.14). This first-order coupled ODE system for \
the potentials ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"A", "'"}], 
    RowBox[{"(", "X", ")"}]}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"B", "'"}], 
    RowBox[{"(", "X", ")"}]}], TraditionalForm]]],
 " can be decoupled easily by noting that this system depends explicitly on ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"A", "'"}], 
     RowBox[{"(", "X", ")"}]}], "+", 
    RowBox[{"3", "h", 
     SqrtBox[
      RowBox[{"2", "X"}]], 
     RowBox[{"B", "'"}], 
     RowBox[{"(", "X", ")"}]}]}], TraditionalForm]]],
 ". The general solution is given by Eqs. (3.15) and (3.16) as we now \
explicitly show..."
}], "Text",
 CellChangeTimes->{{3.7980852074145823`*^9, 3.798085335147868*^9}, {
  3.7980854543084784`*^9, 3.7980855482752275`*^9}, {3.798085703816907*^9, 
  3.798085705830408*^9}, {3.7980859358934116`*^9, 3.798085962502454*^9}, {
  3.818763478799153*^9, 3.8187635099119654`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"welltemp", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"A", "'"}], "[", "X", "]"}], "\[Rule]", 
       FractionBox[
        RowBox[{"l", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", "h", " ", 
            RowBox[{"q", "[", "X", "]"}]}], "+", 
           SuperscriptBox[
            RowBox[{"q", "[", "X", "]"}], "2"], "+", 
           RowBox[{"6", " ", "h", " ", "X", " ", 
            RowBox[{
             RowBox[{"q", "'"}], "[", "X", "]"}]}]}], ")"}]}], 
        RowBox[{
         SqrtBox["2"], " ", 
         SqrtBox["X"], " ", 
         RowBox[{"q", "[", "X", "]"}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", "h"}], "+", 
            RowBox[{"q", "[", "X", "]"}]}], ")"}], "2"]}]]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"A", "''"}], "[", "X", "]"}], "\[Rule]", 
       RowBox[{"D", "[", 
        RowBox[{
         FractionBox[
          RowBox[{"l", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "h", " ", 
              RowBox[{"q", "[", "X", "]"}]}], "+", 
             SuperscriptBox[
              RowBox[{"q", "[", "X", "]"}], "2"], "+", 
             RowBox[{"6", " ", "h", " ", "X", " ", 
              RowBox[{
               RowBox[{"q", "'"}], "[", "X", "]"}]}]}], ")"}]}], 
          RowBox[{
           SqrtBox["2"], " ", 
           SqrtBox["X"], " ", 
           RowBox[{"q", "[", "X", "]"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", "h"}], "+", 
              RowBox[{"q", "[", "X", "]"}]}], ")"}], "2"]}]], ",", "X"}], 
        "]"}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"B", "'"}], "[", "X", "]"}], "\[Rule]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"l", " ", 
          RowBox[{
           RowBox[{"q", "'"}], "[", "X", "]"}]}], 
         RowBox[{
          RowBox[{"q", "[", "X", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "h"}], "+", 
             RowBox[{"q", "[", "X", "]"}]}], ")"}], "2"]}]]}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"B", "''"}], "[", "X", "]"}], "\[Rule]", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"l", " ", 
            RowBox[{
             RowBox[{"q", "'"}], "[", "X", "]"}]}], 
           RowBox[{
            RowBox[{"q", "[", "X", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", "h"}], "+", 
               RowBox[{"q", "[", "X", "]"}]}], ")"}], "2"]}]]}], ",", "X"}], 
        "]"}]}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"HSeq1X", "/.", "welltemp"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"HSeq2X", "/.", "welltemp"}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.7980855810857067`*^9, 3.798085732846835*^9}, {
  3.7980857936117716`*^9, 3.7980858097663984`*^9}, {3.798085905750036*^9, 
  3.798085909035552*^9}, {3.7980869898431234`*^9, 3.798086993009783*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.798085738704297*^9, {3.798085799781876*^9, 3.7980858145921392`*^9}, 
   3.7980859102083206`*^9, 3.798086360122005*^9, 3.7980869934075375`*^9, 
   3.798281957702713*^9, 3.798428550550506*^9, 3.7984576139585485`*^9, 
   3.7984601976313963`*^9, 3.798563055935964*^9, 3.7985633637483377`*^9, 
   3.798563645506051*^9, 3.798563918130598*^9, 3.798564077989789*^9, 
   3.7985731297679963`*^9, 3.798579541281968*^9, 3.7986070862340813`*^9, 
   3.798696004313275*^9, 3.798697586175253*^9, 3.798700032577665*^9, 
   3.798714248448992*^9, 3.7987142938849473`*^9, 3.798714328707328*^9, 
   3.7987144405893793`*^9, 3.798718548587884*^9, 3.7989389122849846`*^9, 
   3.799232942947013*^9, 3.7992358071948767`*^9, 3.799238234860694*^9, 
   3.7992387467675605`*^9, 3.8002676270894194`*^9, 3.8003342643750057`*^9, 
   3.8003348440253196`*^9, 3.801015948180425*^9, 3.8010162538289485`*^9, 
   3.8010240695981345`*^9, {3.8010246465540023`*^9, 3.8010246668594465`*^9}, 
   3.801025006748664*^9, 3.8010335938421593`*^9, 3.8147839167615986`*^9, 
   3.8187635217180843`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.798085738704297*^9, {3.798085799781876*^9, 3.7980858145921392`*^9}, 
   3.7980859102083206`*^9, 3.798086360122005*^9, 3.7980869934075375`*^9, 
   3.798281957702713*^9, 3.798428550550506*^9, 3.7984576139585485`*^9, 
   3.7984601976313963`*^9, 3.798563055935964*^9, 3.7985633637483377`*^9, 
   3.798563645506051*^9, 3.798563918130598*^9, 3.798564077989789*^9, 
   3.7985731297679963`*^9, 3.798579541281968*^9, 3.7986070862340813`*^9, 
   3.798696004313275*^9, 3.798697586175253*^9, 3.798700032577665*^9, 
   3.798714248448992*^9, 3.7987142938849473`*^9, 3.798714328707328*^9, 
   3.7987144405893793`*^9, 3.798718548587884*^9, 3.7989389122849846`*^9, 
   3.799232942947013*^9, 3.7992358071948767`*^9, 3.799238234860694*^9, 
   3.7992387467675605`*^9, 3.8002676270894194`*^9, 3.8003342643750057`*^9, 
   3.8003348440253196`*^9, 3.801015948180425*^9, 3.8010162538289485`*^9, 
   3.8010240695981345`*^9, {3.8010246465540023`*^9, 3.8010246668594465`*^9}, 
   3.801025006748664*^9, 3.8010335938421593`*^9, 3.8147839167615986`*^9, 
   3.8187635217218637`*^9}]
}, Open  ]],

Cell[TextData[{
 "The above solution gives the well-tempered theory for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"l", "=", "0"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " parametrized by free function ",
 Cell[BoxData[
  FormBox[
   RowBox[{"q", "(", "x", ")"}], TraditionalForm]]],
 ". The Friedmann constraint, Hubble equation, and scalar field equation on \
the vacuum become..."
}], "Text",
 CellChangeTimes->{{3.7980870476825128`*^9, 3.798087144747123*^9}, {
  3.8187635402609615`*^9, 3.81876357189614*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"wt", "=", 
    RowBox[{"welltemp", "/.", 
     RowBox[{"X", "\[Rule]", 
      FractionBox[
       SuperscriptBox[
        RowBox[{
         RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "2"], "2"]}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FeqTPwt", "=", 
   RowBox[{
    RowBox[{"FeqTPdsvac", "/.", "wt"}], "//", "FullSimplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"HeqTPwt", "=", 
   RowBox[{
    RowBox[{"HeqTPdsvac", "/.", "wt"}], "//", "FullSimplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SeqTPwt", "=", 
    RowBox[{
     RowBox[{"SeqTPdsvac", "/.", "wt"}], "//", "FullSimplify"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "FeqTPwt", "\
\[IndentingNewLine]", "HeqTPwt", "\[IndentingNewLine]", "SeqTPwt"}], "Input",
 CellChangeTimes->{{3.798087173828869*^9, 3.798087278614324*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"3", " ", 
    SuperscriptBox["h", "2"]}], "+", 
   RowBox[{"A", "[", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], "+", 
   RowBox[{"l", " ", 
    RowBox[{"\[Phi]", "[", "t", "]"}]}]}], "\[Equal]", 
  RowBox[{"\[Rho]\[CapitalLambda]", "+", 
   FractionBox[
    RowBox[{"l", " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], 
    RowBox[{
     RowBox[{"3", " ", "h"}], "+", 
     RowBox[{"q", "[", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], 
      "]"}]}]]}]}]], "Output",
 CellChangeTimes->{{3.7980872171725173`*^9, 3.798087279053419*^9}, 
   3.798281958378813*^9, 3.798428551549695*^9, 3.798457614497611*^9, 
   3.7984601983611355`*^9, 3.798563056865875*^9, 3.798563364459022*^9, 
   3.7985636461622105`*^9, 3.7985639189549546`*^9, 3.7985640787922373`*^9, 
   3.798573130627984*^9, 3.798579541861147*^9, 3.7986070877169666`*^9, 
   3.798696005018772*^9, 3.7986975867629538`*^9, 3.7987000332370863`*^9, 
   3.798714249001693*^9, 3.7987142946627116`*^9, 3.798714329334073*^9, 
   3.7987144413784437`*^9, 3.798718549294182*^9, 3.7989389128785973`*^9, 
   3.799232943551513*^9, 3.799235807818719*^9, 3.799238235464419*^9, 
   3.7992387473751497`*^9, 3.8002676278039403`*^9, 3.800334265240167*^9, 
   3.8003348447059765`*^9, 3.801015948867795*^9, 3.801016254375681*^9, 
   3.80102407019953*^9, {3.8010246471322713`*^9, 3.801024667411088*^9}, 
   3.801025007292982*^9, 3.801033594406126*^9, 3.8147839173899183`*^9, 
   3.8187635867128487`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"l", " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     FractionBox[
      RowBox[{
       RowBox[{
        SuperscriptBox["q", "\[Prime]",
         MultilineFunction->None], "[", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Phi]", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], 
      RowBox[{
       RowBox[{"3", " ", "h", " ", 
        RowBox[{"q", "[", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}]}], "+", 
       SuperscriptBox[
        RowBox[{"q", "[", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], 
        "2"]}]]}], ")"}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{{3.7980872171725173`*^9, 3.798087279053419*^9}, 
   3.798281958378813*^9, 3.798428551549695*^9, 3.798457614497611*^9, 
   3.7984601983611355`*^9, 3.798563056865875*^9, 3.798563364459022*^9, 
   3.7985636461622105`*^9, 3.7985639189549546`*^9, 3.7985640787922373`*^9, 
   3.798573130627984*^9, 3.798579541861147*^9, 3.7986070877169666`*^9, 
   3.798696005018772*^9, 3.7986975867629538`*^9, 3.7987000332370863`*^9, 
   3.798714249001693*^9, 3.7987142946627116`*^9, 3.798714329334073*^9, 
   3.7987144413784437`*^9, 3.798718549294182*^9, 3.7989389128785973`*^9, 
   3.799232943551513*^9, 3.799235807818719*^9, 3.799238235464419*^9, 
   3.7992387473751497`*^9, 3.8002676278039403`*^9, 3.800334265240167*^9, 
   3.8003348447059765`*^9, 3.801015948867795*^9, 3.801016254375681*^9, 
   3.80102407019953*^9, {3.8010246471322713`*^9, 3.801024667411088*^9}, 
   3.801025007292982*^9, 3.801033594406126*^9, 3.8147839173899183`*^9, 
   3.8187635867209067`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"l", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"q", "[", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], "+", 
     FractionBox[
      RowBox[{
       RowBox[{
        SuperscriptBox["q", "\[Prime]",
         MultilineFunction->None], "[", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Phi]", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], 
      RowBox[{
       RowBox[{"3", " ", "h"}], "+", 
       RowBox[{"q", "[", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Phi]", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}]}]]}], 
    ")"}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{{3.7980872171725173`*^9, 3.798087279053419*^9}, 
   3.798281958378813*^9, 3.798428551549695*^9, 3.798457614497611*^9, 
   3.7984601983611355`*^9, 3.798563056865875*^9, 3.798563364459022*^9, 
   3.7985636461622105`*^9, 3.7985639189549546`*^9, 3.7985640787922373`*^9, 
   3.798573130627984*^9, 3.798579541861147*^9, 3.7986070877169666`*^9, 
   3.798696005018772*^9, 3.7986975867629538`*^9, 3.7987000332370863`*^9, 
   3.798714249001693*^9, 3.7987142946627116`*^9, 3.798714329334073*^9, 
   3.7987144413784437`*^9, 3.798718549294182*^9, 3.7989389128785973`*^9, 
   3.799232943551513*^9, 3.799235807818719*^9, 3.799238235464419*^9, 
   3.7992387473751497`*^9, 3.8002676278039403`*^9, 3.800334265240167*^9, 
   3.8003348447059765`*^9, 3.801015948867795*^9, 3.801016254375681*^9, 
   3.80102407019953*^9, {3.8010246471322713`*^9, 3.801024667411088*^9}, 
   3.801025007292982*^9, 3.801033594406126*^9, 3.8147839173899183`*^9, 
   3.818763586727093*^9}]
}, Open  ]],

Cell["\<\
This confirms the Hubble and the scalar field equations are degenerate on the \
de Sitter vacuum...\
\>", "Text",
 CellChangeTimes->{{3.7980872890605416`*^9, 3.79808732404558*^9}, {
  3.8187635965594645`*^9, 3.81876361813993*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"HeqTPwt", "/.", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{"SeqTPwt", ",", 
      RowBox[{
       RowBox[{"\[Phi]", "''"}], "[", "t", "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.798087326642622*^9, 3.7980873529459815`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.7980873464707003`*^9, 3.798087353189118*^9}, 
   3.798281958450604*^9, 3.798428551590416*^9, 3.798457614575718*^9, 
   3.7984601984424934`*^9, 3.798563056948428*^9, 3.7985633645341225`*^9, 
   3.7985636461882615`*^9, 3.7985639190154595`*^9, 3.7985640788982754`*^9, 
   3.7985731308345575`*^9, 3.798579541945795*^9, 3.7986070878643274`*^9, 
   3.798696005050358*^9, 3.7986975868564186`*^9, 3.7987000333317337`*^9, 
   3.798714249082974*^9, 3.798714294742032*^9, 3.7987143294151225`*^9, 
   3.7987144414631724`*^9, 3.798718549391469*^9, 3.798938912956702*^9, 
   3.799232943632227*^9, 3.7992358079202986`*^9, 3.7992382355360126`*^9, 
   3.7992387474771395`*^9, 3.800267627929329*^9, 3.800334265318637*^9, 
   3.800334844868449*^9, 3.8010159489771123`*^9, 3.801016254485029*^9, 
   3.8010240702626047`*^9, {3.801024647216174*^9, 3.801024667502406*^9}, 
   3.8010250073775215`*^9, 3.801033594489168*^9, 3.814783917482669*^9}]
}, Open  ]],

Cell["\<\
Furthermore, the Friedmann constraint can be differentiated to get the same \
equation...\
\>", "Text",
 CellChangeTimes->{{3.798087370089937*^9, 3.7980874032051926`*^9}, {
  3.818763626478111*^9, 3.818763650487769*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{"FeqTPwt", ",", "t"}], "]"}], "/.", "wt"}], "//", 
  "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7980874066745834`*^9, 3.798087474471575*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"l", " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     FractionBox[
      RowBox[{
       RowBox[{
        SuperscriptBox["q", "\[Prime]",
         MultilineFunction->None], "[", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Phi]", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], 
      RowBox[{
       RowBox[{"3", " ", "h", " ", 
        RowBox[{"q", "[", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}]}], "+", 
       SuperscriptBox[
        RowBox[{"q", "[", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], 
        "2"]}]]}], ")"}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{{3.7980874218832693`*^9, 3.7980874747038755`*^9}, 
   3.7982819585508738`*^9, 3.7984285516780667`*^9, 3.798457614644718*^9, 
   3.7984601985300264`*^9, 3.7985630570634766`*^9, 3.7985633646182165`*^9, 
   3.7985636462638855`*^9, 3.798563919111271*^9, 3.7985640789937677`*^9, 
   3.7985731309440794`*^9, 3.798579542030421*^9, 3.798607088174103*^9, 
   3.798696005138028*^9, 3.798697586943334*^9, 3.798700033416976*^9, 
   3.798714249161934*^9, 3.798714294820896*^9, 3.798714329500921*^9, 
   3.7987144416005087`*^9, 3.798718549489596*^9, 3.798938913034809*^9, 
   3.7992329437224464`*^9, 3.79923580800137*^9, 3.7992382356251183`*^9, 
   3.7992387475800295`*^9, 3.800267628041179*^9, 3.800334265439455*^9, 
   3.8003348450778666`*^9, 3.8010159490708456`*^9, 3.8010162545631356`*^9, 
   3.801024070387746*^9, {3.801024647318526*^9, 3.8010246675971923`*^9}, 
   3.801025007454221*^9, 3.801033594587033*^9, 3.814783917569439*^9}]
}, Open  ]],

Cell["\<\
We end this by noting that the resulting equation is a Riccati equation which \
can be solved for the implicit solution at the de Sitter vacuum...\
\>", "Text",
 CellChangeTimes->{{3.79808748650747*^9, 3.7980875606258373`*^9}, {
  3.7980876496228647`*^9, 3.7980876531581945`*^9}, {3.8187636717370977`*^9, 
  3.8187637112593155`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[Phi]toy", "=", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "\[Equal]", 
          RowBox[{"q", "[", 
           FractionBox[
            SuperscriptBox[
             RowBox[{
              RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "2"], "2"], "]"}]}], 
         ",", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "'"}], "[", "t", "]"}], "\[Equal]", 
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"q", "[", 
             FractionBox[
              SuperscriptBox[
               RowBox[{
                RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "2"], "2"], "]"}], 
            ",", "t"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"q", "[", 
          FractionBox[
           SuperscriptBox[
            RowBox[{
             RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "2"], "2"], "]"}], ",", 
         RowBox[{
          RowBox[{"q", "'"}], "[", 
          FractionBox[
           SuperscriptBox[
            RowBox[{
             RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "2"], "2"], "]"}]}], 
        "}"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"riccati", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"y", "'"}], "[", "t", "]"}], "-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"y", "'"}], "[", "t", "]"}], "/.", 
       RowBox[{
        RowBox[{"Solve", "[", 
         RowBox[{
          RowBox[{"HeqTPwt", "/.", "\[Phi]toy"}], ",", 
          RowBox[{
           RowBox[{"y", "'"}], "[", "t", "]"}]}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ")"}]}], "\[Equal]", "0"}]}], ";", 
  "riccati"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\"\<\!\(\*
StyleBox[\"y\",
FontSlant->\"Italic\"]\)(\!\(\*
StyleBox[\"t\",
FontSlant->\"Italic\"]\))\>\"", "\[Equal]", 
   RowBox[{"y", "[", "t", "]"}]}], "/.", 
  RowBox[{
   RowBox[{"DSolve", "[", 
    RowBox[{"riccati", ",", "y", ",", "t"}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.79808756614465*^9, 3.798087585757531*^9}, {
   3.7980876180243673`*^9, 3.7980878176826215`*^9}, 3.8187637189005537`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"3", " ", "h", " ", 
    RowBox[{"y", "[", "t", "]"}]}], "+", 
   SuperscriptBox[
    RowBox[{"y", "[", "t", "]"}], "2"], "+", 
   RowBox[{
    SuperscriptBox["y", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{
  3.7980875876368537`*^9, 3.798087701873135*^9, {3.7980877335124516`*^9, 
   3.798087745327774*^9}, 3.7980877814714394`*^9, {3.798087815062197*^9, 
   3.79808781987031*^9}, 3.798281958590645*^9, 3.7984285517394896`*^9, 
   3.7984576146759615`*^9, 3.798460198547225*^9, 3.7985630571947274`*^9, 
   3.7985633646497684`*^9, 3.798563646299127*^9, 3.7985639191405077`*^9, 
   3.798564079035239*^9, 3.798573130971664*^9, 3.798579542099416*^9, 
   3.7986070881989393`*^9, 3.7986960051639585`*^9, 3.798697586966902*^9, 
   3.7987000334414415`*^9, 3.798714249197033*^9, 3.798714294837041*^9, 
   3.798714329516326*^9, 3.7987144416170673`*^9, 3.7987185495156565`*^9, 
   3.7989389130660515`*^9, 3.799232943747943*^9, 3.799235808021347*^9, 
   3.799238235650912*^9, 3.799238747605133*^9, 3.800267628075568*^9, 
   3.80033426556172*^9, 3.8003348451317477`*^9, 3.801015949102085*^9, 
   3.8010162545943794`*^9, 3.801024070415906*^9, {3.8010246473433123`*^9, 
   3.801024667623645*^9}, 3.8010250074772563`*^9, 3.8010335946097536`*^9, 
   3.814783917618348*^9, 3.81876372073003*^9}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*\\nStyleBox[\\\"y\\\",\\nFontSlant->\\\"Italic\\\"]\\)(\
\\!\\(\\*\\nStyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"]\\))\"\>", 
  "\[Equal]", 
  FractionBox[
   RowBox[{"3", " ", "h"}], 
   RowBox[{
    RowBox[{"-", "1"}], "+", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"3", " ", "h", " ", 
      RowBox[{"(", 
       RowBox[{"t", "-", 
        RowBox[{"C", "[", "1", "]"}]}], ")"}]}]]}]]}]], "Output",
 CellChangeTimes->{
  3.7980875876368537`*^9, 3.798087701873135*^9, {3.7980877335124516`*^9, 
   3.798087745327774*^9}, 3.7980877814714394`*^9, {3.798087815062197*^9, 
   3.79808781987031*^9}, 3.798281958590645*^9, 3.7984285517394896`*^9, 
   3.7984576146759615`*^9, 3.798460198547225*^9, 3.7985630571947274`*^9, 
   3.7985633646497684`*^9, 3.798563646299127*^9, 3.7985639191405077`*^9, 
   3.798564079035239*^9, 3.798573130971664*^9, 3.798579542099416*^9, 
   3.7986070881989393`*^9, 3.7986960051639585`*^9, 3.798697586966902*^9, 
   3.7987000334414415`*^9, 3.798714249197033*^9, 3.798714294837041*^9, 
   3.798714329516326*^9, 3.7987144416170673`*^9, 3.7987185495156565`*^9, 
   3.7989389130660515`*^9, 3.799232943747943*^9, 3.799235808021347*^9, 
   3.799238235650912*^9, 3.799238747605133*^9, 3.800267628075568*^9, 
   3.80033426556172*^9, 3.8003348451317477`*^9, 3.801015949102085*^9, 
   3.8010162545943794`*^9, 3.801024070415906*^9, {3.8010246473433123`*^9, 
   3.801024667623645*^9}, 3.8010250074772563`*^9, 3.8010335946097536`*^9, 
   3.814783917618348*^9, 3.8187637208691063`*^9}]
}, Open  ]],

Cell[TextData[{
 "These are Eqs. (3.17) and (3.18) in the text.\n\n",
 StyleBox["[No-tempering theorem]",
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0.5, 0.5]],
 "\n\nWe prove the no-tempering theorem for the tadpole-free theory, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"l", "=", "0"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", in the next few lines.\n\nWhen ",
 Cell[BoxData[
  FormBox[
   RowBox[{"l", "=", "0"}], TraditionalForm]]],
 ", it can be observed that ",
 StyleBox["HSeq2X",
  FontSlant->"Italic"],
 " reduces to..."
}], "Text",
 CellChangeTimes->{{3.7980878467023754`*^9, 3.7980880163466215`*^9}, {
  3.8187637488994856`*^9, 3.8187637889726553`*^9}, {3.8187638265385714`*^9, 
  3.818763868045848*^9}, {3.8187639192407317`*^9, 3.81876392222079*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"HSeq2X", "/.", 
  RowBox[{"l", "\[Rule]", "0"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"0", "\[Equal]", 
  RowBox[{
   SqrtBox["X"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", "h"}], "+", 
     RowBox[{"q", "[", "X", "]"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SqrtBox["2"], " ", 
      RowBox[{
       SuperscriptBox["A", "\[Prime]",
        MultilineFunction->None], "[", "X", "]"}]}], "+", 
     RowBox[{"6", " ", "h", " ", 
      SqrtBox["X"], " ", 
      RowBox[{
       SuperscriptBox["B", "\[Prime]",
        MultilineFunction->None], "[", "X", "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.818763929332553*^9}]
}, Open  ]],

Cell[TextData[{
 "This means that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"q", "(", "X", ")"}], "=", 
    RowBox[{
     RowBox[{"-", "3"}], "h"}]}], TraditionalForm]]],
 ". Imposing ",
 Cell[BoxData[
  FormBox[
   RowBox[{"l", "=", "0"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"q", "(", "X", ")"}], "=", 
    RowBox[{
     RowBox[{"-", "3"}], "h"}]}], TraditionalForm]]],
 " onto ",
 StyleBox["HSeq1X",
  FontSlant->"Italic"],
 " we obtain..."
}], "Text",
 CellChangeTimes->{
  3.8187639423033905`*^9, {3.8187640374356966`*^9, 3.8187640462614884`*^9}, {
   3.8187640897539287`*^9, 3.818764108221574*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"HSl0", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"HSeq1X", "/.", 
      RowBox[{"l", "\[Rule]", "0"}]}], "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"HSeq2X", "/.", 
         RowBox[{"l", "\[Rule]", "0"}]}], ",", 
        RowBox[{"q", "[", "X", "]"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "//", "Simplify"}]}], ";", 
  "HSl0"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox["A", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}], "+", 
   RowBox[{"9", " ", 
    SqrtBox["2"], " ", "h", " ", 
    SqrtBox["X"], " ", 
    RowBox[{
     SuperscriptBox["B", "\[Prime]",
      MultilineFunction->None], "[", "X", "]"}]}], "+", 
   RowBox[{"2", " ", "X", " ", 
    RowBox[{
     SuperscriptBox["A", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "X", "]"}]}], "+", 
   RowBox[{"6", " ", 
    SqrtBox["2"], " ", "h", " ", 
    SuperscriptBox["X", 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{
     SuperscriptBox["B", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "X", "]"}]}]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{3.818764119875284*^9}]
}, Open  ]],

Cell["The solution to this is given by...", "Text",
 CellChangeTimes->{{3.8187641325457616`*^9, 3.8187641370232425`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"BOfAl0", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"DSolve", "[", 
       RowBox[{"HSl0", ",", "B", ",", "X"}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"C", "[", "1", "]"}], "\[Rule]", "\[Alpha]"}], ",", 
       RowBox[{
        RowBox[{"C", "[", "2", "]"}], "\[Rule]", "\[Beta]"}]}], "}"}]}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<B[A(X)]\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"B", "[", "X", "]"}], "/.", "BOfAl0"}], "//", "Expand"}], 
   ")"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"\<\"B[A(X)]\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"2", " ", "\[Alpha]"}], 
     SqrtBox["X"]]}], "+", "\[Beta]", "-", 
   FractionBox[
    RowBox[{"A", "[", "X", "]"}], 
    RowBox[{"3", " ", 
     SqrtBox["2"], " ", "h", " ", 
     SqrtBox["X"]}]]}]}]], "Output",
 CellChangeTimes->{3.818764147227584*^9}]
}, Open  ]],

Cell[TextData[{
 "This functional (Eq. (3.21)) singles out theories with ",
 Cell[BoxData[
  FormBox[
   RowBox[{"l", "=", "0"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " in which the Hubble and scalar field equation become degenerate in the \
state ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"H", "(", "t", ")"}], "=", "h"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ". To check if this is correct, let us put it back into the field equations \
on-shell..."
}], "Text",
 CellChangeTimes->{{3.8187641532768764`*^9, 3.8187641990843773`*^9}, {
  3.8187642395271034`*^9, 3.8187642443377047`*^9}, {3.818764324797758*^9, 
  3.8187643278681164`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"HSeq1X", "/.", 
     RowBox[{"l", "\[Rule]", "0"}]}], "/.", 
    RowBox[{
     RowBox[{"q", "[", "X", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", "3"}], "h"}]}]}], "/.", "BOfAl0"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"HSeq2X", "/.", 
     RowBox[{"l", "\[Rule]", "0"}]}], "/.", 
    RowBox[{
     RowBox[{"q", "[", "X", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", "3"}], "h"}]}]}], "/.", "BOfAl0"}], "//", 
  "Simplify"}]}], "Input"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.8187642756566305`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.8187642756595774`*^9}]
}, Open  ]],

Cell["Evaluating the field equations on-shell...", "Text",
 CellChangeTimes->{
  3.8187643099956727`*^9, {3.818764342581221*^9, 3.818764356737118*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"FeqTPdswtl0", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"FeqTPdsvac", "/.", 
        RowBox[{"l", "\[Rule]", "0"}]}], "/.", "\[Phi]tox"}], "/.", 
      "BOfAl0"}], "//", "Simplify"}], "//", "Expand"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"HeqTPdswtl0", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"HeqTPdsvac", "/.", 
        RowBox[{"l", "\[Rule]", "0"}]}], "/.", "\[Phi]tox"}], "/.", 
      "BOfAl0"}], "//", "Simplify"}], "//", "Expand"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SeqTPdswtl0", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"SeqTPdsvac", "/.", 
         RowBox[{"l", "\[Rule]", "0"}]}], "/.", "\[Phi]tox"}], "/.", 
       "BOfAl0"}], "//", "Simplify"}], "//", "Expand"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "HeqTPdswtl0", "\
\[IndentingNewLine]", "SeqTPdswtl0"}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"36", " ", 
    SqrtBox["2"], " ", "h", " ", "\[Alpha]"}], "+", 
   RowBox[{"6", " ", 
    RowBox[{"A", "[", 
     RowBox[{"X", "[", "t", "]"}], "]"}]}], "-", 
   FractionBox[
    RowBox[{"6", " ", 
     SqrtBox["2"], " ", "\[Alpha]", " ", 
     RowBox[{
      SuperscriptBox["X", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], 
    RowBox[{"X", "[", "t", "]"}]], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"A", "[", 
      RowBox[{"X", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["X", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], 
    RowBox[{"h", " ", 
     RowBox[{"X", "[", "t", "]"}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     RowBox[{
      SuperscriptBox["A", "\[Prime]",
       MultilineFunction->None], "[", 
      RowBox[{"X", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["X", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "h"]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{3.818764372205293*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"72", " ", 
    SuperscriptBox["h", "2"], " ", "\[Alpha]", " ", 
    SqrtBox[
     RowBox[{"X", "[", "t", "]"}]]}], "+", 
   RowBox[{"6", " ", 
    SqrtBox["2"], " ", "h", " ", 
    RowBox[{"A", "[", 
     RowBox[{"X", "[", "t", "]"}], "]"}], " ", 
    SqrtBox[
     RowBox[{"X", "[", "t", "]"}]]}], "-", 
   FractionBox[
    RowBox[{"12", " ", "h", " ", "\[Alpha]", " ", 
     RowBox[{
      SuperscriptBox["X", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], 
    SqrtBox[
     RowBox[{"X", "[", "t", "]"}]]], "-", 
   FractionBox[
    RowBox[{
     SqrtBox["2"], " ", 
     RowBox[{"A", "[", 
      RowBox[{"X", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["X", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], 
    SqrtBox[
     RowBox[{"X", "[", "t", "]"}]]], "+", 
   RowBox[{"2", " ", 
    SqrtBox["2"], " ", 
    SqrtBox[
     RowBox[{"X", "[", "t", "]"}]], " ", 
    RowBox[{
     SuperscriptBox["A", "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{"X", "[", "t", "]"}], "]"}], " ", 
    RowBox[{
     SuperscriptBox["X", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{3.8187643722177176`*^9}]
}, Open  ]],

Cell["\<\
...confirms the degeneracy of the Hubble and scalar field equations...\
\>", "Text",
 CellChangeTimes->{{3.8187643929894376`*^9, 3.8187644041849546`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"HeqTPdswtl0", "/.", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{"SeqTPdswtl0", ",", 
      RowBox[{
       RowBox[{"X", "'"}], "[", "t", "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], "//", "Simplify"}]], "Input"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.8187644108473167`*^9}]
}, Open  ]],

Cell["However, the Friedmann constraint becomes...", "Text",
 CellChangeTimes->{3.81876442283982*^9}],

Cell[CellGroupData[{

Cell[BoxData["FeqTPdswtl0"], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"3", " ", 
   SuperscriptBox["h", "2"]}], "\[Equal]", 
  RowBox[{
   RowBox[{"6", " ", 
    SqrtBox["2"], " ", "h", " ", "\[Alpha]"}], "+", 
   "\[Rho]\[CapitalLambda]"}]}]], "Output",
 CellChangeTimes->{3.818764432357335*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["This means that ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Rho]", "\[CapitalLambda]"], TraditionalForm]]],
 " ",
 StyleBox["isn\[CloseCurlyQuote]t being dynamically cancelled on the \
self-tuning vacuum but rather is instead tuned by a mass scale ",
  FontSlant->"Italic"],
 "\[Alpha], ",
 StyleBox["i.e. no well-tempering",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{
  3.818764457814714*^9, {3.818764488821078*^9, 3.818764577730652*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["3.2 Self-tuning KGB: a nontrivial tadpole-free limit", "Subsubsection",
 CellChangeTimes->{{3.7980825068185434`*^9, 3.798082512673235*^9}, {
  3.8187646570248003`*^9, 3.818764667652672*^9}}],

Cell["\<\
We obtain the self-tuning subclass of tadpole-free shift symmetric KGB. Back \
at the field equations after taking the de Sitter limit...\
\>", "Text",
 CellChangeTimes->{{3.7980885543682833`*^9, 3.798088680829067*^9}, {
  3.818764708890627*^9, 3.8187647473320813`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{"FeqTPds", "\[IndentingNewLine]", "HeqTPds", "\
\[IndentingNewLine]", "SeqTPds"}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Rho]", "[", "t", "]"}], "+", 
   RowBox[{
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["A", "\[Prime]",
        MultilineFunction->None], "[", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Phi]", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], "+", 
      RowBox[{"3", " ", "h", " ", 
       RowBox[{
        SuperscriptBox["B", "\[Prime]",
         MultilineFunction->None], "[", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Phi]", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], "\[Equal]", 
  RowBox[{
   RowBox[{"3", " ", 
    SuperscriptBox["h", "2"]}], "+", 
   RowBox[{"A", "[", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], "+", 
   RowBox[{"l", " ", 
    RowBox[{"\[Phi]", "[", "t", "]"}]}]}]}]], "Output",
 CellChangeTimes->{
  3.798088648941949*^9, 3.7982819687366467`*^9, 3.7984285551657963`*^9, 
   3.798457614776204*^9, 3.7984602020195265`*^9, 3.7985630575174417`*^9, 
   3.7985633647410736`*^9, 3.798563649093182*^9, 3.798563920536728*^9, 
   3.798564079124257*^9, 3.798573131054165*^9, 3.798579542215274*^9, 
   3.798607088549161*^9, 3.7986960169487457`*^9, 3.798697593733897*^9, {
   3.798700035191065*^9, 3.7987000425109577`*^9}, 3.798714249263818*^9, 
   3.7987142975996866`*^9, 3.798714331769555*^9, 3.798714443674449*^9, 
   3.7987185516601195`*^9, 3.798938913206649*^9, 3.799232943953086*^9, 
   3.799235808092445*^9, 3.7992382373798475`*^9, 3.799238747699073*^9, 
   3.8002676312740517`*^9, 3.800334847380732*^9, 3.8010160215472155`*^9, 
   3.8010162592807803`*^9, {3.801024647434139*^9, 3.8010246677078905`*^9}, 
   3.8010250075569067`*^9, 3.801033594715981*^9, 3.814783921903886*^9, 
   3.818764749074782*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Rho]", "[", "t", "]"}], "+", 
   RowBox[{"w", " ", 
    RowBox[{"\[Rho]", "[", "t", "]"}]}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox["A", "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
   RowBox[{"3", " ", "h", " ", 
    RowBox[{
     SuperscriptBox["B", "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
   RowBox[{
    RowBox[{
     SuperscriptBox["B", "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{
  3.798088648941949*^9, 3.7982819687366467`*^9, 3.7984285551657963`*^9, 
   3.798457614776204*^9, 3.7984602020195265`*^9, 3.7985630575174417`*^9, 
   3.7985633647410736`*^9, 3.798563649093182*^9, 3.798563920536728*^9, 
   3.798564079124257*^9, 3.798573131054165*^9, 3.798579542215274*^9, 
   3.798607088549161*^9, 3.7986960169487457`*^9, 3.798697593733897*^9, {
   3.798700035191065*^9, 3.7987000425109577`*^9}, 3.798714249263818*^9, 
   3.7987142975996866`*^9, 3.798714331769555*^9, 3.798714443674449*^9, 
   3.7987185516601195`*^9, 3.798938913206649*^9, 3.799232943953086*^9, 
   3.799235808092445*^9, 3.7992382373798475`*^9, 3.799238747699073*^9, 
   3.8002676312740517`*^9, 3.800334847380732*^9, 3.8010160215472155`*^9, 
   3.8010162592807803`*^9, {3.801024647434139*^9, 3.8010246677078905`*^9}, 
   3.8010250075569067`*^9, 3.801033594715981*^9, 3.814783921903886*^9, 
   3.818764749086831*^9}],

Cell[BoxData[
 RowBox[{"l", "\[Equal]", 
  RowBox[{
   RowBox[{"9", " ", 
    SuperscriptBox["h", "2"], " ", 
    RowBox[{
     SuperscriptBox["B", "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox["A", "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SuperscriptBox["A", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}], "+", 
   RowBox[{"3", " ", "h", " ", 
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["A", "\[Prime]",
        MultilineFunction->None], "[", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Phi]", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{
           SuperscriptBox["B", "\[Prime]",
            MultilineFunction->None], "[", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Phi]", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}]}], 
         "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox["B", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Phi]", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}]}]}], 
        ")"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{
  3.798088648941949*^9, 3.7982819687366467`*^9, 3.7984285551657963`*^9, 
   3.798457614776204*^9, 3.7984602020195265`*^9, 3.7985630575174417`*^9, 
   3.7985633647410736`*^9, 3.798563649093182*^9, 3.798563920536728*^9, 
   3.798564079124257*^9, 3.798573131054165*^9, 3.798579542215274*^9, 
   3.798607088549161*^9, 3.7986960169487457`*^9, 3.798697593733897*^9, {
   3.798700035191065*^9, 3.7987000425109577`*^9}, 3.798714249263818*^9, 
   3.7987142975996866`*^9, 3.798714331769555*^9, 3.798714443674449*^9, 
   3.7987185516601195`*^9, 3.798938913206649*^9, 3.799232943953086*^9, 
   3.799235808092445*^9, 3.7992382373798475`*^9, 3.799238747699073*^9, 
   3.8002676312740517`*^9, 3.800334847380732*^9, 3.8010160215472155`*^9, 
   3.8010162592807803`*^9, {3.801024647434139*^9, 3.8010246677078905`*^9}, 
   3.8010250075569067`*^9, 3.801033594715981*^9, 3.814783921903886*^9, 
   3.8187647490974236`*^9}]
}, Open  ]],

Cell[TextData[{
 "The self-tuning subclass can be obtained by solving the theory space where \
the scalar field equation becomes trivially satisfied ",
 Cell[BoxData[
  FormBox[
   RowBox[{"H", "=", "h"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ". To achieve this, we first use the kinetic density ",
 Cell[BoxData[
  FormBox["X", TraditionalForm]]],
 " as a variable in the scalar field equation... "
}], "Text",
 CellChangeTimes->{{3.7980886950827765`*^9, 3.7980887873959875`*^9}, {
  3.81876475631896*^9, 3.818764785605812*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SeqTPdsX", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"SeqTPds", "/.", "\[Phi]tox"}], "/.", 
     RowBox[{
      RowBox[{"X", "[", "t", "]"}], "\[Rule]", "X"}]}], "//", "Simplify"}]}], 
  ";", "SeqTPdsX"}]], "Input",
 CellChangeTimes->{{3.79808877506271*^9, 3.7980887812703986`*^9}, {
  3.798088811759617*^9, 3.798088839392263*^9}}],

Cell[BoxData[
 RowBox[{"l", "\[Equal]", 
  RowBox[{
   RowBox[{"6", " ", "h", " ", 
    RowBox[{
     SuperscriptBox["B", "\[Prime]",
      MultilineFunction->None], "[", "X", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", "h", " ", "X"}], "+", 
      RowBox[{
       SuperscriptBox["X", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}], ")"}]}], "+", 
   FractionBox[
    RowBox[{
     RowBox[{
      SuperscriptBox["A", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"6", " ", "h", " ", "X"}], "+", 
       RowBox[{
        SuperscriptBox["X", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], ")"}]}], 
    RowBox[{
     SqrtBox["2"], " ", 
     SqrtBox["X"]}]], "+", 
   RowBox[{
    SqrtBox["2"], " ", 
    SqrtBox["X"], " ", 
    RowBox[{
     SuperscriptBox["X", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{
     SuperscriptBox["A", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "X", "]"}]}], "+", 
   RowBox[{"6", " ", "h", " ", "X", " ", 
    RowBox[{
     SuperscriptBox["X", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{
     SuperscriptBox["B", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "X", "]"}]}]}]}]], "Output",
 CellChangeTimes->{
  3.798088839687945*^9, 3.7982819716414986`*^9, 3.7984285555263433`*^9, 
   3.7984576149610624`*^9, 3.7984602023559947`*^9, 3.79856305787823*^9, 
   3.7985633649254274`*^9, 3.798563649344978*^9, 3.798563920805599*^9, 
   3.7985640793480844`*^9, 3.798573131246235*^9, 3.798579542400158*^9, 
   3.7986070888200855`*^9, 3.798696017372403*^9, 3.798697594403518*^9, 
   3.798700043123728*^9, 3.7987142494716263`*^9, 3.7987142980777664`*^9, 
   3.7987143321377525`*^9, 3.798714443949809*^9, 3.7987185520869308`*^9, 
   3.798938913378477*^9, 3.7992329444019136`*^9, 3.7992358082990847`*^9, 
   3.7992382422784214`*^9, 3.7992387478927794`*^9, 3.8002676315401545`*^9, 
   3.8003348476243505`*^9, 3.801016021765876*^9, 3.801016259530718*^9, 
   3.801024215857394*^9, {3.8010246476154575`*^9, 3.801024667895734*^9}, 
   3.801025007773711*^9, 3.801033594912644*^9, 3.8147839221402197`*^9, 
   3.8187647946398773`*^9}]
}, Open  ]],

Cell[TextData[{
 "This is Eq. (3.24) and turns out to be a first-order ODE for the variable ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"A", "'"}], 
     RowBox[{"(", "X", ")"}]}], "+", 
    RowBox[{"3", "h", 
     SqrtBox[
      RowBox[{"2", "X"}]], 
     RowBox[{"B", "'"}], 
     RowBox[{"(", "X", ")"}]}]}], TraditionalForm]]],
 ". The exact solution is given by Eq. (3.25)..."
}], "Text",
 CellChangeTimes->{{3.798088843911759*^9, 3.7980888861423273`*^9}, 
   3.798089018056126*^9, {3.8187648074935155`*^9, 3.818764876172425*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"selftune", "=", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"A", "'"}], "[", "X", "]"}], "+", 
           RowBox[{"3", "h", 
            SqrtBox[
             RowBox[{"2", "X"}]], 
            RowBox[{
             RowBox[{"B", "'"}], "[", "X", "]"}]}]}], "\[Equal]", 
          FractionBox["l", 
           RowBox[{"3", "h", 
            SqrtBox[
             RowBox[{"2", "X"}]]}]]}], ",", 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"A", "'"}], "[", "X", "]"}], "+", 
             RowBox[{"3", "h", 
              SqrtBox[
               RowBox[{"2", "X"}]], 
              RowBox[{
               RowBox[{"B", "'"}], "[", "X", "]"}]}]}], "\[Equal]", 
            FractionBox["l", 
             RowBox[{"3", "h", 
              SqrtBox[
               RowBox[{"2", "X"}]]}]]}], ",", "X"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"B", "'"}], "[", "X", "]"}], ",", 
         RowBox[{
          RowBox[{"B", "''"}], "[", "X", "]"}]}], "}"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SeqTPdsX", "/.", "selftune"}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.798088893936782*^9, 3.79808890141894*^9}, {
   3.7980889373662767`*^9, 3.798089012063265*^9}, {3.79808909135277*^9, 
   3.7980891032317867`*^9}, {3.798089138887582*^9, 3.798089150156111*^9}, 
   3.8187648513550453`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.798089140613659*^9, 3.798089150478662*^9}, 
   3.798281973396719*^9, 3.7984285555996423`*^9, 3.7984576149989915`*^9, 
   3.798460202398065*^9, 3.798563057948176*^9, 3.7985633649524946`*^9, 
   3.7985636493908143`*^9, 3.7985639208443007`*^9, 3.7985640794090357`*^9, 
   3.7985731312692976`*^9, 3.7985795424626455`*^9, 3.798607088905201*^9, 
   3.798696017448577*^9, 3.798697594440029*^9, 3.798700043157634*^9, 
   3.798714249625058*^9, 3.798714298168206*^9, 3.7987143322277884`*^9, 
   3.7987144439907866`*^9, 3.7987185521585197`*^9, 3.798938913425352*^9, 
   3.7992329444675245`*^9, 3.7992358083311853`*^9, 3.7992382460874233`*^9, 
   3.7992387479173775`*^9, 3.8002676315833616`*^9, 3.8003348476935043`*^9, 
   3.801016021875222*^9, 3.801016259561969*^9, 3.801024218111488*^9, {
   3.8010246476364746`*^9, 3.8010246679165955`*^9}, 3.80102500780686*^9, 
   3.8010335949481277`*^9, 3.814783922201058*^9, 3.818764822931342*^9, 
   3.8187648533406973`*^9}]
}, Open  ]],

Cell[TextData[{
 "The above calculation confirms that the scalar field equation is satisfied \
on-shell. Putting the solution back into the field equations at de Sitter \
state ",
 Cell[BoxData[
  FormBox[
   RowBox[{"H", "=", "h"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", we obtain Eqs. (3.27) and (3.28)..."
}], "Text",
 CellChangeTimes->{{3.798089022714587*^9, 3.7980891802258396`*^9}, {
  3.8187648472991366`*^9, 3.818764847882907*^9}, {3.818764880963909*^9, 
  3.8187648976963167`*^9}, {3.8187649295571647`*^9, 3.818764941398836*^9}, {
  3.8187649737144966`*^9, 3.8187649835587163`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"st", "=", 
    RowBox[{"selftune", "/.", 
     RowBox[{"X", "\[Rule]", 
      FractionBox[
       SuperscriptBox[
        RowBox[{
         RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "2"], "2"]}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FeqTPst", "=", 
   RowBox[{
    RowBox[{"FeqTPds", "/.", "st"}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"HeqTPst", "=", 
   RowBox[{
    RowBox[{"HeqTPds", "/.", "st"}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SeqTPst", "=", 
    RowBox[{
     RowBox[{"SeqTPds", "/.", "st"}], "//", "Simplify"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "FeqTPst", "\
\[IndentingNewLine]", "HeqTPst", "\[IndentingNewLine]", "SeqTPst"}], "Input",
 CellChangeTimes->{{3.798089085194346*^9, 3.7980890861932135`*^9}, {
  3.7980891834193335`*^9, 3.7980892209787645`*^9}, {3.7980892607678847`*^9, 
  3.798089299105559*^9}, {3.8187649993790407`*^9, 3.8187650017299213`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Rho]", "[", "t", "]"}], "+", 
   FractionBox[
    RowBox[{"l", " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], 
    RowBox[{"3", " ", "h"}]]}], "\[Equal]", 
  RowBox[{
   RowBox[{"3", " ", 
    SuperscriptBox["h", "2"]}], "+", 
   RowBox[{"A", "[", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], "+", 
   RowBox[{"l", " ", 
    RowBox[{"\[Phi]", "[", "t", "]"}]}]}]}]], "Output",
 CellChangeTimes->{
  3.798089299632161*^9, 3.798281977325447*^9, 3.7984285557299447`*^9, 
   3.798457615083434*^9, 3.79846020248622*^9, 3.7985630581384544`*^9, 
   3.7985633650306697`*^9, 3.798563649480338*^9, 3.7985639209346066`*^9, 
   3.798564079526003*^9, 3.7985731313522425`*^9, 3.7985795425472636`*^9, 
   3.7986070891846895`*^9, 3.7986960175803967`*^9, 3.798697594532775*^9, 
   3.7987000432916913`*^9, 3.798714249746979*^9, 3.7987142982781935`*^9, 
   3.7987143323932667`*^9, 3.798714444083247*^9, 3.798718552299406*^9, 
   3.798938913519069*^9, 3.7992329445852833`*^9, 3.799235808420212*^9, 
   3.799238270336275*^9, 3.7992387480032477`*^9, 3.8002676317257524`*^9, 
   3.800334847798006*^9, 3.801016021968951*^9, 3.8010162596556883`*^9, 
   3.8010242209573393`*^9, {3.8010246477129726`*^9, 3.8010246680149093`*^9}, 
   3.8010250078842077`*^9, 3.8010335950273533`*^9, 3.8147839222878585`*^9, 
   3.818764955772485*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"9", " ", 
     SuperscriptBox["h", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "w"}], ")"}], " ", 
     RowBox[{"\[Rho]", "[", "t", "]"}]}], "-", 
    RowBox[{"l", " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"3", " ", "h", " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{"l", "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox["A", "\[Prime]",
          MultilineFunction->None], "[", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], "h"], 
  "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{
  3.798089299632161*^9, 3.798281977325447*^9, 3.7984285557299447`*^9, 
   3.798457615083434*^9, 3.79846020248622*^9, 3.7985630581384544`*^9, 
   3.7985633650306697`*^9, 3.798563649480338*^9, 3.7985639209346066`*^9, 
   3.798564079526003*^9, 3.7985731313522425`*^9, 3.7985795425472636`*^9, 
   3.7986070891846895`*^9, 3.7986960175803967`*^9, 3.798697594532775*^9, 
   3.7987000432916913`*^9, 3.798714249746979*^9, 3.7987142982781935`*^9, 
   3.7987143323932667`*^9, 3.798714444083247*^9, 3.798718552299406*^9, 
   3.798938913519069*^9, 3.7992329445852833`*^9, 3.799235808420212*^9, 
   3.799238270336275*^9, 3.7992387480032477`*^9, 3.8002676317257524`*^9, 
   3.800334847798006*^9, 3.801016021968951*^9, 3.8010162596556883`*^9, 
   3.8010242209573393`*^9, {3.8010246477129726`*^9, 3.8010246680149093`*^9}, 
   3.8010250078842077`*^9, 3.8010335950273533`*^9, 3.8147839222878585`*^9, 
   3.8187649557802563`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.798089299632161*^9, 3.798281977325447*^9, 3.7984285557299447`*^9, 
   3.798457615083434*^9, 3.79846020248622*^9, 3.7985630581384544`*^9, 
   3.7985633650306697`*^9, 3.798563649480338*^9, 3.7985639209346066`*^9, 
   3.798564079526003*^9, 3.7985731313522425`*^9, 3.7985795425472636`*^9, 
   3.7986070891846895`*^9, 3.7986960175803967`*^9, 3.798697594532775*^9, 
   3.7987000432916913`*^9, 3.798714249746979*^9, 3.7987142982781935`*^9, 
   3.7987143323932667`*^9, 3.798714444083247*^9, 3.798718552299406*^9, 
   3.798938913519069*^9, 3.7992329445852833`*^9, 3.799235808420212*^9, 
   3.799238270336275*^9, 3.7992387480032477`*^9, 3.8002676317257524`*^9, 
   3.800334847798006*^9, 3.801016021968951*^9, 3.8010162596556883`*^9, 
   3.8010242209573393`*^9, {3.8010246477129726`*^9, 3.8010246680149093`*^9}, 
   3.8010250078842077`*^9, 3.8010335950273533`*^9, 3.8147839222878585`*^9, 
   3.8187649557838*^9}]
}, Open  ]],

Cell["\<\
The Friedmann constraint will be consistent with the Hubble equation as long \
as...\
\>", "Text",
 CellChangeTimes->{{3.798089328962716*^9, 3.7980893488747177`*^9}, {
  3.8187650341019726`*^9, 3.8187650437766113`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"firstlaw", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{"FeqTPst", ",", "t"}], "]"}], "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{"HeqTPst", ",", 
        RowBox[{
         RowBox[{"\[Phi]", "''"}], "[", "t", "]"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", "firstlaw"}], "Input",
 CellChangeTimes->{{3.7980893502764206`*^9, 3.7980893878459697`*^9}, {
  3.7980901523624167`*^9, 3.7980901599594584`*^9}, {3.818765025649384*^9, 
  3.8187650312534366`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"3", " ", "h", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "w"}], ")"}], " ", 
    RowBox[{"\[Rho]", "[", "t", "]"}]}], "+", 
   RowBox[{
    SuperscriptBox["\[Rho]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{{3.798089384504105*^9, 3.7980893882146273`*^9}, 
   3.7980901606358747`*^9, 3.7982819807669907`*^9, 3.79842855581424*^9, 
   3.798457615130312*^9, 3.7984602025471587`*^9, 3.7985630581978083`*^9, 
   3.798563365087556*^9, 3.798563649545352*^9, 3.7985639209967732`*^9, 
   3.79856407963503*^9, 3.798573131413017*^9, 3.798579542600672*^9, 
   3.798607089512225*^9, 3.798696017637532*^9, 3.7986975945943336`*^9, 
   3.7987000433865*^9, 3.7987142499118147`*^9, 3.7987142983642964`*^9, 
   3.7987143324520054`*^9, 3.7987144441425695`*^9, 3.7987185524089413`*^9, 
   3.798938913565945*^9, 3.7992329447311964`*^9, 3.7992358084753838`*^9, 
   3.799238273319111*^9, 3.799238748063713*^9, 3.8002676317909203`*^9, 
   3.800334847863067*^9, 3.801016022031436*^9, 3.8010162597025547`*^9, 
   3.8010242234407673`*^9, {3.8010246477717113`*^9, 3.8010246681040015`*^9}, 
   3.8010250079413643`*^9, 3.8010335950840993`*^9, 3.814783922350665*^9, 
   3.8187650485325165`*^9}]
}, Open  ]],

Cell[TextData[{
 "This is expected and for this reason the ",
 StyleBox["trivial scalar",
  FontSlant->"Italic"],
 " self-tuning unavoidably screens all forms of energy. Nonetheless, this can \
be implemented in the tadpole-free theory.\n\nThe simplified field equations \
of the self-tuned shift symmetric KGB are..."
}], "Text",
 CellChangeTimes->{{3.798089401585076*^9, 3.798089574280279*^9}, {
  3.7986976153473563`*^9, 3.7986976438751273`*^9}, {3.818765057773326*^9, 
  3.818765072417474*^9}, {3.8187651043100576`*^9, 3.8187651170549107`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"FeqTPST", "=", 
   RowBox[{
    RowBox[{"FeqTP", "/.", "st"}], "//", "FullSimplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"HeqTPST", "=", 
   RowBox[{
    RowBox[{"HeqTP", "/.", "st"}], "//", "FullSimplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SeqTPST", "=", 
    RowBox[{
     RowBox[{"SeqTP", "/.", "st"}], "//", "FullSimplify"}]}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"pressure", " ", "equation"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FE2TPST", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"2", 
       RowBox[{
        RowBox[{"H", "'"}], "[", "t", "]"}]}], "+", 
      RowBox[{"3", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"]}]}], "\[Equal]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"2", 
           RowBox[{
            RowBox[{"H", "'"}], "[", "t", "]"}]}], "+", 
          RowBox[{"3", 
           SuperscriptBox[
            RowBox[{"H", "[", "t", "]"}], "2"]}]}], "/.", 
         RowBox[{
          RowBox[{"Solve", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"FE2H", "/.", 
                RowBox[{"\[Phi]0", "\[Rule]", 
                 RowBox[{"Function", "[", 
                  RowBox[{"t", ",", 
                   RowBox[{"\[Phi]", "[", "t", "]"}]}], "]"}]}]}], "/.", 
               "tadpole"}], "/.", "st"}], "//", "FullSimplify"}], ",", 
            RowBox[{
             RowBox[{"H", "'"}], "[", "t", "]"}]}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "//", "FullSimplify"}], "//", 
       "Expand"}], ")"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "FeqTPST", "\
\[IndentingNewLine]", "HeqTPST", "\[IndentingNewLine]", "SeqTPST"}], "Input",
 CellChangeTimes->{{3.7980896171793323`*^9, 3.7980896816039143`*^9}, {
  3.79923818646266*^9, 3.79923821451241*^9}, {3.7992382778297215`*^9, 
  3.799238299438672*^9}, {3.799238584985837*^9, 3.799238591276881*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Rho]", "[", "t", "]"}], "+", 
   FractionBox[
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"l", " ", 
        RowBox[{"H", "[", "t", "]"}]}], "+", 
       RowBox[{"3", " ", "h", " ", 
        RowBox[{"(", 
         RowBox[{"h", "-", 
          RowBox[{"H", "[", "t", "]"}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["A", "\[Prime]",
          MultilineFunction->None], "[", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], 
    RowBox[{"3", " ", 
     SuperscriptBox["h", "2"]}]]}], "\[Equal]", 
  RowBox[{
   RowBox[{"A", "[", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], "+", 
   RowBox[{"3", " ", 
    SuperscriptBox[
     RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
   RowBox[{"l", " ", 
    RowBox[{"\[Phi]", "[", "t", "]"}]}]}]}]], "Output",
 CellChangeTimes->{{3.7980896635379906`*^9, 3.7980896838141212`*^9}, 
   3.798281992834278*^9, 3.7984285575969152`*^9, 3.79845761678786*^9, 
   3.798460145327275*^9, 3.7984602043525567`*^9, 3.798563060084984*^9, 
   3.798563367599119*^9, 3.7985636519701614`*^9, 3.7985639230413013`*^9, 
   3.7985640816949863`*^9, 3.7985731337059083`*^9, 3.7985795441825686`*^9, 
   3.7986070913813963`*^9, 3.7986960194134865`*^9, 3.7986975963777237`*^9, 
   3.798700045401245*^9, 3.7987142518125973`*^9, 3.798714300170134*^9, 
   3.798714334336669*^9, 3.798714446014778*^9, 3.798718554474597*^9, 
   3.7989389151749315`*^9, 3.7992329466016836`*^9, 3.7992358103242884`*^9, 
   3.799238595708516*^9, 3.7992387502495985`*^9, 3.8002676342722154`*^9, 
   3.8003348505038357`*^9, 3.801016024077832*^9, 3.8010162617489777`*^9, 
   3.8010242625062513`*^9, {3.801024649936338*^9, 3.801024670197665*^9}, 
   3.801025009998913*^9, 3.8010335972677836`*^9, 3.8147839246186314`*^9, 
   3.818765131358324*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"P", "[", "t", "]"}], "+", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"9", " ", 
      SuperscriptBox["h", "2"]}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"l", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          RowBox[{"H", "[", "t", "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Phi]", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "-", 
         RowBox[{
          SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], ")"}]}], "+", 
      RowBox[{"3", " ", "h", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "h", " ", 
          RowBox[{"\[Rho]", "[", "t", "]"}]}], "+", 
         RowBox[{"6", " ", "h", " ", 
          RowBox[{
           SuperscriptBox["H", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox["A", "\[Prime]",
            MultilineFunction->None], "[", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Phi]", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Phi]", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{"h", "-", 
               RowBox[{"H", "[", "t", "]"}]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["\[Phi]", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}], ")"}]}]}], 
        ")"}]}]}], ")"}]}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{{3.7980896635379906`*^9, 3.7980896838141212`*^9}, 
   3.798281992834278*^9, 3.7984285575969152`*^9, 3.79845761678786*^9, 
   3.798460145327275*^9, 3.7984602043525567`*^9, 3.798563060084984*^9, 
   3.798563367599119*^9, 3.7985636519701614`*^9, 3.7985639230413013`*^9, 
   3.7985640816949863`*^9, 3.7985731337059083`*^9, 3.7985795441825686`*^9, 
   3.7986070913813963`*^9, 3.7986960194134865`*^9, 3.7986975963777237`*^9, 
   3.798700045401245*^9, 3.7987142518125973`*^9, 3.798714300170134*^9, 
   3.798714334336669*^9, 3.798714446014778*^9, 3.798718554474597*^9, 
   3.7989389151749315`*^9, 3.7992329466016836`*^9, 3.7992358103242884`*^9, 
   3.799238595708516*^9, 3.7992387502495985`*^9, 3.8002676342722154`*^9, 
   3.8003348505038357`*^9, 3.801016024077832*^9, 3.8010162617489777`*^9, 
   3.8010242625062513`*^9, {3.801024649936338*^9, 3.801024670197665*^9}, 
   3.801025009998913*^9, 3.8010335972677836`*^9, 3.8147839246186314`*^9, 
   3.818765131366724*^9}],

Cell[BoxData[
 RowBox[{"l", "\[Equal]", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"3", " ", 
     SuperscriptBox["h", "2"]}]], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", "l", " ", 
      SuperscriptBox[
       RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
     RowBox[{"l", " ", 
      RowBox[{
       SuperscriptBox["H", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}], "+", 
     RowBox[{"9", " ", 
      SuperscriptBox["h", "2"], " ", 
      RowBox[{"H", "[", "t", "]"}], " ", 
      RowBox[{
       SuperscriptBox["A", "\[Prime]",
        MultilineFunction->None], "[", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Phi]", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}], "-", 
     RowBox[{"9", " ", "h", " ", 
      SuperscriptBox[
       RowBox[{"H", "[", "t", "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox["A", "\[Prime]",
        MultilineFunction->None], "[", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Phi]", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}], "-", 
     RowBox[{"3", " ", "h", " ", 
      RowBox[{
       SuperscriptBox["A", "\[Prime]",
        MultilineFunction->None], "[", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Phi]", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["H", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}], "+", 
     RowBox[{"3", " ", "h", " ", 
      RowBox[{"(", 
       RowBox[{"h", "-", 
        RowBox[{"H", "[", "t", "]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["A", "\[Prime]",
          MultilineFunction->None], "[", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Phi]", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox["A", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}]}]}], 
       ")"}], " ", 
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.7980896635379906`*^9, 3.7980896838141212`*^9}, 
   3.798281992834278*^9, 3.7984285575969152`*^9, 3.79845761678786*^9, 
   3.798460145327275*^9, 3.7984602043525567`*^9, 3.798563060084984*^9, 
   3.798563367599119*^9, 3.7985636519701614`*^9, 3.7985639230413013`*^9, 
   3.7985640816949863`*^9, 3.7985731337059083`*^9, 3.7985795441825686`*^9, 
   3.7986070913813963`*^9, 3.7986960194134865`*^9, 3.7986975963777237`*^9, 
   3.798700045401245*^9, 3.7987142518125973`*^9, 3.798714300170134*^9, 
   3.798714334336669*^9, 3.798714446014778*^9, 3.798718554474597*^9, 
   3.7989389151749315`*^9, 3.7992329466016836`*^9, 3.7992358103242884`*^9, 
   3.799238595708516*^9, 3.7992387502495985`*^9, 3.8002676342722154`*^9, 
   3.8003348505038357`*^9, 3.801016024077832*^9, 3.8010162617489777`*^9, 
   3.8010242625062513`*^9, {3.801024649936338*^9, 3.801024670197665*^9}, 
   3.801025009998913*^9, 3.8010335972677836`*^9, 3.8147839246186314`*^9, 
   3.8187651313730907`*^9}]
}, Open  ]],

Cell["\<\
These are Eqs. (3.36), (3.37), and (3.38). Here is also the dark energy \
equation of state...\
\>", "Text",
 CellChangeTimes->{{3.801024114620288*^9, 3.8010241219881907`*^9}, {
  3.818765171664367*^9, 3.8187651918476644`*^9}, {3.8187652290764585`*^9, 
  3.818765254003171*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"solde\[Rho]P", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"FeqTPST", ",", "HeqTPST"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[Rho]", "[", "t", "]"}], ",", 
         RowBox[{"P", "[", "t", "]"}]}], "}"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Rho]eq", "=", 
   RowBox[{
    RowBox[{"\[Rho]", "[", "t", "]"}], "\[Equal]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Rho]", "[", "t", "]"}], "/.", "solde\[Rho]P"}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Peq", "=", 
    RowBox[{
     RowBox[{"P", "[", "t", "]"}], "\[Equal]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"P", "[", "t", "]"}], "/.", "solde\[Rho]P"}], ")"}]}]}], ";"}],
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Rho]DE", "[", "t_", "]"}], "=", 
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Rho]eq", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "-", 
       RowBox[{"3", 
        SuperscriptBox[
         RowBox[{"H", "[", "t", "]"}], "2"]}]}], "//", "Simplify"}], 
     ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"PDE", "[", "t_", "]"}], "=", 
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Peq", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "+", 
        RowBox[{"2", 
         RowBox[{
          RowBox[{"H", "'"}], "[", "t", "]"}]}], "+", 
        RowBox[{"3", 
         SuperscriptBox[
          RowBox[{"H", "[", "t", "]"}], "2"]}]}], "//", "Simplify"}], 
      ")"}]}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"wDE", "[", "t_", "]"}], "=", 
   RowBox[{
    FractionBox[
     RowBox[{"PDE", "[", "t", "]"}], 
     RowBox[{"\[Rho]DE", "[", "t", "]"}]], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SubscriptBox[
StyleBox[\"w\",
FontSlant->\"Italic\"], \"DE\"]\)\>\"", "\[Equal]", 
  RowBox[{"wDE", "[", "t", "]"}]}]}], "Input",
 CellChangeTimes->{{3.8010241462011404`*^9, 3.8010242069864707`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\n \
StyleBox[\\\"w\\\",\\nFontSlant->\\\"Italic\\\"], \\\"DE\\\"]\\)\"\>", 
  "\[Equal]", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "9"}], " ", 
      SuperscriptBox["h", "2"], " ", 
      RowBox[{"A", "[", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Phi]", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}]}], "-", 
     RowBox[{"9", " ", 
      SuperscriptBox["h", "2"], " ", "l", " ", 
      RowBox[{"\[Phi]", "[", "t", "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"l", "-", 
        RowBox[{"3", " ", "h", " ", 
         RowBox[{
          SuperscriptBox["A", "\[Prime]",
           MultilineFunction->None], "[", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["\[Phi]", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}]}], ")"}], " ", 
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"9", " ", 
     SuperscriptBox["h", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Phi]", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], "+", 
       RowBox[{"l", " ", 
        RowBox[{"\[Phi]", "[", "t", "]"}]}], "-", 
       FractionBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["\[Phi]", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"l", " ", 
            RowBox[{"H", "[", "t", "]"}]}], "+", 
           RowBox[{"3", " ", "h", " ", 
            RowBox[{"(", 
             RowBox[{"h", "-", 
              RowBox[{"H", "[", "t", "]"}]}], ")"}], " ", 
            RowBox[{
             SuperscriptBox["A", "\[Prime]",
              MultilineFunction->None], "[", 
             RowBox[{
              FractionBox["1", "2"], " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["\[Phi]", "\[Prime]",
                 MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], 
            " ", 
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], 
        RowBox[{"3", " ", 
         SuperscriptBox["h", "2"]}]]}], ")"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.801024266972036*^9, {3.801024650136408*^9, 3.801024670421239*^9}, 
   3.80102501023059*^9, 3.8010335974809904`*^9, 3.8147839250933285`*^9, 
   3.8187652558649387`*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["[Nearly-tadpole-free theory]",
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0.5, 0.5]],
 "\n\nWe end the section by discussing the special case of a vacuum \
energy-dominated universe in the nearly tadpole-free theory. Recall the \
Friedmann constraint..."
}], "Text",
 CellChangeTimes->{{3.798697695397447*^9, 3.7986977684977136`*^9}, {
   3.798697798847057*^9, 3.7986978728850527`*^9}, 3.7986982343046513`*^9, {
   3.8187652810067854`*^9, 3.8187653263706293`*^9}, 3.818765394260621*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Rho]", "[", "t", "]"}], "-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Rho]", "[", "t", "]"}], "/.", 
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{"FeqTPst", "/.", 
          RowBox[{"l", "\[Rule]", "0"}]}], ",", 
         RowBox[{"\[Rho]", "[", "t", "]"}]}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ")"}]}], "\[Equal]", "0"}], "/.", 
  "vac"}]], "Input",
 CellChangeTimes->{{3.798697885548592*^9, 3.7986979872288313`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"-", "3"}], " ", 
    SuperscriptBox["h", "2"]}], "+", "\[Rho]\[CapitalLambda]", "-", 
   RowBox[{"A", "[", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}]}], 
  "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{{3.798697982139559*^9, 3.798697987602027*^9}, 
   3.798700045494337*^9, 3.7987142519083476`*^9, 3.7987143002508163`*^9, 
   3.798714334419814*^9, 3.798714446090064*^9, 3.798718554550383*^9, 
   3.79893891525307*^9, 3.7992329466545463`*^9, 3.7992358104081326`*^9, 
   3.799238603523039*^9, 3.799238750341903*^9, 3.8002676343509007`*^9, 
   3.800334850633713*^9, 3.80101602415594*^9, 3.801016261827091*^9, 
   3.8010242784597054`*^9, {3.801024650156782*^9, 3.8010246704415226`*^9}, 
   3.8010250102522736`*^9, 3.801033597495431*^9, 3.8147839251132746`*^9, 
   3.818765329804226*^9}]
}, Open  ]],

Cell[TextData[{
 "...implies that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "'"}], 
     RowBox[{"(", "t", ")"}]}], "=", "q"}], TraditionalForm]]],
 ", where ",
 Cell[BoxData[
  FormBox["q", TraditionalForm]]],
 " is a constant. This means the time dependence of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Phi]", "'"}], 
    RowBox[{"(", "t", ")"}]}], TraditionalForm]]],
 " is anchored on the tadpole ",
 StyleBox["l",
  FontSlant->"Italic"],
 ". However, for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"l", "\[NotEqual]", "0"}], TraditionalForm]]],
 ", in general, one needs to specify the potential ",
 Cell[BoxData[
  FormBox[
   RowBox[{"A", "(", "X", ")"}], TraditionalForm]]],
 " to determine the scalar field ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Phi]", "(", "t", ")"}], TraditionalForm]]],
 ". Nonetheless, it is possible to obtain an asymptotic solution for small ",
 Cell[BoxData[
  FormBox["l", TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"|", "l", "|", 
    RowBox[{"\[LessLess]", "1"}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", independent of the theory potential ",
 Cell[BoxData[
  FormBox[
   RowBox[{"A", "(", "X", ")"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ". We do this below..."
}], "Text",
 CellChangeTimes->{{3.798697992595692*^9, 3.798698070186307*^9}, {
   3.7986982390803223`*^9, 3.798698256577418*^9}, {3.7986982917276793`*^9, 
   3.798698367211999*^9}, {3.7986984627392387`*^9, 3.798698510352811*^9}, {
   3.7986985520611763`*^9, 3.798698558256481*^9}, 3.8187653390846343`*^9, {
   3.818765400409585*^9, 3.8187654960731764`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"FeqNTF", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Rho]", "[", "t", "]"}], "-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Rho]", "[", "t", "]"}], "/.", 
        RowBox[{
         RowBox[{"Solve", "[", 
          RowBox[{"FeqTPst", ",", 
           RowBox[{"\[Rho]", "[", "t", "]"}]}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ")"}]}], "\[Equal]", "0"}], "/.", 
    "vac"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Oup", "=", "3"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"coefs", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"\[Alpha]", "[", 
      RowBox[{"i", ",", "t"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "Oup"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Phi]NTF", "=", 
   RowBox[{"\[Phi]", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{"t", ",", 
      RowBox[{"c", "+", 
       RowBox[{"q", " ", "t"}], "+", 
       RowBox[{"Sum", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Alpha]", "[", 
           RowBox[{"i", ",", "t"}], "]"}], 
          SuperscriptBox["l", "i"]}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "Oup"}], "}"}]}], "]"}]}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\"\<\[Phi](\!\(\*
StyleBox[\"t\",
FontSlant->\"Italic\"]\))\>\"", "\[Equal]", 
    RowBox[{"\[Phi]", "[", "t", "]"}]}], "/.", "\[Phi]NTF"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Fseries", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"FeqNTF", "/.", "\[Phi]NTF"}], ",", 
        RowBox[{"{", 
         RowBox[{"l", ",", "0", ",", "Oup"}], "}"}]}], "]"}], "//", 
      "Normal"}], ",", "l", ",", "FullSimplify"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Feqs", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"Fseries", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", "l", ",", "i"}], "]"}], 
      "\[Equal]", "0"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "Oup"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Phi]solNTF", "=", 
   RowBox[{"DSolve", "[", 
    RowBox[{"Feqs", ",", "coefs", ",", "t"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Phi]NTFrule", "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Alpha]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "i_"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"j_", ",", "t"}], "]"}], "\[RuleDelayed]", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Alpha]", "[", 
        RowBox[{"j", ",", "t"}], "]"}], "/.", 
       RowBox[{"\[Phi]solNTF", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "i"}], "}"}]}], "]"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7986985791656017`*^9, 3.798698688520258*^9}, {
  3.7986987206302404`*^9, 3.7986987577280636`*^9}, {3.798698790608677*^9, 
  3.798698864714794*^9}, {3.79869892872945*^9, 3.798699006874263*^9}, {
  3.7987012992318444`*^9, 3.798701317483596*^9}, {3.7987142664659767`*^9, 
  3.798714272344766*^9}, {3.798714362382558*^9, 3.7987143625289965`*^9}, {
  3.798714401985797*^9, 3.798714427675522*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\[Phi](\\!\\(\\*\\nStyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\
\"]\\))\"\>", "\[Equal]", 
  RowBox[{"c", "+", 
   RowBox[{"q", " ", "t"}], "+", 
   RowBox[{"l", " ", 
    RowBox[{"\[Alpha]", "[", 
     RowBox[{"1", ",", "t"}], "]"}]}], "+", 
   RowBox[{
    SuperscriptBox["l", "2"], " ", 
    RowBox[{"\[Alpha]", "[", 
     RowBox[{"2", ",", "t"}], "]"}]}], "+", 
   RowBox[{
    SuperscriptBox["l", "3"], " ", 
    RowBox[{"\[Alpha]", "[", 
     RowBox[{"3", ",", "t"}], "]"}]}]}]}]], "Output",
 CellChangeTimes->{
  3.798698417321551*^9, 3.7986990093077173`*^9, 3.798700045519452*^9, 
   3.798714251965541*^9, 3.7987143002721324`*^9, 3.798714334439867*^9, 
   3.7987144461074777`*^9, 3.7987185545757184`*^9, 3.798938915300181*^9, 
   3.799232946690956*^9, 3.7992358104278555`*^9, 3.7992386062641106`*^9, 
   3.799238750364995*^9, 3.800267634397339*^9, 3.800334850682372*^9, 
   3.80101602418718*^9, 3.801016261842675*^9, {3.8010246501836834`*^9, 
   3.8010246704669557`*^9}, 3.8010250102782145`*^9, 3.801033597519154*^9, 
   3.8147839251561604`*^9, 3.8187655159521236`*^9}]
}, Open  ]],

Cell[TextData[{
 "This is Eq. (3.31) up to ",
 Cell[BoxData[
  FormBox[
   RowBox[{"N", "=", "3"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ". The solution ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Phi]", "(", "t", ")"}], TraditionalForm]]],
 " in the nearly-tadpole-free theory is now stored in \[Phi]",
 StyleBox["solNTF",
  FontSlant->"Italic"],
 ". What we did above is basically put in the Poincare asymptotic solution \
back into the Friedmann constraint, expand the resulting equation in ",
 Cell[BoxData[
  FormBox["l", TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", and solve each equation order by order to obtain ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Alpha]", "i"], "(", "t", ")"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ". The result up to ",
 Cell[BoxData[
  FormBox[
   RowBox[{"O", "(", 
    SuperscriptBox["l", "3"], ")"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " is given by..."
}], "Text",
 CellChangeTimes->{{3.798699017092566*^9, 3.7986990943997765`*^9}, {
  3.818765527202099*^9, 3.81876565598219*^9}, {3.8187656870953197`*^9, 
  3.818765702484083*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\"\<\[Phi](\!\(\*
StyleBox[\"t\",
FontSlant->\"Italic\"]\))\>\"", "\[Equal]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Phi]", "[", "t", "]"}], "/.", "\[Phi]NTF"}], ",", 
        RowBox[{"{", 
         RowBox[{"l", ",", "0", ",", "Oup"}], "}"}]}], "]"}], "//", 
      "Normal"}], ")"}]}], "/.", 
   RowBox[{"\[Phi]solNTF", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"C", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"C", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"C", "[", "3", "]"}], "\[Rule]", "0"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.798699118553114*^9, 3.7986991702636833`*^9}, {
  3.798714378914695*^9, 3.798714381720668*^9}, {3.7987185654601493`*^9, 
  3.798718579910657*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\[Phi](\\!\\(\\*\\nStyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\
\"]\\))\"\>", "\[Equal]", 
  RowBox[{"c", "+", 
   RowBox[{"q", " ", "t"}], "-", 
   FractionBox[
    RowBox[{"l", " ", "t", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"6", " ", "c", " ", "h"}], "+", 
       RowBox[{"q", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          RowBox[{"3", " ", "h", " ", "t"}]}], ")"}]}]}], ")"}]}], 
    RowBox[{"6", " ", "h", " ", "q", " ", 
     RowBox[{
      SuperscriptBox["A", "\[Prime]",
       MultilineFunction->None], "[", 
      FractionBox[
       SuperscriptBox["q", "2"], "2"], "]"}]}]], "-", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"18", " ", 
      SuperscriptBox["h", "2"], " ", 
      SuperscriptBox["q", "3"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["A", "\[Prime]",
         MultilineFunction->None], "[", 
        FractionBox[
         SuperscriptBox["q", "2"], "2"], "]"}], "3"]}]], 
    RowBox[{
     SuperscriptBox["l", "2"], " ", "t", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"9", " ", 
           SuperscriptBox["c", "2"], " ", 
           SuperscriptBox["h", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["q", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"3", " ", "h", " ", "t"}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["A", "\[Prime]",
          MultilineFunction->None], "[", 
         FractionBox[
          SuperscriptBox["q", "2"], "2"], "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["q", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"9", " ", 
           SuperscriptBox["c", "2"], " ", 
           SuperscriptBox["h", "2"]}], "+", 
          RowBox[{"3", " ", "c", " ", "h", " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", 
             RowBox[{"3", " ", "h", " ", "t"}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["q", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"3", " ", "h", " ", "t"}], "+", 
             RowBox[{"3", " ", 
              SuperscriptBox["h", "2"], " ", 
              SuperscriptBox["t", "2"]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["A", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", 
         FractionBox[
          SuperscriptBox["q", "2"], "2"], "]"}]}]}], ")"}]}]}], "+", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"648", " ", 
      SuperscriptBox["h", "3"], " ", 
      SuperscriptBox["q", "5"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["A", "\[Prime]",
         MultilineFunction->None], "[", 
        FractionBox[
         SuperscriptBox["q", "2"], "2"], "]"}], "5"]}]], 
    RowBox[{
     SuperscriptBox["l", "3"], " ", "t", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "36"}], " ", "h", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"9", " ", 
           SuperscriptBox["c", "3"], " ", 
           SuperscriptBox["h", "2"]}], "+", 
          RowBox[{"h", " ", 
           SuperscriptBox["q", "3"], " ", 
           SuperscriptBox["t", "2"]}], "+", 
          RowBox[{"c", " ", 
           SuperscriptBox["q", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"3", " ", "h", " ", "t"}]}], ")"}]}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["A", "\[Prime]",
           MultilineFunction->None], "[", 
          FractionBox[
           SuperscriptBox["q", "2"], "2"], "]"}], "2"]}], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["q", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"108", " ", 
           SuperscriptBox["c", "3"], " ", 
           SuperscriptBox["h", "3"]}], "+", 
          RowBox[{"54", " ", 
           SuperscriptBox["c", "2"], " ", 
           SuperscriptBox["h", "2"], " ", "q", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", 
             RowBox[{"3", " ", "h", " ", "t"}]}], ")"}]}], "+", 
          RowBox[{"36", " ", "c", " ", "h", " ", 
           SuperscriptBox["q", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"3", " ", "h", " ", "t"}], "+", 
             RowBox[{"3", " ", 
              SuperscriptBox["h", "2"], " ", 
              SuperscriptBox["t", "2"]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["q", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "4"}], "+", 
             RowBox[{"18", " ", "h", " ", "t"}], "-", 
             RowBox[{"36", " ", 
              SuperscriptBox["h", "2"], " ", 
              SuperscriptBox["t", "2"]}], "+", 
             RowBox[{"27", " ", 
              SuperscriptBox["h", "3"], " ", 
              SuperscriptBox["t", "3"]}]}], ")"}]}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["A", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", 
          FractionBox[
           SuperscriptBox["q", "2"], "2"], "]"}], "2"]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox["A", "\[Prime]",
          MultilineFunction->None], "[", 
         FractionBox[
          SuperscriptBox["q", "2"], "2"], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "3"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"108", " ", 
              SuperscriptBox["c", "3"], " ", 
              SuperscriptBox["h", "3"], " ", 
              SuperscriptBox["q", "2"]}], "-", 
             RowBox[{"36", " ", "c", " ", "h", " ", 
              SuperscriptBox["q", "4"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "-", 
                RowBox[{"3", " ", "h", " ", "t"}], "+", 
                RowBox[{
                 SuperscriptBox["h", "2"], " ", 
                 SuperscriptBox["t", "2"]}]}], ")"}]}], "+", 
             RowBox[{
              SuperscriptBox["q", "5"], " ", 
              RowBox[{"(", 
               RowBox[{"8", "-", 
                RowBox[{"36", " ", "h", " ", "t"}], "+", 
                RowBox[{"48", " ", 
                 SuperscriptBox["h", "2"], " ", 
                 SuperscriptBox["t", "2"]}], "-", 
                RowBox[{"9", " ", 
                 SuperscriptBox["h", "3"], " ", 
                 SuperscriptBox["t", "3"]}]}], ")"}]}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["A", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", 
            FractionBox[
             SuperscriptBox["q", "2"], "2"], "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["q", "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"108", " ", 
              SuperscriptBox["c", "3"], " ", 
              SuperscriptBox["h", "3"]}], "+", 
             RowBox[{"54", " ", 
              SuperscriptBox["c", "2"], " ", 
              SuperscriptBox["h", "2"], " ", "q", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", 
                RowBox[{"3", " ", "h", " ", "t"}]}], ")"}]}], "+", 
             RowBox[{"36", " ", "c", " ", "h", " ", 
              SuperscriptBox["q", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "-", 
                RowBox[{"3", " ", "h", " ", "t"}], "+", 
                RowBox[{"3", " ", 
                 SuperscriptBox["h", "2"], " ", 
                 SuperscriptBox["t", "2"]}]}], ")"}]}], "+", 
             RowBox[{
              SuperscriptBox["q", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "4"}], "+", 
                RowBox[{"18", " ", "h", " ", "t"}], "-", 
                RowBox[{"36", " ", 
                 SuperscriptBox["h", "2"], " ", 
                 SuperscriptBox["t", "2"]}], "+", 
                RowBox[{"27", " ", 
                 SuperscriptBox["h", "3"], " ", 
                 SuperscriptBox["t", "3"]}]}], ")"}]}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["A", 
             TagBox[
              RowBox[{"(", "3", ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            FractionBox[
             SuperscriptBox["q", "2"], "2"], "]"}]}]}], ")"}]}]}], 
      ")"}]}]}]}]}]], "Output",
 CellChangeTimes->{{3.7986991532532887`*^9, 3.798699170689652*^9}, 
   3.798700053687436*^9, 3.798714260380827*^9, 3.798714301383243*^9, 
   3.798714335111966*^9, 3.7987144476770134`*^9, {3.7987185559008136`*^9, 
   3.798718581505395*^9}, 3.798938916565236*^9, 3.799232948909871*^9, 
   3.7992358117214513`*^9, 3.7992386099813023`*^9, 3.799238751700577*^9, 
   3.8002676360627575`*^9, 3.8003348527060356`*^9, 3.80101602546817*^9, 
   3.8010162630299034`*^9, {3.801024651595538*^9, 3.80102467207007*^9}, 
   3.8010250117853374`*^9, 3.8010335990680695`*^9, 3.8147839265643954`*^9}]
}, Open  ]],

Cell["\<\
This leads to Eqs. (3.32), (3.33), and (3.34). Higher orders can be computed \
to any practical precision.\
\>", "Text",
 CellChangeTimes->{{3.7986990974141703`*^9, 3.7986990989754252`*^9}, {
  3.798699194573922*^9, 3.798699222798211*^9}, {3.798719992562703*^9, 
  3.7987200342212324`*^9}, {3.7987201053034277`*^9, 3.7987201059791384`*^9}, {
  3.8010158746431713`*^9, 3.801015904706606*^9}, {3.8010245637919197`*^9, 
  3.8010245659774218`*^9}, {3.8010246175985928`*^9, 3.8010246180041676`*^9}, {
  3.8187657369760776`*^9, 3.818765804271071*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["3.3 Dynamical stability of the de Sitter vacuum", "Subsubsection",
 CellChangeTimes->{{3.7980825166022067`*^9, 3.798082525281714*^9}, {
  3.79808256435507*^9, 3.7980825712861233`*^9}, {3.80027020526178*^9, 
  3.8002702072655616`*^9}, {3.818765814910313*^9, 3.8187658195363865`*^9}}],

Cell["\<\
We establish the dynamical stability of the de Sitter vacuum in the \
self-tuning theory of Sec. (3.2).

We start by setting up the perturbations (Eqs. (3.39-41)) and helpful \
simplifying functions...\
\>", "Text",
 CellChangeTimes->{{3.798089715941183*^9, 3.7980897873691263`*^9}, {
  3.798089839052487*^9, 3.7980898449721727`*^9}, {3.8187658510901732`*^9, 
  3.8187658818318987`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pert", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"H", "\[Rule]", 
      RowBox[{"Function", "[", 
       RowBox[{"t", ",", 
        RowBox[{"h", "+", 
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{"f", "[", "t", "]"}]}]}]}], "]"}]}], ",", 
     RowBox[{"\[Phi]", "\[Rule]", 
      RowBox[{"Function", "[", 
       RowBox[{"t", ",", 
        RowBox[{
         RowBox[{"\[Phi]", "[", "t", "]"}], "+", 
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{"\[Psi]", "[", "t", "]"}]}]}]}], "]"}]}], ",", 
     RowBox[{"\[Rho]", "\[Rule]", 
      RowBox[{"Function", "[", 
       RowBox[{"t", ",", 
        RowBox[{
         RowBox[{"\[Rho]", "[", "t", "]"}], "+", 
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{"\[Delta]\[Rho]", "[", "t", "]"}]}]}]}], "]"}]}]}], "}"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"linearize", "[", "expr_", "]"}], ":=", 
  RowBox[{
   RowBox[{"Series", "[", 
    RowBox[{"expr", ",", 
     RowBox[{"{", 
      RowBox[{"\[Epsilon]", ",", "0", ",", "1"}], "}"}]}], "]"}], "//", 
   "Normal"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"org", "[", "expr_", "]"}], ":=", 
   RowBox[{"Collect", "[", 
    RowBox[{"expr", ",", "\[Epsilon]", ",", "Simplify"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\"\<\!\(\*
StyleBox[\"H\",
FontSlant->\"Italic\"]\)(\!\(\*
StyleBox[\"t\",
FontSlant->\"Italic\"]\))\>\"", "\[Equal]", 
   RowBox[{"H", "[", "t", "]"}]}], "/.", "pert"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\"\<\[Phi](t)\>\"", "\[Equal]", 
   RowBox[{"\[Phi]", "[", "t", "]"}]}], "/.", "pert"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\"\<\[Rho](\!\(\*
StyleBox[\"t\",
FontSlant->\"Italic\"]\))\>\"", "\[Equal]", 
   RowBox[{"\[Rho]", "[", "t", "]"}]}], "/.", "pert"}]}], "Input",
 CellChangeTimes->{{3.798089851500903*^9, 3.798089867050722*^9}, {
  3.798089899568812*^9, 3.798089937013542*^9}, {3.798282038612888*^9, 
  3.798282040745378*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*\\nStyleBox[\\\"H\\\",\\nFontSlant->\\\"Italic\\\"]\\)(\
\\!\\(\\*\\nStyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"]\\))\"\>", 
  "\[Equal]", 
  RowBox[{"h", "+", 
   RowBox[{"\[Epsilon]", " ", 
    RowBox[{"f", "[", "t", "]"}]}]}]}]], "Output",
 CellChangeTimes->{
  3.7980899382847953`*^9, {3.798282023157092*^9, 3.7982820421329546`*^9}, 
   3.7984285626388493`*^9, 3.7984576168659706`*^9, 3.798563060148243*^9, 
   3.7985633677300572`*^9, 3.79856370169293*^9, 3.798563829219839*^9, 
   3.7985639247260847`*^9, 3.7985640817909184`*^9, 3.798573133793518*^9, 
   3.7985795442891355`*^9, 3.798607093128112*^9, 3.7986960283452935`*^9, 
   3.798699325935045*^9, 3.7987000912482414`*^9, 3.798714260437251*^9, 
   3.798714493033244*^9, 3.7989389165808506`*^9, 3.7992329489278593`*^9, 
   3.7992358117404003`*^9, 3.7992386206746407`*^9, 3.7992387517426033`*^9, 
   3.8002676361323195`*^9, 3.801024429123646*^9, {3.8010246516182747`*^9, 
   3.8010246720972157`*^9}, 3.8010250118116407`*^9, 3.8010335990897026`*^9, 
   3.814783926923467*^9, 3.8187658896113014`*^9}],

Cell[BoxData[
 RowBox[{"\<\"\[Phi](t)\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{"\[Phi]", "[", "t", "]"}], "+", 
   RowBox[{"\[Epsilon]", " ", 
    RowBox[{"\[Psi]", "[", "t", "]"}]}]}]}]], "Output",
 CellChangeTimes->{
  3.7980899382847953`*^9, {3.798282023157092*^9, 3.7982820421329546`*^9}, 
   3.7984285626388493`*^9, 3.7984576168659706`*^9, 3.798563060148243*^9, 
   3.7985633677300572`*^9, 3.79856370169293*^9, 3.798563829219839*^9, 
   3.7985639247260847`*^9, 3.7985640817909184`*^9, 3.798573133793518*^9, 
   3.7985795442891355`*^9, 3.798607093128112*^9, 3.7986960283452935`*^9, 
   3.798699325935045*^9, 3.7987000912482414`*^9, 3.798714260437251*^9, 
   3.798714493033244*^9, 3.7989389165808506`*^9, 3.7992329489278593`*^9, 
   3.7992358117404003`*^9, 3.7992386206746407`*^9, 3.7992387517426033`*^9, 
   3.8002676361323195`*^9, 3.801024429123646*^9, {3.8010246516182747`*^9, 
   3.8010246720972157`*^9}, 3.8010250118116407`*^9, 3.8010335990897026`*^9, 
   3.814783926923467*^9, 3.818765889615686*^9}],

Cell[BoxData[
 RowBox[{"\<\"\[Rho](\\!\\(\\*\\nStyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\
\"]\\))\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{"\[Epsilon]", " ", 
    RowBox[{"\[Delta]\[Rho]", "[", "t", "]"}]}], "+", 
   RowBox[{"\[Rho]", "[", "t", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.7980899382847953`*^9, {3.798282023157092*^9, 3.7982820421329546`*^9}, 
   3.7984285626388493`*^9, 3.7984576168659706`*^9, 3.798563060148243*^9, 
   3.7985633677300572`*^9, 3.79856370169293*^9, 3.798563829219839*^9, 
   3.7985639247260847`*^9, 3.7985640817909184`*^9, 3.798573133793518*^9, 
   3.7985795442891355`*^9, 3.798607093128112*^9, 3.7986960283452935`*^9, 
   3.798699325935045*^9, 3.7987000912482414`*^9, 3.798714260437251*^9, 
   3.798714493033244*^9, 3.7989389165808506`*^9, 3.7992329489278593`*^9, 
   3.7992358117404003`*^9, 3.7992386206746407`*^9, 3.7992387517426033`*^9, 
   3.8002676361323195`*^9, 3.801024429123646*^9, {3.8010246516182747`*^9, 
   3.8010246720972157`*^9}, 3.8010250118116407`*^9, 3.8010335990897026`*^9, 
   3.814783926923467*^9, 3.818765889620138*^9}]
}, Open  ]],

Cell[TextData[{
 "To impose the background, we use ",
 StyleBox["FeqTPst",
  FontSlant->"Italic"],
 " and ",
 StyleBox["HeqTPst",
  FontSlant->"Italic"],
 " and solve for the barotropic fluid..."
}], "Text",
 CellChangeTimes->{{3.7980899491903243`*^9, 3.798090024022979*^9}, {
  3.7980901091544313`*^9, 3.7980901113504825`*^9}, {3.798090168901023*^9, 
  3.798090184834694*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Abg", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"FeqTPst", ",", "HeqTPst", ",", 
        RowBox[{"D", "[", 
         RowBox[{"HeqTPst", ",", "t"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"A", "[", 
         FractionBox[
          SuperscriptBox[
           RowBox[{
            RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "2"], "2"], "]"}], ",", 
        RowBox[{
         RowBox[{"A", "'"}], "[", 
         FractionBox[
          SuperscriptBox[
           RowBox[{
            RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "2"], "2"], "]"}], ",", 
        RowBox[{
         RowBox[{"A", "''"}], "[", 
         FractionBox[
          SuperscriptBox[
           RowBox[{
            RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "2"], "2"], "]"}]}], 
       "}"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Rho]sol", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"DSolve", "[", 
       RowBox[{"firstlaw", ",", "\[Rho]", ",", "t"}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}], "/.", 
     RowBox[{
      RowBox[{"C", "[", "1", "]"}], "\[Rule]", 
      RowBox[{"3", 
       SuperscriptBox["\[Alpha]", "2"]}]}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "Abg", \
"\[IndentingNewLine]", "\[Rho]sol"}], "Input",
 CellChangeTimes->{{3.798090038088194*^9, 3.798090084956257*^9}, {
  3.798090116800469*^9, 3.7980901362821693`*^9}, {3.7980902417069674`*^9, 
  3.798090401771753*^9}, {3.8187659440207176`*^9, 3.8187659443617983`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "3"}], " ", 
      SuperscriptBox["h", "2"]}], "+", 
     RowBox[{"\[Rho]", "[", "t", "]"}], "-", 
     RowBox[{"l", " ", 
      RowBox[{"\[Phi]", "[", "t", "]"}]}], "+", 
     FractionBox[
      RowBox[{"l", " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], 
      RowBox[{"3", " ", "h"}]]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["A", "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{"9", " ", 
        SuperscriptBox["h", "2"], " ", 
        RowBox[{"\[Rho]", "[", "t", "]"}]}], "+", 
       RowBox[{"9", " ", 
        SuperscriptBox["h", "2"], " ", "w", " ", 
        RowBox[{"\[Rho]", "[", "t", "]"}]}], "+", 
       RowBox[{"3", " ", "h", " ", "l", " ", 
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "-", 
       RowBox[{"l", " ", 
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]}], 
      RowBox[{"3", " ", "h", " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["A", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], "\[Rule]", 
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"9", " ", 
          SuperscriptBox["h", "2"], " ", 
          RowBox[{
           SuperscriptBox["\[Rho]", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Phi]", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
         RowBox[{"9", " ", 
          SuperscriptBox["h", "2"], " ", "w", " ", 
          RowBox[{
           SuperscriptBox["\[Rho]", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Phi]", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "-", 
         RowBox[{"9", " ", 
          SuperscriptBox["h", "2"], " ", 
          RowBox[{"\[Rho]", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
         RowBox[{"9", " ", 
          SuperscriptBox["h", "2"], " ", "w", " ", 
          RowBox[{"\[Rho]", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
         RowBox[{"l", " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
         RowBox[{"9", " ", 
          SuperscriptBox["h", "2"], " ", 
          RowBox[{"\[Rho]", "[", "t", "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Phi]", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Phi]", 
            TagBox[
             RowBox[{"(", "3", ")"}],
             Derivative],
            MultilineFunction->None], "[", "t", "]"}]}], "-", 
         RowBox[{"9", " ", 
          SuperscriptBox["h", "2"], " ", "w", " ", 
          RowBox[{"\[Rho]", "[", "t", "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Phi]", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Phi]", 
            TagBox[
             RowBox[{"(", "3", ")"}],
             Derivative],
            MultilineFunction->None], "[", "t", "]"}]}], "-", 
         RowBox[{"3", " ", "h", " ", "l", " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox["\[Phi]", 
            TagBox[
             RowBox[{"(", "3", ")"}],
             Derivative],
            MultilineFunction->None], "[", "t", "]"}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"3", " ", "h", " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Phi]", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "3"]}], ")"}]}], 
      ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.798090086739213*^9, 3.798090355798234*^9, 3.7980904025670705`*^9, 
   3.7982820717125025`*^9, 3.798428562836934*^9, 3.798457616903726*^9, 
   3.7985630602424445`*^9, 3.7985633677708983`*^9, 3.7985637088340445`*^9, 
   3.7985638293172274`*^9, 3.7985639248693223`*^9, 3.79856408184111*^9, 
   3.798573133855579*^9, 3.7985795443360043`*^9, 3.7986070966454053`*^9, 
   3.7986960341855483`*^9, 3.7986993294084463`*^9, 3.798700094441389*^9, 
   3.798714260504851*^9, 3.798714498909091*^9, 3.798938916627718*^9, 
   3.799232948989472*^9, 3.7992358117902126`*^9, 3.799238620851865*^9, 
   3.799238751825553*^9, 3.8002676362103863`*^9, 3.8010244292196426`*^9, {
   3.801024651652358*^9, 3.8010246721452208`*^9}, 3.8010250118453684`*^9, 
   3.801033599142496*^9, 3.8147839269832745`*^9, 3.818765947457056*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\[Rho]", "\[Rule]", 
   RowBox[{"Function", "[", 
    RowBox[{
     RowBox[{"{", "t", "}"}], ",", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "3"}], " ", "t", " ", 
        RowBox[{"(", 
         RowBox[{"h", "+", 
          RowBox[{"h", " ", "w"}]}], ")"}]}]], " ", 
      RowBox[{"(", 
       RowBox[{"3", " ", 
        SuperscriptBox["\[Alpha]", "2"]}], ")"}]}]}], "]"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.798090086739213*^9, 3.798090355798234*^9, 3.7980904025670705`*^9, 
   3.7982820717125025`*^9, 3.798428562836934*^9, 3.798457616903726*^9, 
   3.7985630602424445`*^9, 3.7985633677708983`*^9, 3.7985637088340445`*^9, 
   3.7985638293172274`*^9, 3.7985639248693223`*^9, 3.79856408184111*^9, 
   3.798573133855579*^9, 3.7985795443360043`*^9, 3.7986070966454053`*^9, 
   3.7986960341855483`*^9, 3.7986993294084463`*^9, 3.798700094441389*^9, 
   3.798714260504851*^9, 3.798714498909091*^9, 3.798938916627718*^9, 
   3.799232948989472*^9, 3.7992358117902126`*^9, 3.799238620851865*^9, 
   3.799238751825553*^9, 3.8002676362103863`*^9, 3.8010244292196426`*^9, {
   3.801024651652358*^9, 3.8010246721452208`*^9}, 3.8010250118453684`*^9, 
   3.801033599142496*^9, 3.8147839269832745`*^9, 3.8187659474698877`*^9}]
}, Open  ]],

Cell["The perturbed field equations become...", "Text",
 CellChangeTimes->{{3.7980904092364674`*^9, 3.79809042159181*^9}, {
  3.8187659858682795`*^9, 3.8187659914692802`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Fpert", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"FeqTPST", "/.", "pert"}], "//", "linearize"}], ")"}], "/.", 
      "Abg"}], "/.", "\[Rho]sol"}], "//", "org"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Hpert", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"HeqTPST", "/.", "pf"}], "/.", "pert"}], "//", "linearize"}],
        ")"}], "/.", "Abg"}], "/.", "\[Rho]sol"}], "//", "org"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Spert", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"SeqTPST", "/.", "pert"}], "//", "linearize"}], ")"}], "/.", 
       "Abg"}], "/.", "\[Rho]sol"}], "//", "org"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pertd\[Psi]", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Psi]", "'"}], "[", "t", "]"}], "-", 
     RowBox[{"Collect", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"\[Psi]", "'"}], "[", "t", "]"}], "/.", 
        RowBox[{
         RowBox[{"Solve", "[", 
          RowBox[{
           RowBox[{"Fpert", "//", "Simplify"}], ",", 
           RowBox[{
            RowBox[{"\[Psi]", "'"}], "[", "t", "]"}]}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Psi]", "'"}], "[", "t", "]"}], ",", 
         RowBox[{
          RowBox[{"\[Psi]", "''"}], "[", "t", "]"}], ",", 
         RowBox[{"f", "[", "t", "]"}], ",", 
         RowBox[{
          RowBox[{"f", "'"}], "[", "t", "]"}], ",", 
         RowBox[{"\[Delta]\[Rho]", "[", "t", "]"}]}], "}"}], ",", 
       "FullSimplify"}], "]"}]}], "\[Equal]", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pertdd\[Psi]", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Psi]", "''"}], "[", "t", "]"}], "-", 
     RowBox[{"Collect", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"\[Psi]", "''"}], "[", "t", "]"}], "/.", 
        RowBox[{
         RowBox[{"Solve", "[", 
          RowBox[{
           RowBox[{"Hpert", "//", "Simplify"}], ",", 
           RowBox[{
            RowBox[{"\[Psi]", "''"}], "[", "t", "]"}]}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Psi]", "'"}], "[", "t", "]"}], ",", 
         RowBox[{
          RowBox[{"\[Psi]", "''"}], "[", "t", "]"}], ",", 
         RowBox[{"f", "[", "t", "]"}], ",", 
         RowBox[{
          RowBox[{"f", "'"}], "[", "t", "]"}], ",", 
         RowBox[{"\[Delta]\[Rho]", "[", "t", "]"}]}], "}"}], ",", 
       "FullSimplify"}], "]"}]}], "\[Equal]", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pertdf", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"f", "'"}], "[", "t", "]"}], "-", 
      RowBox[{"Collect", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"f", "'"}], "[", "t", "]"}], "/.", 
         RowBox[{
          RowBox[{"Solve", "[", 
           RowBox[{
            RowBox[{"Spert", "//", "Simplify"}], ",", 
            RowBox[{
             RowBox[{"f", "'"}], "[", "t", "]"}]}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Psi]", "'"}], "[", "t", "]"}], ",", 
          RowBox[{
           RowBox[{"\[Psi]", "''"}], "[", "t", "]"}], ",", 
          RowBox[{"f", "[", "t", "]"}], ",", 
          RowBox[{
           RowBox[{"f", "'"}], "[", "t", "]"}], ",", 
          RowBox[{"\[Delta]\[Rho]", "[", "t", "]"}]}], "}"}], ",", 
        "FullSimplify"}], "]"}]}], "\[Equal]", "0"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "pertd\[Psi]", "\
\[IndentingNewLine]", "pertdd\[Psi]", "\[IndentingNewLine]", "pertdf"}], \
"Input",
 CellChangeTimes->{{3.798090442556134*^9, 3.798090578998145*^9}, {
  3.798090612250264*^9, 3.798090612439907*^9}, {3.798090802286456*^9, 
  3.7980908554088087`*^9}, {3.798091407623886*^9, 3.7980914120946608`*^9}, {
  3.7986071074748583`*^9, 3.7986071835956793`*^9}, {3.7986072185618734`*^9, 
  3.7986072284978094`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Psi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"3", " ", "h", " ", "t", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "w"}], ")"}]}]], " ", 
     RowBox[{"\[Delta]\[Rho]", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], 
    RowBox[{
     RowBox[{"9", " ", "h", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "w"}], ")"}], " ", 
      SuperscriptBox["\[Alpha]", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"3", " ", "h", " ", "t", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "w"}], ")"}]}]], " ", "l", " ", 
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"3", " ", "h", " ", "t", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "w"}], ")"}]}]], " ", "l", " ", 
     RowBox[{"\[Psi]", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], 
    RowBox[{
     RowBox[{"9", " ", "h", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "w"}], ")"}], " ", 
      SuperscriptBox["\[Alpha]", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"3", " ", "h", " ", "t", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "w"}], ")"}]}]], " ", "l", " ", 
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}]}]], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"f", "[", "t", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "9"}], " ", "h", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "w"}], ")"}], " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"3", " ", "h", " ", "t", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "w"}], ")"}]}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "l"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
          RowBox[{"6", " ", 
           SuperscriptBox["h", "2"], " ", 
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], 
      ")"}]}], 
    RowBox[{"h", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"9", " ", "h", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "w"}], ")"}], " ", 
        SuperscriptBox["\[Alpha]", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"3", " ", "h", " ", "t", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "w"}], ")"}]}]], " ", "l", " ", 
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]]}], 
  "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{{3.798090814278818*^9, 3.798090857555244*^9}, 
   3.798091415832902*^9, 3.798282121404046*^9, 3.7984285670886965`*^9, 
   3.798457619910968*^9, 3.7985630652384095`*^9, 3.798563371915366*^9, 
   3.798563833404947*^9, 3.798563929375243*^9, 3.7985640864317226`*^9, 
   3.798573138132547*^9, 3.798579547559847*^9, 3.798607187453049*^9, 
   3.798607229318243*^9, 3.7986960836633606`*^9, 3.798699338297513*^9, 
   3.7987001001141405`*^9, 3.798714263353685*^9, 3.798714536352277*^9, 
   3.798938919062739*^9, 3.7992329515011206`*^9, 3.7992358144299364`*^9, 
   3.7992386239866457`*^9, 3.799238754723028*^9, 3.800267638979935*^9, 
   3.8010244325584965`*^9, {3.8010246539433155`*^9, 3.8010246747487955`*^9}, 
   3.8010250145299373`*^9, 3.8010336021426396`*^9, 3.8147839296720896`*^9, 
   3.8187660025533037`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"-", "3"}], " ", 
    RowBox[{"f", "[", "t", "]"}], " ", 
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}], "-", 
   FractionBox[
    RowBox[{"3", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"3", " ", "h", " ", "t", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "w"}], ")"}]}]], " ", "h", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "w"}], ")"}], " ", 
     RowBox[{"\[Delta]\[Rho]", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], 
    RowBox[{
     RowBox[{"9", " ", "h", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "w"}], ")"}], " ", 
      SuperscriptBox["\[Alpha]", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"3", " ", "h", " ", "t", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "w"}], ")"}]}]], " ", "l", " ", 
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}]}]], "-", 
   FractionBox[
    RowBox[{"6", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"3", " ", "h", " ", "t", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "w"}], ")"}]}]], " ", "h", " ", 
     RowBox[{
      SuperscriptBox["f", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], 
    RowBox[{
     RowBox[{"9", " ", "h", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "w"}], ")"}], " ", 
      SuperscriptBox["\[Alpha]", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"3", " ", "h", " ", "t", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "w"}], ")"}]}]], " ", "l", " ", 
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}]}]], "+", 
   RowBox[{
    SuperscriptBox["\[Psi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], "-", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Psi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"27", " ", 
        SuperscriptBox["h", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", "w"}], ")"}], "2"], " ", 
        SuperscriptBox["\[Alpha]", "2"]}], 
       RowBox[{
        RowBox[{"9", " ", "h", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "w"}], ")"}], " ", 
         SuperscriptBox["\[Alpha]", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"3", " ", "h", " ", "t", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "w"}], ")"}]}]], " ", "l", " ", 
         RowBox[{
          SuperscriptBox["\[Phi]", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}]}]], "+", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[Phi]", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "t", "]"}], 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]]}], ")"}]}]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{{3.798090814278818*^9, 3.798090857555244*^9}, 
   3.798091415832902*^9, 3.798282121404046*^9, 3.7984285670886965`*^9, 
   3.798457619910968*^9, 3.7985630652384095`*^9, 3.798563371915366*^9, 
   3.798563833404947*^9, 3.798563929375243*^9, 3.7985640864317226`*^9, 
   3.798573138132547*^9, 3.798579547559847*^9, 3.798607187453049*^9, 
   3.798607229318243*^9, 3.7986960836633606`*^9, 3.798699338297513*^9, 
   3.7987001001141405`*^9, 3.798714263353685*^9, 3.798714536352277*^9, 
   3.798938919062739*^9, 3.7992329515011206`*^9, 3.7992358144299364`*^9, 
   3.7992386239866457`*^9, 3.799238754723028*^9, 3.800267638979935*^9, 
   3.8010244325584965`*^9, {3.8010246539433155`*^9, 3.8010246747487955`*^9}, 
   3.8010250145299373`*^9, 3.8010336021426396`*^9, 3.8147839296720896`*^9, 
   3.818766002558566*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox["f", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"f", "[", "t", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"3", " ", "h", " ", "t", " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "w"}], ")"}]}]]}], " ", "l", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
           RowBox[{
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", "h", " ", 
               RowBox[{
                SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
                 MultilineFunction->None], "[", "t", "]"}]}], "-", 
              RowBox[{
               SuperscriptBox["\[Phi]", 
                TagBox[
                 RowBox[{"(", "3", ")"}],
                 Derivative],
                MultilineFunction->None], "[", "t", "]"}]}], ")"}]}]}], 
          ")"}]}], "+", 
        RowBox[{"9", " ", "h", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "w"}], ")"}], " ", 
         SuperscriptBox["\[Alpha]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", "h", " ", "w", " ", 
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[Phi]", 
             TagBox[
              RowBox[{"(", "3", ")"}],
              Derivative],
             MultilineFunction->None], "[", "t", "]"}]}], ")"}]}]}], ")"}]}], 
     ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"9", " ", "h", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "w"}], ")"}], " ", 
         SuperscriptBox["\[Alpha]", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"3", " ", "h", " ", "t", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "w"}], ")"}]}]], " ", "l", " ", 
         RowBox[{
          SuperscriptBox["\[Phi]", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}]}], ")"}], " ", 
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}], ")"}]}]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{{3.798090814278818*^9, 3.798090857555244*^9}, 
   3.798091415832902*^9, 3.798282121404046*^9, 3.7984285670886965`*^9, 
   3.798457619910968*^9, 3.7985630652384095`*^9, 3.798563371915366*^9, 
   3.798563833404947*^9, 3.798563929375243*^9, 3.7985640864317226`*^9, 
   3.798573138132547*^9, 3.798579547559847*^9, 3.798607187453049*^9, 
   3.798607229318243*^9, 3.7986960836633606`*^9, 3.798699338297513*^9, 
   3.7987001001141405`*^9, 3.798714263353685*^9, 3.798714536352277*^9, 
   3.798938919062739*^9, 3.7992329515011206`*^9, 3.7992358144299364`*^9, 
   3.7992386239866457`*^9, 3.799238754723028*^9, 3.800267638979935*^9, 
   3.8010244325584965`*^9, {3.8010246539433155`*^9, 3.8010246747487955`*^9}, 
   3.8010250145299373`*^9, 3.8010336021426396`*^9, 3.8147839296720896`*^9, 
   3.8187660025739317`*^9}]
}, Open  ]],

Cell[TextData[{
 "These are Eqs. (3.42-44). We warn, however, that the above equations are \
valid only for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"l", "\[NotEqual]", "0"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"w", "\[NotEqual]", "1"}], TraditionalForm]]],
 ". ",
 StyleBox["pertd",
  FontSlant->"Italic"],
 "\[Psi]",
 StyleBox[" ",
  FontSlant->"Italic"],
 "is the constraint equation to ",
 StyleBox["pertdd",
  FontSlant->"Italic"],
 "\[Psi]. The perturbation equations for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Psi]", "'"}], 
    RowBox[{"(", "t", ")"}]}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", "t", ")"}], TraditionalForm]]],
 " are given by ",
 StyleBox["pertdd",
  FontSlant->"Italic"],
 "\[Psi] and ",
 StyleBox["pertdf",
  FontSlant->"Italic"],
 ". At the same time, the perturbed equation for the perfect fluid is..."
}], "Text",
 CellChangeTimes->{{3.7980908692809877`*^9, 3.798090998119626*^9}, {
  3.7987146412248664`*^9, 3.798714673349126*^9}, {3.8187660172297134`*^9, 
  3.8187660287748103`*^9}, {3.8187660634812584`*^9, 3.8187660806548815`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"pertd\[Rho]", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"firstlaw", "/.", "pert"}], "/.", "\[Rho]sol"}], "//", 
    "Simplify"}]}], ";", "pertd\[Rho]"}]], "Input",
 CellChangeTimes->{{3.798091002277278*^9, 3.7980910485899706`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Epsilon]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", "h", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "w"}], ")"}], " ", 
      RowBox[{"\[Delta]\[Rho]", "[", "t", "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["\[Delta]\[Rho]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], ")"}]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{{3.7980910296822634`*^9, 3.798091049005948*^9}, 
   3.798282125969542*^9, 3.7984285672207327`*^9, 3.7984576199890766`*^9, 
   3.798563065353668*^9, 3.798563372010027*^9, 3.798563833569936*^9, 
   3.7985639294332027`*^9, 3.7985640864994516`*^9, 3.7985731381919556`*^9, 
   3.7985795476288443`*^9, 3.7986110620096145`*^9, 3.7986964463350177`*^9, 
   3.798714263497616*^9, 3.79871456531805*^9, 3.7989389191252313`*^9, 
   3.7992329515788956`*^9, 3.7992358144976587`*^9, 3.799238624067631*^9, 
   3.799238754771763*^9, 3.8002676390540934`*^9, 3.801024432698575*^9, 
   3.8010246748145304`*^9, 3.801025014614436*^9, 3.8010336022154975`*^9, 
   3.8147839297340784`*^9, 3.818766086556713*^9}]
}, Open  ]],

Cell["\<\
The solution to this of course takes the same form as the background...\
\>", "Text",
 CellChangeTimes->{{3.798091064332202*^9, 3.798091088011076*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d\[Rho]", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"DSolve", "[", 
      RowBox[{"pertd\[Rho]", ",", "\[Delta]\[Rho]", ",", "t"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "/.", 
    RowBox[{
     RowBox[{"C", "[", "1", "]"}], "\[Rule]", 
     RowBox[{"3", 
      SuperscriptBox["\[Delta]h", "2"]}]}]}]}], ";", "d\[Rho]"}]], "Input",
 CellChangeTimes->{{3.7980910905005*^9, 3.798091143005795*^9}, 
   3.8187660957907705`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\[Delta]\[Rho]", "\[Rule]", 
   RowBox[{"Function", "[", 
    RowBox[{
     RowBox[{"{", "t", "}"}], ",", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "3"}], " ", "t", " ", 
        RowBox[{"(", 
         RowBox[{"h", "+", 
          RowBox[{"h", " ", "w"}]}], ")"}]}]], " ", 
      RowBox[{"(", 
       RowBox[{"3", " ", 
        SuperscriptBox["\[Delta]h", "2"]}], ")"}]}]}], "]"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.798091128643726*^9, 3.7982821390754056`*^9, 
  3.79842856728511*^9, 3.79845762001122*^9, 3.7985630653750167`*^9, 
  3.7985633720274982`*^9, 3.7985638336141815`*^9, 3.7985639294673924`*^9, 
  3.7985640865209255`*^9, 3.798573138216113*^9, 3.7985795476444674`*^9, 
  3.7986110664532757`*^9, 3.7986964493401065`*^9, 3.7987142635199795`*^9, 
  3.7987146064682517`*^9, 3.798938919140843*^9, 3.7992329516000156`*^9, 
  3.7992358145156116`*^9, 3.7992386240940714`*^9, 3.7992387547925596`*^9, 
  3.8002676390818777`*^9, 3.801024432725048*^9, 3.8010246748371973`*^9, 
  3.801025014644783*^9, 3.8010336022375517`*^9, 3.8147839297538743`*^9, 
  3.8187660977164125`*^9}]
}, Open  ]],

Cell[TextData[{
 "The perturbation equations for the Hubble parameter (",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", "t", ")"}], TraditionalForm]]],
 ") and the scalar field (",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Psi]", "(", "t", ")"}], TraditionalForm]]],
 ") become..."
}], "Text",
 CellChangeTimes->{{3.7980911651989994`*^9, 3.7980912170292397`*^9}, 
   3.8187661085419226`*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pert\[Psi]", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"pertdd\[Psi]", "/.", "d\[Rho]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Psi]", "'"}], "[", "t", "]"}], ",", 
       RowBox[{
        RowBox[{"\[Psi]", "''"}], "[", "t", "]"}], ",", 
       RowBox[{"f", "[", "t", "]"}], ",", 
       RowBox[{
        RowBox[{"f", "'"}], "[", "t", "]"}]}], "}"}], ",", "FullSimplify"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pertf", "=", 
    RowBox[{"Collect", "[", 
     RowBox[{
      RowBox[{"pertdf", "/.", "d\[Rho]"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Psi]", "'"}], "[", "t", "]"}], ",", 
        RowBox[{
         RowBox[{"\[Psi]", "''"}], "[", "t", "]"}], ",", 
        RowBox[{"f", "[", "t", "]"}], ",", 
        RowBox[{
         RowBox[{"f", "'"}], "[", "t", "]"}]}], "}"}], ",", "FullSimplify"}], 
     "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "pert\[Psi]", "\
\[IndentingNewLine]", "pertf"}], "Input",
 CellChangeTimes->{{3.798091219129939*^9, 3.7980912962694883`*^9}, {
  3.7980913321676316`*^9, 3.798091373494635*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"-", "3"}], " ", 
    RowBox[{"f", "[", "t", "]"}], " ", 
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}], "-", 
   FractionBox[
    RowBox[{"9", " ", "h", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "w"}], ")"}], " ", 
     SuperscriptBox["\[Delta]h", "2"], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], 
    RowBox[{
     RowBox[{"9", " ", "h", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "w"}], ")"}], " ", 
      SuperscriptBox["\[Alpha]", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"3", " ", "h", " ", "t", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "w"}], ")"}]}]], " ", "l", " ", 
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}]}]], "-", 
   FractionBox[
    RowBox[{"6", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"3", " ", "h", " ", "t", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "w"}], ")"}]}]], " ", "h", " ", 
     RowBox[{
      SuperscriptBox["f", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], 
    RowBox[{
     RowBox[{"9", " ", "h", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "w"}], ")"}], " ", 
      SuperscriptBox["\[Alpha]", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"3", " ", "h", " ", "t", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "w"}], ")"}]}]], " ", "l", " ", 
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}]}]], "+", 
   RowBox[{
    SuperscriptBox["\[Psi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Psi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"27", " ", 
         SuperscriptBox["h", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", "w"}], ")"}], "2"], " ", 
         SuperscriptBox["\[Alpha]", "2"]}], 
        RowBox[{
         RowBox[{"9", " ", "h", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "w"}], ")"}], " ", 
          SuperscriptBox["\[Alpha]", "2"]}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"3", " ", "h", " ", "t", " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "w"}], ")"}]}]], " ", "l", " ", 
          RowBox[{
           SuperscriptBox["\[Phi]", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[Phi]", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "t", "]"}], 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]]}], ")"}]}]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{3.798091374799714*^9, 3.798091436289708*^9, 
  3.7982821492484455`*^9, 3.7984285681441875`*^9, 3.7984576205593214`*^9, 
  3.798563066246766*^9, 3.79856337278448*^9, 3.798563834649349*^9, 
  3.798563930118224*^9, 3.7985640872963667`*^9, 3.7985731390532017`*^9, 
  3.7985795483151035`*^9, 3.798611070204558*^9, 3.798696453149234*^9, 
  3.7987142641639733`*^9, 3.7987146861611996`*^9, 3.7989389196719713`*^9, 
  3.7992329521242948`*^9, 3.799235815063718*^9, 3.7992386246254654`*^9, 
  3.7992387551972947`*^9, 3.8002676397353897`*^9, 3.801024433290983*^9, 
  3.801024675547594*^9, 3.8010250151916943`*^9, 3.8010336028854203`*^9, 
  3.814783930347283*^9, 3.8187661114369235`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox["f", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"f", "[", "t", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"3", " ", "h", " ", "t", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "w"}], ")"}]}]], " ", "l", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
           RowBox[{
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", "h", " ", 
               RowBox[{
                SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
                 MultilineFunction->None], "[", "t", "]"}]}], "-", 
              RowBox[{
               SuperscriptBox["\[Phi]", 
                TagBox[
                 RowBox[{"(", "3", ")"}],
                 Derivative],
                MultilineFunction->None], "[", "t", "]"}]}], ")"}]}]}], 
          ")"}]}], "-", 
        RowBox[{"9", " ", "h", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "w"}], ")"}], " ", 
         SuperscriptBox["\[Alpha]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", "h", " ", "w", " ", 
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[Phi]", 
             TagBox[
              RowBox[{"(", "3", ")"}],
              Derivative],
             MultilineFunction->None], "[", "t", "]"}]}], ")"}]}]}], ")"}]}], 
     ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"9", " ", "h", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "w"}], ")"}], " ", 
         SuperscriptBox["\[Alpha]", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"3", " ", "h", " ", "t", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "w"}], ")"}]}]], " ", "l", " ", 
         RowBox[{
          SuperscriptBox["\[Phi]", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}]}], ")"}], " ", 
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}], ")"}]}]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{3.798091374799714*^9, 3.798091436289708*^9, 
  3.7982821492484455`*^9, 3.7984285681441875`*^9, 3.7984576205593214`*^9, 
  3.798563066246766*^9, 3.79856337278448*^9, 3.798563834649349*^9, 
  3.798563930118224*^9, 3.7985640872963667`*^9, 3.7985731390532017`*^9, 
  3.7985795483151035`*^9, 3.798611070204558*^9, 3.798696453149234*^9, 
  3.7987142641639733`*^9, 3.7987146861611996`*^9, 3.7989389196719713`*^9, 
  3.7992329521242948`*^9, 3.799235815063718*^9, 3.7992386246254654`*^9, 
  3.7992387551972947`*^9, 3.8002676397353897`*^9, 3.801024433290983*^9, 
  3.801024675547594*^9, 3.8010250151916943`*^9, 3.8010336028854203`*^9, 
  3.814783930347283*^9, 3.818766111442769*^9}]
}, Open  ]],

Cell[TextData[{
 "We can solve ",
 StyleBox["pertf",
  FontSlant->"Italic"],
 " for the perturbation ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", "t", ")"}], TraditionalForm]]],
 " provided the background ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Phi]", "(", "t", ")"}], TraditionalForm]]],
 " (which can be obtained only when given the model ",
 Cell[BoxData[
  FormBox[
   RowBox[{"A", "(", "X", ")"}], TraditionalForm]]],
 "). The solution ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", "t", ")"}], TraditionalForm]]],
 " can then be plugged into ",
 StyleBox["pert",
  FontSlant->"Italic"],
 "\[Psi] to determine the scalar field perturbation. The theory potential ",
 Cell[BoxData[
  FormBox[
   RowBox[{"A", "(", "X", ")"}], TraditionalForm]]],
 " is therefore apparently needed to establish the stability.\n\nResorting to \
physical grounds that all non-vacuum energy forms of cosmic fluid, e.g., \
photons and cold dark matter, will eventually become diluted, we exploit the \
nearly-tadpole-free solution obtained earlier (\[Phi]",
 StyleBox["NTFrule",
  FontSlant->"Italic"],
 "). In this case, the perturbed field equations, up to ",
 Cell[BoxData[
  FormBox[
   RowBox[{"O", "(", "l", ")"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " in the tadpole, become..."
}], "Text",
 CellChangeTimes->{{3.798091647631339*^9, 3.798091770177677*^9}, {
  3.7980919687747836`*^9, 3.798092007322674*^9}, {3.798092049277604*^9, 
  3.7980921797477226`*^9}, {3.798714704159325*^9, 3.798714719363982*^9}, {
  3.7987147661610475`*^9, 3.798714831522149*^9}, {3.7987148622713747`*^9, 
  3.7987149406214266`*^9}, {3.7987149899553986`*^9, 3.7987150062921686`*^9}, {
  3.8187661471649623`*^9, 3.818766147455533*^9}, {3.8187661782023687`*^9, 
  3.818766185445053*^9}, {3.818766219028736*^9, 3.8187662421668344`*^9}, {
  3.8187662812526455`*^9, 3.8187663667200456`*^9}, {3.818766593602789*^9, 
  3.81876674682922*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Fpertvac", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Fpert", "/.", 
              RowBox[{"w", "\[Rule]", 
               RowBox[{"-", "1"}]}]}], "/.", 
             RowBox[{
              RowBox[{"\[Delta]\[Rho]", "[", "t", "]"}], "\[Rule]", 
              "\[Delta]\[CapitalLambda]"}]}], "/.", "\[Phi]NTF"}], "//", 
           "Simplify"}], ",", 
          RowBox[{"{", 
           RowBox[{"l", ",", "0", ",", "1"}], "}"}]}], "]"}], "//", 
        "Normal"}], ")"}], "/.", "\[Phi]NTFrule"}], ",", "l", ",", 
     "Simplify"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Hpertvac", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Hpert", "/.", 
             RowBox[{"w", "\[Rule]", 
              RowBox[{"-", "1"}]}]}], "/.", "\[Phi]NTF"}], "//", "Simplify"}],
           ",", 
          RowBox[{"{", 
           RowBox[{"l", ",", "0", ",", "1"}], "}"}]}], "]"}], "//", 
        "Normal"}], ")"}], "/.", "\[Phi]NTFrule"}], ",", "l", ",", 
     "Simplify"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Spertvac", "=", 
    RowBox[{"Collect", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Series", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Spert", "/.", 
              RowBox[{"w", "\[Rule]", 
               RowBox[{"-", "1"}]}]}], "/.", "\[Phi]NTF"}], "//", 
            "Simplify"}], ",", 
           RowBox[{"{", 
            RowBox[{"l", ",", "0", ",", "1"}], "}"}]}], "]"}], "//", 
         "Normal"}], ")"}], "/.", "\[Phi]NTFrule"}], ",", "l", ",", 
      "Simplify"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "Fpertvac", "\
\[IndentingNewLine]", "Hpertvac", "\[IndentingNewLine]", "Spertvac"}], "Input",
 CellChangeTimes->{{3.798715062913149*^9, 3.7987152011711164`*^9}, {
  3.798715235616856*^9, 3.7987152579938045`*^9}, {3.7987154020973644`*^9, 
  3.7987154452133875`*^9}, {3.7987155520161905`*^9, 3.7987155529089746`*^9}, {
  3.7987156518223114`*^9, 3.7987157039430175`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Epsilon]", " ", 
    RowBox[{"(", 
     RowBox[{"\[Delta]\[CapitalLambda]", "+", 
      RowBox[{
       RowBox[{"f", "[", "t", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "6"}], " ", "h"}], "-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["q", "2"], " ", 
           RowBox[{
            SuperscriptBox["A", "\[Prime]",
             MultilineFunction->None], "[", 
            FractionBox[
             SuperscriptBox["q", "2"], "2"], "]"}]}], "h"]}], ")"}]}], "-", 
      RowBox[{"q", " ", 
       RowBox[{
        SuperscriptBox["A", "\[Prime]",
         MultilineFunction->None], "[", 
        FractionBox[
         SuperscriptBox["q", "2"], "2"], "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Psi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"3", " ", 
      SuperscriptBox["h", "2"], " ", "q", " ", 
      RowBox[{
       SuperscriptBox["A", "\[Prime]",
        MultilineFunction->None], "[", 
       FractionBox[
        SuperscriptBox["q", "2"], "2"], "]"}]}]], 
    RowBox[{"l", " ", "\[Epsilon]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"q", " ", 
        RowBox[{"f", "[", "t", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", " ", "c", " ", "h"}], "-", "q", "+", 
             RowBox[{"6", " ", "h", " ", "q", " ", "t"}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["A", "\[Prime]",
             MultilineFunction->None], "[", 
            FractionBox[
             SuperscriptBox["q", "2"], "2"], "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["q", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "c", " ", "h"}], "-", "q", "+", 
             RowBox[{"3", " ", "h", " ", "q", " ", "t"}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["A", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", 
            FractionBox[
             SuperscriptBox["q", "2"], "2"], "]"}]}]}], ")"}]}], "+", 
       RowBox[{"h", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "3"}], " ", "h", " ", "q", " ", 
           RowBox[{"\[Psi]", "[", "t", "]"}], " ", 
           RowBox[{
            SuperscriptBox["A", "\[Prime]",
             MultilineFunction->None], "[", 
            FractionBox[
             SuperscriptBox["q", "2"], "2"], "]"}]}], "+", 
          RowBox[{
           RowBox[{
            SuperscriptBox["\[Psi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "h", " ", 
              RowBox[{"(", 
               RowBox[{"c", "+", 
                RowBox[{"q", " ", "t"}]}], ")"}], " ", 
              RowBox[{
               SuperscriptBox["A", "\[Prime]",
                MultilineFunction->None], "[", 
               FractionBox[
                SuperscriptBox["q", "2"], "2"], "]"}]}], "+", 
             RowBox[{
              SuperscriptBox["q", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", "c", " ", "h"}], "-", "q", "+", 
                RowBox[{"3", " ", "h", " ", "q", " ", "t"}]}], ")"}], " ", 
              RowBox[{
               SuperscriptBox["A", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", 
               FractionBox[
                SuperscriptBox["q", "2"], "2"], "]"}]}]}], ")"}]}]}], 
         ")"}]}]}], ")"}]}]}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{
  3.798715172034109*^9, 3.798715260523134*^9, {3.7987154349893208`*^9, 
   3.79871544727503*^9}, 3.798715714392131*^9, 3.7989389212809687`*^9, 
   3.799232953662238*^9, 3.799235817209205*^9, 3.7992386263425646`*^9, 
   3.800267641291772*^9, 3.8010244339488163`*^9, 3.801024677277134*^9, 
   3.8010250167754984`*^9, 3.801033604890375*^9, 3.8147839319290557`*^9, 
   3.818766752699769*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox[
    RowBox[{"\[Epsilon]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "3"}], " ", 
        SuperscriptBox["q", "2"], " ", 
        RowBox[{"f", "[", "t", "]"}], " ", 
        RowBox[{
         SuperscriptBox["A", "\[Prime]",
          MultilineFunction->None], "[", 
         FractionBox[
          SuperscriptBox["q", "2"], "2"], "]"}]}], "+", 
       RowBox[{"6", " ", "h", " ", 
        RowBox[{
         SuperscriptBox["f", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "+", 
       RowBox[{"q", " ", 
        RowBox[{
         SuperscriptBox["A", "\[Prime]",
          MultilineFunction->None], "[", 
         FractionBox[
          SuperscriptBox["q", "2"], "2"], "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Psi]", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], 
    RowBox[{"3", " ", "h"}]], "+", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"9", " ", 
      SuperscriptBox["h", "2"], " ", "q", " ", 
      RowBox[{
       SuperscriptBox["A", "\[Prime]",
        MultilineFunction->None], "[", 
       FractionBox[
        SuperscriptBox["q", "2"], "2"], "]"}]}]], 
    RowBox[{"l", " ", "\[Epsilon]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "3"}], " ", "h", " ", 
        SuperscriptBox["q", "3"], " ", 
        RowBox[{
         SuperscriptBox["\[Psi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], " ", 
        RowBox[{
         SuperscriptBox["A", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", 
         FractionBox[
          SuperscriptBox["q", "2"], "2"], "]"}]}], "+", 
       RowBox[{"3", " ", "q", " ", 
        RowBox[{"f", "[", "t", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", " ", "c", " ", "h"}], "-", "q", "+", 
             RowBox[{"6", " ", "h", " ", "q", " ", "t"}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["A", "\[Prime]",
             MultilineFunction->None], "[", 
            FractionBox[
             SuperscriptBox["q", "2"], "2"], "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["q", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "c", " ", "h"}], "-", "q", "+", 
             RowBox[{"3", " ", "h", " ", "q", " ", "t"}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["A", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", 
            FractionBox[
             SuperscriptBox["q", "2"], "2"], "]"}]}]}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "h", " ", 
           RowBox[{"(", 
            RowBox[{"c", "+", 
             RowBox[{"q", " ", "t"}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["A", "\[Prime]",
             MultilineFunction->None], "[", 
            FractionBox[
             SuperscriptBox["q", "2"], "2"], "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["q", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "c", " ", "h"}], "-", "q", "+", 
             RowBox[{"3", " ", "h", " ", "q", " ", "t"}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["A", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", 
            FractionBox[
             SuperscriptBox["q", "2"], "2"], "]"}]}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["\[Psi]", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}]}], 
  "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{
  3.798715172034109*^9, 3.798715260523134*^9, {3.7987154349893208`*^9, 
   3.79871544727503*^9}, 3.798715714392131*^9, 3.7989389212809687`*^9, 
   3.799232953662238*^9, 3.799235817209205*^9, 3.7992386263425646`*^9, 
   3.800267641291772*^9, 3.8010244339488163`*^9, 3.801024677277134*^9, 
   3.8010250167754984`*^9, 3.801033604890375*^9, 3.8147839319290557`*^9, 
   3.818766752716471*^9}],

Cell[BoxData[
 RowBox[{"l", "\[Equal]", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"q", " ", "\[Epsilon]", " ", 
      RowBox[{
       SuperscriptBox["A", "\[Prime]",
        MultilineFunction->None], "[", 
       FractionBox[
        SuperscriptBox["q", "2"], "2"], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "h", " ", 
         RowBox[{"f", "[", "t", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["f", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], ")"}]}], "h"]}], "+", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"3", " ", 
      SuperscriptBox["h", "2"], " ", "q", " ", 
      RowBox[{
       SuperscriptBox["A", "\[Prime]",
        MultilineFunction->None], "[", 
       FractionBox[
        SuperscriptBox["q", "2"], "2"], "]"}]}]], 
    RowBox[{"l", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", "h", " ", 
        RowBox[{
         SuperscriptBox["A", "\[Prime]",
          MultilineFunction->None], "[", 
         FractionBox[
          SuperscriptBox["q", "2"], "2"], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"h", " ", "q"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "c", " ", "h"}], "+", 
             RowBox[{"q", " ", 
              RowBox[{"(", 
               RowBox[{"2", "+", 
                RowBox[{"3", " ", "h", " ", "t"}]}], ")"}]}]}], ")"}], " ", 
           "\[Epsilon]", " ", 
           RowBox[{"f", "[", "t", "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"c", "+", 
             RowBox[{"q", " ", "t"}]}], ")"}], " ", "\[Epsilon]", " ", 
           RowBox[{
            SuperscriptBox["f", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["q", "2"], " ", "\[Epsilon]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"9", " ", 
           SuperscriptBox["h", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"c", "+", 
             RowBox[{"q", " ", "t"}]}], ")"}], " ", 
           RowBox[{"f", "[", "t", "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "c", " ", "h"}], "+", 
             RowBox[{"q", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"3", " ", "h", " ", "t"}]}], ")"}]}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["f", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}]}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["A", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", 
         FractionBox[
          SuperscriptBox["q", "2"], "2"], "]"}]}]}], ")"}]}]}]}]}]], "Output",
 CellChangeTimes->{
  3.798715172034109*^9, 3.798715260523134*^9, {3.7987154349893208`*^9, 
   3.79871544727503*^9}, 3.798715714392131*^9, 3.7989389212809687`*^9, 
   3.799232953662238*^9, 3.799235817209205*^9, 3.7992386263425646`*^9, 
   3.800267641291772*^9, 3.8010244339488163`*^9, 3.801024677277134*^9, 
   3.8010250167754984`*^9, 3.801033604890375*^9, 3.8147839319290557`*^9, 
   3.818766752728937*^9}]
}, Open  ]],

Cell[TextData[{
 "The ",
 Cell[BoxData[
  FormBox[
   RowBox[{"l", "\[Rule]", "0"}], TraditionalForm]]],
 " limit of the above equations lead to..."
}], "Text",
 CellChangeTimes->{{3.7987157332211204`*^9, 3.798715755716856*^9}, {
  3.8187667597865477`*^9, 3.8187668024854608`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pertd\[Psi]vac", "=", 
   RowBox[{
    RowBox[{"Fpertvac", "/.", 
     RowBox[{"l", "\[Rule]", "0"}]}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pertdd\[Psi]vac", "=", 
   RowBox[{
    RowBox[{"Hpertvac", "/.", 
     RowBox[{"l", "\[Rule]", "0"}]}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pertdfvac", "=", 
    RowBox[{
     RowBox[{"Spertvac", "/.", 
      RowBox[{"l", "\[Rule]", "0"}]}], "//", "Simplify"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "pertd\[Psi]vac", "\
\[IndentingNewLine]", "pertdd\[Psi]vac", "\[IndentingNewLine]", \
"pertdfvac"}], "Input",
 CellChangeTimes->{{3.7987157736154633`*^9, 3.7987158546877127`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Epsilon]", " ", 
   RowBox[{"(", 
    RowBox[{"\[Delta]\[CapitalLambda]", "+", 
     RowBox[{
      RowBox[{"f", "[", "t", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "6"}], " ", "h"}], "-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["q", "2"], " ", 
          RowBox[{
           SuperscriptBox["A", "\[Prime]",
            MultilineFunction->None], "[", 
           FractionBox[
            SuperscriptBox["q", "2"], "2"], "]"}]}], "h"]}], ")"}]}], "-", 
     RowBox[{"q", " ", 
      RowBox[{
       SuperscriptBox["A", "\[Prime]",
        MultilineFunction->None], "[", 
       FractionBox[
        SuperscriptBox["q", "2"], "2"], "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[Psi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{3.798715858706352*^9, 3.7989389213590746`*^9, 
  3.7992329537499285`*^9, 3.799235817291117*^9, 3.799238626456984*^9, 
  3.8002676413781443`*^9, 3.8010244340475655`*^9, 3.8010246773888483`*^9, 
  3.8010250169274287`*^9, 3.8010336050181355`*^9, 3.8147839321903577`*^9, 
  3.818766786333466*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"\[Epsilon]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", 
       SuperscriptBox["q", "2"], " ", 
       RowBox[{"f", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["A", "\[Prime]",
         MultilineFunction->None], "[", 
        FractionBox[
         SuperscriptBox["q", "2"], "2"], "]"}]}], "+", 
      RowBox[{"6", " ", "h", " ", 
       RowBox[{
        SuperscriptBox["f", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"q", " ", 
       RowBox[{
        SuperscriptBox["A", "\[Prime]",
         MultilineFunction->None], "[", 
        FractionBox[
         SuperscriptBox["q", "2"], "2"], "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Psi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], "h"], 
  "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.798715858706352*^9, 3.7989389213590746`*^9, 
  3.7992329537499285`*^9, 3.799235817291117*^9, 3.799238626456984*^9, 
  3.8002676413781443`*^9, 3.8010244340475655`*^9, 3.8010246773888483`*^9, 
  3.8010250169274287`*^9, 3.8010336050181355`*^9, 3.8147839321903577`*^9, 
  3.818766786342121*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"q", " ", "\[Epsilon]", " ", 
    RowBox[{
     SuperscriptBox["A", "\[Prime]",
      MultilineFunction->None], "[", 
     FractionBox[
      SuperscriptBox["q", "2"], "2"], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", "h", " ", 
       RowBox[{"f", "[", "t", "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}], ")"}]}], "h"], 
  "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.798715858706352*^9, 3.7989389213590746`*^9, 
  3.7992329537499285`*^9, 3.799235817291117*^9, 3.799238626456984*^9, 
  3.8002676413781443`*^9, 3.8010244340475655`*^9, 3.8010246773888483`*^9, 
  3.8010250169274287`*^9, 3.8010336050181355`*^9, 3.8147839321903577`*^9, 
  3.818766786347364*^9}]
}, Open  ]],

Cell["The perturbations can finally be obtained...", "Text",
 CellChangeTimes->{{3.798716175621768*^9, 3.7987162040075336`*^9}, {
  3.818766809697504*^9, 3.818766810600419*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"solpertvac", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"DSolve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"pertdd\[Psi]vac", ",", "pertdfvac"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Psi]", ",", "f"}], "}"}], ",", "t"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"C", "[", "1", "]"}], "\[Rule]", "\[Delta]H"}], ",", 
      RowBox[{
       RowBox[{"C", "[", "2", "]"}], "\[Rule]", "\[Delta]\[Chi]"}], ",", 
      RowBox[{
       RowBox[{"C", "[", "3", "]"}], "\[Rule]", "\[Delta]\[Xi]"}]}], 
     "}"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"constraint\[Psi]f", "=", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"pertd\[Psi]vac", "/.", "solpertvac"}], "//", "Simplify"}], 
       ",", "\[Delta]\[Xi]"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\"\<\[Psi](\!\(\*
StyleBox[\"t\",
FontSlant->\"Italic\"]\))\>\"", "\[Equal]", 
    RowBox[{"\[Psi]", "[", "t", "]"}]}], "/.", "solpertvac"}], "/.", 
  "constraint\[Psi]f"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\"\<f(t)\>\"", "\[Equal]", 
    RowBox[{"f", "[", "t", "]"}]}], "/.", "solpertvac"}], "/.", 
  "constraint\[Psi]f"}]}], "Input",
 CellChangeTimes->{{3.798716208373974*^9, 3.798716469930303*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\[Psi](\\!\\(\\*\\nStyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\
\"]\\))\"\>", "\[Equal]", 
  RowBox[{"\[Delta]\[Chi]", "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "3"}], " ", "h", " ", "t"}]], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"3", " ", "h", " ", "t"}]], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"3", " ", "h", " ", "t"}]], " ", "h", " ", "t"}]}], ")"}], 
     " ", "\[Delta]H", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"6", " ", 
        SuperscriptBox["h", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["q", "2"], " ", 
        RowBox[{
         SuperscriptBox["A", "\[Prime]",
          MultilineFunction->None], "[", 
         FractionBox[
          SuperscriptBox["q", "2"], "2"], "]"}]}]}], ")"}]}], 
    RowBox[{"3", " ", 
     SuperscriptBox["h", "2"], " ", "q", " ", 
     RowBox[{
      SuperscriptBox["A", "\[Prime]",
       MultilineFunction->None], "[", 
      FractionBox[
       SuperscriptBox["q", "2"], "2"], "]"}]}]], "+", 
   FractionBox[
    RowBox[{"t", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "6"}], " ", 
        SuperscriptBox["h", "2"], " ", "\[Delta]H"}], "+", 
       RowBox[{"h", " ", "\[Delta]\[CapitalLambda]"}], "-", 
       RowBox[{
        SuperscriptBox["q", "2"], " ", "\[Delta]H", " ", 
        RowBox[{
         SuperscriptBox["A", "\[Prime]",
          MultilineFunction->None], "[", 
         FractionBox[
          SuperscriptBox["q", "2"], "2"], "]"}]}]}], ")"}]}], 
    RowBox[{"h", " ", "q", " ", 
     RowBox[{
      SuperscriptBox["A", "\[Prime]",
       MultilineFunction->None], "[", 
      FractionBox[
       SuperscriptBox["q", "2"], "2"], "]"}]}]]}]}]], "Output",
 CellChangeTimes->{{3.798716323603159*^9, 3.7987163299308953`*^9}, 
   3.7987164704987316`*^9, 3.7989389215465317`*^9, 3.7992329538335505`*^9, 
   3.7992358173812046`*^9, 3.799238626540244*^9, 3.8002676415124846`*^9, 
   3.8010244341092815`*^9, 3.801024677458926*^9, 3.8010250169997716`*^9, 
   3.8010336051315794`*^9, 3.8147839323030567`*^9, 3.818766828338814*^9}],

Cell[BoxData[
 RowBox[{"\<\"f(t)\"\>", "\[Equal]", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "3"}], " ", "h", " ", "t"}]], " ", 
   "\[Delta]H"}]}]], "Output",
 CellChangeTimes->{{3.798716323603159*^9, 3.7987163299308953`*^9}, 
   3.7987164704987316`*^9, 3.7989389215465317`*^9, 3.7992329538335505`*^9, 
   3.7992358173812046`*^9, 3.799238626540244*^9, 3.8002676415124846`*^9, 
   3.8010244341092815`*^9, 3.801024677458926*^9, 3.8010250169997716`*^9, 
   3.8010336051315794`*^9, 3.8147839323030567`*^9, 3.818766828346763*^9}]
}, Open  ]],

Cell[TextData[{
 "We checkout ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Psi]", "'"}], 
    RowBox[{"(", "t", ")"}]}], TraditionalForm]]],
 " because the theory is shift symmetric..."
}], "Text",
 CellChangeTimes->{{3.7987167294191403`*^9, 3.7987167579053106`*^9}, {
  3.798716806389377*^9, 3.7987168876251516`*^9}, {3.8187668388141503`*^9, 
  3.8187668646200886`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\"\<\[Psi]'(\!\(\*
StyleBox[\"t\",
FontSlant->\"Italic\"]\))\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Psi]", "'"}], "[", "t", "]"}], "/.", "solpertvac"}], "/.", 
     "constraint\[Psi]f"}], "//", "FullSimplify"}], ")"}]}]], "Input",
 CellChangeTimes->{{3.798716912509098*^9, 3.798716934221386*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\[Psi]'(\\!\\(\\*\\nStyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\
\\\"]\\))\"\>", "\[Equal]", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "3"}], " ", "h", " ", "t"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"h", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "6"}], " ", "h", " ", "\[Delta]H"}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"3", " ", "h", " ", "t"}]], " ", 
          "\[Delta]\[CapitalLambda]"}]}], ")"}]}], "-", 
      RowBox[{
       SuperscriptBox["q", "2"], " ", "\[Delta]H", " ", 
       RowBox[{
        SuperscriptBox["A", "\[Prime]",
         MultilineFunction->None], "[", 
        FractionBox[
         SuperscriptBox["q", "2"], "2"], "]"}]}]}], ")"}]}], 
   RowBox[{"h", " ", "q", " ", 
    RowBox[{
     SuperscriptBox["A", "\[Prime]",
      MultilineFunction->None], "[", 
     FractionBox[
      SuperscriptBox["q", "2"], "2"], "]"}]}]]}]], "Output",
 CellChangeTimes->{{3.7987169156870985`*^9, 3.7987169346948614`*^9}, 
   3.7989389216558805`*^9, 3.7992329539418964`*^9, 3.7992358174948807`*^9, 
   3.7992386269337463`*^9, 3.80026764164697*^9, 3.8010244341678543`*^9, 
   3.801024677574436*^9, 3.801025017111287*^9, 3.8010336052889514`*^9, 
   3.814783932420743*^9, 3.818766831402882*^9, 3.8187668673901224`*^9}]
}, Open  ]],

Cell["\<\
The last two equations are Eqs. (3.51) and (3.52). This shows the dynamical \
stability of the de Sitter vacuum of the self-tuning tadpole-free theory.\
\>", "Text",
 CellChangeTimes->{{3.7987169647778025`*^9, 3.798716979764908*^9}, {
  3.7987170104412165`*^9, 3.7987170722636395`*^9}, {3.798717146039576*^9, 
  3.7987172174297757`*^9}, {3.818766873197451*^9, 3.8187668858679514`*^9}, {
  3.818766921772702*^9, 3.8187669752816353`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["3.4 Self-tuning and the vanishing current-hypersurface", "Subsubsection",
 CellChangeTimes->{{3.798082577147138*^9, 3.7980825858613334`*^9}, {
  3.8002702218726616`*^9, 3.8002702261093073`*^9}, {3.8187670100192175`*^9, 
  3.81876701228531*^9}}],

Cell["\<\
We establish an important connection between the self-tuning theory and the \
vanishing scalar current-hypersurface.

To start, we write down the scalar field equation in its total derivative \
form...\
\>", "Text",
 CellChangeTimes->{{3.79828250753115*^9, 3.7982825190004015`*^9}, {
   3.798282558742696*^9, 3.7982825822164955`*^9}, {3.7982829040142817`*^9, 
   3.798282961734624*^9}, {3.7982850625081863`*^9, 3.798285076877718*^9}, {
   3.7984285743842635`*^9, 3.798428584343584*^9}, 3.8187670154925537`*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"J", "[", "t", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[PartialD]", "b"], 
        RowBox[{"K", "[", 
         RowBox[{"a", ",", "b"}], "]"}]}], ")"}]}], "+", 
     RowBox[{"6", 
      RowBox[{"H", "[", "t", "]"}], 
      RowBox[{"(", 
       FractionBox[
        SuperscriptBox[
         RowBox[{
          RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "2"], "2"], ")"}], 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[PartialD]", "b"], 
        RowBox[{"G", "[", 
         RowBox[{"a", ",", "b"}], "]"}]}], ")"}]}], "-", 
     RowBox[{"2", 
      RowBox[{
       RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[PartialD]", "a"], 
        RowBox[{"G", "[", 
         RowBox[{"a", ",", "b"}], "]"}]}], ")"}]}]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", "\[Rule]", 
       RowBox[{"\[Phi]", "[", "t", "]"}]}], ",", 
      RowBox[{"b", "\[Rule]", 
       FractionBox[
        SuperscriptBox[
         RowBox[{
          RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "2"], "2"]}]}], "}"}]}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"S", "[", "t", "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[PartialD]", "a"], 
        RowBox[{"K", "[", 
         RowBox[{"a", ",", "b"}], "]"}]}], ")"}], "-", 
      RowBox[{"2", 
       RowBox[{"(", 
        FractionBox[
         SuperscriptBox[
          RowBox[{
           RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "2"], "2"], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[PartialD]", "a"], 
           RowBox[{
            SubscriptBox["\[PartialD]", "a"], 
            RowBox[{"G", "[", 
             RowBox[{"a", ",", "b"}], "]"}]}]}], ")"}], "+", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Phi]", "''"}], "[", "t", "]"}], 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["\[PartialD]", "a"], 
            RowBox[{
             SubscriptBox["\[PartialD]", "b"], 
             RowBox[{"G", "[", 
              RowBox[{"a", ",", "b"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "\[Rule]", 
        RowBox[{"\[Phi]", "[", "t", "]"}]}], ",", 
       RowBox[{"b", "\[Rule]", 
        FractionBox[
         SuperscriptBox[
          RowBox[{
           RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "2"], "2"]}]}], 
      "}"}]}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"atoH", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"H", "[", "t", "]"}], "\[Equal]", 
         FractionBox[
          RowBox[{
           RowBox[{"a", "'"}], "[", "t", "]"}], 
          RowBox[{"a", "[", "t", "]"}]]}], ",", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"H", "[", "t", "]"}], "\[Equal]", 
           FractionBox[
            RowBox[{
             RowBox[{"a", "'"}], "[", "t", "]"}], 
            RowBox[{"a", "[", "t", "]"}]]}], ",", "t"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"a", "'"}], "[", "t", "]"}], ",", 
        RowBox[{
         RowBox[{"a", "''"}], "[", "t", "]"}]}], "}"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sfe", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         FractionBox["1", 
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "3"]], 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"a", "[", "t", "]"}], "3"], 
            RowBox[{"J", "[", "t", "]"}]}], ",", "t"}], "]"}]}], "/.", 
        "atoH"}], "//", "Simplify"}], ")"}], "\[Equal]", 
     RowBox[{"S", "[", "t", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"This", " ", "calculation", " ", "confirms", " ", 
    StyleBox["sfe",
     FontSlant->"Italic"], " ", "as", " ", "the", " ", "same", " ", "as", " ", 
    StyleBox["SFE",
     FontSlant->"Italic"]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sfe", "/.", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{"SFE", ",", 
      RowBox[{
       RowBox[{"\[Phi]", "''"}], "[", "t", "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.7982829735506587`*^9, 3.798283399196528*^9}, {
  3.7982836787810736`*^9, 3.7982837372473264`*^9}, {3.7982837744327927`*^9, 
  3.7982838147456875`*^9}, {3.7985638754173346`*^9, 3.7985638973994617`*^9}, {
  3.8187670382477226`*^9, 3.8187670880326257`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.798283385618608*^9, 3.798283399728715*^9}, 
   3.798283746291844*^9, {3.7982838105337863`*^9, 3.798283815247086*^9}, 
   3.7984285907792964`*^9, 3.7984576211297574`*^9, 3.798563066997108*^9, 
   3.798563373355968*^9, 3.798563843821809*^9, 3.798563944219716*^9, 
   3.7985640881407213`*^9, 3.7985731397175846`*^9, 3.798579549352707*^9, 
   3.7987142647994833`*^9, 3.7989389219683037`*^9, 3.799232954535976*^9, 
   3.7992358178113585`*^9, 3.7992386275563593`*^9, 3.800267642025484*^9, 
   3.8010246779208207`*^9, 3.8010250174106503`*^9, 3.8010336056113234`*^9, 
   3.814783940471224*^9, 3.8187670298090763`*^9}]
}, Open  ]],

Cell[TextData[{
 "In the shift symmetric theory, the current ",
 Cell[BoxData[
  FormBox[
   RowBox[{"J", "(", "t", ")"}], TraditionalForm]]],
 " and the heat term ",
 Cell[BoxData[
  FormBox[
   RowBox[{"S", "(", "t", ")"}], TraditionalForm]]],
 " become..."
}], "Text",
 CellChangeTimes->{{3.798282991248067*^9, 3.798282997321971*^9}, {
  3.798283820340648*^9, 3.7982838495339355`*^9}, {3.798428601565091*^9, 
  3.79842860174572*^9}, {3.818767198787222*^9, 3.8187672049161205`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Jtp", "[", "t_", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"J", "[", "t", "]"}], "/.", "tadpole"}], "//", 
    "FullSimplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Stp", "[", "t_", "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"S", "[", "t", "]"}], "/.", "tadpole"}], "//", 
     "FullSimplify"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*
StyleBox[\"J\",
FontSlant->\"Italic\"]\)(\!\(\*
StyleBox[\"t\",
FontSlant->\"Italic\"]\))\>\"", "\[Equal]", 
  RowBox[{"Jtp", "[", "t", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*
StyleBox[\"S\",
FontSlant->\"Italic\"]\)(\!\(\*
StyleBox[\"t\",
FontSlant->\"Italic\"]\))\>\"", "\[Equal]", 
  RowBox[{"Stp", "[", "t", "]"}]}]}], "Input",
 CellChangeTimes->{{3.7982838508063374`*^9, 3.7982839447009735`*^9}, {
  3.7982842147975917`*^9, 3.798284251744196*^9}, {3.7985639533214097`*^9, 
  3.798563968746236*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*\\nStyleBox[\\\"J\\\",\\nFontSlant->\\\"Italic\\\"]\\)(\
\\!\\(\\*\\nStyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"]\\))\"\>", 
  "\[Equal]", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["A", "\[Prime]",
       MultilineFunction->None], "[", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], "+", 
     RowBox[{"3", " ", 
      RowBox[{"H", "[", "t", "]"}], " ", 
      RowBox[{
       SuperscriptBox["B", "\[Prime]",
        MultilineFunction->None], "[", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Phi]", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.7982838521718845`*^9, 3.798283867800827*^9}, {
   3.7982839265628004`*^9, 3.7982839449951324`*^9}, {3.798284240198718*^9, 
   3.798284252517666*^9}, 3.7984286075792274`*^9, 3.7984576211766243`*^9, 
   3.798563067070538*^9, 3.7985633733935447`*^9, 3.798563843913106*^9, 
   3.798563972483363*^9, 3.7985640882014475`*^9, 3.798573139741763*^9, 
   3.79857954944814*^9, 3.798714264847478*^9, 3.7989389219995484`*^9, 
   3.7992329545820265`*^9, 3.7992358178565135`*^9, 3.799238627638139*^9, 
   3.8002676420688066`*^9, 3.8010246779692774`*^9, 3.8010250174316473`*^9, 
   3.8010336056386695`*^9, 3.8147839405370483`*^9, 3.8187672136601486`*^9}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*\\nStyleBox[\\\"S\\\",\\nFontSlant->\\\"Italic\\\"]\\)(\
\\!\\(\\*\\nStyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"]\\))\"\>", 
  "\[Equal]", "l"}]], "Output",
 CellChangeTimes->{{3.7982838521718845`*^9, 3.798283867800827*^9}, {
   3.7982839265628004`*^9, 3.7982839449951324`*^9}, {3.798284240198718*^9, 
   3.798284252517666*^9}, 3.7984286075792274`*^9, 3.7984576211766243`*^9, 
   3.798563067070538*^9, 3.7985633733935447`*^9, 3.798563843913106*^9, 
   3.798563972483363*^9, 3.7985640882014475`*^9, 3.798573139741763*^9, 
   3.79857954944814*^9, 3.798714264847478*^9, 3.7989389219995484`*^9, 
   3.7992329545820265`*^9, 3.7992358178565135`*^9, 3.799238627638139*^9, 
   3.8002676420688066`*^9, 3.8010246779692774`*^9, 3.8010250174316473`*^9, 
   3.8010336056386695`*^9, 3.8147839405370483`*^9, 3.8187672136678267`*^9}]
}, Open  ]],

Cell["\<\
In the self-tuning theory, the above equations reduce further to...\
\>", "Text",
 CellChangeTimes->{{3.798284203288878*^9, 3.7982842089351444`*^9}, {
  3.7982845869342823`*^9, 3.7982847342049913`*^9}, {3.7984287323185663`*^9, 
  3.7984287341141386`*^9}, {3.818767230226866*^9, 3.818767254499802*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Jst", "[", "t_", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Jtp", "[", "t", "]"}], "/.", "st"}], "//", "FullSimplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Sst", "[", "t_", "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Stp", "[", "t", "]"}], "/.", "st"}], "//", "FullSimplify"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*
StyleBox[\"J\",
FontSlant->\"Italic\"]\)(\!\(\*
StyleBox[\"t\",
FontSlant->\"Italic\"]\))\>\"", "\[Equal]", 
  RowBox[{"Jst", "[", "t", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*
StyleBox[\"S\",
FontSlant->\"Italic\"]\)(\!\(\*
StyleBox[\"t\",
FontSlant->\"Italic\"]\))\>\"", "\[Equal]", 
  RowBox[{"Sst", "[", "t", "]"}]}]}], "Input",
 CellChangeTimes->{{3.798428758879073*^9, 3.798428768808404*^9}, {
  3.798563981469945*^9, 3.7985639993332124`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*\\nStyleBox[\\\"J\\\",\\nFontSlant->\\\"Italic\\\"]\\)(\
\\!\\(\\*\\nStyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"]\\))\"\>", 
  "\[Equal]", 
  FractionBox[
   RowBox[{
    RowBox[{"l", " ", 
     RowBox[{"H", "[", "t", "]"}]}], "+", 
    RowBox[{"3", " ", "h", " ", 
     RowBox[{"(", 
      RowBox[{"h", "-", 
       RowBox[{"H", "[", "t", "]"}]}], ")"}], " ", 
     RowBox[{
      SuperscriptBox["A", "\[Prime]",
       MultilineFunction->None], "[", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]}], 
   RowBox[{"3", " ", 
    SuperscriptBox["h", "2"]}]]}]], "Output",
 CellChangeTimes->{3.798284347359041*^9, 3.7982847368495283`*^9, 
  3.798428778452032*^9, 3.798457621230012*^9, 3.798563067203497*^9, 
  3.7985633734478445`*^9, 3.7985638439832945`*^9, 3.798564000819953*^9, 
  3.79856408828239*^9, 3.7985731397922564`*^9, 3.798579549517872*^9, 
  3.79871426490574*^9, 3.7989389220464478`*^9, 3.7992329546388683`*^9, 
  3.7992358179128056`*^9, 3.7992386277465057`*^9, 3.8002676421338353`*^9, 
  3.801024678026902*^9, 3.801025017482732*^9, 3.801033605702099*^9, 
  3.814783940604866*^9, 3.8187672563661785`*^9}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*\\nStyleBox[\\\"S\\\",\\nFontSlant->\\\"Italic\\\"]\\)(\
\\!\\(\\*\\nStyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"]\\))\"\>", 
  "\[Equal]", "l"}]], "Output",
 CellChangeTimes->{3.798284347359041*^9, 3.7982847368495283`*^9, 
  3.798428778452032*^9, 3.798457621230012*^9, 3.798563067203497*^9, 
  3.7985633734478445`*^9, 3.7985638439832945`*^9, 3.798564000819953*^9, 
  3.79856408828239*^9, 3.7985731397922564`*^9, 3.798579549517872*^9, 
  3.79871426490574*^9, 3.7989389220464478`*^9, 3.7992329546388683`*^9, 
  3.7992358179128056`*^9, 3.7992386277465057`*^9, 3.8002676421338353`*^9, 
  3.801024678026902*^9, 3.801025017482732*^9, 3.801033605702099*^9, 
  3.814783940604866*^9, 3.818767256371589*^9}]
}, Open  ]],

Cell[TextData[{
 "The above expression for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"J", "(", "t", ")"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " is Eq. (3.59). However, the scalar current ",
 Cell[BoxData[
  FormBox[
   RowBox[{"j", "(", "t", ")"}], TraditionalForm]]],
 " can also be written as Eq. (3.56)..."
}], "Text",
 CellChangeTimes->{{3.798285050625844*^9, 3.798285051264221*^9}, {
  3.7984287970618486`*^9, 3.79842884764526*^9}, {3.7984289115807314`*^9, 
  3.7984289237312365`*^9}, {3.818767416361495*^9, 3.8187674506830387`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"jsol", "=", 
    RowBox[{
     RowBox[{"DSolve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         FractionBox["1", 
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "3"]], 
         RowBox[{
          SubscriptBox["\[PartialD]", "t"], 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"a", "[", "t", "]"}], "3"], 
            RowBox[{"j", "[", "t", "]"}]}], ")"}]}]}], "\[Equal]", "l"}], ",",
        "j", ",", "t"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\"\<\!\(\*
StyleBox[\"J\",
FontSlant->\"Italic\"]\)(\!\(\*
StyleBox[\"t\",
FontSlant->\"Italic\"]\))\>\"", "\[Equal]", 
   RowBox[{"j", "[", "t", "]"}]}], "/.", "jsol"}]}], "Input",
 CellChangeTimes->{{3.7982847737582026`*^9, 3.798284832168108*^9}, {
  3.798285104918747*^9, 3.798285105569476*^9}, {3.7982851381103573`*^9, 
  3.7982851386573567`*^9}, {3.7984288970662847`*^9, 3.798428948674948*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*\\nStyleBox[\\\"J\\\",\\nFontSlant->\\\"Italic\\\"]\\)(\
\\!\\(\\*\\nStyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"]\\))\"\>", 
  "\[Equal]", 
  RowBox[{
   FractionBox[
    RowBox[{"C", "[", "1", "]"}], 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "3"]], "+", 
   FractionBox[
    RowBox[{
     SubsuperscriptBox["\[Integral]", "1", "t"], 
     RowBox[{
      RowBox[{"l", " ", 
       SuperscriptBox[
        RowBox[{"a", "[", 
         RowBox[{"K", "[", "1", "]"}], "]"}], "3"]}], 
      RowBox[{"\[DifferentialD]", 
       RowBox[{"K", "[", "1", "]"}]}]}]}], 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "3"]]}]}]], "Output",
 CellChangeTimes->{{3.7982847927407513`*^9, 3.798284832925003*^9}, 
   3.7982851067425604`*^9, 3.79828514004601*^9, {3.7984289430803647`*^9, 
   3.7984289544442773`*^9}, 3.7984576213771515`*^9, 3.79856306780733*^9, 
   3.7985633735827775`*^9, 3.7985638442106404`*^9, 3.7985640115874667`*^9, 
   3.7985640884761286`*^9, 3.7985731399306045`*^9, 3.798579549805928*^9, 
   3.798714265173704*^9, 3.798938922265113*^9, 3.7992329548661985`*^9, 
   3.799235818079409*^9, 3.799238627885154*^9, 3.8002676426788445`*^9, 
   3.8010246783037944`*^9, 3.801025017626992*^9, 3.801033605928066*^9, 
   3.814783940846225*^9, 3.8187674396434402`*^9}]
}, Open  ]],

Cell[TextData[{
 "This expression will allow us to make a deduction about the vanishing shift \
current hypersurface, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"J", "(", "t", ")"}], "=", "0"}], TraditionalForm]]],
 ". To get to this, we substitute a power law and exponential ",
 Cell[BoxData[
  FormBox[
   RowBox[{"a", "(", "t", ")"}], TraditionalForm]]],
 " into this expression..."
}], "Text",
 CellChangeTimes->{{3.7984289937117586`*^9, 3.7984290658806005`*^9}, {
  3.7984290962838125`*^9, 3.7984291256768575`*^9}, {3.818767458974513*^9, 
  3.8187674827992096`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"jsol", "=", 
    RowBox[{"j", "\[Rule]", 
     RowBox[{"Function", "[", 
      RowBox[{"t", ",", 
       RowBox[{
        FractionBox["q", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "3"]], "+", 
        RowBox[{
         FractionBox["l", 
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "3"]], 
         RowBox[{"(", 
          RowBox[{"\[Integral]", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"a", "[", "t", "]"}], "3"], 
            RowBox[{"\[DifferentialD]", "t"}]}]}], ")"}]}]}]}], "]"}]}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"apow", "=", 
   RowBox[{"a", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{"t", ",", 
      RowBox[{"\[Alpha]", " ", 
       SuperscriptBox["t", "n"]}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"aexp", "=", 
    RowBox[{"a", "\[Rule]", 
     RowBox[{"Function", "[", 
      RowBox[{"t", ",", 
       RowBox[{"\[Beta]", " ", 
        SuperscriptBox["E", 
         RowBox[{"h", " ", "t"}]]}]}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*
StyleBox[\"J\",
FontSlant->\"Italic\"]\)(\!\(\*
StyleBox[\"t\",
FontSlant->\"Italic\"]\))\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"j", "[", "t", "]"}], "/.", "jsol"}], "/.", "apow"}], "//", 
    "FullSimplify"}], ")"}]}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*
StyleBox[\"J\",
FontSlant->\"Italic\"]\)(\!\(\*
StyleBox[\"t\",
FontSlant->\"Italic\"]\))\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"j", "[", "t", "]"}], "/.", "jsol"}], "/.", "aexp"}], "//", 
    "FullSimplify"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.7984291283230667`*^9, 3.798429242574602*^9}, {
  3.7984292996100097`*^9, 3.7984292997548113`*^9}, {3.798429357078841*^9, 
  3.7984294941488113`*^9}, {3.8187675244431305`*^9, 3.818767524999266*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*\\nStyleBox[\\\"J\\\",\\nFontSlant->\\\"Italic\\\"]\\)(\
\\!\\(\\*\\nStyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"]\\))\"\>", 
  "\[Equal]", 
  RowBox[{
   FractionBox[
    RowBox[{"l", " ", "t"}], 
    RowBox[{"1", "+", 
     RowBox[{"3", " ", "n"}]}]], "+", 
   FractionBox[
    RowBox[{"q", " ", 
     SuperscriptBox["t", 
      RowBox[{
       RowBox[{"-", "3"}], " ", "n"}]]}], 
    SuperscriptBox["\[Alpha]", "3"]]}]}]], "Output",
 CellChangeTimes->{3.7984292460969753`*^9, 3.798429510319928*^9, 
  3.7984576214461546`*^9, 3.798563068095513*^9, 3.798563373665242*^9, 
  3.7985638443642883`*^9, 3.798564017528899*^9, 3.7985640885951614`*^9, 
  3.7985731400618615`*^9, 3.7985795499553633`*^9, 3.7987142652552433`*^9, 
  3.798938922327628*^9, 3.799232955018815*^9, 3.799235818160204*^9, 
  3.799238627975129*^9, 3.8002676432095995`*^9, 3.8010246785078735`*^9, 
  3.8010250177087884`*^9, 3.8010336060795507`*^9, 3.8147839409399714`*^9, 
  3.818767488059819*^9, 3.8187675292162895`*^9}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*\\nStyleBox[\\\"J\\\",\\nFontSlant->\\\"Italic\\\"]\\)(\
\\!\\(\\*\\nStyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"]\\))\"\>", 
  "\[Equal]", 
  RowBox[{
   FractionBox["l", 
    RowBox[{"3", " ", "h"}]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "3"}], " ", "h", " ", "t"}]], " ", "q"}], 
    SuperscriptBox["\[Beta]", "3"]]}]}]], "Output",
 CellChangeTimes->{3.7984292460969753`*^9, 3.798429510319928*^9, 
  3.7984576214461546`*^9, 3.798563068095513*^9, 3.798563373665242*^9, 
  3.7985638443642883`*^9, 3.798564017528899*^9, 3.7985640885951614`*^9, 
  3.7985731400618615`*^9, 3.7985795499553633`*^9, 3.7987142652552433`*^9, 
  3.798938922327628*^9, 3.799232955018815*^9, 3.799235818160204*^9, 
  3.799238627975129*^9, 3.8002676432095995`*^9, 3.8010246785078735`*^9, 
  3.8010250177087884`*^9, 3.8010336060795507`*^9, 3.8147839409399714`*^9, 
  3.818767488059819*^9, 3.8187675292162895`*^9}]
}, Open  ]],

Cell[TextData[{
 "These are Eqs. (3.57) and (3.58). For ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", ">", "0"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"h", ">", "0"}], TraditionalForm]]],
 ", we see that ",
 Cell[BoxData[
  FormBox[
   RowBox[{"J", "(", "t", ")"}], TraditionalForm]]],
 " would always vanish at late times for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"l", "=", "0"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ". The hypersurface ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"J", "(", "t", ")"}], "=", "0"}], TraditionalForm]]],
 " can be interpreted as the late-time asymptotic state of expanding \
cosmologies.\n\nOn the other hand, the current for the tadpole-free theory \
exactly vanishes at the de Sitter state..."
}], "Text",
 CellChangeTimes->{{3.7984295361303205`*^9, 3.798429584876717*^9}, {
  3.7984296227186685`*^9, 3.7984298481360703`*^9}, {3.798429894121627*^9, 
  3.798429910320476*^9}, {3.818767533088405*^9, 3.818767636683556*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"\"\<\!\(\*
StyleBox[\"J\",
FontSlant->\"Italic\"]\)(\!\(\*
StyleBox[\"t\",
FontSlant->\"Italic\"]\))\>\"", "\[Equal]", 
   RowBox[{"Jst", "[", "t", "]"}]}], "/.", 
  RowBox[{"l", "\[Rule]", "0"}]}]], "Input",
 CellChangeTimes->{{3.798429914650177*^9, 3.7984299165477943`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*\\nStyleBox[\\\"J\\\",\\nFontSlant->\\\"Italic\\\"]\\)(\
\\!\\(\\*\\nStyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"]\\))\"\>", 
  "\[Equal]", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"h", "-", 
      RowBox[{"H", "[", "t", "]"}]}], ")"}], " ", 
    RowBox[{
     SuperscriptBox["A", "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}], "]"}], " ", 
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}], "h"]}]], "Output",
 CellChangeTimes->{{3.798429912318962*^9, 3.7984299172281265`*^9}, 
   3.7984576215308123`*^9, 3.7985630681737127`*^9, 3.798563373745322*^9, 
   3.79856384454946*^9, 3.7985640214706545`*^9, 3.798564088758318*^9, 
   3.7985731401560144`*^9, 3.798579550052399*^9, 3.7987142653393097`*^9, 
   3.7989389224681873`*^9, 3.7992329551023693`*^9, 3.799235818315179*^9, 
   3.7992386281102257`*^9, 3.800267643287916*^9, 3.80102467859017*^9, 
   3.801025017800991*^9, 3.8010336061921577`*^9, 3.8147839410297327`*^9, 
   3.81876764041351*^9}]
}, Open  ]],

Cell["\<\
This shows that the late time state of the self-tuning tadpole-free theory is \
cosmic acceleration.\
\>", "Text",
 CellChangeTimes->{{3.798429936452694*^9, 3.7984299580725646`*^9}, {
  3.798430041324526*^9, 3.7984300422053814`*^9}, {3.798430095744633*^9, 
  3.798430191394908*^9}, {3.818767659380295*^9, 3.8187676694116707`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["3.5 Ghost and Laplace stability conditions", "Subsubsection",
 CellChangeTimes->{{3.7980825880468903`*^9, 3.798082597042553*^9}}],

Cell[TextData[{
 "We study ghost and gradient stability constraints for the self-tuning \
tadpole-free KGB. The stability conditions ensuring the absence of ghost and \
gradient instabilities have been originally derived in ",
 ButtonBox["arXiv:1008.0048",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://arxiv.org/abs/1008.0048"], None},
  ButtonNote->"https://arxiv.org/abs/1008.0048"],
 " (Deffayet, et al.) and ",
 ButtonBox["arXiv:1008.0603",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://arxiv.org/abs/1008.0603"], None},
  ButtonNote->"https://arxiv.org/abs/1008.0603"],
 " (Kobayashi, et al.). See also the explicit derivation in ",
 StyleBox["kgb_second_order_action.nb",
  FontSlant->"Italic"],
 " implemented in ",
 StyleBox["xPand",
  FontSlant->"Italic"],
 ".\n\nThe ghost and gradient stability constraints are given by ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", ">", "0"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"g", ">", "0"}], TraditionalForm]]],
 " where..."
}], "Text",
 CellChangeTimes->{
  3.7982861724294863`*^9, {3.7984302059740467`*^9, 3.798430319169034*^9}, {
   3.7984304325460925`*^9, 3.79843051984369*^9}, {3.79843056929123*^9, 
   3.798430631912266*^9}, {3.798430662396411*^9, 3.798430673109482*^9}, {
   3.8187677563627853`*^9, 3.8187677949699683`*^9}, {3.8187678602477303`*^9, 
   3.8187679505161667`*^9}, {3.8187680543935575`*^9, 3.8187680919366813`*^9}, 
   3.81876812986621*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"M", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["\[PartialD]", "X"], 
      RowBox[{"K", "[", 
       RowBox[{"\[Phi]", ",", "X"}], "]"}]}], ")"}], "+", 
    RowBox[{"2", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[PartialD]", "X"], 
       RowBox[{"G", "[", 
        RowBox[{"\[Phi]", ",", "X"}], "]"}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Phi]", "''"}], "[", "t", "]"}], "+", 
       RowBox[{"2", 
        RowBox[{"H", "[", "t", "]"}], 
        RowBox[{
         RowBox[{"\[Phi]", "'"}], "[", "t", "]"}]}]}], ")"}]}], "-", 
    RowBox[{"2", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[PartialD]", "X"], 
         RowBox[{"G", "[", 
          RowBox[{"\[Phi]", ",", "X"}], "]"}]}], ")"}], "2"], 
      SuperscriptBox["M", "2"]], 
     SuperscriptBox["X", "2"]}], "+", 
    RowBox[{"2", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[PartialD]", "X"], 
       RowBox[{
        SubscriptBox["\[PartialD]", "X"], 
        RowBox[{"G", "[", 
         RowBox[{"\[Phi]", ",", "X"}], "]"}]}]}], ")"}], "X", " ", 
     RowBox[{
      RowBox[{"\[Phi]", "''"}], "[", "t", "]"}]}], "-", 
    RowBox[{"2", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[PartialD]", "\[Phi]"], 
         RowBox[{"G", "[", 
          RowBox[{"\[Phi]", ",", "X"}], "]"}]}], ")"}], "-", 
       RowBox[{"X", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[PartialD]", "\[Phi]"], 
          RowBox[{
           SubscriptBox["\[PartialD]", "X"], 
           RowBox[{"G", "[", 
            RowBox[{"\[Phi]", ",", "X"}], "]"}]}]}], ")"}]}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"g", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[PartialD]", "X"], 
       RowBox[{"K", "[", 
        RowBox[{"\[Phi]", ",", "X"}], "]"}]}], ")"}], "+", 
     RowBox[{"2", "X", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[PartialD]", "X"], 
        RowBox[{
         SubscriptBox["\[PartialD]", "X"], 
         RowBox[{"K", "[", 
          RowBox[{"\[Phi]", ",", "X"}], "]"}]}]}], ")"}]}], "+", 
     RowBox[{"6", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[PartialD]", "X"], 
        RowBox[{"G", "[", 
         RowBox[{"\[Phi]", ",", "X"}], "]"}]}], ")"}], 
      RowBox[{"H", "[", "t", "]"}], 
      RowBox[{
       RowBox[{"\[Phi]", "'"}], "[", "t", "]"}]}], "+", 
     RowBox[{"6", 
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[PartialD]", "X"], 
          RowBox[{"G", "[", 
           RowBox[{"\[Phi]", ",", "X"}], "]"}]}], ")"}], "2"], 
       SuperscriptBox["M", "2"]], 
      SuperscriptBox["X", "2"]}], "-", 
     RowBox[{"2", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[PartialD]", "\[Phi]"], 
          RowBox[{"G", "[", 
           RowBox[{"\[Phi]", ",", "X"}], "]"}]}], ")"}], "+", 
        RowBox[{"X", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[PartialD]", "\[Phi]"], 
           RowBox[{
            SubscriptBox["\[PartialD]", "X"], 
            RowBox[{"G", "[", 
             RowBox[{"\[Phi]", ",", "X"}], "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{"6", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[PartialD]", "X"], 
        RowBox[{
         SubscriptBox["\[PartialD]", "X"], 
         RowBox[{"G", "[", 
          RowBox[{"\[Phi]", ",", "X"}], "]"}]}]}], ")"}], 
      RowBox[{"H", "[", "t", "]"}], "X", " ", 
      RowBox[{
       RowBox[{"\[Phi]", "'"}], "[", "t", "]"}]}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"f", ">", "0"}], "\[IndentingNewLine]", 
 RowBox[{"g", ">", "0"}]}], "Input",
 CellChangeTimes->{{3.798119703629019*^9, 3.798119819813185*^9}, {
  3.798119869367134*^9, 3.7981200987159224`*^9}, {3.79812019284424*^9, 
  3.798120279405446*^9}, {3.7981203244318247`*^9, 3.7981204609052224`*^9}, {
  3.7984306114532614`*^9, 3.798430704237939*^9}, {3.818768218571971*^9, 
  3.818768224852185*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}], ")"}], " ", 
    RowBox[{
     SuperscriptBox["G", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"\[Phi]", ",", "X"}], "]"}]}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox["X", "2"], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["G", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"\[Phi]", ",", "X"}], "]"}], "2"]}], "+", 
   RowBox[{
    SuperscriptBox["K", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"\[Phi]", ",", "X"}], "]"}], "+", 
   RowBox[{"2", " ", "X", " ", 
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{
     SuperscriptBox["G", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"\[Phi]", ",", "X"}], "]"}]}], "-", 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["G", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Phi]", ",", "X"}], "]"}], "-", 
      RowBox[{"X", " ", 
       RowBox[{
        SuperscriptBox["G", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"\[Phi]", ",", "X"}], "]"}]}]}], ")"}]}]}], ">", 
  "0"}]], "Output",
 CellChangeTimes->{{3.7984306819624047`*^9, 3.7984307058949194`*^9}, 
   3.798457621562052*^9, 3.798460327437358*^9, 3.798563068243853*^9, 
   3.7985633737831316`*^9, 3.798564057927636*^9, 3.7985640887819347`*^9, 
   3.7985731401830635`*^9, 3.7985795501049967`*^9, 3.7987142653963013`*^9, 
   3.798938922515053*^9, 3.799232955147315*^9, 3.799235818358117*^9, 
   3.7992386287703676`*^9, 3.800267645163378*^9, 3.801024678615056*^9, 
   3.801025017827709*^9, 3.8010336062367735`*^9, 3.8147839465210547`*^9, 
   3.818768135602936*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"6", " ", 
    RowBox[{"H", "[", "t", "]"}], " ", 
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{
     SuperscriptBox["G", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"\[Phi]", ",", "X"}], "]"}]}], "+", 
   RowBox[{"6", " ", 
    SuperscriptBox["X", "2"], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["G", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"\[Phi]", ",", "X"}], "]"}], "2"]}], "+", 
   RowBox[{
    SuperscriptBox["K", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"\[Phi]", ",", "X"}], "]"}], "+", 
   RowBox[{"6", " ", "X", " ", 
    RowBox[{"H", "[", "t", "]"}], " ", 
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{
     SuperscriptBox["G", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"\[Phi]", ",", "X"}], "]"}]}], "+", 
   RowBox[{"2", " ", "X", " ", 
    RowBox[{
     SuperscriptBox["K", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"\[Phi]", ",", "X"}], "]"}]}], "-", 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["G", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Phi]", ",", "X"}], "]"}], "+", 
      RowBox[{"X", " ", 
       RowBox[{
        SuperscriptBox["G", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"\[Phi]", ",", "X"}], "]"}]}]}], ")"}]}]}], ">", 
  "0"}]], "Output",
 CellChangeTimes->{{3.7984306819624047`*^9, 3.7984307058949194`*^9}, 
   3.798457621562052*^9, 3.798460327437358*^9, 3.798563068243853*^9, 
   3.7985633737831316`*^9, 3.798564057927636*^9, 3.7985640887819347`*^9, 
   3.7985731401830635`*^9, 3.7985795501049967`*^9, 3.7987142653963013`*^9, 
   3.798938922515053*^9, 3.799232955147315*^9, 3.799235818358117*^9, 
   3.7992386287703676`*^9, 3.800267645163378*^9, 3.801024678615056*^9, 
   3.801025017827709*^9, 3.8010336062367735`*^9, 3.8147839465210547`*^9, 
   3.818768135611844*^9}]
}, Open  ]],

Cell["In the self-tuning theory, these become...", "Text",
 CellChangeTimes->{{3.798430712964047*^9, 3.7984307326049337`*^9}, {
  3.818768138595869*^9, 3.818768203916206*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"stmod", "=", 
   RowBox[{"st", "/.", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "\[Rule]", 
     SqrtBox[
      RowBox[{"2", "X"}]]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fsim", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"f", "/.", "tadpole"}], "/.", "stmod"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"A", "[", "X", "]"}], ",", 
       RowBox[{
        RowBox[{"A", "'"}], "[", "X", "]"}], ",", 
       RowBox[{
        RowBox[{"A", "''"}], "[", "X", "]"}]}], "}"}], ",", "FullSimplify"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gsim", "=", 
    RowBox[{"Collect", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"g", "/.", "tadpole"}], "/.", "stmod"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"A", "[", "X", "]"}], ",", 
        RowBox[{
         RowBox[{"A", "'"}], "[", "X", "]"}], ",", 
        RowBox[{
         RowBox[{"A", "''"}], "[", "X", "]"}]}], "}"}], ",", "FullSimplify"}],
      "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"fsim", ">", "0"}], "\[IndentingNewLine]", 
 RowBox[{"gsim", ">", "0"}]}], "Input",
 CellChangeTimes->{{3.7981206473042884`*^9, 3.798120708650468*^9}, {
  3.798279610176033*^9, 3.798279647131998*^9}, {3.798430776474401*^9, 
  3.7984308337861695`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"X", " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["A", "\[Prime]",
         MultilineFunction->None], "[", "X", "]"}], "2"]}], 
     RowBox[{"9", " ", 
      SuperscriptBox["h", "2"]}]]}], "+", 
   FractionBox[
    RowBox[{"l", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "l"}], " ", "X"}], "+", 
       RowBox[{"36", " ", 
        SuperscriptBox["h", "2"], " ", 
        RowBox[{"H", "[", "t", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], 
    RowBox[{"162", " ", 
     SuperscriptBox["h", "4"], " ", "X"}]], "-", 
   FractionBox[
    RowBox[{
     SqrtBox["2"], " ", 
     SqrtBox["X"], " ", 
     RowBox[{
      SuperscriptBox["A", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "X", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], 
    RowBox[{"3", " ", "h"}]], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox["A", "\[Prime]",
      MultilineFunction->None], "[", "X", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      FractionBox[
       RowBox[{
        SqrtBox["2"], " ", "l", " ", 
        SqrtBox["X"]}], 
       RowBox[{"27", " ", 
        SuperscriptBox["h", "3"]}]], "-", 
      FractionBox[
       RowBox[{
        RowBox[{"4", " ", 
         RowBox[{"H", "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["\[Phi]", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], 
       RowBox[{"3", " ", 
        SqrtBox["2"], " ", "h", " ", 
        SqrtBox["X"]}]]}], ")"}]}]}], ">", "0"}]], "Output",
 CellChangeTimes->{3.798430786200987*^9, 3.7984308380174108`*^9, 
  3.7984576218159695`*^9, 3.798460327790786*^9, 3.7985630685604396`*^9, 
  3.798563374095441*^9, 3.7985640582669277`*^9, 3.7985640890504017`*^9, 
  3.798573140790574*^9, 3.798579550442805*^9, 3.79871426591584*^9, 
  3.7989389227806168`*^9, 3.7992329554410453`*^9, 3.7992358186387877`*^9, 
  3.7992386291171637`*^9, 3.800267651917658*^9, 3.801024678881213*^9, 
  3.801025018170878*^9, 3.8010336065233583`*^9, 3.814783951201543*^9, 
  3.8187681771408143`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox[
    SuperscriptBox["l", "2"], 
    RowBox[{"54", " ", 
     SuperscriptBox["h", "4"]}]], "+", 
   FractionBox[
    RowBox[{"X", " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["A", "\[Prime]",
        MultilineFunction->None], "[", "X", "]"}], "2"]}], 
    RowBox[{"3", " ", 
     SuperscriptBox["h", "2"]}]], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox["A", "\[Prime]",
      MultilineFunction->None], "[", "X", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{
        SqrtBox["2"], " ", "l", " ", 
        SqrtBox["X"]}], 
       RowBox[{"9", " ", 
        SuperscriptBox["h", "3"]}]], "-", 
      FractionBox[
       RowBox[{
        RowBox[{"H", "[", "t", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], 
       RowBox[{
        SqrtBox["2"], " ", "h", " ", 
        SqrtBox["X"]}]]}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "X"}], "-", 
      FractionBox[
       RowBox[{
        SqrtBox["2"], " ", 
        SqrtBox["X"], " ", 
        RowBox[{"H", "[", "t", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "h"]}], ")"}], " ", 
    RowBox[{
     SuperscriptBox["A", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "X", "]"}]}]}], ">", "0"}]], "Output",
 CellChangeTimes->{3.798430786200987*^9, 3.7984308380174108`*^9, 
  3.7984576218159695`*^9, 3.798460327790786*^9, 3.7985630685604396`*^9, 
  3.798563374095441*^9, 3.7985640582669277`*^9, 3.7985640890504017`*^9, 
  3.798573140790574*^9, 3.798579550442805*^9, 3.79871426591584*^9, 
  3.7989389227806168`*^9, 3.7992329554410453`*^9, 3.7992358186387877`*^9, 
  3.7992386291171637`*^9, 3.800267651917658*^9, 3.801024678881213*^9, 
  3.801025018170878*^9, 3.8010336065233583`*^9, 3.814783951201543*^9, 
  3.8187681771597257`*^9}]
}, Open  ]],

Cell["\<\
These inequalities must be satisfied by any solution to avoid ghost and \
gradient instabilities. We can therefore constrain the self-tuning KGB by \
evaluating the above expressions on the self-tuning vacuum...\
\>", "Text",
 CellChangeTimes->{{3.798430880619602*^9, 3.798430958942305*^9}, {
  3.7984310602050486`*^9, 3.7984310726199617`*^9}, {3.8187682372889147`*^9, 
  3.8187683272014923`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"$Assumptions", "=", 
   RowBox[{
    RowBox[{"h", "\[GreaterEqual]", "0"}], "&&", 
    RowBox[{"q", "\[GreaterEqual]", "0"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fds", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"fsim", "/.", "ds"}], "/.", 
       RowBox[{"X", "\[Rule]", 
        FractionBox[
         SuperscriptBox[
          RowBox[{
           RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "2"], "2"]}]}], "/.", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "\[Rule]", "q"}]}], "/.", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Phi]", "''"}], "[", "t", "]"}], "\[Rule]", "0"}]}], "//", 
    "FullSimplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gds", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"gsim", "/.", "ds"}], "/.", 
        RowBox[{"X", "\[Rule]", 
         FractionBox[
          SuperscriptBox[
           RowBox[{
            RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "2"], "2"]}]}], "/.", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "\[Rule]", "q"}]}], "/.", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Phi]", "''"}], "[", "t", "]"}], "\[Rule]", "0"}]}], "//", 
     "FullSimplify"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"fds", ">", "0"}], "\[IndentingNewLine]", 
 RowBox[{"gds", ">", "0"}]}], "Input",
 CellChangeTimes->{{3.798431094021326*^9, 3.7984312050812416`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"l", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"72", " ", 
        SuperscriptBox["h", "3"]}], "-", 
       RowBox[{"l", " ", "q"}]}], ")"}]}], "-", 
    RowBox[{"3", " ", "h", " ", "q", " ", 
     RowBox[{
      SuperscriptBox["A", "\[Prime]",
       MultilineFunction->None], "[", 
      FractionBox[
       SuperscriptBox["q", "2"], "2"], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"18", " ", 
        SuperscriptBox["h", "3"]}], "-", 
       RowBox[{"2", " ", "l", " ", "q"}], "+", 
       RowBox[{"3", " ", "h", " ", 
        SuperscriptBox["q", "2"], " ", 
        RowBox[{
         SuperscriptBox["A", "\[Prime]",
          MultilineFunction->None], "[", 
         FractionBox[
          SuperscriptBox["q", "2"], "2"], "]"}]}]}], ")"}]}]}], 
   RowBox[{"162", " ", 
    SuperscriptBox["h", "4"], " ", "q"}]], ">", "0"}]], "Output",
 CellChangeTimes->{
  3.7984311619377127`*^9, {3.798431194905484*^9, 3.798431205660625*^9}, 
   3.798457621947459*^9, 3.798460327952915*^9, 3.7985630688636217`*^9, 
   3.798563374282833*^9, 3.798564058445939*^9, 3.7985640891661396`*^9, 
   3.798573141038824*^9, 3.798579550716429*^9, 3.798714266113973*^9, 
   3.798938922983694*^9, 3.7992329555984626`*^9, 3.799235818981905*^9, 
   3.7992386292819123`*^9, 3.8010246790582695`*^9, 3.8010250183133445`*^9, 
   3.8010336066574535`*^9, 3.8147839560316334`*^9, 3.8187683315787425`*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"l", "-", 
      RowBox[{"3", " ", "h", " ", "q", " ", 
       RowBox[{
        SuperscriptBox["A", "\[Prime]",
         MultilineFunction->None], "[", 
        FractionBox[
         SuperscriptBox["q", "2"], "2"], "]"}]}]}], ")"}], "2"], 
   RowBox[{"54", " ", 
    SuperscriptBox["h", "4"]}]], ">", "0"}]], "Output",
 CellChangeTimes->{
  3.7984311619377127`*^9, {3.798431194905484*^9, 3.798431205660625*^9}, 
   3.798457621947459*^9, 3.798460327952915*^9, 3.7985630688636217`*^9, 
   3.798563374282833*^9, 3.798564058445939*^9, 3.7985640891661396`*^9, 
   3.798573141038824*^9, 3.798579550716429*^9, 3.798714266113973*^9, 
   3.798938922983694*^9, 3.7992329555984626`*^9, 3.799235818981905*^9, 
   3.7992386292819123`*^9, 3.8010246790582695`*^9, 3.8010250183133445`*^9, 
   3.8010336066574535`*^9, 3.8147839560316334`*^9, 3.818768331586753*^9}]
}, Open  ]],

Cell["\<\
In the tadpole-free theory, we then obtain Eqs. (3.66) and (3.67)...\
\>", "Text",
 CellChangeTimes->{{3.7984312373564606`*^9, 3.798431284557864*^9}, {
  3.798431331937769*^9, 3.7984313725688524`*^9}, {3.8187684669347525`*^9, 
  3.818768488700796*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"fds", "/.", 
     RowBox[{"l", "\[Rule]", "0"}]}], "//", "Simplify"}], ")"}], ">", 
  "0"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"gds", "/.", 
     RowBox[{"l", "\[Rule]", "0"}]}], "//", "Simplify"}], ")"}], ">", 
  "0"}]}], "Input",
 CellChangeTimes->{{3.7984313566293173`*^9, 3.7984313797606373`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     RowBox[{
      SuperscriptBox["A", "\[Prime]",
       MultilineFunction->None], "[", 
      FractionBox[
       SuperscriptBox["q", "2"], "2"], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"6", " ", 
        SuperscriptBox["h", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["q", "2"], " ", 
        RowBox[{
         SuperscriptBox["A", "\[Prime]",
          MultilineFunction->None], "[", 
         FractionBox[
          SuperscriptBox["q", "2"], "2"], "]"}]}]}], ")"}]}], 
    RowBox[{"18", " ", 
     SuperscriptBox["h", "2"]}]]}], ">", "0"}]], "Output",
 CellChangeTimes->{3.7984313801130686`*^9, 3.7984576219630785`*^9, 
  3.798460327987544*^9, 3.7985630689410295`*^9, 3.7985633743026085`*^9, 
  3.7985640584980536`*^9, 3.7985640891997733`*^9, 3.798573141076124*^9, 
  3.7985795507441196`*^9, 3.798714266134077*^9, 3.7989389230149364`*^9, 
  3.7992329556183596`*^9, 3.799235819066411*^9, 3.7992386293045654`*^9, 
  3.8010246790869336`*^9, 3.8010250183426824`*^9, 3.801033606678968*^9, 
  3.814783959008677*^9, 3.818768491635255*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SuperscriptBox["q", "2"], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["A", "\[Prime]",
       MultilineFunction->None], "[", 
      FractionBox[
       SuperscriptBox["q", "2"], "2"], "]"}], "2"]}], 
   RowBox[{"6", " ", 
    SuperscriptBox["h", "2"]}]], ">", "0"}]], "Output",
 CellChangeTimes->{3.7984313801130686`*^9, 3.7984576219630785`*^9, 
  3.798460327987544*^9, 3.7985630689410295`*^9, 3.7985633743026085`*^9, 
  3.7985640584980536`*^9, 3.7985640891997733`*^9, 3.798573141076124*^9, 
  3.7985795507441196`*^9, 3.798714266134077*^9, 3.7989389230149364`*^9, 
  3.7992329556183596`*^9, 3.799235819066411*^9, 3.7992386293045654`*^9, 
  3.8010246790869336`*^9, 3.8010250183426824`*^9, 3.801033606678968*^9, 
  3.814783959008677*^9, 3.818768491635255*^9}]
}, Open  ]],

Cell["\<\
The latter no-ghost constraint is trivially satisfied. The gradient stability \
constraint, on the other hand, reduces to...\
\>", "Text",
 CellChangeTimes->{{3.7984313968790393`*^9, 3.7984314787248955`*^9}, {
  3.818768542357351*^9, 3.8187685836753445`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Reduce", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"fds", "/.", 
         RowBox[{"l", "\[Rule]", "0"}]}], "/.", 
        RowBox[{
         RowBox[{
          RowBox[{"A", "'"}], "[", 
          FractionBox[
           SuperscriptBox["q", "2"], "2"], "]"}], "\[Rule]", "\[Alpha]"}]}], "//",
        "Simplify"}], ")"}], ">", "0"}], "&&", 
    RowBox[{"h", ">", "0"}], "&&", 
    RowBox[{"q", ">", "0"}]}], ",", "\[Alpha]"}], "]"}]], "Input",
 CellChangeTimes->{{3.798431435384173*^9, 3.798431437138543*^9}, {
  3.7984314888302345`*^9, 3.798431550925689*^9}, {3.798432588160297*^9, 
  3.7984325887934446`*^9}, {3.814783968696783*^9, 3.8147840067411003`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"q", ">", "0"}], "&&", 
  RowBox[{"h", ">", "0"}], "&&", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"6", " ", 
      SuperscriptBox["h", "2"]}], 
     SuperscriptBox["q", "2"]]}], "<", "\[Alpha]", "<", "0"}]}]], "Output",
 CellChangeTimes->{{3.7984315099079723`*^9, 3.798431551466378*^9}, 
   3.798457622147939*^9, 3.7984603282376533`*^9, 3.7985630696917515`*^9, 
   3.798563374457816*^9, 3.798564058677846*^9, 3.798564089358042*^9, 
   3.7985731412772207`*^9, 3.798579551192402*^9, 3.79871426664641*^9, 
   3.798938923345562*^9, 3.7992329561070805`*^9, 3.799235819393895*^9, 
   3.799238629523712*^9, 3.8010246796014795`*^9, 3.8010250184899635`*^9, 
   3.801033606872102*^9, {3.8147839991274443`*^9, 3.8147840073625093`*^9}, 
   3.818768588167797*^9}]
}, Open  ]],

Cell["We can simplify this to...", "Text",
 CellChangeTimes->{{3.7984316863137436`*^9, 3.7984318031108155`*^9}, {
  3.798434819780468*^9, 3.7984348380387354`*^9}, {3.818768618506418*^9, 
  3.8187686270405416`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ggstab", "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"3", 
       SuperscriptBox["h", "2"]}], "X"]}], "<", 
    RowBox[{
     RowBox[{"A", "'"}], "[", "X", "]"}], "<", "0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7984348388878145`*^9, 3.7984348882913914`*^9}}],

Cell[TextData[{
 "This ends Section 3 of this notebook.\n\n[Next line saves the relevant \
equations to ",
 StyleBox["trivial_scalar_field_eqs.m",
  FontSlant->"Italic"],
 " so that Section 4 can start simply by importing this file.]"
}], "Text",
 CellChangeTimes->{{3.8010245998111897`*^9, 3.801024609485137*^9}, {
  3.8187686540350695`*^9, 3.8187687173343124`*^9}, {3.81876876028761*^9, 
  3.818768863950786*^9}}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"SetDirectory", "[", 
    RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";", 
   "\[IndentingNewLine]", 
   RowBox[{"DumpSave", "[", 
    RowBox[{"\"\<trivial_scalar_field_eqs.m\>\"", ",", 
     RowBox[{"{", 
      RowBox[{
      "FeqTPST", ",", "HeqTPST", ",", "SeqTPST", ",", "PDE", ",", "\[Rho]DE", 
       ",", "stmod", ",", "ggstab", ",", "vac", ",", "FeqTPst", ",", 
       "FE2TPST", ",", "Jst"}], "}"}]}], "]"}], ";"}], "*)"}]], "Input",
 CellChangeTimes->{{3.801024752986292*^9, 3.8010247749860363`*^9}, {
  3.801024867604638*^9, 3.8010248688825474`*^9}, {3.8010249019083023`*^9, 
  3.801024905265706*^9}, {3.8010249856910596`*^9, 3.8010249912876644`*^9}, {
  3.8010250385024414`*^9, 3.8010250407825403`*^9}, {3.8010336175014014`*^9, 
  3.8010336946582026`*^9}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Section 4. Self-tuning generalized cubic covariant \
Galileon",
 FontColor->RGBColor[1, 0.5, 0.5]]], "Subsection",
 CellChangeTimes->{{3.798082604112293*^9, 3.7980826105698605`*^9}, {
  3.79856777961098*^9, 3.7985677927265463`*^9}, {3.81876241985061*^9, 
  3.8187624200674095`*^9}}],

Cell[TextData[{
 "We restrict our attention to the generalized cubic Galileon theory - a \
tadpole-free shift symmetric KGB described a power law potential ",
 Cell[BoxData[
  FormBox[
   RowBox[{"A", "(", "X", ")"}], TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->{{3.7984322335371485`*^9, 3.798432286146185*^9}, {
  3.798432451263839*^9, 3.7984324583340597`*^9}, {3.7985630737330256`*^9, 
  3.798563085173378*^9}, {3.818768905140316*^9, 3.818768934701989*^9}}],

Cell[CellGroupData[{

Cell["4.1 generalized cubic covariant Galileon", "Subsubsection",
 CellChangeTimes->{{3.7980826253594775`*^9, 3.7980826299305*^9}, {
  3.798286666824479*^9, 3.7982866725584497`*^9}, {3.798431820278438*^9, 
  3.7984318253520894`*^9}, {3.7984322208840094`*^9, 3.7984322225491056`*^9}, {
  3.7984323400565557`*^9, 3.7984323412340837`*^9}}],

Cell["Importing the results of Section 3...", "Text",
 CellChangeTimes->{{3.8187689529784527`*^9, 3.8187689608191233`*^9}}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"SetDirectory", "[", 
    RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";", 
   "\[IndentingNewLine]", 
   RowBox[{"Get", "[", "\"\<trivial_scalar_field_eqs.m\>\"", "]"}]}], 
  "*)"}]], "Input",
 CellChangeTimes->{{3.8010254127322454`*^9, 3.801025415224187*^9}, {
  3.8010332875989265`*^9, 3.8010332895660706`*^9}, {3.8187718802283535`*^9, 
  3.818771885940422*^9}}],

Cell["\<\
The generalized cubic covariant Galileon (GCCG) can be obtained by...\
\>", "Text",
 CellChangeTimes->{{3.7984322899916286`*^9, 3.7984323047352023`*^9}, {
  3.79843234394687*^9, 3.7984323616333675`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"gccg", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"l", "\[Rule]", "0"}], ",", 
      RowBox[{"A", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{"x", ",", 
         RowBox[{"c", " ", 
          SuperscriptBox["x", "n"]}]}], "]"}]}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\"\<A(X)\>\"", "\[Equal]", 
   RowBox[{"A", "[", "X", "]"}]}], "/.", "gccg"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<B(x)\>\"", "\[Equal]", 
  RowBox[{"\[Integral]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"B", "'"}], "[", "X", "]"}], "/.", "stmod"}], "/.", "gccg"}],
       "//", "Simplify"}], ")"}], 
    RowBox[{"\[DifferentialD]", "X"}]}]}]}]}], "Input",
 CellChangeTimes->{{3.798432363181826*^9, 3.798432377141941*^9}, {
  3.7984324623981037`*^9, 3.7984325407645664`*^9}, {3.798432575590932*^9, 
  3.7984325757259226`*^9}, {3.7984326071149416`*^9, 3.798432692393531*^9}, {
  3.798457626845563*^9, 3.7984576368590927`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"A(X)\"\>", "\[Equal]", 
  RowBox[{"c", " ", 
   SuperscriptBox["X", "n"]}]}]], "Output",
 CellChangeTimes->{
  3.7984326389147015`*^9, 3.7984326937633142`*^9, 3.7984576385677605`*^9, {
   3.7984603046892395`*^9, 3.798460330458449*^9}, 3.7985630949605*^9, 
   3.7985633745423703`*^9, 3.7985641928598747`*^9, 3.798573141556841*^9, 
   3.7985795692324686`*^9, 3.798938931374894*^9, 3.7992329611201344`*^9, 
   3.7992358194931836`*^9, 3.7992386871596746`*^9, 3.8010249316102715`*^9, 
   3.801025051177107*^9, 3.8010333002256765`*^9, 3.801033708982456*^9, 
   3.8010339009277334`*^9, 3.8187689677681*^9, 3.8187698753346796`*^9, 
   3.8187699734958*^9, 3.8187700614799585`*^9}],

Cell[BoxData[
 RowBox[{"\<\"B(x)\"\>", "\[Equal]", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{"c", " ", "n", " ", 
     SuperscriptBox["X", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], "+", "n"}]]}], 
    RowBox[{"3", " ", 
     SqrtBox["2"], " ", "h", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], "+", "n"}], ")"}]}]]}]}]], "Output",
 CellChangeTimes->{
  3.7984326389147015`*^9, 3.7984326937633142`*^9, 3.7984576385677605`*^9, {
   3.7984603046892395`*^9, 3.798460330458449*^9}, 3.7985630949605*^9, 
   3.7985633745423703`*^9, 3.7985641928598747`*^9, 3.798573141556841*^9, 
   3.7985795692324686`*^9, 3.798938931374894*^9, 3.7992329611201344`*^9, 
   3.7992358194931836`*^9, 3.7992386871596746`*^9, 3.8010249316102715`*^9, 
   3.801025051177107*^9, 3.8010333002256765`*^9, 3.801033708982456*^9, 
   3.8010339009277334`*^9, 3.8187689677681*^9, 3.8187698753346796`*^9, 
   3.8187699734958*^9, 3.8187700614955797`*^9}]
}, Open  ]],

Cell["\<\
This is the self-tuning GCCG theory (Eqs. (4.3) and (4.4)). To start, we \
checkout the theoretical constraints studied earlier for preventing ghost and \
gradient instabilities,...\
\>", "Text",
 CellChangeTimes->{{3.7984327089762135`*^9, 3.79843275126159*^9}, {
  3.7984328233806257`*^9, 3.798432840063092*^9}, {3.798460340506852*^9, 
  3.79846038130915*^9}, {3.818768993621997*^9, 3.818768993772159*^9}, {
  3.818769078691823*^9, 3.818769085530922*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ggstab", "/.", "gccg"}]], "Input",
 CellChangeTimes->{{3.798434907230095*^9, 3.798434911851802*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"3", " ", 
     SuperscriptBox["h", "2"]}], "X"]}], "<", 
  RowBox[{"c", " ", "n", " ", 
   SuperscriptBox["X", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "n"}]]}], "<", "0"}]], "Output",
 CellChangeTimes->{3.7984349122453394`*^9, 3.798573141599612*^9, 
  3.7985795693209763`*^9, 3.798938931437377*^9, 3.7992329643627157`*^9, 
  3.7992358195528326`*^9, 3.799238687258974*^9, 3.801024934166953*^9, 
  3.8010250547399845`*^9, 3.801033300300914*^9, 3.8010337090367107`*^9, 
  3.801033901026333*^9, 3.818768999842003*^9, 3.8187698775028105`*^9, 
  3.8187699765107164`*^9}]
}, Open  ]],

Cell[TextData[{
 "For ",
 Cell[BoxData[
  FormBox[
   RowBox[{"c", ">", "0"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"X", ">", "0"}], TraditionalForm]]],
 ", the theory potential ",
 Cell[BoxData[
  FormBox[
   RowBox[{"A", "(", "X", ")"}], TraditionalForm]]],
 " must contain inverse powers of ",
 Cell[BoxData[
  FormBox["X", TraditionalForm]]],
 " (",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "<", "0"}], TraditionalForm]]],
 "). Also, we find..."
}], "Text",
 CellChangeTimes->{{3.7984578575524073`*^9, 3.798457914641469*^9}, {
   3.798457960612085*^9, 3.798457969679285*^9}, 3.8187690076883945`*^9, {
   3.818769055607979*^9, 3.818769062029319*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"nstab", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"n", " ", 
        SuperscriptBox["X", "n"]}], ">", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"3", 
          SuperscriptBox["h", "2"]}], "c"]}]}], ")"}], "/.", 
     RowBox[{"X", "\[Rule]", 
      FractionBox[
       SuperscriptBox["q", "2"], "2"]}]}], "//", "FullSimplify"}]}], ";", 
  "nstab"}]], "Input",
 CellChangeTimes->{{3.798457929054037*^9, 3.798457945038158*^9}, {
  3.798458006798881*^9, 3.7984580145864544`*^9}, {3.7984580923478374`*^9, 
  3.7984581103041077`*^9}, {3.7984583658530927`*^9, 3.798458371134951*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["2", "n"], " ", "c", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", 
      SuperscriptBox["2", "n"], " ", 
      SuperscriptBox["h", "2"]}], "+", 
     RowBox[{"c", " ", "n", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["q", "2"], ")"}], "n"]}]}], ")"}]}], ">", 
  "0"}]], "Output",
 CellChangeTimes->{
  3.798458110768659*^9, {3.798458368429511*^9, 3.798458371707198*^9}, 
   3.798563117389881*^9, 3.7985633761903057`*^9, 3.7985641965805855`*^9, 
   3.7985731416674337`*^9, 3.7985795695106015`*^9, 3.798938931515518*^9, 
   3.799232968137061*^9, 3.7992358198929596`*^9, 3.7992386873235884`*^9, 
   3.8010249383571067`*^9, 3.801025057399141*^9, 3.8010333005394044`*^9, 
   3.801033709125231*^9, 3.801033901133075*^9, 3.818769111668599*^9, 
   3.8187698839759445`*^9, 3.8187699785571103`*^9, 3.8187700693375273`*^9}]
}, Open  ]],

Cell[TextData[{
 "We note that ",
 Cell[BoxData[
  FormBox["q", TraditionalForm]]],
 " is determined by the Friedmann constraint (",
 StyleBox["FeqTPst",
  FontSlant->"Italic"],
 ")..."
}], "Text",
 CellChangeTimes->{{3.7984581818838224`*^9, 3.798458195624707*^9}, {
  3.8187691191664515`*^9, 3.818769128967947*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FeqGCCGqvac", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"FeqTPst", "/.", "gccg"}], "/.", "vac"}], "/.", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "\[Rule]", "q"}]}], "//", 
    "FullSimplify"}]}], ";", "FeqGCCGqvac"}]], "Input",
 CellChangeTimes->{{3.7984581975562243`*^9, 3.7984582037780924`*^9}, {
  3.798458242137171*^9, 3.7984582930184684`*^9}, {3.798458344272196*^9, 
  3.7984583495749598`*^9}, {3.798458422130562*^9, 3.7984584567055564`*^9}, {
  3.8010333423764706`*^9, 3.8010333432730527`*^9}, {3.8010334786692123`*^9, 
  3.801033481465864*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"3", " ", 
    SuperscriptBox["h", "2"]}], "+", 
   RowBox[{
    SuperscriptBox["2", 
     RowBox[{"-", "n"}]], " ", "c", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      SuperscriptBox["q", "2"], ")"}], "n"]}]}], "\[Equal]", 
  "\[Rho]\[CapitalLambda]"}]], "Output",
 CellChangeTimes->{
  3.798458201771885*^9, {3.79845826320441*^9, 3.7984582933820825`*^9}, 
   3.7984583500759525`*^9, {3.798458450986289*^9, 3.7984584574312696`*^9}, 
   3.798563130074403*^9, 3.7985633792442236`*^9, 3.798564200446637*^9, 
   3.7985731418535995`*^9, 3.7985795697356396`*^9, 3.798938931718562*^9, 
   3.799232970631218*^9, 3.799235822453684*^9, 3.7992386875258074`*^9, 
   3.8010249446773396`*^9, 3.801025062207636*^9, 3.801033300558799*^9, 
   3.8010337092851133`*^9, 3.801033901291895*^9}]
}, Open  ]],

Cell[TextData[{
 "Since ",
 Cell[BoxData[
  FormBox[
   RowBox[{"c", ">", "0"}], TraditionalForm]]],
 " then ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Rho]", "\[CapitalLambda]"], ">", 
    RowBox[{"3", 
     SuperscriptBox["h", "2"]}]}], TraditionalForm]]],
 ". We can combine this constraint with ",
 StyleBox["nstab",
  FontSlant->"Italic"],
 " to obtain..."
}], "Text",
 CellChangeTimes->{{3.7984583826232457`*^9, 3.798458403481351*^9}, {
  3.7984589855053997`*^9, 3.798459046054779*^9}, {3.8187702003237934`*^9, 
  3.8187702139745827`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"nstab2", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"nstab", "/.", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         SuperscriptBox["q", "2"], ")"}], "n"], "\[Rule]", "A"}]}], "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"FeqGCCGqvac", "/.", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            SuperscriptBox["q", "2"], ")"}], "n"], "\[Rule]", "A"}]}], ",", 
        "A"}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "//", "FullSimplify"}]}], ";", 
  RowBox[{"Reduce", "[", 
   RowBox[{
    RowBox[{"nstab2", "&&", 
     RowBox[{"c", ">", "0"}], "&&", 
     RowBox[{"h", ">", "0"}], "&&", 
     RowBox[{"\[Rho]\[CapitalLambda]", ">", "0"}], "&&", 
     RowBox[{"\[Rho]\[CapitalLambda]", ">", 
      RowBox[{"3", 
       SuperscriptBox["h", "2"]}]}], "&&", 
     RowBox[{"n", "<", "0"}]}], ",", "n", ",", "Reals"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7984584957626443`*^9, 3.7984586646720257`*^9}, {
  3.7984587204570417`*^9, 3.7984587217080717`*^9}, {3.798459082908351*^9, 
  3.7984590947237854`*^9}, {3.801033845552677*^9, 3.8010338479621367`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"c", ">", "0"}], "&&", 
  RowBox[{"h", ">", "0"}], "&&", 
  RowBox[{"\[Rho]\[CapitalLambda]", ">", 
   RowBox[{"3", " ", 
    SuperscriptBox["h", "2"]}]}], "&&", 
  RowBox[{
   FractionBox[
    RowBox[{"3", " ", 
     SuperscriptBox["h", "2"]}], 
    RowBox[{
     RowBox[{"3", " ", 
      SuperscriptBox["h", "2"]}], "-", "\[Rho]\[CapitalLambda]"}]], "<", "n", 
   "<", "0"}]}]], "Output",
 CellChangeTimes->{3.7984585135576725`*^9, 3.7984585740011473`*^9, 
  3.7984586100446906`*^9, 3.7984586652953367`*^9, 3.7984587222543077`*^9, 
  3.7984590956665163`*^9, 3.7985631899031773`*^9, 3.7985633812132425`*^9, 
  3.7985642029214606`*^9, 3.7985731420067663`*^9, 3.7985795702104177`*^9, 
  3.7989389319997454`*^9, 3.7992329728632407`*^9, 3.799235824522485*^9, 
  3.7992386876806536`*^9, 3.8010250857156553`*^9, 3.801033300719398*^9, 
  3.8010337106389933`*^9, 3.801033848681527*^9, 3.8010339015432625`*^9}]
}, Open  ]],

Cell["\<\
This is Eq. (4.5) in the text.

In what follows, we setup the field equations (Eqs. (4.6-8))...\
\>", "Text",
 CellChangeTimes->{{3.7984591270948925`*^9, 3.7984592073235497`*^9}, {
  3.798459239869853*^9, 3.798459408035815*^9}, {3.798459481258748*^9, 
  3.798459579473407*^9}, {3.7984596954762764`*^9, 3.7984597131289606`*^9}, {
  3.7985632158697844`*^9, 3.798563223537712*^9}, {3.8187702702204676`*^9, 
  3.818770298914048*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"FeqGCCG", "=", 
   RowBox[{
    RowBox[{"FeqTPST", "/.", "gccg"}], "//", "FullSimplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"HeqGCCG", "=", 
   RowBox[{
    RowBox[{"HeqTPST", "/.", "gccg"}], "//", "FullSimplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SeqGCCG", "=", 
    RowBox[{
     RowBox[{"SeqTPST", "/.", "gccg"}], "//", "FullSimplify"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FE2GCCG", "=", 
    RowBox[{
     RowBox[{"FE2TPST", "/.", "gccg"}], "//", "FullSimplify"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "FeqGCCG", "\
\[IndentingNewLine]", "HeqGCCG", "\[IndentingNewLine]", "SeqGCCG"}], "Input",
 CellChangeTimes->{{3.798459714674646*^9, 3.79845984061158*^9}, {
   3.7984604806336718`*^9, 3.7984604839320908`*^9}, 3.7984605295715537`*^9, {
   3.7992386397799416`*^9, 3.7992386576053715`*^9}, {3.801033549102909*^9, 
   3.801033564060049*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"3", " ", "h", " ", 
     SuperscriptBox[
      RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
    RowBox[{"h", " ", 
     RowBox[{"\[Rho]", "[", "t", "]"}]}], "+", 
    RowBox[{
     SuperscriptBox["2", 
      RowBox[{"-", "n"}]], " ", "c", " ", 
     RowBox[{"(", 
      RowBox[{"h", "-", 
       RowBox[{"2", " ", "h", " ", "n"}], "+", 
       RowBox[{"2", " ", "n", " ", 
        RowBox[{"H", "[", "t", "]"}]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], ")"}], "n"]}]}], 
   "h"], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.7984597460229626`*^9, 3.798459807473343*^9, 
  3.7984598463240795`*^9, 3.7984604198515534`*^9, 3.7984604938869505`*^9, 
  3.7984605307045083`*^9, 3.798563231921891*^9, 3.798563390223564*^9, 
  3.7985642130877666`*^9, 3.798573146113691*^9, 3.7985795747773843`*^9, 
  3.7989389356707597`*^9, 3.7992329800064535`*^9, 3.799235830673193*^9, 
  3.7992386927998333`*^9, 3.801025134411129*^9, 3.801033304035728*^9, 
  3.8010337148578205`*^9, 3.801033905966254*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"3", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"P", "[", "t", "]"}], "+", 
      RowBox[{"\[Rho]", "[", "t", "]"}], "+", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox["2", 
      RowBox[{"1", "-", "n"}]], " ", "c", " ", "n", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], ")"}], "n"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        RowBox[{"(", 
         RowBox[{"h", "-", 
          RowBox[{"H", "[", "t", "]"}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], ")"}]}], 
    RowBox[{"h", " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{3.7984597460229626`*^9, 3.798459807473343*^9, 
  3.7984598463240795`*^9, 3.7984604198515534`*^9, 3.7984604938869505`*^9, 
  3.7984605307045083`*^9, 3.798563231921891*^9, 3.798563390223564*^9, 
  3.7985642130877666`*^9, 3.798573146113691*^9, 3.7985795747773843`*^9, 
  3.7989389356707597`*^9, 3.7992329800064535`*^9, 3.799235830673193*^9, 
  3.7992386927998333`*^9, 3.801025134411129*^9, 3.801033304035728*^9, 
  3.8010337148578205`*^9, 3.801033905972177*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "h"], 
   RowBox[{
    SuperscriptBox["2", 
     RowBox[{"1", "-", "n"}]], " ", "c", " ", "n", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"], ")"}], 
     RowBox[{
      RowBox[{"-", "1"}], "+", "n"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          RowBox[{"(", 
           RowBox[{"h", "-", 
            RowBox[{"H", "[", "t", "]"}]}], ")"}], " ", 
          RowBox[{"H", "[", "t", "]"}]}], "-", 
         RowBox[{
          SuperscriptBox["H", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], ")"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"2", " ", "n"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"h", "-", 
         RowBox[{"H", "[", "t", "]"}]}], ")"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], "\[Equal]",
   "0"}]], "Output",
 CellChangeTimes->{3.7984597460229626`*^9, 3.798459807473343*^9, 
  3.7984598463240795`*^9, 3.7984604198515534`*^9, 3.7984604938869505`*^9, 
  3.7984605307045083`*^9, 3.798563231921891*^9, 3.798563390223564*^9, 
  3.7985642130877666`*^9, 3.798573146113691*^9, 3.7985795747773843`*^9, 
  3.7989389356707597`*^9, 3.7992329800064535`*^9, 3.799235830673193*^9, 
  3.7992386927998333`*^9, 3.801025134411129*^9, 3.801033304035728*^9, 
  3.8010337148578205`*^9, 3.8010339059780054`*^9}]
}, Open  ]],

Cell["The conserved scalar current becomes (Eq. (4.9))...", "Text",
 CellChangeTimes->{{3.801025303026254*^9, 3.8010253157420044`*^9}, {
  3.818770312057952*^9, 3.81877031562429*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"JGCCG", "[", "t_", "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Jst", "[", "t", "]"}], "/.", "gccg"}], "//", "Simplify"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*
StyleBox[\"J\",
FontSlant->\"Italic\"]\)(\!\(\*
StyleBox[\"t\",
FontSlant->\"Italic\"]\))\>\"", "\[Equal]", 
  RowBox[{"JGCCG", "[", "t", "]"}]}]}], "Input",
 CellChangeTimes->{{3.801025320419751*^9, 3.801025332870923*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*\\nStyleBox[\\\"J\\\",\\nFontSlant->\\\"Italic\\\"]\\)(\
\\!\\(\\*\\nStyleBox[\\\"t\\\",\\nFontSlant->\\\"Italic\\\"]\\))\"\>", 
  "\[Equal]", 
  FractionBox[
   RowBox[{
    SuperscriptBox["2", 
     RowBox[{"1", "-", "n"}]], " ", "c", " ", "n", " ", 
    RowBox[{"(", 
     RowBox[{"h", "-", 
      RowBox[{"H", "[", "t", "]"}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"], ")"}], "n"]}], 
   RowBox[{"h", " ", 
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}]]}]], "Output",
 CellChangeTimes->{3.801025333218112*^9, 3.8010333041321163`*^9, 
  3.801033714939002*^9, 3.801033906084778*^9}]
}, Open  ]],

Cell["The dark energy density and pressure also becomes...", "Text",
 CellChangeTimes->{{3.801025142649282*^9, 3.801025158697087*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[Rho]DEGCCG", "[", "t_", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Rho]DE", "[", "t", "]"}], "/.", "gccg"}], "//", 
    "Simplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"PDEGCCG", "[", "t_", "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"PDE", "[", "t", "]"}], "/.", "gccg"}], "//", "Simplify"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Rho]\), \(DE\)]\)\>\"", "\[Equal]", 
  RowBox[{"\[Rho]DEGCCG", "[", "t", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SubscriptBox[
StyleBox[\"P\",
FontSlant->\"Italic\"], \"DE\"]\)\>\"", "\[Equal]", 
  RowBox[{"PDEGCCG", "[", "t", "]"}]}]}], "Input",
 CellChangeTimes->{{3.8010251856071043`*^9, 3.801025270366391*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(DE\\)]\\)\"\>", 
  "\[Equal]", 
  FractionBox[
   RowBox[{
    SuperscriptBox["2", 
     RowBox[{"-", "n"}]], " ", "c", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"h", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"2", " ", "n"}]}], ")"}]}], "-", 
      RowBox[{"2", " ", "n", " ", 
       RowBox[{"H", "[", "t", "]"}]}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"], ")"}], "n"]}], 
   "h"]}]], "Output",
 CellChangeTimes->{{3.8010252561071243`*^9, 3.801025270955529*^9}, 
   3.8010333041823835`*^9, 3.8010337149828806`*^9, 3.80103390612796*^9}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\n \
StyleBox[\\\"P\\\",\\nFontSlant->\\\"Italic\\\"], \\\"DE\\\"]\\)\"\>", 
  "\[Equal]", 
  FractionBox[
   RowBox[{
    SuperscriptBox["2", 
     RowBox[{"-", "n"}]], " ", "c", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"], ")"}], "n"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", "h", " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"2", " ", "n", " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], 
   RowBox[{"3", " ", "h", " ", 
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}]]}]], "Output",
 CellChangeTimes->{{3.8010252561071243`*^9, 3.801025270955529*^9}, 
   3.8010333041823835`*^9, 3.8010337149828806`*^9, 3.801033906135296*^9}]
}, Open  ]],

Cell["[We save the above results for the next sections.]", "Text",
 CellChangeTimes->{{3.801025361517212*^9, 3.8010253700413184`*^9}, {
  3.818770328678132*^9, 3.8187703367259073`*^9}, {3.8187703918908772`*^9, 
  3.818770393947567*^9}}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"SetDirectory", "[", 
    RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";", 
   "\[IndentingNewLine]", 
   RowBox[{"DumpSave", "[", 
    RowBox[{"\"\<self_tuning_GCCG.m\>\"", ",", 
     RowBox[{"{", 
      RowBox[{
      "FeqGCCG", ",", "HeqGCCG", ",", "SeqGCCG", ",", "FE2GCCG", ",", "JGCCG",
        ",", "\[Rho]DEGCCG", ",", "PDEGCCG"}], "}"}]}], "]"}], ";"}], 
  "*)"}]], "Input",
 CellChangeTimes->{{3.7992328930295906`*^9, 3.7992329265197477`*^9}, {
   3.7992330205502195`*^9, 3.799233023870008*^9}, {3.7992358563276987`*^9, 
   3.7992358637052464`*^9}, {3.7992359023374233`*^9, 3.799235942420407*^9}, {
   3.799235973612751*^9, 3.79923598178771*^9}, {3.7992386670315065`*^9, 
   3.799238699361287*^9}, {3.79930408839076*^9, 3.799304090836706*^9}, 
   3.8010252992119184`*^9, {3.80102535421974*^9, 3.801025390994443*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["4.2(a) Single non-\[CapitalLambda] fluid", "Subsubsection",
 CellChangeTimes->{{3.7992319233740425`*^9, 3.7992319660758677`*^9}, {
  3.8005361548781505`*^9, 3.8005361552189455`*^9}}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"SetDirectory", "[", 
    RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";", 
   "\[IndentingNewLine]", 
   RowBox[{"Get", "[", "\"\<self_tuning_GCCG.m\>\"", "]"}]}], "*)"}]], "Input",
 CellChangeTimes->{{3.7992330020560856`*^9, 3.7992330171740956`*^9}, {
  3.801025726890063*^9, 3.8010257293515286`*^9}, {3.8187704207896433`*^9, 
  3.8187704330065327`*^9}}],

Cell[TextData[{
 "In this section, we study the case wherein the universe is filled with \
either baryonic or radiative fluid, other than vacuum energy. This begins by \
letting ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Rho]", "\[Rule]", 
    RowBox[{
     SubscriptBox["\[Rho]", "\[CapitalLambda]"], "+", "\[Rho]"}]}], 
   TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Rho]", "+", "P"}], "=", 
    RowBox[{"\[Rho]", "(", 
     RowBox[{"1", "+", "w"}], ")"}]}], TraditionalForm]]],
 " in ",
 StyleBox["FeqGCCG",
  FontSlant->"Italic"],
 " and ",
 StyleBox["HeqGCCG",
  FontSlant->"Italic"],
 ", where ",
 Cell[BoxData[
  FormBox["\[Rho]", TraditionalForm]]],
 " is the density of a fluid with equation of state ",
 Cell[BoxData[
  FormBox["w", TraditionalForm]]],
 ",..."
}], "Text",
 CellChangeTimes->{{3.7992320796766706`*^9, 3.7992323308041587`*^9}, {
  3.7992323884308887`*^9, 3.799232393945969*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"SF", ":", " ", 
    RowBox[{"single", " ", "fluid"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"FeqSF", "=", 
     RowBox[{"FeqGCCG", "/.", 
      RowBox[{
       RowBox[{"\[Rho]", "[", "t", "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"\[Rho]", "[", "t", "]"}], "+", "\[CapitalLambda]"}]}]}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"HeqSF", "=", 
     RowBox[{"HeqGCCG", "/.", 
      RowBox[{
       RowBox[{"\[Rho]", "[", "t", "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"P", "[", "t", "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "w"}], ")"}], 
         RowBox[{"\[Rho]", "[", "t", "]"}]}]}]}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "FeqSF", 
   "\[IndentingNewLine]", "HeqSF"}]}]], "Input",
 CellChangeTimes->{{3.7992323990790977`*^9, 3.7992325473914704`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["2", "n"], " ", "h", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "\[CapitalLambda]"}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
       RowBox[{"\[Rho]", "[", "t", "]"}]}], ")"}]}], "+", 
    RowBox[{"c", " ", 
     RowBox[{"(", 
      RowBox[{"h", "-", 
       RowBox[{"2", " ", "h", " ", "n"}], "+", 
       RowBox[{"2", " ", "n", " ", 
        RowBox[{"H", "[", "t", "]"}]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], ")"}], "n"]}]}], 
   "h"], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGBQA2Kl/29ZyvzeONaUP3QD0Stmt20uB9IflSxLKoC0lmpe
wCQg7bS7ZM4UIC3nlf5+BpAWWn7EaCaQfn5xznwQvWvLo/7ZQPrEr6tT5wDp
ayKOyx8D6dN9m28+B9J/DFym1fm/cZSKqHM4AqRfzU1MOgmkEw7E7gTRiw16
TkkFvHFc1OWYmgSkfyabCucD6Rt/dG8VAenAa8yzi4H0tV/MW9qBdEPNpm0d
QFqvw/sFiL61LPBvP5D+z7b8wEQg/WI6Z9wJIB0yVe4piK5zLVp/GkiLefAV
PwTSbP+nFL0B0hv+x30G0Rm1Hby8gW8cK43nTuID0lbdS2UFgfRB9X8iZkDa
4okk067iN44AzK+eEw==
  "]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"3", " ", 
    SuperscriptBox["2", "n"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "w"}], ")"}], " ", 
       RowBox[{"\[Rho]", "[", "t", "]"}]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], "+", 
   FractionBox[
    RowBox[{"2", " ", "c", " ", "n", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], ")"}], "n"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        RowBox[{"(", 
         RowBox[{"h", "-", 
          RowBox[{"H", "[", "t", "]"}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], ")"}]}], 
    RowBox[{"h", " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGBQA2Kl/29ZyvzeONaUP3QD0Stmt20uB9IflSxLKoC0lmpe
wCQg7bS7ZM4UIC3nlf5+BpAWWn7EaCaQfn5xznwQvWvLo/7ZQPrEr6tT5wDp
ayKOyx8D6dN9m28+B9J/DFym1fm/cZSKqHM4AqRfzU1MOgmkEw7E7gTRiw16
TkkFvHFc1OWYmgSkfyabCucD6Rt/dG8VAenAa8yzi4H0tV/MW9qBdEPNpm0d
QFqvw/sFiL61LPBvP5D+z7b8wEQg/WI6Z9wJIB0yVe4piK5zLVp/GkiLefAV
PwTSbP+nFL0B0hv+x30G0Rm1Hby8gW8cK43nTuID0lbdS2UFgfRB9X8iZkD6
BK8U067iN44Ay1SdzQ==
  "]]
}, Open  ]],

Cell[TextData[{
 "We eliminate the fluid variable ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Rho]", "(", "t", ")"}], TraditionalForm]]],
 " in the above equations to obtain a first-order differential equation in \
both ",
 Cell[BoxData[
  FormBox[
   RowBox[{"H", "(", "t", ")"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Phi]", "'"}], 
    RowBox[{"(", "t", ")"}]}], TraditionalForm]]],
 "..."
}], "Text",
 CellChangeTimes->{{3.799233084369952*^9, 3.799233195449114*^9}, {
  3.799233310230794*^9, 3.799233339205505*^9}, {3.799233373313922*^9, 
  3.7992334023727007`*^9}, {3.8187705085049486`*^9, 3.818770531929909*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"FHeqSF", "=", 
   RowBox[{
    RowBox[{"HeqSF", "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{"FeqSF", ",", 
        RowBox[{"\[Rho]", "[", "t", "]"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "//", "FullSimplify"}]}], 
  ";"}], "\[IndentingNewLine]", "FHeqSF"}], "Input",
 CellChangeTimes->{{3.799233199727089*^9, 3.7992332063812294`*^9}, {
  3.799233237660423*^9, 3.799233294398714*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", 
    RowBox[{"h", " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", 
      SuperscriptBox["2", "n"], " ", "h", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "w"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"\[CapitalLambda]", "-", 
           RowBox[{"3", " ", 
            SuperscriptBox[
             RowBox[{"H", "[", "t", "]"}], "2"]}]}], ")"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox["H", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}]}], ")"}], " ", 
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}], "+", 
     RowBox[{"c", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Phi]", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"], ")"}], "n"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", "h", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "-", "w", "+", 
              RowBox[{"2", " ", "n", " ", "w"}]}], ")"}]}], "-", 
           RowBox[{"6", " ", "n", " ", "w", " ", 
            RowBox[{"H", "[", "t", "]"}]}]}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["\[Phi]", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], "-", 
        RowBox[{"2", " ", "n", " ", 
         RowBox[{
          SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], ")"}]}], 
  "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.7992332949433637`*^9, 3.7992360052232523`*^9, 
  3.7992375425461392`*^9, 3.799290535039342*^9, 3.799295205235879*^9, 
  3.799304060602474*^9, 3.799304599770011*^9, 3.799305472971857*^9, 
  3.799309440614462*^9, 3.7993115373419466`*^9, 3.799457084054868*^9, 
  3.7994656792696433`*^9, 3.7997743889610157`*^9, 3.7999170623936496`*^9, 
  3.799927572659089*^9, 3.799928268947404*^9, 3.8000942957616644`*^9, 
  3.800240940300479*^9, 3.8002669072983027`*^9, 3.8002746428875265`*^9, 
  3.8002761856616135`*^9, 3.8003173468163824`*^9, 3.8003194154311314`*^9, 
  3.8003198125261087`*^9, 3.8003343169415083`*^9, 3.8003379271618524`*^9, 
  3.800449778350382*^9, 3.8004508586960344`*^9, 3.8004565733332767`*^9, 
  3.8005011464080515`*^9, 3.8005236706908555`*^9, 3.8005246998552365`*^9, 
  3.800590446192172*^9, 3.800593559070812*^9, 3.8005987668865805`*^9, 
  3.800674474044768*^9, 3.8187705388487525`*^9}]
}, Open  ]],

Cell[TextData[{
 "The above equation and the scalar field equation provide the dynamical \
system for the variables ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Phi]", "'"}], 
      RowBox[{"(", "t", ")"}]}], ",", 
     RowBox[{"H", "(", "t", ")"}]}], ")"}], TraditionalForm]]],
 ". It turns out useful to also regard the shift current ",
 Cell[BoxData[
  FormBox[
   RowBox[{"J", "(", "t", ")"}], TraditionalForm]]],
 " as the dynamical variable in place of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Phi]", "'"}], 
    RowBox[{"(", "t", ")"}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " because ",
 Cell[BoxData[
  FormBox[
   RowBox[{"J", "(", "t", ")"}], TraditionalForm]]],
 " satisfies the simpler equation ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"J", "'"}], 
      RowBox[{"(", "t", ")"}]}], "+", 
     RowBox[{"3", 
      RowBox[{"H", "(", "t", ")"}], 
      RowBox[{"J", "(", "t", ")"}]}]}], "=", "0"}], TraditionalForm]]],
 ". The transformation is provided by..."
}], "Text",
 CellChangeTimes->{{3.7992334087422495`*^9, 3.79923348615797*^9}, {
  3.799233520919492*^9, 3.799233552143244*^9}, {3.7992356460782614`*^9, 
  3.799235657766291*^9}, {3.7992356992568283`*^9, 3.7992357363813868`*^9}, {
  3.7992360197675743`*^9, 3.7992360600654793`*^9}, {3.7992360903942924`*^9, 
  3.799236099176984*^9}, {3.818770558380993*^9, 3.8187706594822426`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Phi]toJ", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"J", "[", "t", "]"}], "\[Equal]", 
         RowBox[{"JGCCG", "[", "t", "]"}]}], ",", 
        RowBox[{
         RowBox[{"\[Phi]", "'"}], "[", "t", "]"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", 
     RowBox[{"Element", "[", 
      RowBox[{"n", ",", "Reals"}], "]"}]}], "]"}]}], ";", 
  "\[Phi]toJ"}]], "Input",
 CellChangeTimes->{{3.799236100935959*^9, 3.7992361139430404`*^9}, {
  3.7992361939993157`*^9, 3.799236213213798*^9}, {3.799305773211502*^9, 
  3.7993057903380136`*^9}}],

Cell[BoxData[
 TemplateBox[{
  "Solve","ifun",
   "\"Inverse functions are being used by \
\\!\\(\\*RowBox[{\\\"Solve\\\"}]\\), so some solutions may not be found; use \
Reduce for complete solution information.\"",2,9,1,16780914564511075985,
   "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.7992362135530033`*^9, 3.799237545861404*^9, 
  3.799290599181491*^9, 3.799295205413144*^9, 3.7993040606962037`*^9, 
  3.79930459992623*^9, 3.7993057912128677`*^9, 3.7993094409587746`*^9, 
  3.799311537597865*^9, 3.7994570842004156`*^9, 3.7994656793738546`*^9, 
  3.799774389205288*^9, 3.7999170625821447`*^9, 3.799927572825718*^9, 
  3.799928269125421*^9, 3.8000942959997053`*^9, 3.800240940532241*^9, 
  3.8002669074230547`*^9, 3.8002746430034547`*^9, 3.8002761857618866`*^9, 
  3.800317346997548*^9, 3.8003194155572033`*^9, 3.8003198126338167`*^9, 
  3.8003343171668024`*^9, 3.800337927458371*^9, 3.800449778646592*^9, 
  3.800450858781804*^9, 3.8004565734542933`*^9, 3.800501146539707*^9, 
  3.80052367086165*^9, 3.8005246998851967`*^9, 3.8005904464223824`*^9, 
  3.800593559164643*^9, 3.8005987670112157`*^9, 3.800674474450705*^9, 
  3.8187706627304277`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
   SuperscriptBox[
    RowBox[{"(", 
     FractionBox[
      RowBox[{
       SuperscriptBox["2", 
        RowBox[{"1", "-", "n"}]], " ", "c", " ", "n", " ", 
       RowBox[{"(", 
        RowBox[{"h", "-", 
         RowBox[{"H", "[", "t", "]"}]}], ")"}]}], 
      RowBox[{"h", " ", 
       RowBox[{"J", "[", "t", "]"}]}]], ")"}], 
    FractionBox["1", 
     RowBox[{"1", "-", 
      RowBox[{"2", " ", "n"}]}]]]}], "}"}]], "Output",
 CellChangeTimes->{3.7992361145791364`*^9, 3.7992362135569925`*^9, 
  3.7992375459283915`*^9, 3.799290599296356*^9, 3.799295205470687*^9, 
  3.799304060758688*^9, 3.7993046000199523`*^9, 3.7993057912366657`*^9, 
  3.7993094416748447`*^9, 3.7993115376856337`*^9, 3.799457084255082*^9, 
  3.7994656794172926`*^9, 3.7997743892438436`*^9, 3.7999170626449757`*^9, 
  3.7999275728479424`*^9, 3.7999282692357645`*^9, 3.8000942961067905`*^9, 
  3.800240940648103*^9, 3.800266907463373*^9, 3.800274643041175*^9, 
  3.8002761858087587`*^9, 3.8003173471093574`*^9, 3.8003194156059504`*^9, 
  3.80031981267414*^9, 3.800334317265052*^9, 3.8003379275417323`*^9, 
  3.800449778742449*^9, 3.8004508588206987`*^9, 3.800456573507807*^9, 
  3.8005011466135025`*^9, 3.800523670919335*^9, 3.800524699925047*^9, 
  3.8005904464733214`*^9, 3.800593559208705*^9, 3.800598767291849*^9, 
  3.800674474598127*^9, 3.818770662789691*^9}]
}, Open  ]],

Cell["\<\
With this, we obtain the dynamical system given by Eqs. (4.10) and (4.11)...\
\>", "Text",
 CellChangeTimes->{{3.7992362323049946`*^9, 3.799236239196338*^9}, {
  3.818770688217576*^9, 3.818770717764443*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"FHeqSFJ", "=", 
   RowBox[{
    RowBox[{"FHeqSF", "/.", "\[Phi]toJ"}], "/.", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Phi]", "''"}], "[", "t", "]"}], "\[Rule]", 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "/.", "\[Phi]toJ"}], ",", 
       "t"}], "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dSJ", "=", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"FHeqSFJ", ",", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"J", "'"}], "[", "t", "]"}], "+", 
           RowBox[{"3", 
            RowBox[{"H", "[", "t", "]"}], 
            RowBox[{"J", "[", "t", "]"}]}]}], "\[Equal]", "0"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"J", "'"}], "[", "t", "]"}], ",", 
         RowBox[{
          RowBox[{"H", "'"}], "[", "t", "]"}]}], "}"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dSJ1", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"J", "'"}], "[", "t", "]"}], "\[Equal]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"J", "'"}], "[", "t", "]"}], "/.", "dSJ"}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dSJ2", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"H", "'"}], "[", "t", "]"}], "\[Equal]", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"H", "'"}], "[", "t", "]"}], "/.", "dSJ"}], ")"}], ",", 
       RowBox[{
        RowBox[{"Element", "[", 
         RowBox[{"n", ",", "Reals"}], "]"}], "&&", 
        RowBox[{"Element", "[", 
         RowBox[{"h", ",", "Reals"}], "]"}], "&&", 
        RowBox[{"Element", "[", 
         RowBox[{"c", ",", "Reals"}], "]"}], "&&", 
        RowBox[{"Element", "[", 
         RowBox[{"w", ",", "Reals"}], "]"}], "&&", 
        RowBox[{"Element", "[", 
         RowBox[{"\[CapitalLambda]", ",", "Reals"}], "]"}], "&&", 
        RowBox[{"h", ">", "0"}], "&&", 
        RowBox[{"c", ">", "0"}], "&&", 
        RowBox[{"w", ">", 
         RowBox[{"-", "1"}]}]}]}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "dSJ1", \
"\[IndentingNewLine]", "dSJ2"}], "Input",
 CellChangeTimes->{{3.79923625403498*^9, 3.799236292255803*^9}, {
  3.799237564421588*^9, 3.799237584103507*^9}, {3.7992376832113776`*^9, 
  3.7992377757984314`*^9}, {3.799237806599765*^9, 3.799237842246294*^9}, {
  3.799290692885029*^9, 3.7992907458432183`*^9}, {3.799305808290682*^9, 
  3.799305847874972*^9}, {3.7993059405147743`*^9, 3.7993060034571843`*^9}, {
  3.7993060389676228`*^9, 3.7993060542859554`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["J", "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"-", "3"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{"J", "[", "t", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.799236308738578*^9, {3.799237804257598*^9, 3.7992378443934746`*^9}, {
   3.7992907295424733`*^9, 3.799290746951095*^9}, 3.799295220407395*^9, 
   3.799304075236737*^9, 3.799304614266632*^9, {3.799305989998715*^9, 
   3.799306007521716*^9}, 3.7993060584569798`*^9, 3.799309445345001*^9, 
   3.79931154197332*^9, 3.7994570876284876`*^9, 3.7994656828307643`*^9, 
   3.799774393381195*^9, 3.7999170660602455`*^9, 3.799927576461432*^9, 
   3.7999282728120556`*^9, 3.800094300771435*^9, 3.800240944372154*^9, 
   3.800266911061894*^9, 3.8002746465971947`*^9, 3.800276189217984*^9, 
   3.8003173521585293`*^9, 3.800319419255642*^9, 3.800319816927111*^9, 
   3.800334321910304*^9, 3.8003379316601467`*^9, 3.800449782728671*^9, 
   3.8004508625367928`*^9, 3.8004565776410136`*^9, 3.800501150261745*^9, 
   3.800523675376301*^9, 3.80052470128692*^9, 3.80059045015609*^9, 
   3.800593563053626*^9, 3.800598772962693*^9, 3.800674478788086*^9, 
   3.818770710405159*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["H", "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"3", " ", 
       RowBox[{"(", 
        RowBox[{"h", "-", 
         RowBox[{"H", "[", "t", "]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["2", "n"]}], " ", "h", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", "n"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "w"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"\[CapitalLambda]", "-", 
            RowBox[{"3", " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "t", "]"}], "2"]}]}], ")"}]}], "-", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               RowBox[{"2", " ", "n"}]}], ")"}], " ", "w"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               RowBox[{"2", " ", "n"}]}], ")"}]}], "-", 
            RowBox[{"2", " ", "n", " ", 
             RowBox[{"H", "[", "t", "]"}]}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            SuperscriptBox[
             RowBox[{"(", 
              FractionBox[
               RowBox[{
                SuperscriptBox["2", 
                 RowBox[{"1", "-", "n"}]], " ", "c", " ", "n", " ", 
                RowBox[{"(", 
                 RowBox[{"h", "-", 
                  RowBox[{"H", "[", "t", "]"}]}], ")"}]}], 
               RowBox[{"h", " ", 
                RowBox[{"J", "[", "t", "]"}]}]], ")"}], 
             FractionBox["2", 
              RowBox[{"1", "-", 
               RowBox[{"2", " ", "n"}]}]]], ")"}], "n"]}]}], ")"}]}], ")"}], 
     "/", 
     RowBox[{"(", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["2", "n"], " ", "h", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", "n"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"h", "-", 
            RowBox[{"H", "[", "t", "]"}]}], ")"}]}], "+", 
         RowBox[{"c", " ", "n", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            SuperscriptBox[
             RowBox[{"(", 
              FractionBox[
               RowBox[{
                SuperscriptBox["2", 
                 RowBox[{"1", "-", "n"}]], " ", "c", " ", "n", " ", 
                RowBox[{"(", 
                 RowBox[{"h", "-", 
                  RowBox[{"H", "[", "t", "]"}]}], ")"}]}], 
               RowBox[{"h", " ", 
                RowBox[{"J", "[", "t", "]"}]}]], ")"}], 
             FractionBox["2", 
              RowBox[{"1", "-", 
               RowBox[{"2", " ", "n"}]}]]], ")"}], "n"]}]}], ")"}]}], ")"}]}],
     ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.799236308738578*^9, {3.799237804257598*^9, 3.7992378443934746`*^9}, {
   3.7992907295424733`*^9, 3.799290746951095*^9}, 3.799295220407395*^9, 
   3.799304075236737*^9, 3.799304614266632*^9, {3.799305989998715*^9, 
   3.799306007521716*^9}, 3.7993060584569798`*^9, 3.799309445345001*^9, 
   3.79931154197332*^9, 3.7994570876284876`*^9, 3.7994656828307643`*^9, 
   3.799774393381195*^9, 3.7999170660602455`*^9, 3.799927576461432*^9, 
   3.7999282728120556`*^9, 3.800094300771435*^9, 3.800240944372154*^9, 
   3.800266911061894*^9, 3.8002746465971947`*^9, 3.800276189217984*^9, 
   3.8003173521585293`*^9, 3.800319419255642*^9, 3.800319816927111*^9, 
   3.800334321910304*^9, 3.8003379316601467`*^9, 3.800449782728671*^9, 
   3.8004508625367928`*^9, 3.8004565776410136`*^9, 3.800501150261745*^9, 
   3.800523675376301*^9, 3.80052470128692*^9, 3.80059045015609*^9, 
   3.800593563053626*^9, 3.800598772962693*^9, 3.800674478788086*^9, 
   3.818770710420741*^9}]
}, Open  ]],

Cell["\<\
It is of course best to nondimensionalize the equations. We do this using the \
following rules...\
\>", "Text",
 CellChangeTimes->{{3.799290755341732*^9, 3.799290759264658*^9}, {
  3.7992908953637323`*^9, 3.7992909533120317`*^9}, {3.7992909889242973`*^9, 
  3.7992910171079645`*^9}, {3.818770734076831*^9, 3.8187707464174786`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"cto\[Beta]", "=", 
   RowBox[{"c", "\[Rule]", 
    RowBox[{"\[Beta]", " ", 
     SuperscriptBox["h", 
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "n"}], "-", "2"}], ")"}]}]]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nondimDSJ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"J", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"h", " ", 
       RowBox[{"x", "[", "\[Tau]", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"J", "'"}], "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"h", " "}], "2"], 
       RowBox[{
        RowBox[{"x", "'"}], "[", "\[Tau]", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"H", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"h", " ", 
       RowBox[{"y", "[", "\[Tau]", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"H", "'"}], "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox["h", "2"], " ", 
       RowBox[{
        RowBox[{"y", "'"}], "[", "\[Tau]", "]"}]}]}], ",", 
     RowBox[{"\[CapitalLambda]", "\[Rule]", 
      RowBox[{"3", 
       SuperscriptBox["h", "2"], "\[Lambda]"}]}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7992910264138894`*^9, 3.7992911433319497`*^9}, {
   3.799291231427535*^9, 3.7992912332642555`*^9}, {3.7992915866543837`*^9, 
   3.7992916173568077`*^9}, 3.799293733757636*^9, 3.818770753193979*^9}],

Cell["The resulting dynamical system is then...", "Text",
 CellChangeTimes->{{3.7992911531680417`*^9, 3.799291172742538*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"dSJ1", "/.", "cto\[Beta]"}], "/.", "nondimDSJ"}], ",", 
   RowBox[{
    RowBox[{"Element", "[", 
     RowBox[{"n", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"\[Beta]", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"h", ",", "Reals"}], "]"}]}], ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{
     RowBox[{"\[Beta]", ">", "0"}], "&&", 
     RowBox[{"h", ">", "0"}]}]}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"dSJ2", "/.", "cto\[Beta]"}], "/.", "nondimDSJ"}], ",", 
   RowBox[{
    RowBox[{"Element", "[", 
     RowBox[{"n", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"\[Beta]", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"Element", "[", 
     RowBox[{"h", ",", "Reals"}], "]"}], "&&", 
    RowBox[{"h", ">", "0"}], "&&", 
    RowBox[{"\[Beta]", ">", "0"}], "&&", 
    RowBox[{"w", ">", 
     RowBox[{"-", "1"}]}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.79929117536479*^9, 3.7992911774368534`*^9}, {
  3.799291314312796*^9, 3.799291343471299*^9}, {3.7992914070385003`*^9, 
  3.7992914218428698`*^9}, {3.7992917081878633`*^9, 3.799291728194395*^9}, {
  3.799292421750102*^9, 3.7992924306734495`*^9}, {3.7992924972555647`*^9, 
  3.799292501479858*^9}, {3.799292665727598*^9, 3.799292669825855*^9}, {
  3.7993060756865635`*^9, 3.7993061913566*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"3", " ", 
    RowBox[{"x", "[", "\[Tau]", "]"}], " ", 
    RowBox[{"y", "[", "\[Tau]", "]"}]}], "+", 
   RowBox[{
    SuperscriptBox["x", "\[Prime]",
     MultilineFunction->None], "[", "\[Tau]", "]"}]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{{3.799291325351534*^9, 3.7992913387734537`*^9}, 
   3.7992913704223237`*^9, 3.7992914753646607`*^9, 3.7992916732742724`*^9, {
   3.7992917145060563`*^9, 3.7992917286776476`*^9}, 3.7992924312679925`*^9, 
   3.7992925023716893`*^9, 3.799292671014186*^9, 3.799293739157713*^9, 
   3.7992952205377417`*^9, 3.7993040753148446`*^9, 3.799304614375947*^9, 
   3.7993061384083614`*^9, 3.7993061932044926`*^9, 3.799309445496667*^9, 
   3.799311542145658*^9, 3.7994570877993145`*^9, 3.7994656829202805`*^9, 
   3.7997743934958534`*^9, 3.7999170661775503`*^9, 3.7999275766414366`*^9, 
   3.799928273029839*^9, 3.8000943008464985`*^9, 3.800240944455844*^9, 
   3.8002669111576552`*^9, 3.8002746469136133`*^9, 3.8002761893025756`*^9, 
   3.800317352385577*^9, 3.800319419355195*^9, 3.80031981702888*^9, 
   3.800334322079921*^9, 3.8003379317426634`*^9, 3.800449782833391*^9, 
   3.800450862609568*^9, 3.8004565777377553`*^9, 3.800501150374443*^9, 
   3.800523675518964*^9, 3.8005247013627143`*^9, 3.800590450228367*^9, 
   3.800593563143696*^9, 3.800598773070462*^9, 3.8006744788575983`*^9, 
   3.818770774823457*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["h", "2"], " ", 
   RowBox[{
    SuperscriptBox["y", "\[Prime]",
     MultilineFunction->None], "[", "\[Tau]", "]"}]}], "\[Equal]", 
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"3", " ", "h", " ", 
       RowBox[{"(", 
        RowBox[{"h", "-", 
         RowBox[{"h", " ", 
          RowBox[{"y", "[", "\[Tau]", "]"}]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["h", 
           RowBox[{
            RowBox[{"-", "2"}], " ", "n"}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               RowBox[{"2", " ", "n"}]}], ")"}], " ", "w"}]}], ")"}], " ", 
          "\[Beta]", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            SuperscriptBox[
             RowBox[{"(", 
              FractionBox[
               RowBox[{
                SuperscriptBox["2", 
                 RowBox[{"1", "-", "n"}]], " ", 
                SuperscriptBox["h", 
                 RowBox[{
                  RowBox[{"-", "2"}], " ", "n"}]], " ", "n", " ", "\[Beta]", 
                " ", 
                RowBox[{"(", 
                 RowBox[{"h", "-", 
                  RowBox[{"h", " ", 
                   RowBox[{"y", "[", "\[Tau]", "]"}]}]}], ")"}]}], 
               RowBox[{"x", "[", "\[Tau]", "]"}]], ")"}], 
             FractionBox["2", 
              RowBox[{"1", "-", 
               RowBox[{"2", " ", "n"}]}]]], ")"}], "n"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"2", " ", "n"}], "+", 
            RowBox[{"2", " ", "n", " ", 
             RowBox[{"y", "[", "\[Tau]", "]"}]}]}], ")"}]}], "-", 
         RowBox[{"3", " ", 
          SuperscriptBox["2", "n"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", "n"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "w"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"\[Lambda]", "-", 
            SuperscriptBox[
             RowBox[{"y", "[", "\[Tau]", "]"}], "2"]}], ")"}]}]}], ")"}]}], 
      ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "3"}], " ", 
          SuperscriptBox["2", "n"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", "n"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"y", "[", "\[Tau]", "]"}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["h", 
           RowBox[{
            RowBox[{"-", "2"}], " ", "n"}]], " ", "n", " ", "\[Beta]", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            SuperscriptBox[
             RowBox[{"(", 
              FractionBox[
               RowBox[{
                SuperscriptBox["2", 
                 RowBox[{"1", "-", "n"}]], " ", 
                SuperscriptBox["h", 
                 RowBox[{
                  RowBox[{"-", "2"}], " ", "n"}]], " ", "n", " ", "\[Beta]", 
                " ", 
                RowBox[{"(", 
                 RowBox[{"h", "-", 
                  RowBox[{"h", " ", 
                   RowBox[{"y", "[", "\[Tau]", "]"}]}]}], ")"}]}], 
               RowBox[{"x", "[", "\[Tau]", "]"}]], ")"}], 
             FractionBox["2", 
              RowBox[{"1", "-", 
               RowBox[{"2", " ", "n"}]}]]], ")"}], "n"]}]}], ")"}]}], ")"}]}],
     ")"}]}]}]], "Output",
 CellChangeTimes->{{3.799291325351534*^9, 3.7992913387734537`*^9}, 
   3.7992913704223237`*^9, 3.7992914753646607`*^9, 3.7992916732742724`*^9, {
   3.7992917145060563`*^9, 3.7992917286776476`*^9}, 3.7992924312679925`*^9, 
   3.7992925023716893`*^9, 3.799292671014186*^9, 3.799293739157713*^9, 
   3.7992952205377417`*^9, 3.7993040753148446`*^9, 3.799304614375947*^9, 
   3.7993061384083614`*^9, 3.7993061932044926`*^9, 3.799309445496667*^9, 
   3.799311542145658*^9, 3.7994570877993145`*^9, 3.7994656829202805`*^9, 
   3.7997743934958534`*^9, 3.7999170661775503`*^9, 3.7999275766414366`*^9, 
   3.799928273029839*^9, 3.8000943008464985`*^9, 3.800240944455844*^9, 
   3.8002669111576552`*^9, 3.8002746469136133`*^9, 3.8002761893025756`*^9, 
   3.800317352385577*^9, 3.800319419355195*^9, 3.80031981702888*^9, 
   3.800334322079921*^9, 3.8003379317426634`*^9, 3.800449782833391*^9, 
   3.800450862609568*^9, 3.8004565777377553`*^9, 3.800501150374443*^9, 
   3.800523675518964*^9, 3.8005247013627143`*^9, 3.800590450228367*^9, 
   3.800593563143696*^9, 3.800598773070462*^9, 3.8006744788575983`*^9, 
   3.818770777228995*^9}]
}, Open  ]],

Cell[TextData[{
 "To simplify this, notice that all of the ",
 Cell[BoxData[
  FormBox["h", TraditionalForm]]],
 " factors appearing inside the large parenthesis in the right hand side \
would just cancel out each other. Explicitly, in the numerator and \
denominator we can manually pick up the factors of",
 StyleBox[" ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox["h", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " and evaluate manually..."
}], "Text",
 CellChangeTimes->{{3.7992917642590647`*^9, 3.7992918504087725`*^9}, {
  3.799292017233549*^9, 3.7992920217508264`*^9}, {3.7992926982437663`*^9, 
  3.7992927328024197`*^9}, {3.818770795779251*^9, 3.8187708448963575`*^9}, {
  3.8187709348575077`*^9, 3.8187709439277277`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "numerator", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       SuperscriptBox["h", 
        RowBox[{
         RowBox[{"-", "2"}], " ", "n"}]], ")"}], 
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["h", 
            RowBox[{
             RowBox[{"-", "2"}], " ", "n"}]], " ", "h"}], ")"}], 
         FractionBox["2", 
          RowBox[{"1", "-", 
           RowBox[{"2", " ", "n"}]}]]], ")"}], "n"]}], " ", ",", 
     RowBox[{"Assumptions", "\[Rule]", 
      RowBox[{
       RowBox[{"h", ">", "0"}], "&&", 
       RowBox[{
        RowBox[{"Im", "[", "n", "]"}], "\[Equal]", "0"}]}]}]}], "]"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", "denominator", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       SuperscriptBox["h", 
        RowBox[{
         RowBox[{"-", "2"}], " ", "n"}]], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["h", 
            RowBox[{
             RowBox[{"-", "2"}], " ", "n"}]], " ", "h"}], ")"}], 
         FractionBox["2", 
          RowBox[{"1", "-", 
           RowBox[{"2", " ", "n"}]}]]], ")"}], "n"]}], ",", 
     RowBox[{"Assumptions", "\[Rule]", 
      RowBox[{
       RowBox[{"h", ">", "0"}], "&&", 
       RowBox[{
        RowBox[{"Im", "[", "n", "]"}], "\[Equal]", "0"}]}]}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7992918541655693`*^9, 3.799291989499936*^9}, 
   3.799292686011421*^9, {3.7992927361978626`*^9, 3.7992928145432982`*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.7992928190533204`*^9, 3.7992952234750605`*^9, 
  3.79930407817356*^9, 3.7993046171303387`*^9, 3.7993094482302504`*^9, 
  3.799311545797147*^9, 3.7994570904542503`*^9, 3.7994656854817667`*^9, 
  3.799774396874849*^9, 3.799917068852648*^9, 3.799927579366178*^9, 
  3.7999282755553226`*^9, 3.8000943044425297`*^9, 3.800240946977611*^9, 
  3.8002669138609123`*^9, 3.800274649573662*^9, 3.8002761920717783`*^9, 
  3.8003173559086456`*^9, 3.8003194235872283`*^9, 3.8003198208141465`*^9, 
  3.800334325548006*^9, 3.800337934880522*^9, 3.8004497867090282`*^9, 
  3.8004508656394653`*^9, 3.8004565811081915`*^9, 3.8005011532547417`*^9, 
  3.8005236800933995`*^9, 3.8005247043355465`*^9, 3.8005904530470734`*^9, 
  3.8005935670706177`*^9, 3.8005987757921925`*^9, 3.800674481463908*^9}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.7992928190533204`*^9, 3.7992952234750605`*^9, 
  3.79930407817356*^9, 3.7993046171303387`*^9, 3.7993094482302504`*^9, 
  3.799311545797147*^9, 3.7994570904542503`*^9, 3.7994656854817667`*^9, 
  3.799774396874849*^9, 3.799917068852648*^9, 3.799927579366178*^9, 
  3.7999282755553226`*^9, 3.8000943044425297`*^9, 3.800240946977611*^9, 
  3.8002669138609123`*^9, 3.800274649573662*^9, 3.8002761920717783`*^9, 
  3.8003173559086456`*^9, 3.8003194235872283`*^9, 3.8003198208141465`*^9, 
  3.800334325548006*^9, 3.800337934880522*^9, 3.8004497867090282`*^9, 
  3.8004508656394653`*^9, 3.8004565811081915`*^9, 3.8005011532547417`*^9, 
  3.8005236800933995`*^9, 3.8005247043355465`*^9, 3.8005904530470734`*^9, 
  3.8005935670706177`*^9, 3.8005987757921925`*^9, 3.8006744814781547`*^9}]
}, Open  ]],

Cell[TextData[{
 "The overall ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["h", "2"], TraditionalForm]]],
 " dependence in the right hand side therefore cancels out the same ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["h", "2"], TraditionalForm]]],
 " factor in the left hand side.\n\nThe nondimensionalized dynamical system \
for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"x", "=", 
      RowBox[{"h", " ", 
       RowBox[{"J", "(", "t", ")"}]}]}], ",", 
     RowBox[{"y", "=", 
      RowBox[{"h", " ", 
       RowBox[{"H", "(", "t", ")"}]}]}]}], ")"}], TraditionalForm]]],
 " is then..."
}], "Text",
 CellChangeTimes->{{3.7992928591678925`*^9, 3.7992929609833665`*^9}, {
  3.818770974233565*^9, 3.8187709823193893`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"dsj1", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "'"}], "[", "\[Tau]", "]"}], "\[Equal]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"x", "'"}], "[", "\[Tau]", "]"}], "/.", 
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{"Simplify", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"dSJ1", "/.", "cto\[Beta]"}], "/.", "nondimDSJ"}], ",", 
           RowBox[{"Assumptions", "\[Rule]", 
            RowBox[{
             RowBox[{"\[Beta]", ">", "0"}], "&&", 
             RowBox[{"h", ">", "0"}], "&&", 
             RowBox[{
              RowBox[{"Im", "[", "n", "]"}], "\[Equal]", "0"}]}]}]}], "]"}], 
         ",", 
         RowBox[{
          RowBox[{"x", "'"}], "[", "\[Tau]", "]"}]}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dsj2", "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"dSJ2", "/.", "cto\[Beta]"}], "/.", "nondimDSJ"}], "/.", 
       RowBox[{"h", "\[Rule]", "1"}]}], ",", 
      RowBox[{
       RowBox[{"Element", "[", 
        RowBox[{"n", ",", "Reals"}], "]"}], "&&", 
       RowBox[{"Element", "[", 
        RowBox[{"\[Beta]", ",", "Reals"}], "]"}], "&&", 
       RowBox[{"Element", "[", 
        RowBox[{
         RowBox[{"x", "[", "\[Tau]", "]"}], ",", "Reals"}], "]"}], "&&", 
       RowBox[{"Element", "[", 
        RowBox[{
         RowBox[{"y", "[", "\[Tau]", "]"}], ",", "Reals"}], "]"}]}], ",", 
      RowBox[{"Assumptions", "\[Rule]", 
       RowBox[{
        RowBox[{"\[Beta]", ">", "0"}], "&&", 
        RowBox[{
         RowBox[{"Im", "[", "n", "]"}], "\[Equal]", "0"}]}]}]}], "]"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", "dsj1", "\
\[IndentingNewLine]", "dsj2"}], "Input",
 CellChangeTimes->{{3.7992930156987314`*^9, 3.7992930613873205`*^9}, {
  3.799295155708523*^9, 3.7992951795405855`*^9}, {3.7993045674080877`*^9, 
  3.799304577789545*^9}, {3.799306310693755*^9, 3.7993063330672264`*^9}, {
  3.7993064165249825`*^9, 3.799306431220435*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["x", "\[Prime]",
    MultilineFunction->None], "[", "\[Tau]", "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"-", "3"}], " ", 
   RowBox[{"x", "[", "\[Tau]", "]"}], " ", 
   RowBox[{"y", "[", "\[Tau]", "]"}]}]}]], "Output",
 CellChangeTimes->{3.799293061970996*^9, 3.799293777092266*^9, 
  3.7992951841248317`*^9, 3.7992952239433746`*^9, 3.799304078610911*^9, 
  3.7993046392969947`*^9, 3.799306356336838*^9, 3.7993064600738955`*^9, 
  3.7993094661409006`*^9, 3.799311566738301*^9, 3.7994571093021455`*^9, 
  3.7994657035211697`*^9, 3.799774416381971*^9, 3.799917087672551*^9, 
  3.7999275982917194`*^9, 3.7999282941768017`*^9, 3.80009432557708*^9, 
  3.800240964930025*^9, 3.8002669459412904`*^9, 3.800274667897626*^9, 
  3.8002762116605015`*^9, 3.800317378164441*^9, 3.800319443571186*^9, 
  3.8003198410314007`*^9, 3.800334347686818*^9, 3.800337958799306*^9, 
  3.800449807743773*^9, 3.800450885351911*^9, 3.800456602973628*^9, 
  3.8005011733918886`*^9, 3.8005237126456776`*^9, 3.8005247236169524`*^9, 
  3.8005904728726177`*^9, 3.800593590733673*^9, 3.800598796808577*^9, 
  3.8006744995856667`*^9, 3.81877101385999*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["y", "\[Prime]",
    MultilineFunction->None], "[", "\[Tau]", "]"}], "\[Equal]", 
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"3", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"y", "[", "\[Tau]", "]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               RowBox[{"2", " ", "n"}]}], ")"}], " ", "w"}]}], ")"}], " ", 
          "\[Beta]", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", 
               FractionBox[
                RowBox[{
                 SuperscriptBox["2", 
                  RowBox[{"1", "-", "n"}]], " ", "n", " ", "\[Beta]", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"y", "[", "\[Tau]", "]"}]}], ")"}]}], 
                RowBox[{"x", "[", "\[Tau]", "]"}]]}], ")"}], 
             FractionBox["2", 
              RowBox[{"1", "-", 
               RowBox[{"2", " ", "n"}]}]]], ")"}], "n"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"2", " ", "n"}], "+", 
            RowBox[{"2", " ", "n", " ", 
             RowBox[{"y", "[", "\[Tau]", "]"}]}]}], ")"}]}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["2", "n"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", "n"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "w"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "\[Lambda]"}], "+", 
            SuperscriptBox[
             RowBox[{"y", "[", "\[Tau]", "]"}], "2"]}], ")"}]}]}], ")"}]}], 
      ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "3"}], " ", 
          SuperscriptBox["2", "n"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", "n"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"y", "[", "\[Tau]", "]"}]}], ")"}]}], "+", 
         RowBox[{"n", " ", "\[Beta]", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", 
               FractionBox[
                RowBox[{
                 SuperscriptBox["2", 
                  RowBox[{"1", "-", "n"}]], " ", "n", " ", "\[Beta]", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"y", "[", "\[Tau]", "]"}]}], ")"}]}], 
                RowBox[{"x", "[", "\[Tau]", "]"}]]}], ")"}], 
             FractionBox["2", 
              RowBox[{"1", "-", 
               RowBox[{"2", " ", "n"}]}]]], ")"}], "n"]}]}], ")"}]}], ")"}]}],
     ")"}]}]}]], "Output",
 CellChangeTimes->{3.799293061970996*^9, 3.799293777092266*^9, 
  3.7992951841248317`*^9, 3.7992952239433746`*^9, 3.799304078610911*^9, 
  3.7993046392969947`*^9, 3.799306356336838*^9, 3.7993064600738955`*^9, 
  3.7993094661409006`*^9, 3.799311566738301*^9, 3.7994571093021455`*^9, 
  3.7994657035211697`*^9, 3.799774416381971*^9, 3.799917087672551*^9, 
  3.7999275982917194`*^9, 3.7999282941768017`*^9, 3.80009432557708*^9, 
  3.800240964930025*^9, 3.8002669459412904`*^9, 3.800274667897626*^9, 
  3.8002762116605015`*^9, 3.800317378164441*^9, 3.800319443571186*^9, 
  3.8003198410314007`*^9, 3.800334347686818*^9, 3.800337958799306*^9, 
  3.800449807743773*^9, 3.800450885351911*^9, 3.800456602973628*^9, 
  3.8005011733918886`*^9, 3.8005237126456776`*^9, 3.8005247236169524`*^9, 
  3.8005904728726177`*^9, 3.800593590733673*^9, 3.800598796808577*^9, 
  3.8006744995856667`*^9, 3.8187710138756475`*^9}]
}, Open  ]],

Cell["This are Eqs. (4.19) and (4.20) in the text.", "Text",
 CellChangeTimes->{{3.79929308356279*^9, 3.7992931040294943`*^9}, {
  3.799293166893463*^9, 3.7992933569901347`*^9}, {3.7992945302192287`*^9, 
  3.7992945315824733`*^9}, {3.8187710187633133`*^9, 3.8187710410740776`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["4.2(b) Dynamical system analysis with single non-\[CapitalLambda] \
fluid", "Subsubsection",
 CellChangeTimes->{{3.799294558189759*^9, 3.799294574345481*^9}, {
  3.800449839296393*^9, 3.800449842248505*^9}, {3.800536146457469*^9, 
  3.800536148034758*^9}}],

Cell[TextData[{
 "It is useful to obtain the fixed points ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"x", "'"}], 
       RowBox[{"(", "t", ")"}]}], "=", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"y", "'"}], 
       RowBox[{"(", "t", ")"}]}], "=", "0"}]}], ")"}], TraditionalForm]]],
 " of the system analytically, if possible. We proceed in this direction by \
scanning the axes. A most obvious fixed point is located at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "=", "1"}], TraditionalForm]]],
 " (this is the self-tuning vacuum)..."
}], "Text",
 CellChangeTimes->{
  3.7992945351681256`*^9, 3.818771071139445*^9, {3.818771111875538*^9, 
   3.818771116220109*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"fpjdef", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"x", "'"}], "[", "\[Tau]", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"y", "'"}], "[", "\[Tau]", "]"}], "\[Rule]", "0"}]}], "}"}]}],
    ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"dsj1", "/.", "fpjdef"}], "/.", 
    RowBox[{
     RowBox[{"y", "[", "\[Tau]", "]"}], "\[Rule]", "1"}]}], ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{
     RowBox[{"Im", "[", "n", "]"}], "\[Equal]", "0"}]}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"dsj2", "/.", "fpjdef"}], "/.", 
    RowBox[{
     RowBox[{"y", "[", "\[Tau]", "]"}], "\[Rule]", "1"}]}], ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{
     RowBox[{"Im", "[", "n", "]"}], "\[Equal]", "0"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.7992933587008605`*^9, 3.799293462448082*^9}, {
  3.7992935181352873`*^9, 3.799293529616125*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"x", "[", "\[Tau]", "]"}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{
  3.7992933957285423`*^9, 3.7992934261668067`*^9, 3.799293462916041*^9, 
   3.7992935307163024`*^9, 3.79929378570726*^9, 3.799295241414976*^9, 
   3.7993040471993833`*^9, {3.799304078657775*^9, 3.7993041017871227`*^9}, 
   3.7993063762349443`*^9, 3.7993064658430786`*^9, 3.7994571456435003`*^9, 
   3.799465703588463*^9, 3.7997744164243107`*^9, 3.799917087738396*^9, 
   3.799927598356482*^9, 3.8004498733953433`*^9, 3.80052371272774*^9, 
   3.800524723673555*^9, 3.818771074716792*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.7992933957285423`*^9, 3.7992934261668067`*^9, 3.799293462916041*^9, 
   3.7992935307163024`*^9, 3.79929378570726*^9, 3.799295241414976*^9, 
   3.7993040471993833`*^9, {3.799304078657775*^9, 3.7993041017871227`*^9}, 
   3.7993063762349443`*^9, 3.7993064658430786`*^9, 3.7994571456435003`*^9, 
   3.799465703588463*^9, 3.7997744164243107`*^9, 3.799917087738396*^9, 
   3.799927598356482*^9, 3.8004498733953433`*^9, 3.80052371272774*^9, 
   3.800524723673555*^9, 3.818771074739314*^9}]
}, Open  ]],

Cell[TextData[{
 "Thus, we obtain the de Sitter fixed point ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"x", "=", "0"}], ",", 
     RowBox[{"y", "=", "1"}]}], ")"}], TraditionalForm]]],
 ". Checking out the ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 "-axis,..."
}], "Text",
 CellChangeTimes->{{3.7992935354939523`*^9, 3.799293678460991*^9}, {
  3.79929386559881*^9, 3.7992938838112845`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"dsj1", "/.", "fpjdef"}], "/.", 
    RowBox[{
     RowBox[{"y", "[", "\[Tau]", "]"}], "\[Rule]", "0"}]}], ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{
     RowBox[{"Im", "[", "n", "]"}], "\[Equal]", "0"}]}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"dsj2", "/.", "fpjdef"}], "/.", 
    RowBox[{
     RowBox[{"y", "[", "\[Tau]", "]"}], "\[Rule]", "0"}]}], ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{
     RowBox[{"Im", "[", "n", "]"}], "\[Equal]", "0"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.7992938941002765`*^9, 3.799293904600201*^9}, {
  3.7993063902775326`*^9, 3.7993064013315916`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.799293905559435*^9, 3.7992952435233707`*^9, 
  3.799304049464506*^9, 3.7993041056455584`*^9, 3.7993063793098297`*^9, 
  3.7993064685671883`*^9, 3.799457164049898*^9, 3.7994657036631794`*^9, 
  3.7997744479056473`*^9, 3.8004498737054067`*^9, 3.800523712816403*^9, 
  3.800524723730401*^9, 3.8187711272712293`*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"2", " ", "n"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["2", "n"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "w"}], ")"}], " ", "\[Lambda]"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", "n"}]}], ")"}], " ", "w"}]}], ")"}], " ", 
       "\[Beta]", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox[
            RowBox[{
             SuperscriptBox["2", 
              RowBox[{"1", "-", "n"}]], " ", "n", " ", "\[Beta]"}], 
            RowBox[{"x", "[", "\[Tau]", "]"}]], ")"}], 
          FractionBox["2", 
           RowBox[{"1", "-", 
            RowBox[{"2", " ", "n"}]}]]], ")"}], "n"]}]}], ")"}]}], 
   RowBox[{
    RowBox[{
     RowBox[{"-", "3"}], " ", 
     SuperscriptBox["2", "n"]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["2", 
      RowBox[{"1", "+", "n"}]], " ", "n"}], "+", 
    RowBox[{"n", " ", "\[Beta]", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox[
          RowBox[{
           SuperscriptBox["2", 
            RowBox[{"1", "-", "n"}]], " ", "n", " ", "\[Beta]"}], 
          RowBox[{"x", "[", "\[Tau]", "]"}]], ")"}], 
        FractionBox["2", 
         RowBox[{"1", "-", 
          RowBox[{"2", " ", "n"}]}]]], ")"}], "n"]}]}]], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{3.799293905559435*^9, 3.7992952435233707`*^9, 
  3.799304049464506*^9, 3.7993041056455584`*^9, 3.7993063793098297`*^9, 
  3.7993064685671883`*^9, 3.799457164049898*^9, 3.7994657036631794`*^9, 
  3.7997744479056473`*^9, 3.8004498737054067`*^9, 3.800523712816403*^9, 
  3.800524723730401*^9, 3.8187711276638083`*^9}]
}, Open  ]],

Cell[TextData[{
 "The fixed points on the ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 "-axis are the real roots of the numerator of the above equation..."
}], "Text",
 CellChangeTimes->{{3.7992939278953857`*^9, 3.799293970860111*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fpjxax", "=", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["2", "n"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "w"}], ")"}], " ", "\[Lambda]"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"2", " ", "n"}]}], ")"}], " ", "w"}]}], ")"}], " ", 
           "\[Beta]", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             SuperscriptBox[
              RowBox[{"(", 
               FractionBox[
                RowBox[{
                 SuperscriptBox["2", 
                  RowBox[{"1", "-", "n"}]], " ", "n", " ", "\[Beta]"}], 
                RowBox[{"x", "[", "\[Tau]", "]"}]], ")"}], 
              FractionBox["2", 
               RowBox[{"1", "-", 
                RowBox[{"2", " ", "n"}]}]]], ")"}], "n"]}]}], "\[Equal]", 
         "0"}], "}"}], ",", 
       RowBox[{"x", "[", "\[Tau]", "]"}]}], "]"}], "]"}], "//", "Quiet"}]}], 
  ";", "fpjxax"}]], "Input",
 CellChangeTimes->{{3.799293972168435*^9, 3.799294097207429*^9}, {
  3.7992941749193926`*^9, 3.799294189470594*^9}, {3.7992942690744915`*^9, 
  3.799294273142047*^9}, {3.7993064888303833`*^9, 3.7993066287160378`*^9}, {
  3.7993066591663504`*^9, 3.7993066598826227`*^9}, {3.7993067166082687`*^9, 
  3.799306720387843*^9}, {3.7993067692992816`*^9, 3.7993067790245934`*^9}, {
  3.818771141185214*^9, 3.8187711444265604`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "[", "\[Tau]", "]"}], "\[Rule]", 
     RowBox[{
      SuperscriptBox["2", 
       RowBox[{"-", "n"}]], " ", "n", " ", "\[Beta]", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", 
         FractionBox[
          SuperscriptBox["2", 
           FractionBox["1", 
            RowBox[{"1", "-", 
             RowBox[{"2", " ", "n"}]}]]], 
          SqrtBox[
           RowBox[{
            SuperscriptBox["3", 
             FractionBox["1", "n"]], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              FractionBox[
               RowBox[{
                SuperscriptBox["2", "n"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", "w"}], ")"}], " ", "\[Lambda]"}], 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "+", "w", "-", 
                  RowBox[{"2", " ", "n", " ", "w"}]}], ")"}], " ", 
                "\[Beta]"}]], ")"}], 
             FractionBox["1", "n"]]}]]]}], ")"}], 
       RowBox[{"1", "-", 
        RowBox[{"2", " ", "n"}]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "[", "\[Tau]", "]"}], "\[Rule]", 
     RowBox[{
      SuperscriptBox["2", 
       RowBox[{"-", "n"}]], " ", "n", " ", "\[Beta]", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox[
         SuperscriptBox["2", 
          FractionBox["1", 
           RowBox[{"1", "-", 
            RowBox[{"2", " ", "n"}]}]]], 
         SqrtBox[
          RowBox[{
           SuperscriptBox["3", 
            FractionBox["1", "n"]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             FractionBox[
              RowBox[{
               SuperscriptBox["2", "n"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", "w"}], ")"}], " ", "\[Lambda]"}], 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", "w", "-", 
                 RowBox[{"2", " ", "n", " ", "w"}]}], ")"}], " ", 
               "\[Beta]"}]], ")"}], 
            FractionBox["1", "n"]]}]]], ")"}], 
       RowBox[{"1", "-", 
        RowBox[{"2", " ", "n"}]}]]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7992940026963453`*^9, 3.799294026866583*^9}, {
   3.7992940647019663`*^9, 3.799294098423002*^9}, 3.79929427404067*^9, 
   3.799295249170648*^9, 3.7993041526150465`*^9, {3.799306557550376*^9, 
   3.799306579271266*^9}, {3.7993066140575724`*^9, 3.799306634466691*^9}, 
   3.7993066755003757`*^9, {3.7993067444998484`*^9, 3.799306779790139*^9}, 
   3.7994572036531596`*^9, 3.799465704563558*^9, 3.799774452172274*^9, 
   3.800449875352963*^9, 3.8005237144117117`*^9, 3.800524724577742*^9, {
   3.8187711371873274`*^9, 3.818771145072508*^9}}]
}, Open  ]],

Cell[TextData[{
 "These exist on both sides of the ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 "-axis.\n\nWe now provide the phase portraits of figures 1 and 2 in the \
text. The gradient stability condition becomes ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"-", "1"}], "/", 
    RowBox[{"(", 
     RowBox[{"\[Lambda]", "-", "1"}], ")"}]}], "<", "n", "<", "0"}]],
  CellChangeTimes->{3.7984585135576725`*^9, 3.7984585740011473`*^9, 
   3.7984586100446906`*^9, 3.7984586652953367`*^9, 3.7984587222543077`*^9, 
   3.7984590956665163`*^9, 3.7985631899031773`*^9, 3.7985633812132425`*^9, 
   3.7985642029214606`*^9, 3.7985731420067663`*^9, 3.7985795702104177`*^9, 
   3.7989389319997454`*^9, 3.7992329728632407`*^9, 3.799235824522485*^9, 
   3.7992386876806536`*^9}],
 ".\n\n[Case 1: ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"n", "=", 
     RowBox[{"-", "1"}]}], ",", " ", 
    RowBox[{"\[Lambda]", "=", "1.9"}], ",", 
    RowBox[{"\[Beta]", "=", "1"}], ",", 
    RowBox[{"w", "=", "0"}]}], TraditionalForm]]],
 "]\n\nThe vector field ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"x", "'"}], 
      RowBox[{"(", "t", ")"}]}], ",", 
     RowBox[{
      RowBox[{"y", "'"}], 
      RowBox[{"(", "t", ")"}]}]}], ")"}], TraditionalForm]]],
 " would have an imaginary component unless ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"y", "(", "\[Tau]", ")"}], ">", "1"}], TraditionalForm]]],
 " (region above self-tuning vacuum). Setting up the parameters and also the \
curve ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["y", "C"], "(", "x", ")"}], TraditionalForm]]],
 " on which the vector ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"dy", "/", "d"}], "\[Tau]"}], TraditionalForm]]],
 " diverges..."
}], "Text",
 CellChangeTimes->{{3.7992943175100746`*^9, 3.7992943193506875`*^9}, {
  3.7992943850121875`*^9, 3.799294396432416*^9}, {3.799294638667667*^9, 
  3.7992946961756153`*^9}, {3.799294759013976*^9, 3.799294813893032*^9}, {
  3.7992948660762725`*^9, 3.7992948935487413`*^9}, {3.799294943139053*^9, 
  3.7992949532668967`*^9}, {3.79929537120448*^9, 3.799295373465403*^9}, {
  3.799296750718292*^9, 3.799296750718292*^9}, {3.79931183658018*^9, 
  3.799311842692356*^9}, {3.7993119746004767`*^9, 3.7993120359764957`*^9}, {
  3.7994572265212784`*^9, 3.799457227412456*^9}, {3.799774596802822*^9, 
  3.799774664500803*^9}, {3.8187711677595863`*^9, 3.8187712761174307`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"SFcase1", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"n", "\[Rule]", 
      RowBox[{"-", "1"}]}], ",", 
     RowBox[{"\[Lambda]", "\[Rule]", 
      FractionBox["19", "10"]}], ",", 
     RowBox[{"\[Beta]", "\[Rule]", "1"}], ",", 
     RowBox[{"w", "\[Rule]", "0"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"zSFcase1", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"dsj2", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "/.", "SFcase1"}], "//", 
           "Denominator"}], ")"}], "/.", 
         RowBox[{
          RowBox[{"y", "[", "\[Tau]", "]"}], "\[Rule]", 
          RowBox[{
           RowBox[{"z", "[", "\[Tau]", "]"}], "+", "1"}]}]}], ")"}], 
       "\[Equal]", "0"}], ",", 
      RowBox[{"z", "[", "\[Tau]", "]"}]}], "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\"\<\!\(\*SubscriptBox[\(y\), \(C\)]\)(x)\>\"", "\[Equal]", 
     RowBox[{
      RowBox[{"z", "[", "\[Tau]", "]"}], "+", "1"}]}], "/.", "zSFcase1"}], "/.", 
   RowBox[{
    RowBox[{"x", "[", "\[Tau]", "]"}], "\[Rule]", "x"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"noghostSF", "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", 
      RowBox[{"\[Lambda]", "-", "1"}]]}], "<", "n", "<", "0"}]}], ";", 
  RowBox[{"noghostSF", "/.", "SFcase1"}]}]}], "Input",
 CellChangeTimes->{{3.799774485508873*^9, 3.7997745640655794`*^9}, {
  3.7997746296624618`*^9, 3.799774716060463*^9}, {3.799777351878085*^9, 
  3.799777355152294*^9}, {3.7997778507108192`*^9, 3.7997778698293777`*^9}, {
  3.800450058078086*^9, 3.8004500739376717`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(y\\), \\(C\\)]\\)(x)\"\>", "\[Equal]", 
  RowBox[{"1", "+", 
   FractionBox[
    SuperscriptBox["x", 
     RowBox[{"2", "/", "5"}]], 
    RowBox[{"3", " ", 
     SuperscriptBox["6", 
      RowBox[{"1", "/", "5"}]]}]]}]}]], "Output",
 CellChangeTimes->{{3.7997744729701285`*^9, 3.799774512894017*^9}, {
   3.7997745498327255`*^9, 3.7997745646449733`*^9}, {3.79977470794343*^9, 
   3.7997747165112424`*^9}, 3.7997773565811434`*^9, {3.799777853811649*^9, 
   3.7997778712097287`*^9}, 3.7999282961067905`*^9, 3.8004498754397316`*^9, {
   3.8004500606632347`*^9, 3.8004500744163947`*^9}, 3.80045660308533*^9, 
   3.8005237145310106`*^9, 3.8005247246186314`*^9, 3.8187712854155045`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.7997744729701285`*^9, 3.799774512894017*^9}, {
   3.7997745498327255`*^9, 3.7997745646449733`*^9}, {3.79977470794343*^9, 
   3.7997747165112424`*^9}, 3.7997773565811434`*^9, {3.799777853811649*^9, 
   3.7997778712097287`*^9}, 3.7999282961067905`*^9, 3.8004498754397316`*^9, {
   3.8004500606632347`*^9, 3.8004500744163947`*^9}, 3.80045660308533*^9, 
   3.8005237145310106`*^9, 3.8005247246186314`*^9, 3.8187712854155045`*^9}]
}, Open  ]],

Cell["\<\
The phase portrait of the dynamical system (figure 1) is shown below...\
\>", "Text",
 CellChangeTimes->{{3.799774724594407*^9, 3.79977474282321*^9}, {
  3.818771312534456*^9, 3.818771314897483*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"SFp1", "=", 
   RowBox[{"StreamPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"dsj1", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "/.", "SFcase1"}], ",", 
       RowBox[{
        RowBox[{"dsj2", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "/.", "SFcase1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "[", "\[Tau]", "]"}], ",", "0", ",", "2.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y", "[", "\[Tau]", "]"}], ",", 
       RowBox[{"1", "+", 
        SuperscriptBox["10", 
         RowBox[{"-", "5"}]]}], ",", "2"}], "}"}], ",", 
     RowBox[{"PlotTheme", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<Scientific\>\"", ",", "\"\<Red\>\""}], "}"}]}], ",", 
     RowBox[{"AxesStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Style", "[", 
         RowBox[{"\"\<\!\(\*
StyleBox[\"J\",
FontSlant->\"Italic\"]\)/\!\(\*
StyleBox[\"h\",
FontSlant->\"Italic\"]\)\>\"", ",", 
          RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}], ",", 
        RowBox[{"Style", "[", 
         RowBox[{"\"\<\!\(\*
StyleBox[\"H\",
FontSlant->\"Italic\"]\)/\!\(\*
StyleBox[\"h\",
FontSlant->\"Italic\"]\)\>\"", ",", 
          RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"RotateLabel", "\[Rule]", "False"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "2.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"StreamPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              FractionBox["3", "2"], ",", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"z", "[", "\[Tau]", "]"}], "+", "1"}], "/.", 
                  "zSFcase1"}], "/.", 
                 RowBox[{
                  RowBox[{"x", "[", "\[Tau]", "]"}], "\[Rule]", 
                  FractionBox["3", "2"]}]}], ")"}], "+", 
               RowBox[{"(", 
                RowBox[{"4", " ", 
                 SuperscriptBox["10", 
                  RowBox[{"-", "2"}]]}], ")"}]}]}], "}"}], ",", "Green"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1", ",", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"z", "[", "\[Tau]", "]"}], "+", "1"}], "/.", 
                  "zSFcase1"}], "/.", 
                 RowBox[{
                  RowBox[{"x", "[", "\[Tau]", "]"}], "\[Rule]", "1"}]}], 
                ")"}], "+", 
               RowBox[{"(", 
                RowBox[{"4", " ", 
                 SuperscriptBox["10", 
                  RowBox[{"-", "2"}]]}], ")"}]}]}], "}"}], ",", "Green"}], 
           "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              FractionBox["1", "2"], ",", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"z", "[", "\[Tau]", "]"}], "+", "1"}], "/.", 
                  "zSFcase1"}], "/.", 
                 RowBox[{
                  RowBox[{"x", "[", "\[Tau]", "]"}], "\[Rule]", 
                  FractionBox["1", "2"]}]}], ")"}], "+", 
               RowBox[{"(", 
                RowBox[{"4", " ", 
                 SuperscriptBox["10", 
                  RowBox[{"-", "2"}]]}], ")"}]}]}], "}"}], ",", "Green"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              FractionBox["3", "2"], ",", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"z", "[", "\[Tau]", "]"}], "+", "1"}], "/.", 
                  "zSFcase1"}], "/.", 
                 RowBox[{
                  RowBox[{"x", "[", "\[Tau]", "]"}], "\[Rule]", 
                  FractionBox["3", "2"]}]}], ")"}], "-", 
               RowBox[{"(", 
                RowBox[{"4", " ", 
                 SuperscriptBox["10", 
                  RowBox[{"-", "2"}]]}], ")"}]}]}], "}"}], ",", "Red"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1", ",", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"z", "[", "\[Tau]", "]"}], "+", "1"}], "/.", 
                  "zSFcase1"}], "/.", 
                 RowBox[{
                  RowBox[{"x", "[", "\[Tau]", "]"}], "\[Rule]", "1"}]}], 
                ")"}], "-", 
               RowBox[{"(", 
                RowBox[{"1", " ", 
                 SuperscriptBox["10", 
                  RowBox[{"-", "2"}]]}], ")"}]}]}], "}"}], ",", "Red"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              FractionBox["6", "10"], ",", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"z", "[", "\[Tau]", "]"}], "+", "1"}], "/.", 
                  "zSFcase1"}], "/.", 
                 RowBox[{
                  RowBox[{"x", "[", "\[Tau]", "]"}], "\[Rule]", 
                  FractionBox["1", "2"]}]}], ")"}], "-", 
               RowBox[{"(", 
                RowBox[{"1", " ", 
                 SuperscriptBox["10", 
                  RowBox[{"-", "2"}]]}], ")"}]}]}], "}"}], ",", "Red"}], 
           "}"}], ",", "Automatic"}], "}"}], ",", "Fine"}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"yc1", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"z", "[", "\[Tau]", "]"}], "+", "1"}], "/.", "zSFcase1"}], "/.", 
      RowBox[{
       RowBox[{"x", "[", "\[Tau]", "]"}], "\[Rule]", "x"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "2.5"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"SFp1", ",", "yc1"}], "]"}]}], "Input",
 CellChangeTimes->CompressedData["
1:eJwdz1tIk3EABfDVKGIomLKcF6Qtt4lsCUNEZF42JbZqU75pUoimmS+Vt/ag
QzMo1GQPta2x2RRRmc4HneaDCjq7ki5Zwh6+6iErLwM/TUZlMbX+53s4/Dgv
B46wpoG6eZzD4aSTwHrnWrtNz6gG+CEzPKrLfQKvxhSzno2IxmB4R8KqVHvH
YZTONQWDadI5mPlRw9ql3f0Cd/b2v8Fs5fYWfDnZHYJWbvVvWNs6dQB9Gfnc
p8TO6LsnYCrXEwcLTov5UBHOSoZmcVgIm9OT5PBhwJsPL9AjhdD26qgI2iN7
OihfGaLgFcPFSpgV6GG9Hms6dODHov+Yk1hvThHAUassEYZq/BW9RHrj1w14
StZreUZc9/VbYfjvpstFpIT0MGz2LnvggXV0Ap5RN83AsR+3Z6H/sHD+O5y4
9gLG/okOwJbgo1VootSidex+0J+Dg7wc771iRvXerWH95/j6Bi4oxpfgfCe1
Citkm0FY63TTsGyy/xOUrLi34KKjPQTttnheB3H3s4K1dOOdAEr6jIlwKKU7
FebZ08QwUq2UQ8Gt6SJYbsvVQcbto+DbxvNVbO8S3IGvtY+N0KGNM8Ee39LJ
+8SZmAQeNK6VXIY/Cx7ooabtkgEm7PNLYaa0atZfwqj0SfQc7LA8H2GIC2Vt
Hvgfs3pZSA==
  "]],

Cell[BoxData[
 GraphicsBox[{{{}, {
     {RGBColor[0., 1., 0.], 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{1.6173760514285909`, 1.289456550318906}, {1.614217346991284,
         1.291417364438139}, {1.6110603641273182`, 1.2929462985463371`}, {
        1.598461750777227, 1.297408574311428}, {1.5734648940459133`, 
        1.3034120364752892`}, {1.5487678665090094`, 1.307707336969664}, {
        1.52422075356931, 1.3111485566292949`}, {1.5, 1.313958638252871}, {
        1.478850309983895, 1.3158703288998266`}, {1.4583870641951011`, 
        1.3174100438900722`}, {1.4381983960972318`, 1.3188009686176339`}, {
        1.4178724391539, 1.3202662884765377`}, {1.4141618659567683`, 
        1.3205091450246178`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{1.4090072041126858`, 1.3208465169926313`}, {
        1.3783840131355691`, 1.3228508009824074`}, {1.3399458233870518`, 
        1.325055771750968}, {1.3014917180001233`, 1.327344967373204}, {
        1.2640560176061857`, 1.3294230709654817`}, {1.2276387222052394`, 
        1.331290082527802}, {1.2027090955006867`, 1.3324562619000593`}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{1.197549047659446, 1.3326976430255624`}, {
        1.1922398317972838`, 1.3329460020601638`}, {1.1578179105279784`, 
        1.3344494934974935`}, {1.1243315225429829`, 1.3358592207747177`}, {
        1.0917806678422972`, 1.3371751838918362`}, {1.060165346425921, 
        1.3383973828488487`}, {1.0294399637832226`, 1.3395442854847042`}, {
        0.9995589254035692, 1.3406343596383512`}, {0.9910865547358818, 
        1.3409358416281418`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.9859241315890694, 1.3411195419953104`}, {
        0.9705222312869614, 1.3416676053097902`}, {0.9423298814333985, 
        1.342644022499021}, {0.9168747225745176, 1.3435084499548393`}, {
        0.8920450572535555, 1.344342431337853}, {0.8678408854705122, 
        1.345145966648062}, {0.8442622072253878, 1.3459190558854668`}, {
        0.8213090225181823, 1.3466616990500673`}, {0.7989813313488955, 
        1.3473738961418629`}, {0.7794108630343913, 1.3479886811946107`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.7742476711290543, 1.3481493243586404`}, {
        0.7562024296240781, 1.3487069521070403`}, {0.715690430322503, 
        1.3499447829400688`}, {0.6772102617157373, 1.3511139478000178`}, {
        0.6407619238037808, 1.3522144466868866`}, {0.6063454165866337, 
        1.353246279600676}, {0.5737656770268945, 1.3542208636687876`}, {
        0.5677147015575872, 1.3544025124935066`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.5625513370870983, 1.354557515450041}, {0.5428276420871623,
         1.3551496160186238`}, {0.5135313117674369, 1.3560325366501846`}, {
        0.4858766860677183, 1.3568696255634705`}, {0.46223411996541736`, 
        1.3575874097042244`}, {0.4398217476254527, 1.3582696283194062`}, {
        0.4185588546263344, 1.358920060801914}, {0.3983647265465728, 
        1.359542486544646}, {0.36085990745916, 1.3607184353823767`}, {
        0.3560203558410779, 1.3608754135525394`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.35085738065825683`, 1.3610428824547753`}, {
        0.3266615749912958, 1.3618277099757838`}, {0.2954967025805621, 
        1.3628743689226073`}, {0.26730522869854156`, 1.3638475127946155`}, {
        0.2417608855243162, 1.3647549396960408`}, {0.21853740523696807`, 
        1.3656044477311142`}, {0.1784256300636617, 1.3671406821835759`}, {
        0.14571509666013913`, 1.3684781661147407`}, {0.1443665263173663, 
        1.3685372853591309`}}]}, 
      {Arrowheads[{{0.01340279405891524, 1.}}], 
       ArrowBox[{{0.13920579239092715`, 1.368763523976838}, {
        0.11904576907618464`, 1.3696473083130747`}, {0.09729121594206538, 
        1.3706768676749916`}, {0.05645516243755105, 1.37288931772836}, {
        0.032387968289993296`, 1.3744670227744304`}, {0.018497946647249526`, 
        1.3755968045187914`}, {0.01063325600731135, 1.3764186119715343`}, {
        0.005839973350856757, 1.3770391763492509`}, {0.0032918845608823975`, 
        1.3774758030018912`}, {0.0019171573444927684`, 1.377779361162516}, {
        0.0011154292376435273`, 1.3779803155372432`}}]}}, 
     {RGBColor[0., 1., 0.], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{1.0468602383881345`, 1.2463924089122314`}, {
        1.0446115863341365`, 1.2491786370779745`}, {1.035628456537196, 
        1.256709438150105}, {1.026679386116647, 1.2616940674051098`}, {
        1.0222154346757701`, 1.263861271956586}, {1.0177632736743814`, 
        1.2658222077281434`}, {1., 1.2729423729238598`}, {0.9788061852198062, 
        1.2785069177726682`}, {0.9579843700273958, 1.2832615150245827`}, {
        0.9373512541216628, 1.2877469320300505`}, {0.9170955367892847, 
        1.2916939885426248`}, {0.8777234957892935, 1.2984088441126478`}, {
        0.850864101545814, 1.3024042096635413`}}]}, 
      {Arrowheads[{{0.003424569720752729, 1.}}], 
       ArrowBox[{{0.8457546301233554, 1.3031642493695568`}, {
        0.8398663639749169, 1.304040135679974}, {0.8107080604374367, 
        1.3080112740021077`}}]}}, 
     {RGBColor[0., 1., 0.], 
      {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBUQGu/iFib1JlAgAAABQAAAACAAAAukT0xAGI4D8gAY/zu9ryPypL6jqn
h+A/qOCGpWnh8j/mmQOIsIbgP8UdzrDP6fI/bYQ9lrmF4D+DaZh5Wu7yP4Ol
xn3ChOA/DtgrPOnx8j+utYW+KYLgP1/8ZYd5+fI/IYVRfZB/4D8vYy+tYP/y
P/7JP+L2fOA/7mErU2QE8z/eorfMjnLgPzcEEC1uFPM/pXMzO1pt4D/VypEc
IhvzP9fhZn0laOA/KUOryyAh8z+14b5XUVPgP6+fWCmzNvM/AAAAAAAA4D/p
97PS73bzP6D3OcJXHd8/CMIIE7Sh8z+3V8EsXz/ePz2NNZMFxfM/CKDkTDeN
3D8A3ble7gL0Pxl+/aD+7to/Ffhw32Ez9D9/N0he/GTZP/rXmLTlW/Q/WrTc
prJH1z9ew9A3O470Pwr42CagmNY/6l7x8d2c9D+TYaqq
        "]]}, 
      {Arrowheads[{{0.015462033281349992`, 1.}}], 
       ArrowBox[{{0.34816647943809254`, 1.2899357987789337`}, {
        0.3331994138412505, 1.2949406525433347`}, {0.3050071035385844, 
        1.3035493014986743`}, {0.279047606206039, 1.3110152035189644`}, {
        0.2551767452465862, 1.3175297800343793`}, {0.23325034406319783`, 
        1.3232844524750946`}, {0.1943988481637724, 1.3330520259624663`}}]}}, 
     {RGBColor[1., 0., 0.], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{1.572150146333973, 1.2494216534827736`}, {
        1.5477752434702745`, 1.243917671042672}, {1.5236503600880318`, 
        1.238741632012865}, {1.5, 1.2339586382528709`}, {1.4621727554457549`, 
        1.2270311902549351`}, {1.425517950083928, 1.2205888582227433`}, {
        1.3899155506584124`, 1.214460009157652}, {1.3691655088768238`, 
        1.2109977657557465`}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{1.364070258638396, 1.210147598960675}, {1.3554055682545778`,
         1.2087018540592094`}, {1.3208506373472046`, 1.2028897671748742`}, {
        1.287298226454435, 1.1973405106854023`}, {1.2547483355762696`, 
        1.1920540845907945`}, {1.2232009647127071`, 1.1870304888910497`}, {
        1.1925810894250235`, 1.1822203222882572`}, {1.1628136852744932`, 
        1.177574183484505}, {1.1600959557823938`, 1.1771529075556024`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{1.1549912298479519`, 1.1763616227106328`}, {
        1.1338987522611168`, 1.1730920724797937`}, {1.1058362903848935`, 
        1.1687739892741225`}, {1.0785692532387232`, 1.164600532020942}, {
        1.052040594415505, 1.1605522988737023`}, {1.026250313915239, 
        1.1566292898324033`}, {1.001198411737925, 1.1528315048970448`}, {
        0.9789409281191224, 1.1494651810169676`}, {0.9571951024401174, 
        1.1461799753205437`}, {0.9507264333312948, 1.1452038983595638`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.9456185652856324, 1.144433156768794}, {0.9359609347009098,
         1.142975887807773}, {0.9152384249014993, 1.1398529184786548`}, {
        0.8753283791220711, 1.1338503343713786`}, {0.8374649651018321, 
        1.1281722229987146`}, {0.8014332246064129, 1.1227767650480587`}, {
        0.7670181994014438, 1.1176221412068073`}, {0.7412794027159818, 
        1.1137659963263928`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.7361707275400445, 1.1130006228761056`}, {
        0.7342198894869248, 1.1127083514749603`}, {0.7030382948628559, 
        1.1080353958525173`}, {0.6733129260478213, 1.1035776848391912`}, {
        0.6448832935604054, 1.099309628934694}, {0.6177493974006082, 
        1.0952312281390253`}, {0.5919112375684298, 1.0913424824521858`}, {
        0.5709246828247533, 1.0881803605222335`}, {0.5508045675449006, 
        1.0851460075473784`}, {0.5318391651941999, 1.0822828637838857`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.5267314738367121, 1.0815109521820643`}, {
        0.5129477777627005, 1.0794277004140211`}, {0.4779091129938951, 
        1.074121744954235}, {0.44525681801055017`, 1.069162325070141}, {
        0.41482824282707387`, 1.064527340160739}, {0.3866145118820697, 
        1.0602196699089583`}, {0.3604145315838968, 1.0562109686428167`}, {
        0.3360272083409143, 1.0524728906903305`}, {0.3224610019773485, 
        1.0503898059994097`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.3173551522699733, 1.0496058051465154`}, {
        0.3133332136748555, 1.048988238341855}, {0.29225994202938144`, 
        1.045746184151938}, {0.2726763841957434, 1.0427279378448868`}, {
        0.25445153096519263`, 1.0399147091450076`}, {0.2217171352348682, 
        1.0348491709435201`}, {0.193335148681439, 1.0304413023009837`}, {
        0.17104856125417356`, 1.0269687661031568`}, {0.15149786167214563`, 
        1.023913888605652}, {0.1342498950342279, 1.0212131924550794`}, {
        0.11887150643929315`, 1.0188032002980492`}, {0.1131732248562248, 
        1.0179092262138012`}}]}, 
      {Arrowheads[{{0.01048778327751763, 1.}}], 
       ArrowBox[{{0.10806995559801284`, 1.0171086005523144`}, {
        0.09309968563134166, 1.0147599919078827`}, {0.07293484375422904, 
        1.0115935913216867`}, {0.044750927861455556`, 1.0071553596952272`}, {
        0.027613294979743536`, 1.0044172105947642`}, {0.015840274073646986`, 
        1.0025168521663737`}, {0.009248817671566309, 1.0014595267041282`}, {
        0.005508671265975141, 1.0008736511845058`}, {0.0031727967766398907`, 
        1.0005125874919532`}, {0.0018248549061572158`, 1.0002983360125064`}, {
        0.0010493921105052691`, 1.0001677270445342`}}]}}, 
     {RGBColor[1., 0., 0.], 
      {Arrowheads[{{0.01390524881490878, 1.}}], 
       ArrowBox[{{1., 1.2229423729238598`}, {0.9989995553733121, 
        1.2215647642633658`}, {0.9983552069957475, 1.2207531317730806`}, {
        0.9977116894407687, 1.2199893788090608`}, {0.9927743532706518, 
        1.2150260814944935`}, {0.987879295662194, 1.211167509356114}, {
        0.9830225736768502, 1.2078681341928121`}, {0.9722232974649926, 
        1.2015831530782672`}, {0.9615936141957325, 1.1963328967059217`}, {
        0.9511230039952969, 1.1917156207464583`}, {0.923285208395599, 
        1.18100049161154}, {0.8964827299619615, 1.172153558120693}, {
        0.8706379403188569, 1.164444986861148}}]}}, 
     {RGBColor[1., 0., 0.], 
      {Arrowheads[{{0.011715170856498591`, 1.}}], 
       ArrowBox[{{0.610108897553157, 1.195206338722194}, {0.6100137006287764, 
        1.1924994496013956`}, {0.6099187918189087, 1.1889471275470573`}, {
        0.6095401592930233, 1.185935976716371}, {0.6080337149342001, 
        1.1803600497347275`}, {0.6020858131325492, 1.1691148023211035`}, {
        0.6014970592970553, 1.168358078824309}, {0.6009092554763625, 
        1.1676265790784317`}, {0.6, 1.1665373068414686`}, {0.586898848437567, 
        1.1559679852515394`}, {0.5741597239144092, 1.1472143935420147`}, {
        0.5564885006795518, 1.1363529161659054`}, {0.5395108780647802, 
        1.1278046151443446`}, {0.5231643784082611, 1.120551790435826}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{2.5, 1.600562520878983}, {2.492334321187608, 
        1.5996110149098046`}, {2.461605265614578, 1.5957988679089632`}, {
        2.4313030705588963`, 1.5920430516717028`}, {2.4014277360205636`, 
        1.588343566198023}, {2.371979261999579, 1.584700411487924}, {
        2.3429576484959433`, 1.5811135875414055`}, {2.3143628955096567`, 
        1.5775830943584679`}, {2.294936452637495, 1.5751870820248268`}}]}, 
      {Arrowheads[{{0.019999999999999987`, 1.}}], 
       ArrowBox[{{2.289809610163747, 1.574554749184452}, {2.2861950030407177`,
         1.5741089319391108`}, {2.258453971089128, 1.5706911002833344`}, {
        2.2306323774688885`, 1.5672612859718953`}, {2.202614789230432, 
        1.5638047063021538`}, {2.174989190228409, 1.5604016573490171`}, {
        2.148343564317466, 1.55713243518739}, {2.1221116835321103`, 
        1.5539189808503002`}, {2.0956983120546413`, 1.5506802525601968`}, {
        2.084726559677504, 1.5493374732166811`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{2.079599126091481, 1.5487099515895153`}, {
        2.0696479219613986`, 1.5474920721761203`}, {2.0445049853287225`, 
        1.5444302615571115`}, {2.0185213774819504`, 1.5412907815622694`}, {
        1.9934767468080112`, 1.5382836942083298`}, {1.9688077070032053`, 
        1.5353295639107511`}, {1.943950871763833, 1.5323489550849918`}, {
        1.91942652968563, 1.5294166300608687`}, {1.8957795966260265`, 
        1.5266100215994691`}, {1.8744441471693765`, 1.5240856636694156`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{1.8693143078271033`, 1.5234781221641218`}, {
        1.849012175917979, 1.5210722346143042`}, {1.8254403416845357`, 
        1.5182769363049549`}, {1.8021941869071327`, 1.51552940161225}, {
        1.7792737115857704`, 1.5128296305361904`}, {1.7566789157204483`, 
        1.5101776230767752`}, {1.734409799311167, 1.507573379234005}, {
        1.7124663623579255`, 1.5050168990078798`}, {1.6908486048607247`, 
        1.5025081823983992`}, {1.6695565268195645`, 1.5000472294055636`}, {
        1.6640923587043523`, 1.4994182290398461`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{1.6589605574273447`, 1.4988274886358235`}, {
        1.648568334298675, 1.4976312018432643`}, {1.6278622333622863`, 
        1.4952572615253925`}, {1.6074382240103986`, 1.4929254084519485`}, {
        1.5872963062430119`, 1.4906356426229326`}, {1.5478587454617414`, 
        1.4861823726981835`}, {1.5095495510184749`, 1.4818974517511454`}, {
        1.4722968052843317`, 1.4777706027518611`}, {1.4536290522354578`, 
        1.4757225284347169`}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{1.4484941727688974`, 1.4751591711453012`}, {
        1.436028590630432, 1.4737915486703734`}, {1.4007449070567757`, 
        1.4699602895066828`}, {1.3664457545633624`, 1.4662768252607885`}, {
        1.3447233897501667`, 1.463965981342104}, {1.3234013359003105`, 
        1.4617144817662688`}, {1.3024693377882823`, 1.4595207667404466`}, {
        1.2819171401885707`, 1.4573832764717998`}, {1.2430175688449163`, 
        1.4533844713827044`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{1.2378782974413574`, 1.4528627086200059`}, {
        1.2033012504026646`, 1.4493643671122332`}, {1.1660054727203162`, 
        1.4456517063617453`}, {1.1299417507729168`, 1.4421202704405285`}, {
        1.0950280427563757`, 1.4387575810058868`}, {1.0611823068666018`, 
        1.4355511597151256`}, {1.0322224516269252`, 1.432854083608859}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{1.0270788174671361`, 1.4323772477907482`}, {
        0.9967203266152096, 1.4296002628263875`}, {0.966085285687856, 
        1.4268485136954172`}, {0.936455356444069, 1.424235410311489}, {
        0.9077863980473526, 1.4217530873281856`}, {0.8800342696612106, 
        1.4193936793990896`}, {0.8531548304491471, 1.4171493211777828`}, {
        0.8271039395746655, 1.4150121473178483`}, {0.82122375706463, 
        1.4145385742065528`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.8160747384157159, 1.4141238869451418`}, {
        0.8018695626170771, 1.412979842642439}, {0.7774495440528641, 
        1.4110517997191923`}, {0.7538145613912877, 1.409222714818415}, {
        0.7309352921416081, 1.407487284210415}, {0.7087824138130869, 
        1.4058402041654992`}, {0.6873266039149851, 1.4042761709539762`}, {
        0.6665385399565633, 1.4027898808461523`}, {0.6463888994470826, 
        1.401376030112336}, {0.6100104484464154, 1.3988985381342074`}}]}, 
      {Arrowheads[{{0.009565296324603508, 1.}}], 
       ArrowBox[{{0.6048561209296048, 1.3985561684702135`}, {
        0.5719024468009077, 1.3964039334622083`}, {0.5380515237767797, 
        1.3942816423961906`}, {0.5062279442300207, 1.3923615298375458`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.7395777000659527, 2.}, {0.7242325007567482, 
        1.9886722140146533`}, {0.697206478490981, 1.9685100908186532`}, {
        0.671458808165677, 1.9491042781123546`}, {0.6446938317692538, 
        1.9287484327265059`}, {0.6191736632050708, 1.9091713184210544`}, {
        0.5948983024731282, 1.8903729351959997`}, {0.5751295181282605, 
        1.8749053683178345`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.5710639229224553, 1.871718643898338}, {0.5499441620260077,
         1.8550441194212184`}, {0.528989697350916, 1.8383772017397635`}, {
        0.5090043555481515, 1.8223525300069792`}, {0.4899881366177137, 
        1.8069701042228639`}, {0.47184050462901644`, 1.7921768176150894`}, {
        0.4544609236514731, 1.7779195634113258`}, {0.43784939368508385`, 
        1.7641983416115736`}, {0.42200591472984855`, 1.751013152215833}, {
        0.4106344152425215, 1.7415116760589562`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.40667035012168273`, 1.7381994945588883`}, {
        0.39108700783053196`, 1.7251788058283626`}, {0.3628551395671837, 
        1.70128350911367}, {0.3348456781832702, 1.6770452514234648`}, {
        0.3093170472373863, 1.654738164902848}, {0.2848915872186598, 
        1.6333120057699668`}, {0.2626724690542484, 1.6136477014125565`}, {
        0.25056214726205, 1.6028441020466186`}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{0.24670741156737427`, 1.5994052982871938`}, {
        0.24243238600293732`, 1.5955915545841095`}, {0.2239440313235121, 
        1.5789898680381178`}, {0.20703824386759492`, 1.5637212966180662`}, {
        0.19154586248680808`, 1.5496644951674399`}, {0.16237967841729012`, 
        1.522987564008065}, {0.13807299308223983`, 1.5006438549318895`}, {
        0.11748524751252055`, 1.4817383757362093`}, {0.10012910905429769`, 
        1.4658132978852538`}, {0.09399757467763188, 1.4602152840608595`}}]}, 
      {Arrowheads[{{0.004794942466133613, 1.}}], 
       ArrowBox[{{0.09018268069806976, 1.4567323338033418`}, {
        0.07299191470778607, 1.4410373805088186`}, {0.053510892894776854`, 
        1.4234274411960572`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{1.6256338724938044`, 2.}, {1.6080607264860813`, 
        1.9939152696247666`}, {1.581012224265189, 1.9845060759206015`}, {
        1.5545485685589213`, 1.9752578425259628`}, {1.5286538408263743`, 
        1.9661671197084734`}, {1.503312122526645, 1.957230457735754}, {
        1.4785074951188302`, 1.948444406875427}, {1.4542240400620252`, 
        1.9398055173951132`}, {1.43072381944172, 1.9314096529979101`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{1.4258611627830615`, 1.9296664011894067`}, {
        1.4086886544567565`, 1.9235088133467606`}, {1.3873190055043854`, 
        1.9158218938056748`}, {1.3663368919582144`, 1.9082495809391768`}, {
        1.3457423138182436`, 1.9007918747472672`}, {1.325535271084473, 
        1.8934487752299454`}, {1.305715763756903, 1.8862202823872118`}, {
        1.2672393553203636`, 1.8721071167255092`}, {1.2317001572412023`, 
        1.8589836406939835`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{1.2268565931880855`, 1.8571880277489543`}, {
        1.1943957107266066`, 1.8451324517271463`}, {1.159893161420619, 
        1.832240048947983}, {1.1266701274418915`, 1.8197442659821645`}, {
        1.0946206145684492`, 1.807619603301022}, {1.0636386285783157`, 
        1.795840561375884}, {1.0337241694714923`, 1.7844071402067527`}, {
        1.0335041767402833`, 1.7843225823245805`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{1.0286824005557353`, 1.782469252079382}, {1.004877237247978,
         1.7733193397936269`}, {0.9760830648710842, 1.7622440762014628`}, {
        0.9482508996842589, 1.7514893597233807`}, {0.9214231047521316, 
        1.7410662039230018`}, {0.8954725908808127, 1.7309415681094606`}, {
        0.8692554152879128, 1.7205815028783462`}, {0.8439809477908276, 
        1.7105507177362584`}, {0.83616115976195, 1.7074371895529197`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.8313618978034399, 1.705526314563487}, {0.8195379465330879,
         1.7008184880363846`}, {0.795963492133517, 1.6913950553276624`}, {
        0.7723508142898924, 1.6819614076547733`}, {0.7495302364163288, 
        1.6728161270447017`}, {0.7275017585128266, 1.6639592134974484`}, {
        0.7062653805793854, 1.6553906670130123`}, {0.6857574072870501, 
        1.647091572741769}, {0.6659141433068654, 1.6390430158340932`}, {
        0.6467355886388312, 1.6312449962899844`}, {0.6396811822696409, 
        1.6283691482237244`}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{0.6348977096002745, 1.6264190846880757`}, {
        0.6282217432829474, 1.6236975141094436`}, {0.5929852514964645, 
        1.60929071267662}, {0.5600017389362496, 1.5957591623731784`}, {
        0.5230234632603658, 1.5805256743556833`}, {0.4889430515846708, 
        1.5664357102628677`}, {0.4573869030811267, 1.553368224165737}, {
        0.44382864471103656`, 1.547758709567173}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.4390553603163914, 1.545783838771531}, {0.4279814169216949,
         1.5412021701352956`}, {0.4005694801782688, 1.52987759590782}, {
        0.3751176872941314, 1.5193694598854535`}, {0.35143799849832885`, 
        1.5096090821380055`}, {0.32934237401990696`, 1.5005277827352843`}, {
        0.3087232457702153, 1.492081463074511}, {0.2895190294790626, 
        1.4842400710257144`}, {0.2716106611031834, 1.476955996367914}, {
        0.25487907659931236`, 1.4701816288801288`}, {0.2478851150617626, 
        1.4673708365864768`}}]}, 
      {Arrowheads[{{0.014511909270782193`, 1.}}], 
       ArrowBox[{{0.24309201936515226`, 1.465444546832889}, {
        0.22464298254670836`, 1.4580300922013936`}, {0.19820419399947728`, 
        1.4475216145630847`}, {0.17759711607919448`, 1.4394257940610233`}, {
        0.1593163794039503, 1.4323268241289826`}, {0.1430108670250065, 
        1.4260708856391835`}, {0.1283294619936246, 1.4205041594638446`}, {
        0.10332725018536987`, 1.411199606009696}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{2.5, 1.2733992501617488`}, {2.4680973584600316`, 
        1.2721917948079664`}, {2.4314763201021687`, 1.2708444141630075`}, {
        2.3954083588500477`, 1.2694406520340928`}, {2.360723090362276, 
        1.2678959361952855`}, {2.3266140165847533`, 1.2662903834775072`}, {
        2.2935543806845713`, 1.264770310637535}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{2.2883945397683525`, 1.2645245954854272`}, {
        2.2583958690297075`, 1.2630792780419495`}, {2.22585355615137, 
        1.2613224024523602`}, {2.197448561309543, 1.2595754046000411`}, {
        2.170041280306708, 1.2577581875115869`}, {2.143033084839469, 
        1.2559128827286787`}, {2.1158253466044323`, 1.2540816217929975`}, {
        2.088978843128373, 1.252234185359925}, {2.082169277989492, 
        1.2517345293819042`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{2.077017437552438, 1.2513565099607395`}, {
        2.0630759809532764`, 1.2503335471150925`}, {2.0375505752985665`, 
        1.2484116281455562`}, {2.0118364413836636`, 1.246500349538372}, {
        1.986016410373676, 1.2445981429699982`}, {1.9605507699540978`, 
        1.24268215939219}, {1.9354395201249281`, 1.2407523988049467`}, {
        1.9106826608861676`, 1.2388088612082684`}, {1.8862801922378165`, 
        1.2368515466021557`}, {1.8709922837885375`, 1.2355984789727583`}}]}, 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{1.865843858390825, 1.2351764902337725`}, {1.862232114179874,
         1.2348804549866084`}, {1.838538426712341, 1.2328955863616262`}, {
        1.8151991298352168`, 1.2308969407272095`}, {1.7921938454907032`, 
        1.2288910697526727`}, {1.7695021956210015`, 1.2268845251073313`}, {
        1.7471241802261117`, 1.2248773067911842`}, {1.7250597993060337`, 
        1.2228694148042325`}, {1.7033090528607677`, 1.2208608491464759`}, {
        1.681871940890314, 1.2188516098179139`}, {1.6607484633946719`, 
        1.2168416968185471`}, {1.6600388082122377`, 1.2167731319932964`}}]}, 
      {Arrowheads[{{0.00927485930619019, 1.}}], 
       ArrowBox[{{1.654897060700171, 1.2162763512631967`}, {1.639938620373842,
         1.2148311101483753`}, {1.5991859255450294`, 1.2108245868188683`}, {
        1.5595399441922884`, 1.2068487108526451`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.02000000000000002, 1.}}], 
       ArrowBox[{{2.5, 1.941373934516877}, {2.4767895988710547`, 
        1.9363636261508839`}, {2.4450006154268937`, 1.9294781773947145`}, {
        2.413751804602074, 1.922686006367566}, {2.383043166396596, 
        1.9159871130694386`}, {2.3528327083425227`, 1.909376061124788}, {
        2.3230784379719185`, 1.9028474141580707`}, {2.298115770040238, 
        1.8973550616416401`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{2.2930708438425635`, 1.8962446215967583`}, {
        2.2649384602811145`, 1.8900373351584345`}, {2.236552752960916, 
        1.8837559031255162`}, {2.2086232333241855`, 1.8775568760705303`}, {
        2.1811499013709232`, 1.8714402539934771`}, {2.1541327571011295`, 
        1.8654060368943575`}, {2.1275379490512707`, 1.8594496353459125`}, {
        2.1013316257578127`, 1.8535664599208839`}, {2.0913844635736245`, 
        1.8513279879472484`}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{2.086344804619085, 1.8501938820467385`}, {2.075513787220755,
         1.8477565106192717`}, {2.050084433440099, 1.842019787441076}, {
        2.025043564415844, 1.836356290386297}, {2.000391180147989, 
        1.8307660194549342`}, {1.9761272806365349`, 1.825248974646988}, {
        1.952251865881482, 1.8198051559624584`}, {1.9283050751394368`, 
        1.8143464257789095`}, {1.9041812054872627`, 1.8088533458882083`}, {
        1.8848463870213097`, 1.8044410327502522`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{1.879810342873799, 1.8032909834149058`}, {1.857527176374072,
         1.798176333471173}, {1.8350178245675286`, 1.7929954304670699`}, {
        1.8123452656205048`, 1.787782197437303}, {1.7899991209544412`, 
        1.7826336244588639`}, {1.7684690119907778`, 1.7776467016087443`}, {
        1.7461163563886624`, 1.772431361768414}, {1.7246159513476007`, 
        1.7673892535863653`}, {1.7034564465309607`, 1.7624164380676297`}, {
        1.68212649160211, 1.7574089762172376`}, {1.6785357627713573`, 
        1.7565647612168576`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{1.6735071841966416`, 1.7553824938657263`}, {
        1.6610953552060732`, 1.7524643530898902`}, {1.6408563526687931`, 
        1.7476837417061561`}, {1.620934203675017, 1.742968735019868}, {
        1.6008536279094885`, 1.7382209259848564`}, {1.5608007468297487`, 
        1.7287508032356942`}, {1.5219149672831502`, 1.7195284852205877`}, {
        1.4841962892696938`, 1.7105539719395382`}, {1.4724451604823132`, 
        1.707748383620225}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{1.467420687485646, 1.706548787989438}, {1.4476447127893788`,
         1.7018272633925444`}, {1.4121769352503688`, 1.693334640544768}, {
        1.3777096540608262`, 1.6850623843613686`}, {1.344242869220752, 
        1.6770104948423468`}, {1.3117765807301454`, 1.6691789719877024`}, {
        1.2802426316848468`, 1.6615560259694204`}, {1.2665212615130408`, 
        1.6582336310396706`}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{1.261500649889267, 1.6570179758686336`}, {
        1.2495728651806957`, 1.654129866959486}, {1.2197672812176923`, 
        1.646900494957899}, {1.190825879795837, 1.6398679099646591`}, {
        1.1552425736798118`, 1.6312025196347495`}, {1.1209723950013026`, 
        1.6228383703547973`}, {1.0879422055561938`, 1.614762323190436}, {
        1.0607461664322593`, 1.6081039315791814`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{1.055728681363982, 1.6068754357087691`}, {
        1.0253092415497163`, 1.5994219794710207`}, {0.995560190580116, 
        1.5921314050472333`}, {0.9667585760274536, 1.58507637700157}, {
        0.9388312596876139, 1.5782437563996652`}, {0.9117802815738373, 
        1.571631790948365}, {0.885630813458551, 1.5652422319364285`}, {
        0.8603444147764188, 1.5590671958023559`}, {0.8550212600770861, 
        1.5577684059024905`}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{0.8500027864102597, 1.5565439547491113`}, {
        0.8358826449621053, 1.5530987989846485`}, {0.8122070634502746, 
        1.5473291579218083`}, {0.7892792296755907, 1.5417503890523356`}, {
        0.767060703072718, 1.5363546088147313`}, {0.7455130430763203, 
        1.531133933647497}, {0.724626606431687, 1.5260850582137944`}, {
        0.7044006105950683, 1.5212060858612972`}, {0.6848099060675706, 
        1.5164912460552724`}, {0.6658293433503003, 1.511934768260988}, {
        0.6491701333765142, 1.5079524485324287`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.644145996026292, 1.5067514479255413`}, {
        0.6295980453508678, 1.5032738165687116`}, {0.5955055206056216, 
        1.4951770665066093`}, {0.5634149411182813, 1.4876094494343137`}, {
        0.5332262606039195, 1.4805422370757375`}, {0.5047934556384176, 
        1.4739387756994433`}, {0.4779705027976565, 1.4677624115739931`}, {
        0.45703796421743137`, 1.4629815689736048`}, {0.4429285975963907, 
        1.459783193932115}}]}, 
      {Arrowheads[{{0.019907709496031774`, 1.}}], 
       ArrowBox[{{0.4378907234347086, 1.4586411858311377`}, {
        0.4371220129484093, 1.4584669310612712`}, {0.4181623260456676, 
        1.4542024431026037`}, {0.4000985805642836, 1.450172050363213}, {
        0.36641762208589856`, 1.4427493316047042`}, {0.3355965539538735, 
        1.4360703369106331`}, {0.3073944991800994, 1.4300652056187189`}, {
        0.2817086988171944, 1.4246975497597285`}, {0.2582637463668678, 
        1.4198891404981198`}, {0.23678423533082904`, 1.4155617489983505`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.2630763153896431, 2.}, {0.2599322929124752, 
        1.9936306513935764`}, {0.24834158115439176`, 1.969853530967733}, {
        0.2373525107292384, 1.9470814189634424`}, {0.226965081637015, 
        1.925314315380705}, {0.2171792938777217, 1.9045522202195209`}, {
        0.20744134917406662`, 1.883851049733377}, {0.19820935969206505`, 
        1.8640330383187054`}, {0.1812632463930224, 1.8270464927037804`}, {
        0.17508961638747547`, 1.8130553118445016`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.17300423905005405`, 1.808329260645857}, {
        0.16477287021385742`, 1.7896746652128326`}, {0.15004328717578788`, 
        1.7557147507930995`}, {0.13607526464501307`, 1.7232790827640883`}, {
        0.12363036312882769`, 1.69389190751652}, {0.11251879794683434`, 
        1.667239223684479}, {0.10255078441863553`, 1.6430070299020492`}, {
        0.09359458321620488, 1.62096098379822}, {0.09243195884424375, 
        1.6180682543251788`}}]}, 
      {Arrowheads[{{0.016186201227517658`, 1.}}], 
       ArrowBox[{{0.09050556946824048, 1.613275198666868}, {
        0.08551845501151598, 1.600866743001981}, {0.07142580082322439, 
        1.5651334937516246`}, {0.05991667754227369, 1.5354769610978318`}, {
        0.05028610595038274, 1.510508295038433}, {0.042290422248547885`, 
        1.4896080427379519`}, {0.03005015111944974, 1.457362773679299}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.7929131122484323, 1.2122650971050195`}, {
        0.7927293569957031, 1.2147889371793883`}, {0.789937270658696, 
        1.2237689542365227`}, {0.7871421056327983, 1.2279400165115881`}, {
        0.7843484358033876, 1.2311392060763082`}, {0.7769488515587999, 
        1.2377536902959223`}, {0.7695847627240903, 1.2428243788680469`}, {
        0.762262374721038, 1.247065175094878}, {0.7476609255061957, 
        1.2548933270819274`}, {0.7332512857376733, 1.2611185951906867`}, {
        0.7120605090669546, 1.2678033766088443`}, {0.6914060915279917, 
        1.2734845994217936`}, {0.6516399210722335, 1.2832842193761052`}, {
        0.612904187762071, 1.2923233794168656`}, {0.6114752535735615, 
        1.2926163067999856`}}]}, 
      {Arrowheads[{{0.012634628305945172`, 1.}}], 
       ArrowBox[{{0.6064147986427371, 1.2936536854505936`}, {
        0.5762293287431004, 1.299841619630525}, {0.54155624835501, 
        1.3062079640855593`}, {0.5088258509374886, 1.3117914368504462`}, {
        0.4779537865120411, 1.3167265895570999`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999987`, 1.}}], 
       ArrowBox[{{2.5, 1.7698738742809381`}, {2.486599272761354, 
        1.7675988635703903`}, {2.4578017388050646`, 1.7626982121862413`}, {
        2.4288041032262155`, 1.7577676797225426`}, {2.4002066708924854`, 
        1.7528969094179436`}, {2.372609746671552, 1.748175544511094}, {
        2.3440937476021797`, 1.7432673613218685`}, {2.3166139168380617`, 
        1.738517853413135}, {2.2963355460693617`, 1.7350069006754083`}}]}, 
      {Arrowheads[{{0.020000000000000018`, 1.}}], 
       ArrowBox[{{2.2912455823890436`, 1.7341256355026695`}, {
        2.2895485533960445`, 1.7338318156165982`}, {2.262275956292977, 
        1.729114042763963}, {2.235368664119556, 1.7244542485919405`}, {
        2.2094273082621676`, 1.7199452847981467`}, {2.1838723269311924`, 
        1.7154966531556444`}, {2.1581241583370105`, 1.7110178554374964`}, {
        2.1322647127288237`, 1.7065224522189337`}, {2.1067622748822465`, 
        1.7020843362264784`}, {2.0876674124769288`, 1.6987576354211238`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{2.082578377098652, 1.6978710253093547`}, {
        2.0816168447972787`, 1.6977035074601314`}, {2.05682842247392, 
        1.6933799659198918`}, {2.032397007912172, 1.68911371160576}, {
        2.0083226011120323`, 1.6849047445177363`}, {1.9846052020735026`, 
        1.68075306465582}, {1.961244810796582, 1.6766586720200116`}, {
        1.9382169744816806`, 1.6726186057572907`}, {1.915497240329207, 
        1.6686299050146363`}, {1.8930856083391614`, 1.6646925697920487`}, {
        1.8790487460407272`, 1.6622247819755513`}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{1.8739610827734148`, 1.6613303318371528`}, {
        1.8709820785115432`, 1.6608066000895272`}, {1.8491866508463528`, 
        1.6569719959070728`}, {1.827699325343591, 1.6531887572446848`}, {
        1.8065201020032569`, 1.6494568841023642`}, {1.7856489808253502`, 
        1.6457763764801097`}, {1.7650657874865323`, 1.6421446616319155`}, {
        1.7447503476634634`, 1.6385591668117752`}, {1.7247026613561436`, 
        1.6350198920196888`}, {1.7049227285645725`, 1.6315268372556557`}, {
        1.6704742430646544`, 1.6254405388644193`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{1.6653873522515446`, 1.6245417060746878`}, {
        1.6284805325557783`, 1.6180168184800625`}, {1.6046809768353079`, 
        1.6138067542235375`}, {1.581313904624789, 1.609671457913502}, {
        1.5583679291399288`, 1.6056094135362535`}, {1.5358316635964364`, 
        1.6016191050780895`}, {1.5136937212100194`, 1.597699016525307}, {
        1.4919427151963855`, 1.593847631864204}, {1.4705672587712435`, 
        1.5900634350810776`}, {1.4619214590497152`, 1.5885333235949453`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{1.4568348137976814`, 1.587633102149075}, {
        1.4495559651503018`, 1.586344910162226}, {1.4288974475492675`, 
        1.5826905410939456`}, {1.4085803191838497`, 1.5790988118625344`}, {
        1.388593193269756, 1.5755682064542897`}, {1.3689246830226944`, 
        1.5720972088555094`}, {1.3304979623925006`, 1.5653279730315297`}, {
        1.2932090630189343`, 1.5587789762809763`}, {1.2570590227798277`, 
        1.5524480413463555`}, {1.2533383759901617`, 1.5517979731964788`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{1.2482497709419427`, 1.550908896577237}, {1.222077227907529,
         1.5463360527708303`}, {1.1882151066594713`, 1.5404354751457614`}, {
        1.1554240872930905`, 1.5347387730625113`}, {1.1236555980658225`, 
        1.5292384111124415`}, {1.0928610672351013`, 1.523926853886914}, {
        1.0629919230583622`, 1.51879656597729}, {1.0446508940044978`, 
        1.5156609675873722`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{1.039559078401307, 1.5147904663324951`}, {
        1.0339995937930402`, 1.5138400119749311`}, {1.0058712544884996`, 
        1.5090536766086817`}, {0.9786050792070057, 1.5044352815727646`}, {
        0.9521689947253458, 1.4999791469066102`}, {0.9265309278203067, 
        1.495679592649649}, {0.9016588052686756, 1.4915309388413118`}, {
        0.8775205538472391, 1.4875275055210277`}, {0.8540841003327845, 
        1.4836636127282286`}, {0.8357696825604328, 1.4806630337255433`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.8306718505159355, 1.479828489533296}, {0.8092072477677702,
         1.4763340471350113`}, {0.7877464414303278, 1.4728623642262395`}, {
        0.7669116270984669, 1.469513921778016}, {0.7466794793808833, 
        1.466284109792328}, {0.7079298822233299, 1.460161937216509}, {
        0.6713110468272323, 1.4544589665146817`}, {0.6433629264228188, 
        1.4501646137315827`}, {0.6265716719053733, 1.4476163985579875`}}]}, 
      {Arrowheads[{{0.013875571710872964`, 1.}}], 
       ArrowBox[{{0.6214644578033831, 1.4468413355359857`}, {
        0.616697195294648, 1.4461178630492428`}, {0.5912419565949812, 
        1.4423035830757238`}, {0.5669253134760797, 1.4387066424190857`}, {
        0.5436753690902044, 1.4353119096873896`}, {0.5214202265896164, 
        1.4321042534886965`}, {0.5000879891265767, 1.4290685424310667`}, {
        0.4796067598533465, 1.4261896451225613`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.020000000000000007`, 1.}}], ArrowBox[CompressedData["
1:eJwBQQG+/iFib1JlAgAAABMAAAACAAAAv9eELVilwz8MqR8AdcTxP75oFA0V
pcM/xc08BuXI8T9TsU2xjqTDP9DDV0TKzPE/5AzOrJ6jwz8NrxlKcNHxP2R7
yn2uosM/RC+weeTU8T8S8RcuvqHDPwzCeOfF1/E/vKV/+/udwz9vqBYfweDx
P1XKQVTrjsM/h0HunNL38T+gAPHelVLDP/aWhdssLPI/wCCdWFxkwj+aOF+5
6aDyP9c+22fL7sE/8QT0jxzL8j+q7wyjKHvBP4w9i3q+7/I/wLOnoTB9wD+B
pB4xyjDzP3KA12/zFb8/7h3sZ2Zp8z9mEU+8UHy7P51A7quuzvM/iP9m3D0/
uD9agH1BMyD0P7QqFYLNWbU/nDt1yglk9D/oVg+JrcWxP3m1iXmJs/Q/YqxH
bpR7sT8hXz1LnLn0P+YMoh8=
        "]]}, 
      {Arrowheads[{{0.003986585965358968, 1.}}], 
       ArrowBox[{{0.06515971722797109, 1.2994228194513229`}, {
        0.05763812665605578, 1.3092870387980726`}, {0.03952486859567254, 
        1.3316550032201202`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{1.0723996400818072`, 2.}, {1.0688406919749969`, 
        1.9981714041558833`}, {1.0385689308097132`, 1.9824961791898499`}, {
        1.0093326563632652`, 1.967253677228325}, {0.9811318686356526, 
        1.9524438982713082`}, {0.9539665676268758, 1.9380668423188}, {
        0.926855019463715, 1.9237063332439228`}, {0.9006714523281578, 
        1.9097454534182923`}, {0.8895504609713861, 1.9037700522227776`}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{0.8850000310484066, 1.9013250683603165`}, {
        0.875458292587777, 1.896198212887111}, {0.8510882611398544, 
        1.8830225815147719`}, {0.8264023049282736, 1.8694164806046039`}, {
        0.8026279121505523, 1.8562250790141483`}, {0.7796527678108993, 
        1.8434085148491992`}, {0.7575143102412454, 1.8309800754078258`}, {
        0.7353370414520906, 1.818538162619117}, {0.713918836993933, 
        1.8064574278593124`}, {0.7043512291612685, 1.801029896893176}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.6998581500253593, 1.7984810543224978`}, {
        0.693259696866773, 1.7947378711284128`}, {0.6733596210706101, 
        1.7833794924264177`}, {0.6541552932540884, 1.7723584626011115`}, {
        0.6355833970658511, 1.7616509525002788`}, {0.6176439325058988, 
        1.7512569621239193`}, {0.6003368995742309, 1.7411764914720331`}, {
        0.5674201678883686, 1.7218769611477687`}, {0.5366332413008834, 
        1.7036732133335737`}, {0.5212976299191061, 1.694512714071134}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.5168628815077613, 1.691863683097416}, {0.5025600750416541,
         1.6833201144830419`}, {0.4711514888980161, 1.6643683251104715`}, {
        0.44205396607634595`, 1.6466731005182156`}, {0.41491398978302, 
        1.6300896960086277`}, {0.38958670103030046`, 1.6145483221822314`}, {
        0.36604647386238365`, 1.6000220212385057`}, {0.34411864103354795`, 
        1.5864302958782357`}, {0.34051132850133814`, 1.5841878148231638`}}]}, 
      {Arrowheads[{{0.019681532943139995`, 1.}}], 
       ArrowBox[{{0.33612423656085677`, 1.5814605849323395`}, {
        0.32362853529807145`, 1.5736926488022067`}, {0.30447731083310986`, 
        1.561757202813863}, {0.2866094483431771, 1.5505884350610257`}, {
        0.2699152703735891, 1.5401303797610453`}, {0.2542850994696617, 
        1.5303270711312713`}, {0.22594309794122047`, 1.5125298438453405`}, {
        0.20103608192271644`, 1.496887053129228}, {0.18133707711645544`, 
        1.4845307169931925`}, {0.16378992057130748`, 1.4735397508984742`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.020000000000000014`, 1.}}], 
       ArrowBox[{{2.5, 1.4356675384495945`}, {2.4900007835378646`, 
        1.434869776434064}, {2.45997028808401, 1.432504854643177}, {
        2.429740105799519, 1.4301089738976582`}, {2.3999092971763014`, 
        1.4277750110614027`}, {2.371076922706267, 1.4255958429983044`}, {
        2.3412318869321043`, 1.4234570382600205`}, {2.312415740360165, 
        1.4214768089932335`}, {2.2939518132284897`, 1.420230825953327}}]}, 
      {Arrowheads[{{0.019999999999999987`, 1.}}], 
       ArrowBox[{{2.288797844506233, 1.4198830257497006`}, {
        2.2840111494691158`, 1.4195600099150452`}, {2.255400780737622, 
        1.4176114957425574`}, {2.227155909689986, 1.415719142521762}, {
        2.1998741307059575`, 1.4139749801483108`}, {2.1729775885473717`, 
        1.4122900941137975`}, {2.1458884279760646`, 1.4105755699098155`}, {
        2.118689807966319, 1.4088437686571726`}, {2.0918501243178618`, 
        1.407166327815615}, {2.082598136689929, 1.40659924714002}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{2.0774421221803268`, 1.4062832203240463`}, {
        2.065369377030692, 1.4055432473851424`}, {2.0392475661048106`, 
        1.4039745273657553`}, {2.013484691540217, 1.402460167757453}, {
        1.9880807533369107`, 1.4010001685602362`}, {1.963035751494893, 
        1.3995945297741046`}, {1.9383496860141627`, 1.398243251399058}, {
        1.913999295270629, 1.3969406772930903`}, {1.8899613176402, 
        1.3956811513141953`}, {1.8711394918574646`, 1.394716102234801}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{1.8659805631411996`, 1.3944518837483875`}, {
        1.842822601718657, 1.3932912437376235`}, {1.819721863427543, 
        1.3921608621399464`}, {1.796933538249534, 1.391073528669342}, {
        1.7744576261846299`, 1.3900292433258103`}, {1.7522941272328305`, 
        1.3890280061093514`}, {1.7304241979311434`, 1.3880647211608355`}, {
        1.7088289948165756`, 1.3871342926211323`}, {1.6875085178891274`, 
        1.3862367204902428`}, {1.6664627671487984`, 1.3853720047681661`}, {
        1.6595656899271067`, 1.38509943601745}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{1.654404028541496, 1.3848954499592585`}, {
        1.6251954442294987`, 1.3837411425504527`}, {1.585027026058676, 
        1.3822417059679917`}, {1.559951134797089, 1.381352434405573}, {
        1.5353095143262896`, 1.3805136656392072`}, {1.511091919982399, 
        1.379722699786303}, {1.4872881071015374`, 1.3789768369642696`}, {
        1.4638878310198247`, 1.3782733772905158`}, {1.4478990380495986`, 
        1.3778120971933105`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{1.4427354959783734`, 1.3776631279000704`}, {
        1.4408808470733816`, 1.3776096208824506`}, {1.4182569105983291`, 
        1.3769828678574838`}, {1.3960057769307874`, 1.3763904183330236`}, {
        1.3741172014068763`, 1.3758295724264793`}, {1.352580939362717, 
        1.37529763025526}, {1.331386746134429, 1.3747918919367743`}, {
        1.3105243770581336`, 1.3743096575884324`}, {1.2697541327060013`, 
        1.3734049012718128`}, {1.236168233319289, 1.3726891942060604`}}]}, 
      {Arrowheads[{{0.010868032515534507`, 1.}}], 
       ArrowBox[{{1.2310037152816533`, 1.3725791396260658`}, {
        1.2301882489952825`, 1.3725617622446737`}, {1.191826091163378, 
        1.371786689104305}, {1.1546920467702844`, 1.3710947604966162`}, {
        1.1187416919888582`, 1.3704773224338103`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{2.5, 1.1145814432583228`}, {2.487570482721133, 
        1.1145294203689198`}, {2.4526583748235615`, 1.1143877870041492`}, {
        2.4182166004701866`, 1.1142391444663997`}, {2.3849506599773025`, 
        1.114072978996202}, {2.3481044710906946`, 1.1138495453097905`}, {
        2.312682914610603, 1.1136042549096672`}, {2.293375550641938, 
        1.1134635240773434`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{2.2882099973384937`, 1.1134258725047628`}, {
        2.2778312110931176`, 1.1133502218240592`}, {2.242694581094329, 
        1.1131005600811936`}, {2.208072399234456, 1.1128420095652118`}, {
        2.17479570003297, 1.1125613936389012`}, {2.1420571938948383`, 
        1.1122719515484596`}, {2.109049591225029, 1.1119869225400836`}, {
        2.081589190591577, 1.1117534098930877`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{2.0764236999197103`, 1.1117079758311463`}, {
        2.0528192808513444`, 1.1114990364176947`}, {2.0252335937119232`, 
        1.1112450078457405`}, {1.998000885270783, 1.110984255599947}, {
        1.9711211555279227`, 1.1107167796803132`}, {1.9445944044833432`, 
        1.1104425800868398`}, {1.918420632137044, 1.1101616568195265`}, {
        1.8925998384890255`, 1.1098740098783733`}, {1.869806801789778, 
        1.1096105557797808`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{1.8646414689123751`, 1.1095497807460215`}, {
        1.8420171872878308`, 1.1092785449745484`}, {1.8172553297346536`, 
        1.1089707270118758`}, {1.7928464508797581`, 1.108656185375364}, {
        1.7687905507231427`, 1.1083349200650123`}, {1.7450876292648079`, 
        1.1080069310808205`}, {1.7217376865047533`, 1.1076722184227892`}, {
        1.6987407224429798`, 1.107330782090918}, {1.6760618034240704`, 
        1.1069829568047838`}, {1.6580336788812045`, 1.1066980917005866`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{1.6528686392008003`, 1.106616098516047}, {
        1.6315532995485937`, 1.1062691435284577`}, {1.609723714692027, 
        1.1059031555382657`}, {1.5881772412229076`, 1.1055311133133874`}, {
        1.566913879141236, 1.1051530168538233`}, {1.5459336284470118`, 
        1.104768866159573}, {1.5252364891402352`, 1.1043786612306368`}, {
        1.4846915446890248`, 1.1035800886687062`}, {1.4462769109807627`, 
        1.1027781309606586`}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{1.4411124577061225`, 1.1026651068478432`}, {
        1.4069989924359747`, 1.101910292728613}, {1.3698513846341351`, 
        1.1010390693504502`}, {1.333722873629769, 1.100146347538014}, {
        1.2985001106705598`, 1.0992348457957748`}, {1.2641830957565074`, 
        1.098304564123733}, {1.234550780511027, 1.097462845290275}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{1.2293872278508793`, 1.097314276464388}, {1.198266310063873,
         1.096387660990241}, {1.1666665392852913`, 1.0954010395287908`}, {
        1.1359725165518662`, 1.0943956381375377`}, {1.1061842418635979`, 
        1.093371456816482}, {1.083320556155586, 1.0925514910847554`}, {
        1.0609879753157008`, 1.0917221572157958`}, {1.0391705671848672`, 
        1.090884008345971}, {1.022881879927687, 1.0902372867321068`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{1.0177202665120162`, 1.0900320964588084`}, {
        0.9766500574559315, 1.0883222030949724`}, {0.9372534915988642, 
        1.0865803987567055`}, {0.8995352447602118, 1.084816609687782}, {
        0.8633678596673765, 1.0830352609791372`}, {0.8286238790477611, 
        1.0812407777217061`}, {0.8113232016657597, 1.0803080934280174`}}]}, 
      {Arrowheads[{{0.010023102322617668`, 1.}}], 
       ArrowBox[{{0.8061650013900069, 1.0800300134271787`}, {
        0.7951758456287676, 1.0794375850064242`}, {0.7630364344978054, 
        1.077628958474934}, {0.7322614383915168, 1.0758178200921724`}, {
        0.7027880765111527, 1.0740080644340173`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.45855845543795976`, 2.}, {0.4447729028506322, 
        1.9837343823745286`}, {0.4294165927515734, 1.9654286871297728`}, {
        0.4141087987940913, 1.9471568993733568`}, {0.3994508556791746, 
        1.9295118106278937`}, {0.38547977776036496`, 1.9125211307011964`}, {
        0.3720845219770369, 1.8961017301698235`}, {0.35818914494140386`, 
        1.8786379136996505`}, {0.3449549190610974, 1.8618567525390617`}, {
        0.3278820221182598, 1.8399679624294456`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.3247049997596016, 1.8358947711125262`}, {
        0.3202025696357555, 1.8301223033061516`}, {0.29650205745622277`, 
        1.79953183367394}, {0.27490521976830834`, 1.7712293232431267`}, {
        0.25519275504712424`, 1.7450225362072167`}, {0.2371453617677825, 
        1.7207192367597162`}, {0.22060068559643198`, 1.698168062586625}, {
        0.20539637219922138`, 1.6772176513739427`}, {0.20068604233501347`, 
        1.6706423985551453`}}]}, 
      {Arrowheads[{{0.016767286847053895`, 1.}}], 
       ArrowBox[{{0.19767774613386402`, 1.6664430518752686`}, {
        0.1902746959983828, 1.656108971741964}, {0.17652761748390047`, 
        1.6366783317992335`}, {0.16393869152576362`, 1.6187163593728346`}, {
        0.15229147299396145`, 1.6020136822898494`}, {0.13159504998227228`, 
        1.572098712339292}, {0.1139841319946553, 1.5463584183179018`}, {
        0.09890024540309672, 1.524141600930408}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{2.057618488977221, 2.}, {2.048408435354509, 
        1.9974478721762532`}, {2.023417594071407, 1.9905016169544345`}, {
        1.9988087353358064`, 1.983639976505454}, {1.9745818591477087`, 
        1.9768629508293127`}, {1.950736965507113, 1.9701705399260092`}, {
        1.9272740544140197`, 1.9635627437955452`}, {1.9041931258684288`, 
        1.9570395624379195`}, {1.881042742684789, 1.9504993521505933`}, {
        1.8586714695524456`, 1.9441883550546564`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{1.8537006816573147`, 1.942782786170674}, {
        1.8347419763175101`, 1.9374189315759411`}, {1.8126333767810698`, 
        1.9311160665530944`}, {1.7908928682856247`, 1.9248958754042091`}, {
        1.7689926157324878`, 1.918638499235112}, {1.7474118512947348`, 
        1.9124554931064388`}, {1.7266298071454407`, 1.9064584120788255`}, {
        1.7050202284711067`, 1.900159594461739}, {1.6842471171961675`, 
        1.8940611573962651`}, {1.6638085928809865`, 1.8880428725514362`}, {
        1.655172247691828, 1.8855036820660311`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{1.6502163209149863`, 1.8840465793399939`}, {
        1.6432027750859266`, 1.8819845115962848`}, {1.622889207873613, 
        1.8759986179105055`}, {1.6033516275221071`, 1.8702021262745208`}, {
        1.584124441914924, 1.864481395458454}, {1.5647420589355794`, 
        1.858722784232428}, {1.5260817969249931`, 1.8472345501013214`}, {
        1.488561727043582, 1.8360315750718583`}, {1.4521818492913465`, 
        1.8251138591440388`}, {1.4521722236496737`, 1.825110954912128}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{1.4472267344346177`, 1.8236188104836604`}, {
        1.416942163668286, 1.8144814023178626`}, {1.3827595670203001`, 
        1.8041182384567107`}, {1.3495509561932881`, 1.7940084014239637`}, {
        1.3173163311872504`, 1.7841518912196215`}, {1.2860556920021868`, 
        1.7745487078436843`}, {1.255701305207669, 1.7651852347777366`}, {
        1.2496007918918268`, 1.76329666744006}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{1.2446661521895526`, 1.7617690256036402`}, {
        1.2261854373732688`, 1.756047855503362}, {1.1975080884989862`, 
        1.7471365700205612`}, {1.169669258584821, 1.7384513783293343`}, {
        1.1356833633860717`, 1.7277985574147205`}, {1.1029531661571041`, 
        1.7174875632580657`}, {1.071407573961996, 1.7075036229935647`}, {
        1.0475158057572695`, 1.6999105488449953`}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{1.042592759347796, 1.6983459490169848`}, {1.040975493864825,
         1.697831963755413}, {1.0115858329296692`, 1.6884578126778047`}, {
        0.9831674982206063, 1.6793663968949368`}, {0.9556493968017143, 
        1.6705429435410026`}, {0.9289604357370711, 1.6619726797501984`}, {
        0.903103303859436, 1.6536540834690583`}, {0.8781033920842399, 
        1.6455897098171437`}, {0.8539236605995675, 1.6377709016881912`}, {
        0.8458637503658145, 1.6351590070294246`}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{0.8409496466565672, 1.633566542490917}, {0.8305270695935034,
         1.6301890019759373`}, {0.8078765792541325, 1.6228353535741178`}, {
        0.7859351497695395, 1.61570129937647}, {0.7646657413278092, 
        1.608778182276729}, {0.7440313141170263, 1.6020573451686322`}, {
        0.724022769130589, 1.595535298210674}, {0.704639604532762, 
        1.5892101414889697`}, {0.6858576762679278, 1.5830756027886814`}, {
        0.6676528402804706, 1.5771254098949739`}, {0.6444888525569895, 
        1.5695501054167658`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.6395790420373071, 1.5679444531404438`}, {
        0.6328778689152187, 1.565752972667954}, {0.600121537992073, 
        1.555042652089219}, {0.5692537679978744, 1.544956770387786}, {
        0.5401805210947631, 1.5354647926199314`}, {0.512762707350755, 
        1.5265272553078575`}, {0.4868612368338662, 1.5181046949737642`}, {
        0.4665138606102358, 1.5115043406329485`}, {0.4471354305240755, 
        1.5052308285261495`}, {0.4431167029527031, 1.5039329198500742`}}]}, 
      {Arrowheads[{{0.002760878207979365, 1.}}], 
       ArrowBox[{{0.43820102320991267`, 1.5023453269431986`}, {
        0.42866788491518426`, 1.4992664561605418`}, {0.41105316212336107`, 
        1.4935935210432985`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], ArrowBox[CompressedData["
1:eJwBkQFu/iFib1JlAgAAABgAAAACAAAA+KhWApv/0T/19n+N8DzyP1G0OuNm
/9E/DVFitfBB8j+n84uH1/7RPzTeR1UxSPI/3km7gLj90T+HwwBGOE7yP9lT
JSct/NE/sIu4SPtT8j/pxpmBofrRP184GuB4WPI/YC2bohX50T9hE/SjSVzy
PxHJAsbk8tE/8XFQnoVo8j++/c9gsuzRP//d47LccfI/fZw6MJnY0T/eowZb
LInyP+rkSqaAxNE/clmgBcea8j+Oh3QEbbDRP/jtoOqbqfI/tg1tW31g0T/v
XmzC+tjyP46HpD6IWNE/n4taZeXc8j/oomIllVDRP2tz3NG54PI/fxqLy0ZE
0T8FDcf6gObyP6UlRw/hqdA/FypKAS4f8z9K4nKhahPQP6daMNcATvM/EzGk
D4rdzT9J3oZUXaDzP5IuOE7xtcs/rmO+3knh8z9rrC4VWrDJP8OfzZ/QF/Q/
0FNSAeABxz+qI4AvXVr0PyC32Fbuk8Q/Ho7yjqqR9D+Nha8yRVvDPyMO7Fb1
qvQ/AnbOgA==
        "]]}, 
      {Arrowheads[{{0.007392919863591784, 1.}}], 
       ArrowBox[{{0.14688606012823024`, 1.2945444126236259`}, {
        0.1281917255386922, 1.3066423635855187`}, {0.10189403853228204`, 
        1.3223880892131985`}, {0.08152882885425729, 1.3340349913678473`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{0.0998356333594239, 2.}, {0.0991362843565391, 
        1.9963086085801678`}, {0.09400726794919345, 1.969157830779198}, {
        0.08918692311493456, 1.9433230102792223`}, {0.08470038353315437, 
        1.918888319843465}, {0.08047224816567701, 1.8956012411822512`}, {
        0.0761797454911492, 1.8710986764365756`}, {0.07217824291302083, 
        1.8479641975214758`}, {0.06841035615729558, 1.8259765510946926`}, {
        0.06489521331530557, 1.8052094882703122`}, {0.06344319369386259, 
        1.7966075691633658`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.06258337947653952, 1.7915139380338736`}, {
        0.05804005885123725, 1.7645988220680628`}, {0.05204065465446283, 
        1.7282762419636426`}, {0.04677565652097117, 1.6957411005970997`}, {
        0.042123720246751165`, 1.6664927506084826`}, {0.03800530730172767, 
        1.6401744132382525`}, {0.03434087915582554, 1.61642930972687}, {
        0.02998312743660405, 1.5874775942747936`}}]}, 
      {Arrowheads[{{0.003880118008520187, 1.}}], 
       ArrowBox[{{0.02921425931307042, 1.5823694438873974`}, {
        0.028239347497393374`, 1.5758923953318658`}, {0.02334932258557059, 
        1.542713848689568}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.005260087773871449, 1.}}], 
       ArrowBox[{{0.7919087672848721, 1.1725413304281673`}, {
        0.7774196718839619, 1.1656402165057709`}, {0.7591845387315184, 
        1.1586772353628532`}, {0.7414717375205243, 1.1524486380900951`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.020000000000000014`, 1.}}], 
       ArrowBox[{{1.2930898843559777`, 2.}, {1.284964448083057, 
        1.9965068452877808`}, {1.2511536885246606`, 1.9819604740152528`}, {
        1.218430854254983, 1.9677884097981115`}, {1.1868428433951357`, 
        1.9540028951606612`}, {1.1562489615817846`, 1.9405672025299867`}, {
        1.1254462633022786`, 1.9267739912210229`}, {1.1038522134503126`, 
        1.9170391635039739`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{1.099142938863013, 1.9149161723516004`}, {
        1.0957018470578577`, 1.9133648915075077`}, {1.06689223427014, 
        1.900305369486703}, {1.0390585844652522`, 1.8876069364595218`}, {
        1.0111819934386093`, 1.8748967708854185`}, {0.9841954829512858, 
        1.8625242292110946`}, {0.958099053003282, 1.8504893114365504`}, {
        0.9328927035945975, 1.8387920175617851`}, {0.9113463750439514, 
        1.8287369782427911`}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{0.9066669280196885, 1.826549031277903}, {0.8848704863957169,
         1.816327668869595}, {0.8619846786056528, 1.805539955891671}, {
        0.8398490713551731, 1.7950485504925273`}, {0.8184076219098847, 
        1.7848360954405702`}, {0.7976042875353948, 1.774885233504205}, {
        0.7774390682317033, 1.7651959646834319`}, {0.7579119639988102, 
        1.755768288978251}, {0.73483502379094, 1.7445643723063549`}, {
        0.7202446904421526, 1.7374383652749879`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.7156030308889051, 1.7351713506823156`}, {
        0.7126553701878289, 1.733731695372199}, {0.6913194451588948, 
        1.7232531198572034`}, {0.6707736906735555, 1.7131115074427872`}, {
        0.6509645487012289, 1.7032897198103698`}, {0.6318384612113328, 
        1.6937706186413715`}, {0.6133418701732852, 1.6845370656172103`}, {
        0.5954212175565039, 1.6755719224193069`}, {0.5613405120859115, 
        1.6584474623204528`}, {0.5307000962517591, 1.642947530103201}}]}, 
      {Arrowheads[{{0.013872324706671628`, 1.}}], 
       ArrowBox[{{0.526094578802522, 1.6406079697993556`}, {
        0.49985109418145046`, 1.6272580890988866`}, {0.47200891032369613`, 
        1.6130375058946054`}, {0.4459040033774612, 1.5996557210381126`}, {
        0.42146301655114365`, 1.587076557218552}, {0.3985474208166227, 
        1.5752449017932817`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.016486995694039514`, 1.}}], 
       ArrowBox[{{0.38108628045201876`, 1.1683817008996489`}, {
        0.3807484205243748, 1.1699553319922438`}, {0.38053037664725714`, 
        1.1708676957257413`}, {0.38031229354121693`, 1.1717185834972412`}, {
        0.3786946689401453, 1.176972555759253}, {0.3770775454754118, 
        1.1809986844932978`}, {0.37546230438889205`, 1.184419296350729}, {
        0.37133423255345377`, 1.1917273086010147`}, {0.36722882199353823`, 
        1.197691629754706}, {0.3631500555560211, 1.2028720392924062`}, {
        0.3497835166149596, 1.2171042123489526`}, {0.33677529584996174`, 
        1.2283292833891828`}, {0.3241472274270026, 1.237853407019035}, {
        0.30599762176950385`, 1.2501695977763219`}, {0.28870807058234843`, 
        1.260675579545227}, {0.2566587738791928, 1.277874037821745}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0077983081827027725`, 1.}}], 
       ArrowBox[{{0.451061808439757, 1.143402151035344}, {
        0.43964945215769907`, 1.132525480952428}, {0.42859301247221265`, 
        1.123556286280369}, {0.4135965144731629, 1.1127232294111449`}, {
        0.39925325309555754`, 1.1043262326061232`}, {0.38550224539935457`, 
        1.097294445967555}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.004458396348294303, 1.}}], 
       ArrowBox[{{0.05739719892813806, 1.0724455909447304`}, {
        0.057389936887784564`, 1.0716574765505362`}, {0.057380849521150745`, 
        1.0709573698510089`}, {0.05735043578964602, 1.0737078197380978`}, {
        0.05731992465816229, 1.0783276062411808`}, {0.05728936056372663, 
        1.079984042519434}, {0.05716692288584025, 1.0844303293622548`}, {
        0.057044309158141814`, 1.0874380630929923`}, {0.05672747014494144, 
        1.0942393743698184`}, {0.05641052528274217, 1.099210365443969}, {
        0.05514271801526514, 1.1154588575582265`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.006520572066815892, 1.}}], 
       ArrowBox[{{0.048840214081744, 1.127924889204398}, {0.04636524918336746,
         1.1473236653517964`}, {0.04514941126972798, 1.1560903209291726`}, {
        0.04395642160885326, 1.164237885615976}, {0.03927602419319933, 
        1.1946047978323497`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.018457511902844684`, 1.}}], 
       ArrowBox[{{2.3205002273497652`, 2.}, {2.3186132020011945`, 
        1.9995346211875704`}, {2.2909917038031207`, 1.9927327723419817`}, {
        2.2637701287078063`, 1.9860092044046964`}, {2.2375483613693885`, 
        1.9794813387381684`}, {2.211749900763292, 1.9730351579385197`}, {
        2.1857670676921916`, 1.966552105990437}, {2.1601529795511, 
        1.9601427963392224`}, {2.1354607537350274`, 1.953917842430177}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.008898222118046141, 1.}}], 
       ArrowBox[{{0.5833248239191485, 2.}, {0.568639767105958, 
        1.9864069279965673`}, {0.5504471529133154, 1.9694310332111558`}, {
        0.5330286685468129, 1.9530219802140365`}, {0.5162691055806878, 
        1.9371140331475865`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.004198789230986922, 1.}}], 
       ArrowBox[{{2.5, 1.6855052189901933`}, {2.485749592433922, 
        1.6834114946626826`}, {2.4570830337623595`, 1.679188821286953}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0033012707211984866`, 1.}}], 
       ArrowBox[{{1.7329477758685188`, 1.2910040032082688`}, {
        1.719609002167015, 1.2982639158847182`}, {1.7063398648006978`, 
        1.3029728975615344`}, {1.7050161114474538`, 1.30331661160041}, {
        1.7036930419761354`, 1.3036491351930939`}, {1.702370667288001, 
        1.3039713502017942`}, {1.701643656170026, 1.3041444841379808`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.006941944390520667, 1.}}], 
       ArrowBox[{{2.5, 1.8545385073939504`}, {2.486314231824748, 
        1.8519157924964456`}, {2.4574360604955396`, 1.846368737849028}, {
        2.429572654917132, 1.8409839106131947`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.011280292381775286`, 1.}}], 
       ArrowBox[{{2.491549959595268, 1.6833922382603497`}, {
        2.4624239970005033`, 1.6791081860566983`}, {2.4330972115959644`, 
        1.6747963523340221`}, {2.404172071810973, 1.670540081649396}, {
        2.37625104607485, 1.6664227185598954`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.005979510571435398, 1.}}], 
       ArrowBox[{{2.5, 1.5172376564738013`}, {2.4978787481348435`, 
        1.5170206515491653`}, {2.4676964675421553`, 1.5139437540586766`}, {
        2.4385392627839484`, 1.5109986273261555`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.013886087044949806`, 1.}}], 
       ArrowBox[{{2.4905650235758383`, 1.8533770311218531`}, {
        2.4617948705780037`, 1.8478284572620627`}, {2.433478187840956, 
        1.8423509189304164`}, {2.4049632946891952`, 1.8368412015474629`}, {
        2.376844822366861, 1.8313958422671233`}, {2.349717402118094, 
        1.8261113782433194`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0031391612904981153`, 1.}}], 
       ArrowBox[{{1.8418958418947622`, 1.3021182035613978`}, {
        1.8405872681987556`, 1.3029636523124897`}, {1.8370657727148045`, 
        1.3047310075187095`}, {1.8335468541463138`, 1.3060736541280005`}, {
        1.8300313091126699`, 1.3071885185020347`}, {1.8160121631638964`, 
        1.3106209777989413`}, {1.814614222161271, 1.3108930960957326`}, {
        1.8132170714241744`, 1.3111576418491226`}, {1.8118207185807653`, 
        1.3114151129500797`}, {1.8110530618574228`, 1.3115538916711136`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.012873435143853635`, 1.}}], 
       ArrowBox[{{2.5, 1.0356815808382969`}, {2.466773021449157, 
        1.0357699359976178`}, {2.432853188455992, 1.0358601506288685`}, {
        2.399374818497716, 1.0359491571973605`}, {2.367000106126667, 
        1.0360351436089565`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.006282598830052999, 1.}}], 
       ArrowBox[{{2.5, 1.1928959802393209`}, {2.4695148484444056`, 
        1.1923509556331946`}, {2.4351036208936367`, 1.1916733087061566`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019295282384897076`, 1.}}], 
       ArrowBox[{{2.467587121679597, 1.8491289249564327`}, {
        2.4381054853015653`, 1.8434489620115178`}, {2.409042945112192, 
        1.8378366044492183`}, {2.381028145394466, 1.8323932603434576`}, {
        2.3534563776115336`, 1.8270203702885603`}, {2.3256910188983624`, 
        1.8216155766545206`}, {2.2983128420456693`, 1.816274590178766}, {
        2.2719026198441714`, 1.811093121598724}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.01673012219263052, 1.}}], 
       ArrowBox[{{2.468854457934679, 1.6802737101752716`}, {2.438977478308728,
         1.6758815558296085`}, {2.4101602420975077`, 1.671635041295513}, {
        2.3817905897406577`, 1.667449147292257}, {2.3532247796931793`, 
        1.6632357017308297`}, {2.325051285026958, 1.6590773592857455`}, {
        2.297858578813877, 1.6550567746315203`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.011412811692719875`, 1.}}], 
       ArrowBox[{{2.4771049520634385`, 1.5157126461057961`}, {
        2.447476327743699, 1.5127093557366071`}, {2.417647369230272, 
        1.5096798967187894`}, {2.38821907910422, 1.5067027749982287`}, {
        2.3597924599466062`, 1.5038564965208103`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019039392497975427`, 1.}}], 
       ArrowBox[{{2.5, 1.3497730382396884`}, {2.477087743004646, 
        1.3482387260304147`}, {2.4468670234282106`, 1.3464635758268173`}, {
        2.417631499037538, 1.3453758262742195`}, {2.3888266843313968`, 
        1.3446761803258873`}, {2.3598492516615863`, 1.3439144831432661`}, {
        2.331217054919114, 1.343276888429223}, {2.303447947994985, 
        1.3429495498866268`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.00387503817933088, 1.}}], 
       ArrowBox[{{1.9576699832120954`, 1.3078089355358757`}, {
        1.9539670006567318`, 1.310093844482293}, {1.9391870732721415`, 
        1.3147369424080073`}, {1.9244807173679934`, 1.3173564977346106`}, {
        1.923014667181424, 1.3175725742281874`}, {1.9215494966424904`, 
        1.3177832579259465`}, {1.9199388315665273`, 1.3180091479415066`}, {
        1.9192802276813832`, 1.3180998927584537`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.01914575807118988, 1.}}], 
       ArrowBox[{{2.4866424893860124`, 1.0354446478696948`}, {
        2.4521854039560957`, 1.0355361097196176`}, {2.4188746120545717`, 
        1.035624632063491}, {2.38604131310381, 1.0357120429605167`}, {
        2.352991405806975, 1.0358000846624669`}, {2.320374715202288, 
        1.0358868647545676`}, {2.2888410663279743`, 1.0359704908220457`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.005171183907520518, 1.}}], 
       ArrowBox[{{2.085851243382348, 1.3167339431579734`}, {2.082297599486229,
         1.3180619816681727`}, {2.0787467621133175`, 1.3190435863836285`}, {
        2.0711634626687725`, 1.32089116370986}, {2.0635976603949313`, 
        1.3222187527192675`}, {2.0334040192433718`, 1.3262475673315375`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{2.338686893968081, 1.03151239617281}, {2.3088143167943684`, 
        1.0315912288913758`}, {2.2793191394144285`, 1.0316691602049404`}, {
        2.2502013618282612`, 1.0317461901135045`}, {2.2214609840358657`, 
        1.0318223186170674`}, {2.1930980060372423`, 1.0318975457156296`}, {
        2.1651124278323914`, 1.0319718714091908`}, {2.1375042494213123`, 
        1.0320452956977508`}, {2.132059998170957, 1.032059795202339}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{2.126894325968735, 1.032073552776035}, {2.110273470804006, 
        1.0321178185813102`}, {2.083420091980471, 1.0321894400598683`}, {
        2.0538009824920684`, 1.0322686714645213`}, {2.0239767333715295`, 
        1.0323485670406258`}, {1.9945627635152623`, 1.032427134273827}, {
        1.9661744918196722`, 1.0325023806497688`}, {1.9382143460712047`, 
        1.032576366145409}, {1.9202674382293312`, 1.0326239816536582`}}]}, 
      {Arrowheads[{{0.005769665341524377, 1.}}], 
       ArrowBox[{{1.9151017658879121`, 1.0326376868621627`}, {
        1.9100609584791695`, 1.0326510607875692`}, {1.88229405457427, 
        1.0327243371366897`}, {1.85549335988721, 1.0327940677532124`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.009922210562104836, 1.}}], 
       ArrowBox[{{2.263093178647998, 1.3254755920273136`}, {
        2.2619147699410087`, 1.32590247226191}, {2.2585574045997587`, 
        1.3268304337226144`}, {2.255203001263406, 1.327515818924067}, {
        2.2518519704276803`, 1.3280738995141859`}, {2.2384863208043178`, 
        1.3297461296239783`}, {2.225184964498726, 1.3308798825209494`}, {
        2.192969638242158, 1.3332054331668242`}, {2.1611694431078297`, 
        1.334673365360794}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.013431083705328133`, 1.}}], 
       ArrowBox[{{2.4964914540490195`, 1.193348918348122}, {2.461433163168041,
         1.192673557468596}, {2.426125064617861, 1.1920062971053142`}, {
        2.3913165814060826`, 1.1913228357095442`}, {2.3577571365403083`, 
        1.190598871732553}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019933051917873527`, 1.}}], 
       ArrowBox[{{2.4876892680962346`, 1.5175265617678402`}, {
        2.4568790978379287`, 1.5143757117898797`}, {2.426491446310926, 
        1.5112796269638273`}, {2.397160091612177, 1.5083204550175433`}, {
        2.3682744998939365`, 1.5054181867145449`}, {2.339193144976184, 
        1.5024899614965115`}, {2.3105033164574564`, 1.499613650108548}, {
        2.2827923039362945`, 1.4968671232957589`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.013776977239228142`, 1.}}], 
       ArrowBox[{{0.563997129158869, 1.9813699811104566`}, {
        0.5454410712186666, 1.9639086326501698`}, {0.5276910801845501, 
        1.9470482816005017`}, {0.5099901995701415, 1.93021534828971}, {
        0.49299716502240315`, 1.9139285769117844`}, {0.47674987139821157`, 
        1.8982106317855774`}, {0.46113463412693717`, 1.8829935199545327`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{2.4762095449460877`, 1.6814188762478222`}, {
        2.446981536516167, 1.6771113839560474`}, {2.4176688301101583`, 
        1.6727910696989012`}, {2.388149051834231, 1.6684418636504494`}, {
        2.3590434172981403`, 1.664150441184609}, {2.3309731421116404`, 
        1.6600034776752977`}, {2.3033401882346185`, 1.6559166594483232`}, {
        2.2755156142007733`, 1.6518025238965266`}, {2.2717958805416845`, 
        1.6512522495440185`}}]}, 
      {Arrowheads[{{0.004412408634337302, 1.}}], 
       ArrowBox[{{2.266685802920565, 1.6504962963194223`}, {
        2.2480742804805747`, 1.647743022994374}, {2.2215910475444947`, 
        1.6438201087163318`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.01999999999999998, 1.}}], 
       ArrowBox[{{2.4727288116855886`, 1.8498189597106895`}, {
        2.4438535800758507`, 1.8442263918235957`}, {2.415426467926208, 
        1.8387050585171845`}, {2.3869163162862144`, 1.8331690827720009`}, {
        2.3582014318326214`, 1.8275996005407413`}, {2.3298960130062265`, 
        1.8220971312816334`}, {2.3026142582478246`, 1.8167621944529044`}, {
        2.275765405084978, 1.8114971055508167`}, {2.269906010614193, 
        1.8103492569649884`}}]}, 
      {Arrowheads[{{0.006755563094701956, 1.}}], 
       ArrowBox[{{2.2648366756524654`, 1.809356180121311}, {2.248727443087437,
         1.8062004001323133`}, {2.222067698759284, 1.8009669277466418`}, {
        2.1963534986045996`, 1.7958915379430498`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.004894772463467918, 1.}}], 
       ArrowBox[{{2.11480296145879, 1.9355116336390719`}, {2.089817400250011, 
        1.9293081072078373`}, {2.065733471816512, 1.9232852712925412`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{2.02842659469868, 1.0305732003562242`}, {2.002229155133991, 
        1.0306426228360532`}, {1.9763798948949094`, 1.0307110929225398`}, {
        1.9508788139814357`, 1.0307786106156835`}, {1.9257259123935704`, 
        1.030845175915485}, {1.9009211901313126`, 1.030910788821944}, {
        1.8764646471946627`, 1.0309754493350602`}, {1.84909346419014, 
        1.0310481017437159`}, {1.8217996992907226`, 1.0311207470842125`}}]}, 
      {Arrowheads[{{0.014575119150196594`, 1.}}], 
       ArrowBox[{{1.8166340268754615`, 1.0311344244219294`}, {
        1.7943510981810946`, 1.0311934065610269`}, {1.7681469480382301`, 
        1.0312617588525068`}, {1.7423491984764763`, 1.0313287469917336`}, {
        1.7163685365225958`, 1.0313964979639156`}, {1.6907536993529686`, 
        1.0314627232701872`}, {1.6660534241439735`, 1.0315251344116825`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019952253358090002`, 1.}}], 
       ArrowBox[{{2.4877589784482255`, 1.1936586750678533`}, {
        2.4517120332199904`, 1.192995162932601}, {2.416971831827228, 
        1.1922897533989945`}, {2.382777379644133, 1.191567338920193}, {
        2.3483369464775956`, 1.190853139930493}, {2.3143884752779433`, 
        1.1901225099625898`}, {2.2816699089955037`, 1.1893508025491792`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{2.423915590406845, 1.673492812701947}, {2.3950037484902493`,
         1.669228093310353}, {2.3665333284912915`, 1.6650238965108706`}, {
        2.3379801629768995`, 1.6608069898474598`}, {2.309224693146338, 
        1.656561435744059}, {2.2808738319481154`, 1.652373176520638}, {
        2.2535344923307363`, 1.6483281544971633`}, {2.226622440487519, 
        1.644342787307031}, {2.2195073717079232`, 1.6432892965277588`}}]}, 
      {Arrowheads[{{0.00659384419085184, 1.}}], 
       ArrowBox[{{2.2143973909850687`, 1.6425326885819262`}, {
        2.1995232037560153`, 1.6403303459791514`}, {2.172798336801084, 
        1.6363720529267662`}, {2.147009394287586, 1.6325491305631183`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.020000000000000018`, 1.}}], 
       ArrowBox[{{2.478525216392713, 1.8509697690749611`}, {2.44909245059814, 
        1.8452735684204424`}, {2.4200975378165404`, 1.8396480035056877`}, {
        2.3915404780479133`, 1.834093074330697}, {2.363421271292258, 
        1.82860878089547}, {2.335739917549576, 1.8231951232000072`}, {
        2.307977460074181, 1.8177669485599735`}, {2.28001498243932, 
        1.812305550710304}, {2.2757096477567136`, 1.81146284325167}}]}, 
      {Arrowheads[{{0.014621073978006455`, 1.}}], 
       ArrowBox[{{2.270640156775733, 1.81047056316752}, {2.2524525451233917`, 
        1.806910599279906}, {2.2258902086047923`, 1.8016817638976839`}, {
        2.199750860656236, 1.7965221982281487`}, {2.1734267913822873`, 
        1.791331291544589}, {2.147472164759123, 1.7862030668890783`}, {
        2.122441144762919, 1.7812315473036904`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0194363414398645, 1.}}], 
       ArrowBox[{{2.407817402650728, 1.5086328656156112`}, {2.377767505853458,
         1.505596554924391}, {2.348130562435733, 1.5026146603085957`}, {
        2.3195260024668642`, 1.49976880588136}, {2.2913571207861874`, 
        1.4969795727879327`}, {2.2629969123548377`, 1.4941646018290489`}, {
        2.2350193574248336`, 1.4914011066010775`}, {2.2079984362481926`, 
        1.4887663007003873`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.005660230136848187, 1.}}], 
       ArrowBox[{{0.35349968471659904`, 2.}, {0.34585638781454353`, 
        1.9884832454452332`}, {0.33337573440150936`, 1.9694640093642453`}, {
        0.3214298504544005, 1.951100515027768}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{1.7723298656442814`, 1.0298111769912988`}, {
        1.7490331315436605`, 1.0298715600428272`}, {1.7260476886856964`, 
        1.029930858512075}, {1.703373537070389, 1.029989072399042}, {
        1.6810106766977386`, 1.0300462017037286`}, {1.6589591075677452`, 
        1.0301022464261345`}, {1.6372188296804084`, 1.0301572065662599`}, {
        1.615789843035729, 1.0302110821241046`}, {1.5912860087452996`, 
        1.030273091926925}, {1.5666011399281792`, 1.0303359406168358`}, {
        1.5657029169246135`, 1.0303381996135053`}}]}, 
      {Arrowheads[{{0.0128552937735373, 1.}}], 
       ArrowBox[{{1.560537242738871, 1.0303511910874874`}, {
        1.5422783401644407`, 1.0303971115325656`}, {1.5188607130341547`, 
        1.0304540880128426`}, {1.4958220181946658`, 1.030509458768785}, {
        1.4726135309867632`, 1.030565716445049}, {1.449744628515688, 
        1.03062020028067}, {1.4277246878866812`, 1.0306702495146831`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999983`, 1.}}], 
       ArrowBox[{{2.4305717237726636`, 1.674120681555046}, {2.401120516036114,
         1.6697812677556203`}, {2.372100533361869, 1.6655018587262893`}, {
        2.3435117757499278`, 1.6612824544670528`}, {2.3153542432002916`, 
        1.6571230549779106`}, {2.28762793571296, 1.6530236602588635`}, {
        2.2598207961616343`, 1.6489116719615868`}, {2.2318160268802103`, 
        1.6447712863554593`}, {2.2261608912743474`, 1.6439348622049417`}}]}, 
      {Arrowheads[{{0.01440177374700981, 1.}}], 
       ArrowBox[{{2.221050792518997, 1.6431790518568974`}, {
        2.2042065170589824`, 1.6406876953670337`}, {2.1775851558882424`, 
        1.6367460909228637`}, {2.151381244161711, 1.6328636410496964`}, {
        2.124994496027758, 1.6289543671698778`}, {2.098973420708649, 
        1.6250987413033613`}, {2.073866527426651, 1.6213772354700984`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0000652692059732714, 1.}}], 
       ArrowBox[{{1.2101428720847536`, 1.2591143874445756`}, {
        1.2097243557142927`, 1.2596431150768321`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{2.396675463569575, 1.8352411123869605`}, {
        2.3680153176736773`, 1.829654264824267}, {2.3397829660776646`, 
        1.8241374679023115`}, {2.311978408781535, 1.8186907216210926`}, {
        2.2846016457852896`, 1.8133140259806113`}, {2.2576526770889283`, 
        1.8080073809808674`}, {2.2306245021320112`, 1.8026863427053628`}, {
        2.2034009249014286`, 1.797332358699105}, {2.1939130007246255`, 
        1.7954625176022945`}}]}, 
      {Arrowheads[{{0.013699242101325318`, 1.}}], 
       ArrowBox[{{2.188844794467055, 1.7944636963458296`}, {
        2.1765681522181763`, 1.7920442661543536`}, {2.150712390903251, 
        1.786920902263367}, {2.125269905390317, 1.7818662429254006`}, {
        2.099646998440158, 1.7767805132510235`}, {2.0743849343644487`, 
        1.7717569242494673`}, {2.050024977474864, 1.7668886869299636`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{2.4800529172702213`, 1.1924749530317016`}, {
        2.444628630383141, 1.1917850556436704`}, {2.4089471014230117`, 
        1.1911035527767946`}, {2.3737800566089815`, 1.190405260867608}, {
        2.3398992221601986`, 1.1896649963526433`}, {2.3065558164938884`, 
        1.1889075883436426`}, {2.2734703728341077`, 1.1881694909079983`}}]}, 
      {Arrowheads[{{0.005841094936603859, 1.}}], 
       ArrowBox[{{2.2683060540204205`, 1.188050460664695}, {2.239869005161268,
         1.1873927723256412`}, {2.2079772733877605`, 1.1865864149966059`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.003128554719244258, 1.}}], 
       ArrowBox[{{0.17767550810897484`, 2.}, {0.17481510212019502`, 
        1.9915242768251318`}, {0.1674096694150371, 1.9693513298691268`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0189504001239241, 1.}}], 
       ArrowBox[{{2.330441685834205, 1.5016843257837316`}, {
        2.3011363435746643`, 1.4987489337501068`}, {2.2722347140513364`, 
        1.4958674989334537`}, {2.2443423663685387`, 1.4931209571592299`}, {
        2.216875950972017, 1.4904306470436648`}, {2.1892224922407646`, 
        1.4877148746140714`}, {2.161943120178974, 1.4850500268125342`}, {
        2.1355989647908373`, 1.4825124905811367`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.01847450137584695, 1.}}], 
       ArrowBox[{{2.2548824552383278`, 1.4949629103148274`}, {
        2.2263059821171067`, 1.4921285902340187`}, {2.198124209510201, 
        1.4893477038520362`}, {2.1709291881890835`, 1.4867004017171173`}, {
        2.144150590740513, 1.4841088809951897`}, {2.117189125273606, 
        1.481492208566626}, {2.0905933958433716`, 1.4789258395513338`}, {
        2.06491200650482, 1.4764852290692212`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{2.4028031257886076`, 1.8365972368441332`}, {
        2.373646393194779, 1.8309113163930608`}, {2.344907615437596, 
        1.825294868184441}, {2.316586792517059, 1.819747892218274}, {
        2.2886839244331676`, 1.8142703884945597`}, {2.261199011185922, 
        1.8088623570132982`}, {2.2341320527753217`, 1.8035237977744893`}, {
        2.207483049201367, 1.7982547107781333`}, {2.2000481033140438`, 
        1.7967809285166099`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{2.1949810034741084`, 1.7957765093890683`}, {
        2.181252000464058, 1.7930550960242297`}, {2.1549436019443937`, 
        1.7878412112378528`}, {2.128444318624277, 1.7825946556823427`}, {
        2.102326804905065, 1.7774134416650988`}, {2.0771637151881133`, 
        1.7723955814935217`}, {2.0524044003607695`, 1.7674458669587338`}, {
        2.0274688709254427`, 1.7624653510538284`}, {2.002885770706082, 
        1.7575464378891588`}, {1.9923318596463881`, 1.7554247460580825`}}]}, 
      {Arrowheads[{{0.0007981006277630972, 1.}}], 
       ArrowBox[{{1.9872674925863367`, 1.754406637590036}, {1.979183743526637,
         1.7527815315750785`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{1.6423036098311052`, 1.0296279428218107`}, {
        1.6205951673786245`, 1.0296826386781486`}, {1.5991867924065748`, 
        1.0297362084710404`}, {1.5780784849149558`, 1.0297886522004864`}, {
        1.5367620723730102`, 1.0298901614690399`}, {1.51314128586914, 
        1.0299484161737713`}, {1.4893436309020842`, 1.030007550398381}, {
        1.4658997128613993`, 1.0300649255832346`}, {1.4433401371366426`, 
        1.0301179031686973`}, {1.4356766129074523`, 1.0301356176977885`}}]}, 
      {Arrowheads[{{0.007252964152806785, 1.}}], 
       ArrowBox[{{1.4305109361858308`, 1.030147558356919}, {1.421151009147789,
         1.030169194185925}, {1.398796153235438, 1.0302214130373777`}, {
        1.3767727531700822`, 1.03027177622038}, {1.3555779927222131`, 
        1.0303175002322553`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{2.4012290838845303`, 1.1903359483045972`}, {
        2.3666684002781206`, 1.1896074613712606`}, {2.3318544138470862`, 
        1.1888873929318553`}, {2.2975470330653014`, 1.188150487504587}, {
        2.2645061664066413`, 1.1873714896076601`}, {2.2319947650751715`, 
        1.1865751798241697`}, {2.1992453007043693`, 1.1857869719354772`}, {
        2.1946543412202457`, 1.1856725424522254`}}]}, 
      {Arrowheads[{{0.005189992529768403, 1.}}], 
       ArrowBox[{{2.1894902545527817`, 1.1855438277966357`}, {
        2.166971962412231, 1.1849825602571884`}, {2.13588893931675, 
        1.184137639104909}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.008001762184699751, 1.}}], 
       ArrowBox[{{1.3321368884042537`, 1.0275688646131447`}, {
        1.311230625445749, 1.027617791063754}, {1.2901650263200728`, 
        1.0276676048482245`}, {1.2494678535732695`, 1.0277592464124181`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.011516626929743506`, 1.}}], 
       ArrowBox[{{1.272565914816282, 1.0255002378460012`}, {
        1.2315908599327459`, 1.0255996556874063`}, {1.1919733480975894`, 
        1.0256927010545485`}, {1.153583580103651, 1.0257788112068287`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{2.351424880222558, 1.826500002083097}, {2.322591288701174, 
        1.820853352257099}, {2.29420097248089, 1.8152797865452306`}, {
        2.26621903808265, 1.8097751077655035`}, {2.2386454855064537`, 
        1.8043393159179173`}, {2.2114803147523023`, 1.798972411002472}, {
        2.1847235258201945`, 1.793674393019168}, {2.158375118710131, 
        1.7884452619680054`}, {2.148701876079099, 1.7865209657175423`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{2.1436354597548055`, 1.785513104516496}, {
        2.1324350934221115`, 1.7832850178489836`}, {2.106903449956136, 
        1.778193660662103}, {2.0812962620330326`, 1.7730881588134086`}, {
        2.0555025838644965`, 1.7679502648794583`}, {2.0300818861868266`, 
        1.76287715511602}, {2.0055936397363228`, 1.7579660057788626`}, {
        1.981499925788873, 1.7531224363214095`}, {1.9572340896041154`, 
        1.7482483385848284`}, {1.941021227940041, 1.7449862993462524`}}]}, 
      {Arrowheads[{{0.0025383539495450282`, 1.}}], 
       ArrowBox[{{1.9359570243631206`, 1.743967378003288}, {
        1.9333124978939737`, 1.7434352974065033`}, {1.9102515173703722`, 
        1.7387748976238182`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.01849600104984908, 1.}}], 
       ArrowBox[{{2.256953936094704, 1.1852251515374612`}, {
        2.2234969776885567`, 1.1844625566486584`}, {2.1912856092026303`, 
        1.1836585717916042`}, {2.1595952169477295`, 1.1828374529776011`}, {
        2.127670866884076, 1.1820242268441494`}, {2.0962144324379284`, 
        1.1811952153495953`}, {2.065927787035545, 1.1803267404522853`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.015488906450258891`, 1.}}], 
       ArrowBox[{{0.5261201155348708, 1.945219461508281}, {0.50793001810174, 
        1.9278058202556387`}, {0.4905204321517017, 1.9109974459807961`}, {
        0.4738913576847557, 1.894794338683752}, {0.45731097236179596`, 
        1.8786196192660412`}, {0.44141372023395614`, 1.8629933910674628`}, {
        0.4262371507122089, 1.8479391905164926`}, {0.41166861556363576`, 
        1.8333864083277018`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0030332959127439647`, 1.}}], 
       ArrowBox[{{0.02638848027637982, 2.}, {0.0261565817132572, 
        1.9954479052300123`}, {0.02481095783522781, 1.9687015953164455`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0180154492610485, 1.}}], 
       ArrowBox[{{2.181634902019515, 1.4871196786073217`}, {
        2.1537601589106625`, 1.4843989077175177`}, {2.1262713819771855`, 
        1.4817310198695202`}, {2.0997475204821434`, 1.4791953396260384`}, {
        2.0736308621553645`, 1.4767149754215907`}, {2.047335378736157, 
        1.474209791694392}, {2.021397545501806, 1.4717542470126954`}, {
        1.9963538377295962`, 1.469422799944755}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{2.244592780010743, 1.8054543793781914`}, {2.216949048233798,
         1.7999924420656592`}, {2.189704393379041, 1.794598816019366}, {
        2.162858815446474, 1.7892735012393126`}, {2.1364123144360954`, 
        1.7840164977254984`}, {2.1103648903479066`, 1.778827805477924}, {
        2.084716543181907, 1.773707424496589}, {2.0594672729380963`, 
        1.7686553547814932`}, {2.0419363025735975`, 1.765139481864935}}]}, 
      {Arrowheads[{{0.01911859284930896, 1.}}], 
       ArrowBox[{{2.0368714647336215`, 1.764123718001436}, {2.034617079616474,
         1.7636715963326366`}, {2.0096930970125557`, 1.75867381778313}, {
        1.9845868959130435`, 1.753643922077777}, {1.9598451318047196`, 
        1.7486782606841174`}, {1.9360144601743656`, 1.7438731850696902`}, {
        1.9125693376613508`, 1.7391351325078896`}, {1.8889560714035096`, 
        1.7343668219508648`}, {1.8656790926353215`, 1.7296590273842884`}, {
        1.8432428325912666`, 1.7251025227938335`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.014626558246390713`, 1.}}], 
       ArrowBox[{{1.2037647617350027`, 1.0239683491346327`}, {
        1.164092501725286, 1.0240656856417836`}, {1.1256830580532233`, 
        1.0241563421701896`}, {1.0885790870712797`, 1.0242405050108558`}, {
        1.0526526197220585`, 1.0243176152907654`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999987`, 1.}}], 
       ArrowBox[{{2.250949975220978, 1.1851318639352064`}, {2.218050583764673,
         1.1843333370142963`}, {2.184905640040164, 1.1835431033592738`}, {
        2.152251800852062, 1.1827362831724764`}, {2.120825723004977, 
        1.1818879966562426`}, {2.0899134469750984`, 1.1810224049146496`}, {
        2.0587707501975494`, 1.1801646273098876`}, {2.0443926274272513`, 
        1.1797553320820477`}}]}, 
      {Arrowheads[{{0.003938340125196161, 1.}}], 
       ArrowBox[{{2.0392290286249, 1.1796083423545258`}, {2.0280888949153413`,
         1.1792912214314635`}, {1.9985591433714849`, 1.1783787448688852`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.006307455677687309, 1.}}], 
       ArrowBox[{{0.3213628537636821, 1.9489879914595476`}, {
        0.30906561371476265`, 1.9299633928995292`}, {0.2973932215544647, 
        1.9117025892997668`}, {0.2862372530607636, 1.8941010438678414`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.004762796921931595, 1.}}], 
       ArrowBox[{{2.0413244611687613`, 1.9168869722282214`}, {
        2.0170230401474183`, 1.910801353118347}, {1.9936018920070646`, 
        1.9048948200045355`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.004633585753540971, 1.}}], 
       ArrowBox[{{1.9695799140486854`, 1.8986228550509074`}, {
        1.9459479531955184`, 1.8926543619432472`}, {1.9231754042984543`, 
        1.886863384567545}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.009147099718917655, 1.}}], 
       ArrowBox[{{1.9460863827622477`, 1.8927235135120244`}, {
        1.9229412732066045`, 1.886834740685117}, {1.899628351248154, 
        1.8809107657710602`}, {1.876651054095318, 1.875057195031302}, {
        1.8545128189565179`, 1.8693796347272897`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.008897349811572756, 1.}}], 
       ArrowBox[{{1.8767104056045794`, 1.8751079582396377`}, {
        1.854207849612678, 1.8693339102128488`}, {1.8315414431898933`, 
        1.8635249563195253`}, {1.8092027376288748`, 1.8577858141592705`}, {
        1.7876832842222707`, 1.8522212013316868`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.010877189348137023`, 1.}}], 
       ArrowBox[{{1.8314650291512262`, 1.8635321522004378`}, {
        1.8092206549752585`, 1.85779564971133}, {1.787344501692762, 
        1.8521360420403403`}, {1.7653083522785824`, 1.8464418210772222`}, {
        1.7435921951277686`, 1.8408168266983613`}, {1.7226760186353693`, 
        1.8353648987801432`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.01756753060640452, 1.}}], 
       ArrowBox[{{2.110989179463087, 1.4810549898582372`}, {2.083799965566511,
         1.478432980634639}, {2.056988315051408, 1.475863191840056}, {
        2.0311205729899857`, 1.4734239541180105`}, {2.0056511616901256`, 
        1.471039447290246}, {1.980006813619588, 1.468630503891484}, {
        1.9547123390904042`, 1.466270433634716}, {1.9302925484146043`, 
        1.4640325462329338`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.017595539825278873`, 1.}}], 
       ArrowBox[{{2.114648885366975, 1.1804420385080676`}, {
        2.0827931788142324`, 1.179604729384156}, {2.0521460413009915`, 
        1.1787266791996536`}, {2.0220049464228147`, 1.1778314975135245`}, {
        1.991637214416246, 1.1769439073212533`}, {1.9617227566664608`, 
        1.1760411341412662`}, {1.9329414845586341`, 1.175100403491989}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0062888321806617254`, 1.}}], 
       ArrowBox[{{1.7223545675430114`, 1.8351336214709688`}, {
        1.7009320867034265`, 1.8295547490089044`}, {1.6798221070250932`, 
        1.824044516433339}, {1.6594933802498897`, 1.8187058835740209`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.013981609618145735`, 1.}}], 
       ArrowBox[{{1.1317880534520395`, 1.0235729043324024`}, {
        1.0938322000435448`, 1.0236621770668792`}, {1.0571054169120921`, 
        1.0237444191804588`}, {1.0216499855157672`, 1.0238198161613659`}, {
        0.9873390614803108, 1.023887811544924}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0031561497183104875`, 1.}}], 
       ArrowBox[{{0.9534065013976917, 1.021660927587909}, {0.9207991868459635,
         1.0217288879471003`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{2.1687097161248894`, 1.7904915304499054`}, {
        2.141793920993399, 1.7851397447850752`}, {2.115268154974529, 
        1.779855710535902}, {2.089132418068279, 1.7746394277023865`}, {
        2.0633867102746484`, 1.7694908962845273`}, {2.038031031593637, 
        1.7644101162823258`}, {2.013065382025246, 1.7593970876957812`}, {
        1.988489761569475, 1.7544518105248934`}, {1.9661011177786576`, 
        1.749936676486407}}]}, 
      {Arrowheads[{{0.01806900077858172, 1.}}], 
       ArrowBox[{{1.961037358269146, 1.7489155505404266`}, {1.940046497316332,
         1.7446828616706582`}, {1.9156107603242403`, 1.7397595898705847`}, {
        1.8915311514963489`, 1.7349000154726486`}, {1.8683418630789574`, 
        1.7301996845800565`}, {1.8455293882294037`, 1.7255658346511502`}, {
        1.8225526395668412`, 1.7209019917288737`}, {1.7999044385302958`, 
        1.7162981347933375`}, {1.7780776065587927`, 1.7118442428246523`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.015298878256774303`, 1.}}], 
       ArrowBox[{{1.8296631363943807`, 1.7205508706809898`}, {
        1.8062879416639903`, 1.7158172714141184`}, {1.7832557254404298`, 
        1.7111463673709792`}, {1.7610809554839435`, 1.7066322013871698`}, {
        1.7392691695373679`, 1.7021835029004868`}, {1.7172992313394313`, 
        1.697705304984201}, {1.6956455976442169`, 1.6932861059271214`}, {
        1.6747827252058074`, 1.6890144040180564`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.005879647858648621, 1.}}], 
       ArrowBox[{{0.4103112540057302, 1.8291782070124745`}, {
        0.3954016203214534, 1.8142409474536723`}, {0.36756780726577737`, 
        1.7860167889720067`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{2.191417959718311, 1.641227670890182}, {2.1631954658470693`,
         1.6370260474976475`}, {2.135414571374511, 1.6328884936544836`}, {
        2.108075276300635, 1.62881500936069}, {2.0811775806254422`, 
        1.6248055946162665`}, {2.054689993522158, 1.6208568458587105`}, {
        2.0285810241640094`, 1.6169653595255187`}, {2.0028506725509962`, 
        1.6131311356166917`}, {1.9870464717304428`, 1.610776588266872}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{1.9819371723740047`, 1.61001539272173}, {
        1.9774989386831179`, 1.6093541741322288`}, {1.9525258225603754`, 
        1.6056344750721305`}, {1.9279313241827682`, 1.6019720384363967`}, {
        1.903715443550296, 1.598366864225027}, {1.8798781806629594`, 
        1.5948189524380219`}, {1.8559699813555297`, 1.5912591298920882`}, {
        1.8318882851863263`, 1.5876722793654137`}, {1.8081535827406707`, 
        1.5841394848002208`}, {1.7852863646038835`, 1.5807418301387302`}, {
        1.7775611619721199`, 1.5795946855960257`}}]}, 
      {Arrowheads[{{0.00745681830638557, 1.}}], 
       ArrowBox[{{1.772451499334288, 1.5788359324746577`}, {
        1.7627858210490772`, 1.5774006393665096`}, {1.7401249012047861`, 
        1.574034025898741}, {1.7177847339394647`, 1.5707182578220684`}, {
        1.6962464481215676`, 1.5675296032231354`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.014551524474567765`, 1.}}], 
       ArrowBox[{{2.015745687113744, 1.4727477672442668`}, {
        1.9895952390058307`, 1.4702748525740368`}, {1.9643682890325553`, 
        1.4679306480920609`}, {1.9395310466571123`, 1.4656405145987041`}, {
        1.9145226435507254`, 1.4633263636765748`}, {1.8898565619062253`, 
        1.4610602476119905`}, {1.8660462839164413`, 1.4589142186912685`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.006115230907031233, 1.}}], 
       ArrowBox[{{1.6590675187994122`, 1.8184289436630154`}, {
        1.6382440705081809`, 1.8129652382998962`}, {1.6177258285773986`, 
        1.8075695922944726`}, {1.5979706025477391`, 1.802344094683288}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.008785827967265486, 1.}}], 
       ArrowBox[{{2.468854443667213, 2.}, {2.4639009528188094`, 
        1.998846163482645}, {2.4354913720973714`, 1.9922381780419665`}, {
        2.4074799836722054`, 1.9857038005434091`}, {2.380464075987718, 
        1.9793534429001551`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.003869917812537549, 1.}}], 
       ArrowBox[{{0.025351919508110405`, 1.2150881158452465`}, {
        0.02247159181357322, 1.236388144351126}, {0.019874259260291946`, 
        1.2546924867875535`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{2.1102459082844707`, 1.1797222640761051`}, {
        2.0789137196471397`, 1.1788562294939835`}, {2.0473433548114985`, 
        1.1779982248349388`}, {2.0162493423724777`, 1.17712416032974}, {
        1.9863462109250063`, 1.1762099462091546`}, {1.9569419986227947`, 
        1.175278705198343}, {1.9273146546213666`, 1.174354849414561}, {
        1.9037095166355884`, 1.173595576577385}}]}, 
      {Arrowheads[{{0.002758150898545948, 1.}}], 
       ArrowBox[{{1.8985464963157843`, 1.1734295050598627`}, {
        1.898133574018372, 1.1734162231767202`}, {1.8700681519114615`, 
        1.1724406708037323`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0029990286121474637`, 1.}}], 
       ArrowBox[{{0.8890715049000664, 1.0204716852737106`}, {
        0.8580874618924591, 1.0205348320569982`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.01670829295631445, 1.}}], 
       ArrowBox[{{1.9757930621366304`, 1.4687477342901578`}, {
        1.9499174905211416`, 1.4663303975637656`}, {1.924403427177786, 
        1.4639637487479373`}, {1.8997931345147594`, 1.4617238197085172`}, {
        1.8755642084579516`, 1.4595372506753082`}, {1.8511677671544682`, 
        1.4573271190839159`}, {1.8271063563443355`, 1.4551641126088906`}, {
        1.803882521767579, 1.4531189189247817`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.007793815448351036, 1.}}], 
       ArrowBox[{{0.023028161640464687`, 1.9873405919620457`}, {
        0.021756380330563485`, 1.9589752421629014`}, {0.020580100734430132`, 
        1.9322680350671777`}, {0.019476253802176925`, 
        1.9068981051498368`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.010002384272616462`, 1.}}], 
       ArrowBox[{{1.637960293606849, 1.8128705068552007`}, {
        1.6175275456823004`, 1.8074792737877956`}, {1.5974383494123572`, 
        1.802163159472993}, {1.5772001026916933`, 1.7968132976114055`}, {
        1.538065063306852, 1.7864173018092957`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.004085826464580948, 1.}}], 
       ArrowBox[{{1.655449732817837, 1.6865006634666329`}, {
        1.6343907417356303`, 1.6821718910506585`}, {1.6141044391351376`, 
        1.6779895585819258`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.003985675624453383, 1.}}], 
       ArrowBox[{{1.6005974911411442`, 1.6700432046571319`}, {
        1.5602516606348356`, 1.6618089327521701`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.003891008264580675, 1.}}], 
       ArrowBox[{{1.5525580585131165`, 1.680615689767765}, {1.513252778174868,
         1.6721839725228917`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{2.0430699749448635`, 1.1773432575302758`}, {
        2.0124870649512188`, 1.176439776940237}, {1.9816694438333449`, 
        1.1755441739165664`}, {1.9513212449639294`, 1.1746328157601598`}, {
        1.92214660171566, 1.1736820697719124`}, {1.8934639094090084`, 
        1.1727144659624984`}, {1.8645615251068999`, 1.1717540045938324`}, {
        1.836546569445328, 1.1707946021176001`}}]}, 
      {Arrowheads[{{0.002193879663699945, 1.}}], 
       ArrowBox[{{1.831384354409465, 1.1706051836739784`}, {
        1.8087339844617925`, 1.1697687998897692`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{2.063806471256903, 1.6207446202712512`}, {
        2.0371641759624373`, 1.6167879881206924`}, {2.0109537650632268`, 
        1.6128948127239022`}, {1.9851444108906435`, 1.609061690372671}, {
        1.9597052857760588`, 1.6052852173587884`}, {1.9346363897194732`, 
        1.6015653936822547`}, {1.9099377227208856`, 1.5979022193430692`}, {
        1.8856092847802972`, 1.5942956943412327`}, {1.8616510758977076`, 
        1.5907458186767451`}, {1.8594169301846761`, 1.5904149562340322`}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{1.8543069707549553`, 1.5896582044925411`}, {
        1.838063096073116, 1.5872525923496055`}, {1.8148453453065234`, 
        1.5838160153598149`}, {1.7915582209046481`, 1.5803676846175243`}, {
        1.7681014377265845`, 1.576892634927784}, {1.7449839721008973`, 
        1.5734710231329434`}, {1.7227148003561505`, 1.5701830060753494`}, {
        1.7008042208899823`, 1.5669508472109746`}, {1.6787368324650944`, 
        1.5636935829313636`}, {1.6569830619576464`, 1.560486529482225}, {
        1.6499000895362985`, 1.5594456781800594`}}]}, 
      {Arrowheads[{{0.0008585688309510057, 1.}}], 
       ArrowBox[{{1.644789287280229, 1.5586946396517563`}, {1.636013336243798,
         1.5574050031092674`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.009722457846760462, 1.}}], 
       ArrowBox[{{1.5765013510881638`, 1.7968771392094236`}, {
        1.5566479175371422`, 1.7915980767906177`}, {1.5174669201236908`, 
        1.7811556228748633`}, {1.4794504990347632`, 1.770980988882512}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0028435232419185283`, 1.}}], 
       ArrowBox[{{0.8269749867722038, 1.0189153162524232`}, {
        0.797597527426443, 1.0189760481737535`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.008204505858760728, 1.}}], 
       ArrowBox[{{0.2995905641083369, 1.914664513014962}, {0.2874850971357983,
         1.8955979278621928`}, {0.2759519173221017, 1.877269250805293}, {
        0.25460241917123466`, 1.8428256209791003`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.005464069566521814, 1.}}], 
       ArrowBox[{{0.7941636302562203, 1.0159765951444708`}, {
        0.765439477860727, 1.0160473571576778`}, {0.7377124094249883, 
        1.016112597343244}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.007858762473384115, 1.}}], 
       ArrowBox[{{0.7572522268354465, 1.018269200320132}, {0.7291478544715148,
         1.0183212582524734`}, {0.7021236933582966, 1.0183662580053232`}, {
        0.6760604697523048, 1.01840369559878}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.004786411952398661, 1.}}], 
       ArrowBox[{{0.658367703378355, 1.0261205431655263`}, {
        0.6331797132601769, 1.026042905651047}, {0.6089177472458579, 
        1.0259520992738396`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.004389628146850107, 1.}}], 
       ArrowBox[{{0.590093293968242, 1.0190827183959716`}, {
        0.5669842149707334, 1.0190765251243317`}, {0.5447423794972481, 
        1.0190605627916103`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.016298236152561464`, 1.}}], 
       ArrowBox[{{1.911834181872231, 1.4633964103366426`}, {1.88658553650886, 
        1.461074953440411}, {1.8616908184212102`, 1.4588033071634356`}, {
        1.8376809185228635`, 1.4566561874346011`}, {1.8140443720155714`, 
        1.4545616222438127`}, {1.7902438126139744`, 1.452443981022589}, {
        1.7667712790009873`, 1.4503724918622354`}, {1.7441188098595253`, 
        1.4484163828540568`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.010375675854320171`, 1.}}], 
       ArrowBox[{{1.6831900961120176`, 1.5648104006391717`}, {
        1.661514941507682, 1.5616153833377255`}, {1.6401904747189702`, 
        1.558475709641319}, {1.61871269714079, 1.5553112077537092`}, {
        1.5975415411415468`, 1.552196362248506}, {1.5771369390896457`, 
        1.5492056576993194`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.01145744457943221, 1.}}], 
       ArrowBox[{{1.536555124063323, 1.7860716231468476`}, {
        1.4972073818327407`, 1.7755681395293474`}, {1.459146984489, 
        1.7653563117932243`}, {1.422224018379683, 1.7554100319312549`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.004021490145348484, 1.}}], 
       ArrowBox[{{0.5276493710298689, 1.015966732718451}, {0.5064688289142486,
         1.015974772619625}, {0.4861018255017537, 1.015974357227475}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.008006140647837914, 1.}}], 
       ArrowBox[{{1.8329017071906413`, 1.169386605013195}, {
        1.8047000511093545`, 1.1684015677571509`}, {1.7769307520494162`, 
        1.1674028738818798`}, {1.750242345542849, 1.1663700384585411`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.010096985734784231`, 1.}}], 
       ArrowBox[{{1.6227004002356984`, 1.554571945000091}, {1.601601406258338,
         1.5514878554024802`}, {1.5808453710634827`, 1.5484584530222913`}, {
        1.5599394357104521`, 1.5454045703636172`}, {1.5194766664279682`, 
        1.539517127552635}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.01325958176571094, 1.}}], 
       ArrowBox[{{1.780172837012323, 1.4506748030687473`}, {
        1.7563141113816694`, 1.4485876472053776`}, {1.7333084015072597`, 
        1.4466206613094148`}, {1.710662582894529, 1.4447046253561264`}, {
        1.687858617770004, 1.4427664767131643`}, {1.6653709456690677`, 
        1.4408725534495495`}, {1.6436740061271038`, 1.4390891936343035`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.007592887856491777, 1.}}], 
       ArrowBox[{{0.38099820251817734`, 1.802201653935327}, {
        0.3524524359211727, 1.7728895491199939`}, {0.3264738061503714, 
        1.7458046478837785`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0072267933671157835`, 1.}}], 
       ArrowBox[{{0.013203910290566724`, 1.8996382602251394`}, {
        0.012424926209341002`, 1.873217747509033}, {0.011707473442846568`, 
        1.8484524782575176`}, {0.011036153188852203`, 
        1.8250069847642711`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.00411972734980629, 1.}}], 
       ArrowBox[{{0.3472418351338988, 1.1473746201376651`}, {
        0.3462784004967072, 1.140989746079123}, {0.3453215996191996, 
        1.1373061275100838`}, {0.3443702584741945, 1.1344367781930926`}, {
        0.34060991094749427`, 1.1258768079167343`}, {0.3387470488414547, 
        1.1224881286568378`}, {0.33689992452506373`, 1.1195407530993653`}, {
        0.32957612026270694`, 1.1093103511640132`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.003798062637241077, 1.}}], 
       ArrowBox[{{1.5006018304304949`, 1.6545521303937263`}, {
        1.4621817621063848`, 1.6465761850387834`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.007494586549647978, 1.}}], 
       ArrowBox[{{1.482122759880146, 1.6517235347204924`}, {
        1.4436542533232988`, 1.6437082635570048`}, {1.406323283825443, 
        1.6359198684409428`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.010459556023002178`, 1.}}], 
       ArrowBox[{{1.8017860831076897`, 1.1677573787081417`}, {
        1.7744711169454253`, 1.1667328733093612`}, {1.7469432260109867`, 
        1.165714890352172}, {1.7198411846208963`, 1.1646838625118}, {
        1.6938037670916755`, 1.163620222463471}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.01905351128044641, 1.}}], 
       ArrowBox[{{1.5578700675595316`, 1.7917268457269317`}, {
        1.5183508515233621`, 1.7811580523752066`}, {1.4788922903942687`, 
        1.7705990056188436`}, {1.440643425413846, 1.7603207470189537`}, {
        1.4036533063036085`, 1.7503319802212731`}, {1.3677747838990113`, 
        1.7406065942885909`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.002535081956987286, 1.}}], 
       ArrowBox[{{0.4404827801388762, 1.1718803855076498`}, {
        0.4392889981063724, 1.1791173419535188`}, {0.4380931282123303, 
        1.1829908500749682`}, {0.4333133991351064, 1.1935694400658703`}, {
        0.43283610223235724`, 1.1943596560518381`}, {0.4323590201829152, 
        1.1951274092100088`}, {0.43161998669874696`, 1.1962772493513085`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.007097898134171168, 1.}}], 
       ArrowBox[{{1.3843266226391076`, 1.744688622713281}, {1.348403797589869,
         1.7349338319960494`}, {1.3135668727118388`, 1.7254401035958522`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.009825526898265281, 1.}}], 
       ArrowBox[{{1.5647638092440603`, 1.5474157192303084`}, {
        1.5442296584616613`, 1.544413657056792}, {1.5036858529092805`, 
        1.5384937240366527`}, {1.4643149913051825`, 1.532767498486805}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.009423212261828918, 1.}}], 
       ArrowBox[{{1.7890204554704396`, 2.}, {1.7804045191055902`, 
        1.9972866785354115`}, {1.759119308679446, 1.9905575439846008`}, {
        1.7376766451266121`, 1.9837886914699854`}, {1.7165488878271582`, 
        1.9770992748829794`}, {1.6962083961611547`, 1.970608448114997}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.00411395539633867, 1.}}], 
       ArrowBox[{{1.684087627448232, 1.9564462795791284`}, {
        1.6634398787359637`, 1.9499388943411409`}, {1.6435641438360789`, 
        1.9436268964695547`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.008141775124955905, 1.}}], 
       ArrowBox[{{1.6678757196225147`, 1.952009721990878}, {
        1.6476118352734122`, 1.9455699027843696`}, {1.6271968605016143`, 
        1.9390912606302466`}, {1.6070840665752073`, 1.9326902643713528`}, {
        1.5877267247622775`, 1.926483382850532}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0039028730399530798`, 1.}}], 
       ArrowBox[{{1.5682334481145976`, 1.9177016131688798`}, {
        1.5298439780942263`, 1.9053680085365878`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0025647066715938317`, 1.}}], 
       ArrowBox[{{1.6799230773632967`, 1.330162378280256}, {
        1.6534603048338326`, 1.3315079857782135`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.004648935220799328, 1.}}], ArrowBox[CompressedData["
1:eJwBcQGO/iFib1JlAgAAABYAAAACAAAA+XZv19tuvT+3br7YG5nxP3zQOkq4
br0/aMjEcmWU8T9DFEHGlG69P+IDmLExkPE/7I03IoJtvT9i7snfrorxP+PM
mCM7a70/wTU6HKmC8T8TgKEZ9Wi9P5UaoXbzffE/9v+Iza9mvT/p/1lNRHrx
P2yLVerLXL0/EVTRpkxu8T97YsAG8VK9P/nI9wzeZfE/iPgzzh1JvT8q7n6S
Al/xP9eYEW46Lb0/0xWXOn9P8T97QYxlhxG9P/lUVNiVQ/E/fI8qCQD2vD8Q
NbNCpDnxP9RxcuKu6rw/K2r+P/M18T+Gd92DZN+8PxUmRhFyMvE/siDpgPHN
vD9NfNUXVS3xPxr+FBYIt7w/wWcG9hcn8T81E+zXTai8P7e5OcpSI/E/WBnu
Tp6ZvD8RH/JNuh/xPwKr53zqCLw/MluUpu4B8T/1PIRO6Xu7P6Rdn+8W7PA/
vl3xvEryuj/bICiNgdrwP8B+tQU=
        "]]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{1.6751769272630972`, 1.953400499053374}, {1.654414886126704,
         1.9467974628155331`}, {1.6339999787974673`, 1.9402817607068277`}, {
        1.6135224905494427`, 1.933748608590245}, {1.5928875704198413`, 
        1.9271747117586986`}, {1.5725675140533943`, 1.9206823043570795`}, {
        1.5530346170948326`, 1.9143936205302776`}, {1.514492678322559, 
        1.901948556222411}, {1.4784391498034926`, 1.8902418407062618`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.013652141784591629`, 1.}}], 
       ArrowBox[{{1.5496094883789047`, 1.544375556208652}, {1.528537335428016,
         1.5412995151126898`}, {1.4877903341451821`, 1.535377105851519}, {
        1.4483327794500895`, 1.5296655056561992`}, {1.4100224772300272`, 
        1.5241447484778516`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.014456749787769833`, 1.}}], 
       ArrowBox[{{0.3047717851000974, 1.9231873608575796`}, {
        0.29202349877795053`, 1.9030393996661394`}, {0.27993052129167645`, 
        1.8837355100807731`}, {0.2684928526412751, 1.8652756921014797`}, {
        0.25710387331583984`, 1.846863654882895}, {0.24627282417634505`, 
        1.8292001277489656`}, {0.22628451645517636`, 1.7961186037350705`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.007625949660299172, 1.}}], 
       ArrowBox[{{1.7180668517080908`, 1.1634485204449236`}, {
        1.691197295191436, 1.1624082485548617`}, {1.664746902913259, 
        1.1613556382418455`}, {1.639344421231277, 1.160272181871444}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0036634511723806946`, 1.}}], 
       ArrowBox[{{0.46961069805759725`, 1.0127556850505621`}, {
        0.4317622094736043, 1.0127959480614792`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.012933868402451502`, 1.}}], 
       ArrowBox[{{1.7225910751635551`, 1.447543929002947}, {
        1.6993117564867284`, 1.445528749375053}, {1.6768682527661316`, 
        1.4436311728581364`}, {1.6547773726468251`, 1.4417835512733657`}, {
        1.632531527948804, 1.4399143515249022`}, {1.6105956124082113`, 
        1.4380883081038236`}, {1.5894345197611894`, 1.4363701555012065`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.002687329694003148, 1.}}], 
       ArrowBox[{{1.7906070694116667`, 1.3350735313998092`}, {
        1.7628594365478298`, 1.3360216682692683`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.011481533745599327`, 1.}}], 
       ArrowBox[{{1.5388082170491573`, 1.909022187666308}, {
        1.4999716662152482`, 1.8964746830056192`}, {1.4624193409517396`, 
        1.8842608295355778`}, {1.4259991615004106`, 1.8723504659498857`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.011115349754778975`, 1.}}], 
       ArrowBox[{{1.466141255254124, 1.6472819692613996`}, {
        1.4274573440191367`, 1.6392416250522421`}, {1.390029535309977, 
        1.631448015428239}, {1.3537143569433632`, 1.6238787946413125`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.007086844812267562, 1.}}], 
       ArrowBox[{{1.372905689394497, 1.6269138180636311`}, {
        1.3365212079946351`, 1.619344318322807}, {1.3012245059807033`, 
        1.6119966630063458`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.010517797781175722`, 1.}}], 
       ArrowBox[{{1.3664851911615674`, 1.7405378072258157`}, {
        1.3303908357839658`, 1.730707950908828}, {1.295499523702029, 
        1.7211634321650706`}, {1.26166944172465, 1.7118780746773152`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.007445696150912703, 1.}}], 
       ArrowBox[{{1.662693651505493, 1.1623444790570114`}, {1.636455920388078,
         1.1612462897122255`}, {1.6106319296286886`, 1.160136446129325}, {
        1.5858422897643631`, 1.1589974669511396`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.004782693017916738, 1.}}], 
       ArrowBox[{{1.579694283372866, 1.162098299075572}, {1.5545071762064278`,
         1.1608854590265951`}, {1.530343417750147, 1.1596458712484803`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.004651113285792832, 1.}}], 
       ArrowBox[{{1.5154392570842123`, 1.1671072177779434`}, {
        1.4909477371687372`, 1.165673561659183}, {1.4674737952332244`, 
        1.1642187723944297`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.009185827754872065, 1.}}], 
       ArrowBox[{{1.5043316407506762`, 1.165727265551257}, {
        1.4803516264296874`, 1.1642700210511328`}, {1.4561718859818873`, 
        1.1628161633110992`}, {1.4323915977877104`, 1.1613555320508846`}, {
        1.4096099402275915`, 1.1598779669902182`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.008919821114007196, 1.}}], 
       ArrowBox[{{1.4470722882214093`, 1.1596194940569273`}, {
        1.4237856473768973`, 1.1581838610401678`}, {1.4003035420838477`, 
        1.1567510354690795`}, {1.3772123656878732`, 1.1553125950066487`}, {
        1.3550985115345855`, 1.153860117315863}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.008278764602901582, 1.}}], 
       ArrowBox[{{1.621225832632349, 1.4410241631351495`}, {
        1.5996872983300259`, 1.439239875543844}, {1.5779969408065326`, 
        1.4374345478220505`}, {1.55661022972538, 1.4356713003612331`}, {
        1.535982634750079, 1.4340132535528556`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.011269266128651518`, 1.}}], 
       ArrowBox[{{1.472068323385516, 1.5355839849129898`}, {
        1.4324477032269798`, 1.5298014846697436`}, {1.3940884541349519`, 
        1.5242280074967414`}, {1.3568510749605294`, 1.5188433970492652`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.015163555730803522`, 1.}}], 
       ArrowBox[{{1.524653419934743, 1.9050729281293974`}, {
        1.4856167491984618`, 1.8924156501887721`}, {1.447788065428854, 
        1.8800800990312023`}, {1.411217220136796, 1.8680763324036325`}, {
        1.3757546587896585`, 1.8563741770652278`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.013252692690904374`, 1.}}], 
       ArrowBox[{{0.38610363285187205`, 1.805372371180213}, {
        0.3708533800448556, 1.7897849575986307`}, {0.34252288876997944`, 
        1.7604851698954926`}, {0.3156390737212077, 1.7324354084990379`}, {
        0.2912588486217865, 1.7066276527644424`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0030938711426375582`, 1.}}], 
       ArrowBox[{{0.0055219785361138255`, 1.0437110272319965`}, {
        0.0054600909746551985`, 1.0513709226475128`}, {0.005336532050349145, 
        1.0647979212806977`}, {0.00521427932504436, 1.0756734833029828`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.004411416510797398, 1.}}], 
       ArrowBox[{{0.00785227511687298, 1.8188889271244373`}, {
        0.0073761668400355255`, 1.7954516926627144`}, {0.006931681681102637, 
        1.773322201017899}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0004589834029886056, 1.}}], 
       ArrowBox[{{1.6689605736264097`, 1.269858339240715}, {
        1.6676946595668052`, 1.2694169879978319`}, {1.6664301412657776`, 
        1.2689836690371363`}, {1.6651670092577961`, 1.2685578845692842`}, {
        1.6644728660997083`, 1.2683267261555402`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{1.4628114896137543`, 1.7661980268535449`}, {
        1.4240464555932995`, 1.7557247884306442`}, {1.386526566780812, 
        1.745545325159433}, {1.3502518231762917`, 1.7356596370399109`}, {
        1.3140343206576865`, 1.7257836394908348`}, {1.2789474811752173`, 
        1.716182035952556}, {1.2634403099596505`, 1.7119206294813725`}}]}, 
      {Arrowheads[{{0.004647696826168644, 1.}}], 
       ArrowBox[{{1.2584592716306342`, 1.710551828642495}, {1.245037749313427,
         1.7068635633063733`}, {1.2121657913186847`, 1.69780201090839}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.006509455084600051, 1.}}], 
       ArrowBox[{{1.2271631329315789`, 1.701161696890927}, {
        1.1942436027954297`, 1.692082894354046}, {1.1623382652327492`, 
        1.6832585740347812`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.002942986790989195, 1.}}], 
       ArrowBox[{{2.0180115700289627`, 1.3498641261547588`}, {
        1.987607625303882, 1.3495970259814885`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.018664816749574792`, 1.}}], 
       ArrowBox[{{1.5105781247324277`, 1.9002545482460662`}, {
        1.4724732939163718`, 1.887811485819386}, {1.4344297259028007`, 
        1.8753800154009594`}, {1.397569608820673, 1.8632681574451766`}, {
        1.3619419838309463`, 1.8514859670811026`}, {1.327399727450748, 
        1.8400032789215428`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{1.4717419976010697`, 1.6492482642726194`}, {
        1.4326968632368198`, 1.641109815184982}, {1.394919618511761, 
        1.633222479905123}, {1.3571983259313163`, 1.6253430892790974`}, {
        1.3206330187008346`, 1.6176989231531846`}, {1.2852697851499044`, 
        1.6102974893407151`}, {1.2694813524019297`, 1.6069918861867245`}}]}, 
      {Arrowheads[{{0.0013305740155488003`, 1.}}], 
       ArrowBox[{{1.2644252902173534`, 1.6059333051754932`}, {
        1.250970360289761, 1.6031162644016979`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.003088495694038371, 1.}}], 
       ArrowBox[{{2.147724192092902, 1.3588606390444604`}, {2.115828615569306,
         1.3579551890513137`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.006919751018260053, 1.}}], 
       ArrowBox[{{0.45239133910600304`, 1.009388054858604}, {
        0.4151116323581867, 1.009475565549444}, {0.38090092699190264`, 
        1.0095446119684395`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.002950287165814211, 1.}}], 
       ArrowBox[{{1.8682257009182544`, 2.}, {1.8607574581613824`, 
        1.9977530675528374`}, {1.839051990868679, 1.9911706646154064`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.008676341153047521, 1.}}], 
       ArrowBox[{{1.393984963294703, 1.1554225214526275`}, {
        1.3713345222904032`, 1.1539741143523703`}, {1.3484921540353185`, 
        1.1525278141497466`}, {1.3260336402818034`, 1.1510773001518562`}, {
        1.3045347627822126`, 1.1496162516657995`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.018760460520694314`, 1.}}], 
       ArrowBox[{{1.4987984127873277`, 1.5375911331264411`}, {
        1.4589580601976202`, 1.5318286258808331`}, {1.4191719408167194`, 
        1.5260728606052265`}, {1.380575377362061, 1.5205161590998226`}, {
        1.343213967685921, 1.5151652966876101`}, {1.3069509182314711`, 
        1.5099999473996215`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.010673374330274751`, 1.}}], 
       ArrowBox[{{1.3660943337950386`, 1.5171501252605917`}, {
        1.3285346433489171`, 1.5118128985738877`}, {1.2921838216996306`, 
        1.5066782528793254`}, {1.2569077621022862`, 1.5017256781621369`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{1.437101536397032, 1.8767049690226119`}, {
        1.3998291257763384`, 1.8643926702050684`}, {1.3638072469087836`, 
        1.852419010720857}, {1.3278444565177405`, 1.84045690788725}, {
        1.2930140209268126`, 1.8288103310857655`}, {1.2593633137021096`, 
        1.8174893561793288`}, {1.241094667696043, 1.8113132245909207`}}]}, 
      {Arrowheads[{{0.0009656334469606917, 1.}}], 
       ArrowBox[{{1.2362010656905453`, 1.8096588310514534`}, {
        1.2267502141453004`, 1.8064637555791627`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.008083959699452489, 1.}}], 
       ArrowBox[{{1.5691205123336713`, 1.4359255163889413`}, {
        1.548083443292747, 1.4342373536084374`}, {1.5268974696409967`, 
        1.4325287868677066`}, {1.4858656638349272`, 1.429295289028284}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0019357522848909058`, 1.}}], 
       ArrowBox[{{0.10014872529710753`, 1.1269829316703337`}, {
        0.09955813186003037, 1.1306678616894386`}, {0.09896910515698339, 
        1.13406302372629}, {0.09661903724639279, 1.1466669627149715`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0075053200984730225`, 1.}}], 
       ArrowBox[{{0.23937250948193362`, 1.8205532204663066`}, {
        0.21853133342715847`, 1.7856654734220445`}, {0.1998678699692319, 
        1.7538315330386003`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0010784982921297215`, 1.}}], 
       ArrowBox[{{0.5664897463933204, 1.1957772612167468`}, {
        0.5652021736723022, 1.1992707549148147`}, {0.5639142145512633, 
        1.2020014361698093`}, {0.5632926642454067, 1.2031585725503866`}, {
        0.5626712207772975, 1.2042428424596276`}, {0.5617082735381035, 
        1.205806925387542}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.002575670783158144, 1.}}], 
       ArrowBox[{{0.5616905219401619, 1.2408607075539648`}, {
        0.5498417306613409, 1.247527291410179}, {0.5381810238586535, 
        1.2533075755713072`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{1.4973511435973346`, 1.6532271167744812`}, {
        1.4568639793607032`, 1.6448216780921308`}, {1.4176181004347583`, 
        1.6366647302582544`}, {1.3796135068195006`, 1.628756273272852}, {
        1.3428501985149295`, 1.6210963071359237`}, {1.3061417459323357`, 
        1.6134442827448583`}, {1.2950567610217605`, 1.6111325530811202`}}]}, 
      {Arrowheads[{{0.008621501977826025, 1.}}], 
       ArrowBox[{{1.2899998660163325`, 1.6100779576725777`}, {
        1.2705648672164744`, 1.6060248657105414`}, {1.2361648264484395`, 
        1.5988455848639656`}, {1.2028058313849497`, 1.591883853712155}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.007041398935590981, 1.}}], 
       ArrowBox[{{0.8861405121093732, 2.}, {0.8722370173153521, 
        1.9914450476329677`}, {0.8478768582665515, 1.976328213224789}, {
        0.8243405686260973, 1.9616214680402395`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.01361133946863817, 1.}}], 
       ArrowBox[{{0.8784363898693184, 1.9949358723616626`}, {
        0.8535369202063906, 1.9794195613589427`}, {0.828690129919466, 
        1.9639221982788302`}, {0.8047187916160017, 1.9488639222472002`}, {
        0.7816642166932112, 1.9342606161458418`}, {0.7594024709594541, 
        1.9200646313293857`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.01868986002740339, 1.}}], 
       ArrowBox[{{0.8615435277816673, 1.9846594385598102`}, {
        0.8360438465160069, 1.9686927163644148`}, {0.811492170743706, 
        1.953201726197546}, {0.7878885004647644, 1.9381864680592042`}, {
        0.7643364380098367, 1.9231904046700214`}, {0.7416291654002406, 
        1.9086316838110478`}, {0.7198071705073226, 1.8945264464114393`}, {
        0.6987489897170428, 1.8808262696837283`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.017828780147416196`, 1.}}], 
       ArrowBox[{{0.7974041034836986, 1.9436735232874693`}, {
        0.7731658834651343, 1.9282093323918699`}, {0.7498457416662356, 
        1.913219732932161}, {0.7274436780870022, 1.8987047249083406`}, {
        0.7050922843007443, 1.884209181699485}, {0.6835576291482008, 
        1.87014930029659}, {0.662879484804041, 1.856541503511548}, {
        0.6429385347442566, 1.8433365229086813`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.017016737651044996`, 1.}}], 
       ArrowBox[{{0.7379289354692771, 1.9049454296150397`}, {
        0.7148699878480447, 1.8899704441108713`}, {0.6927016676400145, 
        1.8754694007328947`}, {0.671423974845186, 1.8614422994811088`}, {
        0.6501961417022031, 1.8474349799002272`}, {0.6297592166687309, 
        1.8338620391037286`}, {0.6101523573161423, 1.8207402237939574`}, {
        0.5912580909303183, 1.8080192938638782`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.013701605005743318`, 1.}}], 
       ArrowBox[{{0.6604927314444368, 1.8541047138740852`}, {
        0.6394102730200664, 1.8400734099027538`}, {0.6191931567569637, 
        1.8265161465058861`}, {0.5990252150655597, 1.8129790479302117`}, {
        0.5796242663920262, 1.7998756602866137`}, {0.5610289508708932, 
        1.7872231114298531`}, {0.5431233480985708, 1.7749700177956462`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.010728071816336884`, 1.}}], 
       ArrowBox[{{0.5890897530422863, 1.8059053788257526`}, {
        0.5698845686218736, 1.792819572064885}, {0.550727988941615, 
        1.7797543745588542`}, {0.5323160856729455, 1.7671224944552735`}, {
        0.5146870735537127, 1.7549414961969427`}, {0.4977263083703736, 
        1.7431586864554618`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.008088597373936284, 1.}}], 
       ArrowBox[{{0.5249067223867274, 1.7610261938857648`}, {
        0.5066817509461863, 1.748429240627631}, {0.48918144798968566`, 
        1.7362651971266831`}, {0.45635484752880506`, 1.7132358393963427`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.004153959056104255, 1.}}], 
       ArrowBox[{{0.664479707272932, 1.198622206488879}, {0.6642852905666465, 
        1.2004385381030995`}, {0.663967875250737, 1.20272896095868}, {
        0.6636501347956392, 1.2041903777924532`}, {0.6633321907391948, 
        1.205359942756366}, {0.6620594262235434, 1.2089458431055358`}, {
        0.6607856764050559, 1.2115457996732144`}, {0.6576660368343606, 
        1.2171567608462874`}, {0.6545474392176786, 1.2212100687712149`}, {
        0.6420784795859673, 1.2339622669855754`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.00263827634696476, 1.}}], 
       ArrowBox[{{2.132341888801916, 2.}, {2.1303251912141086`, 
        1.9994644762407887`}, {2.1060104647495517`, 1.9929571282824081`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0053552934092621456`, 1.}}], 
       ArrowBox[{{2.3698192976592636`, 1.9634782439055312`}, {
        2.3423840724097644`, 1.9571307039820363`}, {2.315925631717067, 
        1.9509637921450735`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.004156732132074932, 1.}}], 
       ArrowBox[{{0.004302149030092914, 1.7679895751872192`}, {
        0.00402710646508976, 1.7458704194054613`}, {0.0037709957150154857`, 
        1.725048076581635}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.01652083125330796, 1.}}], 
       ArrowBox[{{1.2801410593030442`, 1.7163676288780403`}, {
        1.2458978691483542`, 1.7069345620813559`}, {1.2117098277190717`, 
        1.697511179807386}, {1.1786034988492944`, 1.6883580032028571`}, {
        1.1466237384834612`, 1.6794838185210728`}, {1.115635978788255, 
        1.6708622670021203`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.00799188632261427, 1.}}], 
       ArrowBox[{{2.349844383697225, 1.956772670032862}, {2.322458354445163, 
        1.950435807709226}, {2.29545755477819, 1.9441706904869451`}, {
        2.269419829073937, 1.9380849360180503`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{1.4417964244152928`, 1.6428654085757877`}, {
        1.4024059004888076`, 1.6346462865509652`}, {1.364230500473158, 
        1.6266739221446214`}, {1.3272702243683443`, 1.6189483153567554`}, {
        1.2915250721743659`, 1.6114694661873674`}, {1.2558337554525283`, 
        1.6039985963818015`}, {1.2395402587470137`, 1.6005875815677366`}}]}, 
      {Arrowheads[{{0.007820310977072727, 1.}}], 
       ArrowBox[{{1.2344841758426954`, 1.5995290995242883`}, {
        1.2212498916972443`, 1.5967585254670698`}, {1.1878179649136, 
        1.5897568305745027`}, {1.1554045230863363`, 1.5829707803101079`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0120256599832559, 1.}}], 
       ArrowBox[{{1.5617065277991837`, 1.4353967832194492`}, {
        1.5400390268469795`, 1.4336339563998348`}, {1.5191593243911747`, 
        1.4319801130487615`}, {1.4779184406934045`, 1.4287458531678432`}, {
        1.4378463503578767`, 1.425669893356384}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.010379178800997245`, 1.}}], 
       ArrowBox[{{1.3152210585995938`, 1.5121338468198462`}, {
        1.278690536448202, 1.506929403446224}, {1.2433436680699996`, 
        1.5019255302906003`}, {1.2090487237025744`, 1.497101531268724}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0007402655263614458, 1.}}], 
       ArrowBox[{{0.2191485939139998, 1.127339714190229}, {
        0.21913620287410993`, 1.1265366532245449`}, {0.21912381260353275`, 
        1.125735765436772}, {0.2191019533093742, 1.1246367904722572`}, {
        0.2190582865429171, 1.1234014524076088`}, {0.21900240801824092`, 
        1.1222770501345163`}, {0.21894659350197695`, 1.1213899013297268`}, {
        0.21886854448002271`, 1.1203565105004996`}, {0.21881174022884148`, 
        1.1197014725568442`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0034984668885724717`, 1.}}], 
       ArrowBox[{{0.2099806390048329, 1.14669485387092}, {
        0.20829474652246846`, 1.153257823047465}, {0.20342950893384698`, 
        1.169584383216784}, {0.19861556014331236`, 1.1809378648398021`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.004728380506657389, 1.}}], 
       ArrowBox[{{0.281083513371263, 1.1366914293972519`}, {
        0.2810068778248633, 1.1354784899414327`}, {0.28093033911521303`, 
        1.1345409458905678`}, {0.2805692144776266, 1.1312824053243609`}, {
        0.2802094156087006, 1.1290159532290076`}, {0.27985073345200845`, 
        1.1271696323972398`}, {0.27904251468755303`, 1.1237611471242666`}, {
        0.278238823556771, 1.1210143646294766`}, {0.27743930890685253`, 
        1.1186652427026589`}, {0.2742779374906229, 1.111195550279593}, {
        0.2711706347074776, 1.1056161082429234`}, {0.2696297427822266, 
        1.1031321933538123`}, {0.2681010450245071, 1.1008633088942898`}, {
        0.26203597372210113`, 1.0926154810168653`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0021885408743935308`, 1.}}], 
       ArrowBox[{{0.20040152065221467`, 1.0999254614272518`}, {
        0.19806493017090201`, 1.093320514841621}, {0.1969069865227811, 
        1.0905301798007772`}, {0.1957587432663903, 1.0880525355295327`}, {
        0.19120557299864874`, 1.07931496759676}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.006141575774174144, 1.}}], 
       ArrowBox[{{1.1302299985491686`, 1.676035571693447}, {
        1.0991933253052704`, 1.6673604136731708`}, {1.0691265190871104`, 
        1.6589361952419035`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.003260517575795715, 1.}}], 
       ArrowBox[{{0.0011536047357022772`, 1.0898109099258229`}, {
        0.0010402211622764566`, 1.1234963685824588`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0023777787050855556`, 1.}}], 
       ArrowBox[{{0.005537501373059988, 1.2751305450595876`}, {
        0.004871654537590576, 1.288216200996177}, {0.004279907892990817, 
        1.2996640698182682`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.003954768699023218, 1.}}], 
       ArrowBox[{{1.1266413153310326`, 1.2680634335913874`}, {
        1.1074298168005674`, 1.2764931765375762`}, {1.0884279867986257`, 
        1.2823319594692637`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0031734669918300324`, 1.}}], 
       ArrowBox[{{1.104456516762692, 1.3881969345514484`}, {
        1.0716975353441807`, 1.3868588802388697`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.007701520787782087, 1.}}], 
       ArrowBox[{{1.4697004352325138`, 1.4296622423558103`}, {
        1.429459927691606, 1.4265446898068814`}, {1.39036584679681, 
        1.4235810191142773`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0004978596038152047, 1.}}], 
       ArrowBox[{{1.8908928943918246`, 1.2856126771679175`}, {
        1.8894881898657645`, 1.28524406459945}, {1.8880849284348729`, 
        1.2848805796842049`}, {1.8866831029874218`, 1.284521952678644}, {
        1.8859126999862372`, 1.2843266705402134`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0013775994047143178`, 1.}}], 
       ArrowBox[{{0.6565519064598672, 1.153310934184357}, {0.643924884585253, 
        1.146744161810282}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.006657010134708954, 1.}}], 
       ArrowBox[{{1.41927881106239, 2.}, {1.3898447129685516`, 
        1.988446197052791}, {1.3552876902591324`, 1.9747951584356067`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0034702291517789536`, 1.}}], 
       ArrowBox[{{1.322489986048313, 1.953396540328988}, {1.2891548757923386`,
         1.9401997623777505`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.014176335090033207`, 1.}}], 
       ArrowBox[{{1.3761698085638814`, 1.9722333158585945`}, {
        1.340410957582184, 1.958257371691536}, {1.3057854733509768`, 
        1.9446378666135087`}, {1.2723414237214112`, 1.9313862595162723`}, {
        1.239934605140032, 1.918468173724547}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.006666951399809194, 1.}}], 
       ArrowBox[{{1.2538694196081628`, 1.9243689754905542`}, {
        1.2214045470767654`, 1.9113677675824225`}, {1.189953168413126, 
        1.8986979975619382`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.009895652144684262, 1.}}], 
       ArrowBox[{{1.238133311230702, 1.9180557151232316`}, {
        1.2054525378723508`, 1.9049356797071582`}, {1.173902624557921, 
        1.8921795269691115`}, {1.1433440854577681`, 1.8797527525778708`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0063072889792916325`, 1.}}], 
       ArrowBox[{{1.1574328033133745`, 1.884944348029217}, {
        1.1267914679393072`, 1.8724465696229458`}, {1.0971196004994552`, 
        1.8602759316394413`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0014600686217689073`, 1.}}], 
       ArrowBox[{{1.4808349254389273`, 2.}, {1.4667139239159457`, 
        1.9946952644750613`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.006135708634949124, 1.}}], 
       ArrowBox[{{1.1117443308278423`, 1.8663950945227052`}, {
        1.0819731138945055`, 1.854138124688813}, {1.0531504868837616`, 
        1.842206390830315}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.002006900783504801, 1.}}], 
       ArrowBox[{{1.1893824476951163`, 1.2832321591669775`}, {
        1.169335781678984, 1.2885267119725312`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.012926542809955047`, 1.}}], 
       ArrowBox[{{2.2889057857505772`, 1.9435875275741457`}, {
        2.262340727047847, 1.9373668669259179`}, {2.2362025185360794`, 
        1.9312246845976737`}, {2.2098782492228057`, 1.9250470534348856`}, {
        2.183926101512545, 1.9189403199411847`}, {2.1589042578098168`, 
        1.9130108306202014`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.00844649192013782, 1.}}], 
       ArrowBox[{{1.344685972815726, 1.1507711836754297`}, {
        1.3226353432739322`, 1.1493289588130433`}, {1.300396340222866, 
        1.1478882911795503`}, {1.2785340841903445`, 1.1464445090882702`}, {
        1.2576136957041852`, 1.1449929408525232`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.006210208288148981, 1.}}], 
       ArrowBox[{{0.3982643849556449, 1.005364820337976}, {
        0.36477822094829415`, 1.005459014464034}, {0.33410461078511433`, 
        1.0055453633919444`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0033719813228467468`, 1.}}], 
       ArrowBox[{{0.19021778089208555`, 1.1898653843106906`}, {
        0.1806648343720035, 1.2055667737756117`}, {0.17598013506801397`, 
        1.2126393624382175`}, {0.17139019256190244`, 1.219160736496242}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.00723772018295087, 1.}}], 
       ArrowBox[{{0.6581955417979032, 2.}, {0.6386838518008796, 
        1.9839286589713399`}, {0.6193281095327798, 1.967838189781336}, {
        0.6006775096507285, 1.9522191345392066`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0015582422000462353`, 1.}}], 
       ArrowBox[{{1.1065903951848897`, 1.2314687111705687`}, {
        1.0974578306515543`, 1.2233002653910465`}, {1.0965518864846118`, 
        1.222683342250683}, {1.0956471403775818`, 1.2220832267668333`}, {
        1.0942471132146097`, 1.221183108033472}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.00006726156130158455, 1.}}], 
       ArrowBox[{{1.2774631460616401`, 1.2630582229759073`}, {
        1.277061685831404, 1.2636254287513007`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.006793716533206931, 1.}}], 
       ArrowBox[{{0.1699053053548422, 1.9748280476164684`}, {
        0.1621630119372008, 1.9515432186471215`}, {0.15489505943957263`, 
        1.929375539140369}, {0.14800468599470104`, 1.9081441535006527`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0000741417725884485, 1.}}], 
       ArrowBox[{{1.3373615886476096`, 1.264761367667686}, {1.337069886578881,
         1.2654696372774288`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.013835804987254547`, 1.}}], 
       ArrowBox[{{0.17466221914141275`, 1.989649623983099}, {
        0.16643418124143186`, 1.9648291153182735`}, {0.1587250165240291, 
        1.9412432391929213`}, {0.15106072362194234`, 1.9177388916564597`}, {
        0.14382556027180163`, 1.89530611948169}, {0.13705187308004052`, 
        1.8740085163212588`}, {0.13064262222735812`, 1.853655301217224}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.00007517620004848984, 1.}}], 
       ArrowBox[{{1.3925658210236171`, 1.2688028208299382`}, {
        1.3922646793249207`, 1.26951873711705}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.01857750088102888, 1.}}], 
       ArrowBox[{{0.17442988290737846`, 1.9875396736634041`}, {
        0.16563936475806731`, 1.9610038531040395`}, {0.157358236385116, 
        1.9357250240684563`}, {0.14958649778852456`, 1.9117031865566552`}, {
        0.14232414896829296`, 1.8889383405686355`}, {0.13510716720176638`, 
        1.866259406670411}, {0.12830884110418958`, 1.844665640116378}, {
        0.12196174661770275`, 1.8242240301285035`}, {0.11596815591588513`, 
        1.8047336090408836`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.00344347545569588, 1.}}], 
       ArrowBox[{{0.4692826265218545, 1.4111248520868909`}, {
        0.4339080375403095, 1.4073459555230245`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0036320918379033956`, 1.}}], 
       ArrowBox[{{0.46626952667416305`, 1.302864315514712}, {
        0.42954323626872726`, 1.3105629876059552`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.00009398663428681405, 1.}}], 
       ArrowBox[{{1.4409715221724977`, 1.2695255603938307`}, {
        1.440918584718392, 1.2704951280343042`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0003801350756473279, 1.}}], 
       ArrowBox[{{1.1782582404772335`, 1.2286151360579152`}, {
        1.1772860674907046`, 1.22806996788693}, {1.1763151229531814`, 
        1.2275365020273428`}, {1.1748125548298305`, 
        1.2267309599949607`}}]}}}}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV02k4lYsWB/DNS+cx5KhzOzcpNsmWpLp1CuH/loqkGUVFxq04xM1wcKJQ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        "]]},
      Annotation[#, "Charting`Private`Tag$19827#1"]& ]}, {}, {}}},
  AspectRatio->1,
  AxesStyle->Directive[
    RGBColor[1, 0, 0], 15],
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{
    FormBox[
     StyleBox[
     "\"\\!\\(\\*\\nStyleBox[\\\"J\\\",\\nFontSlant->\\\"Italic\\\"]\\)/\\!\\(\
\\*\\nStyleBox[\\\"h\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"", FontSize -> 16, 
      StripOnInput -> False], TraditionalForm], 
    FormBox[
     StyleBox[
     "\"\\!\\(\\*\\nStyleBox[\\\"H\\\",\\nFontSlant->\\\"Italic\\\"]\\)/\\!\\(\
\\*\\nStyleBox[\\\"h\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"", FontSize -> 16, 
      StripOnInput -> False], TraditionalForm]},
  FrameStyle->Automatic,
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{{0}, {0}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[
    RGBColor[1, 0, 0], 15],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "TransparentPolygonMesh" -> True},
  PlotRange->{{0, 2.5}, {1, 2}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  RotateLabel->False,
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.799295082463289*^9, 3.7992952791756773`*^9, 3.799295316993283*^9, 
   3.7992953836475773`*^9, 3.799295464057206*^9, {3.799295744930395*^9, 
   3.7992957686540623`*^9}, {3.7992959244414425`*^9, 3.7992959287685547`*^9}, 
   3.799295976670162*^9, {3.79929602817704*^9, 3.7992960444233503`*^9}, {
   3.799296162327355*^9, 3.799296171001664*^9}, {3.7992962268574495`*^9, 
   3.7992962722855005`*^9}, 3.799296362426506*^9, 3.7992963986697054`*^9, {
   3.7992964395032535`*^9, 3.799296487444091*^9}, {3.79929653580893*^9, 
   3.7992965526330857`*^9}, {3.7992966484811306`*^9, 3.7992966618217583`*^9}, 
   3.799296757806192*^9, 3.799304224947053*^9, 3.799304402439687*^9, 
   3.7993068401645327`*^9, {3.7993069842164936`*^9, 3.7993070416170516`*^9}, {
   3.7994572651008854`*^9, 3.7994572915308313`*^9}, 3.7994574209486237`*^9, {
   3.79945806800346*^9, 3.7994580754208636`*^9}, 3.799465708527379*^9, 
   3.799774933799523*^9, 3.7997749952856445`*^9, 3.7997750443616886`*^9, 
   3.799775239235194*^9, 3.7997753195306444`*^9, {3.7997754340434513`*^9, 
   3.7997754443787627`*^9}, 3.7997755301743145`*^9, {3.7997755945900707`*^9, 
   3.799775600942664*^9}, {3.7997757555519047`*^9, 3.799775782165985*^9}, {
   3.79977585124674*^9, 3.7997758956148634`*^9}, 3.799776014279085*^9, {
   3.7997760820416636`*^9, 3.79977610547944*^9}, {3.799776166811507*^9, 
   3.7997762090659657`*^9}, {3.799777338299523*^9, 3.7997773666588163`*^9}, {
   3.7997778595698013`*^9, 3.799777909136444*^9}, 3.799777954648285*^9, 
   3.7999283033395367`*^9, 3.8004498772130475`*^9, {3.8004500655860043`*^9, 
   3.80045007955371*^9}, 3.800456664707203*^9, 3.8005237165541105`*^9, 
   3.8005241093880105`*^9, 3.8005247254075756`*^9, 3.818771321501153*^9}]
}, Open  ]],

Cell[TextData[{
 "We observe here an interesting case wherein aside from the expected de \
Sitter vacuum at ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"H", "/", "h"}], "=", "1"}], TraditionalForm]]],
 " there is also a de Sitter state at ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"H", "/", "h"}], "=", 
    SqrtBox["\[Lambda]"]}], TraditionalForm]]],
 ". We can find this by checking out the ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]]],
 "-axis..."
}], "Text",
 CellChangeTimes->{{3.7994574325612926`*^9, 3.799457551881804*^9}, {
  3.799913967903141*^9, 3.799913974516498*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Series", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"dsj2", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "/.", 
             RowBox[{"n", "\[Rule]", "1"}]}], "/.", 
            RowBox[{
             RowBox[{"x", "[", "\[Tau]", "]"}], "\[Rule]", "\[Epsilon]"}]}], 
           ",", 
           RowBox[{"{", 
            RowBox[{"\[Epsilon]", ",", "0", ",", "0"}], "}"}]}], "]"}], "//", 
         "Normal"}], ")"}], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"y", "[", "\[Tau]", "]"}], ">", "0"}], ",", 
      RowBox[{"\[Lambda]", ">", "0"}]}], "}"}], ",", 
    RowBox[{"y", "[", "\[Tau]", "]"}]}], "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.799457566611379*^9, 3.799457630918314*^9}, {
  3.799457674398344*^9, 3.7994576759338427`*^9}, {3.799776360666791*^9, 
  3.7997763922096024`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"y", "[", "\[Tau]", "]"}], "\[Rule]", 
   RowBox[{"ConditionalExpression", "[", 
    RowBox[{
     SqrtBox["\[Lambda]"], ",", 
     RowBox[{"\[Lambda]", ">", "0"}]}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7994575871962624`*^9, 3.7994576324028673`*^9}, 
   3.7994576775745506`*^9, {3.7997763725442467`*^9, 3.7997763925951753`*^9}, 
   3.8004498776069355`*^9, 3.8005237168937063`*^9, 3.8005247254584436`*^9, 
   3.8187713355274887`*^9}]
}, Open  ]],

Cell[TextData[{
 "Thus, the other de Sitter state corresponds to ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "=", 
    RowBox[{
     RowBox[{"H", "/", "h"}], "=", 
     SqrtBox["\[Lambda]"]}]}], TraditionalForm]]],
 ", or in the earlier set of variables ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"\[CapitalLambda]", "=", 
     RowBox[{"3", 
      SuperscriptBox["h", "2"], "\[Lambda]"}]}], ")"}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"3", 
     SuperscriptBox["H", "2"]}], "=", "\[CapitalLambda]"}], TraditionalForm]]],
 ".\n\n[Case 2: ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"n", "=", 
     RowBox[{"-", "2"}]}], ",", " ", 
    RowBox[{"\[Lambda]", "=", "1.9"}], ",", 
    RowBox[{"\[Beta]", "=", "1"}], ",", 
    RowBox[{"w", "=", "0"}]}], TraditionalForm]]],
 "]\n\nSetting up..."
}], "Text",
 CellChangeTimes->{{3.799457652751074*^9, 3.7994576627589903`*^9}, {
  3.7994577035147915`*^9, 3.7994577474866095`*^9}, {3.7994577929460325`*^9, 
  3.7994578200599723`*^9}, {3.799457852974985*^9, 3.7994579108315897`*^9}, {
  3.7997764841592965`*^9, 3.7997765222072663`*^9}, {3.799777153891939*^9, 
  3.79977716892284*^9}, {3.799777200091672*^9, 3.7997772136514645`*^9}, {
  3.799777290424427*^9, 3.7997773178909116`*^9}, {3.818771344973628*^9, 
  3.818771354450082*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"SFcase2", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"n", "\[Rule]", 
      RowBox[{"-", "2"}]}], ",", 
     RowBox[{"\[Lambda]", "\[Rule]", 
      FractionBox["7", "5"]}], ",", 
     RowBox[{"\[Beta]", "\[Rule]", "1"}], ",", 
     RowBox[{"w", "\[Rule]", "0"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"zSFcase2", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"dsj2", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "/.", "SFcase2"}], "//", 
            "Denominator"}], ")"}], "/.", 
          RowBox[{
           RowBox[{"y", "[", "\[Tau]", "]"}], "\[Rule]", 
           RowBox[{
            RowBox[{"z", "[", "\[Tau]", "]"}], "+", "1"}]}]}], ")"}], 
        "\[Equal]", "0"}], "}"}], ",", 
      RowBox[{"z", "[", "\[Tau]", "]"}]}], "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{"\"\<\!\(\*SubscriptBox[\(y\), \(C\)]\)(x)\>\"", "\[Equal]", 
      RowBox[{
       RowBox[{"z", "[", "\[Tau]", "]"}], "+", "1"}]}], "/.", "zSFcase1"}], "/.", 
    RowBox[{
     RowBox[{"x", "[", "\[Tau]", "]"}], "\[Rule]", "x"}]}], "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"noghostSF", "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", 
      RowBox[{"\[Lambda]", "-", "1"}]]}], "<", "n", "<", "0"}]}], ";", 
  RowBox[{"noghostSF", "/.", "SFcase2"}]}]}], "Input",
 CellChangeTimes->{{3.7997773911913495`*^9, 3.7997775395042877`*^9}, {
   3.799777577119648*^9, 3.799777620575962*^9}, {3.799777820322299*^9, 
   3.7997778218955936`*^9}, 3.7999170993553*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"z", "[", "\[Tau]", "]"}], "\[Rule]", 
   FractionBox[
    SuperscriptBox[
     RowBox[{"x", "[", "\[Tau]", "]"}], 
     RowBox[{"4", "/", "9"}]], 
    RowBox[{
     SuperscriptBox["2", 
      RowBox[{"1", "/", "9"}]], " ", 
     SuperscriptBox["15", 
      RowBox[{"5", "/", "9"}]]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.7997774269894266`*^9, 3.7997775400216646`*^9}, {
   3.7997775789704685`*^9, 3.7997775903797197`*^9}, 3.799777621407238*^9, 
   3.7997778227312107`*^9, 3.7999171006408596`*^9, 3.7999276192597046`*^9, 
   3.799928311279327*^9, 3.800449877673845*^9, 3.800523716948077*^9, 
   3.8005247254937196`*^9, 3.818771367405652*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.7997774269894266`*^9, 3.7997775400216646`*^9}, {
   3.7997775789704685`*^9, 3.7997775903797197`*^9}, 3.799777621407238*^9, 
   3.7997778227312107`*^9, 3.7999171006408596`*^9, 3.7999276192597046`*^9, 
   3.799928311279327*^9, 3.800449877673845*^9, 3.800523716948077*^9, 
   3.8005247254937196`*^9, 3.818771367405652*^9}]
}, Open  ]],

Cell["\<\
The phase portraits of this dynamical system (figure 2) is shown below...\
\>", "Text",
 CellChangeTimes->{{3.7997776594374123`*^9, 3.7997776938170795`*^9}, {
  3.8187713858847804`*^9, 3.818771388128648*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"SFp2", "=", 
   RowBox[{"StreamPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"dsj1", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "/.", "SFcase2"}], ",", 
       RowBox[{
        RowBox[{"dsj2", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "/.", "SFcase2"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "[", "\[Tau]", "]"}], ",", "0", ",", "0.65"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y", "[", "\[Tau]", "]"}], ",", 
       RowBox[{"1", "+", 
        SuperscriptBox["10", 
         RowBox[{"-", "5"}]]}], ",", "1.3"}], "}"}], ",", 
     RowBox[{"PlotTheme", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<Scientific\>\"", ",", "\"\<Red\>\""}], "}"}]}], ",", 
     RowBox[{"AxesStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Style", "[", 
         RowBox[{"\"\<\!\(\*
StyleBox[\"J\",
FontSlant->\"Italic\"]\)/\!\(\*
StyleBox[\"h\",
FontSlant->\"Italic\"]\)\>\"", ",", 
          RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}], ",", 
        RowBox[{"Style", "[", 
         RowBox[{"\"\<\!\(\*
StyleBox[\"H\",
FontSlant->\"Italic\"]\)/\!\(\*
StyleBox[\"h\",
FontSlant->\"Italic\"]\)\>\"", ",", 
          RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"RotateLabel", "\[Rule]", "False"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0.65"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1.3"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"StreamPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.2", ",", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"z", "[", "\[Tau]", "]"}], "+", "1"}], "/.", 
                  "zSFcase2"}], "/.", 
                 RowBox[{
                  RowBox[{"x", "[", "\[Tau]", "]"}], "\[Rule]", "0.2"}]}], 
                ")"}], "+", 
               RowBox[{"(", 
                RowBox[{"2", " ", 
                 SuperscriptBox["10", 
                  RowBox[{"-", "2"}]]}], ")"}]}]}], "}"}], ",", "Green"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.4", ",", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"z", "[", "\[Tau]", "]"}], "+", "1"}], "/.", 
                  "zSFcase2"}], "/.", 
                 RowBox[{
                  RowBox[{"x", "[", "\[Tau]", "]"}], "\[Rule]", "0.4"}]}], 
                ")"}], "+", 
               RowBox[{"(", 
                RowBox[{"2", " ", 
                 SuperscriptBox["10", 
                  RowBox[{"-", "2"}]]}], ")"}]}]}], "}"}], ",", "Green"}], 
           "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.6", ",", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"z", "[", "\[Tau]", "]"}], "+", "1"}], "/.", 
                  "zSFcase2"}], "/.", 
                 RowBox[{
                  RowBox[{"x", "[", "\[Tau]", "]"}], "\[Rule]", "0.6"}]}], 
                ")"}], "+", 
               RowBox[{"(", 
                RowBox[{"2", " ", 
                 SuperscriptBox["10", 
                  RowBox[{"-", "2"}]]}], ")"}]}]}], "}"}], ",", "Green"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.2", ",", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"z", "[", "\[Tau]", "]"}], "+", "1"}], "/.", 
                  "zSFcase2"}], "/.", 
                 RowBox[{
                  RowBox[{"x", "[", "\[Tau]", "]"}], "\[Rule]", "0.2"}]}], 
                ")"}], "-", 
               RowBox[{"(", 
                RowBox[{"2", " ", 
                 SuperscriptBox["10", 
                  RowBox[{"-", "2"}]]}], ")"}]}]}], "}"}], ",", "Red"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.4", ",", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"z", "[", "\[Tau]", "]"}], "+", "1"}], "/.", 
                  "zSFcase2"}], "/.", 
                 RowBox[{
                  RowBox[{"x", "[", "\[Tau]", "]"}], "\[Rule]", "0.4"}]}], 
                ")"}], "-", 
               RowBox[{"(", 
                RowBox[{"2", " ", 
                 SuperscriptBox["10", 
                  RowBox[{"-", "2"}]]}], ")"}]}]}], "}"}], ",", "Red"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.6", ",", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"z", "[", "\[Tau]", "]"}], "+", "1"}], "/.", 
                  "zSFcase2"}], "/.", 
                 RowBox[{
                  RowBox[{"x", "[", "\[Tau]", "]"}], "\[Rule]", "0.6"}]}], 
                ")"}], "-", 
               RowBox[{"(", 
                RowBox[{"2", " ", 
                 SuperscriptBox["10", 
                  RowBox[{"-", "2"}]]}], ")"}]}]}], "}"}], ",", "Red"}], 
           "}"}], ",", "Automatic"}], "}"}], ",", "Fine"}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"yc2", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"z", "[", "\[Tau]", "]"}], "+", "1"}], "/.", "zSFcase2"}], "/.", 
      RowBox[{
       RowBox[{"x", "[", "\[Tau]", "]"}], "\[Rule]", "x"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "0.65"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"SFp2", ",", "yc2"}], "]"}]}], "Input",
 CellChangeTimes->{{3.7997777080193043`*^9, 3.7997777815434093`*^9}, {
  3.799927636153455*^9, 3.799927644213808*^9}, {3.799928315621602*^9, 
  3.7999283457991805`*^9}, {3.7999283806515617`*^9, 3.7999283850906324`*^9}, {
  3.799928477330576*^9, 3.799928653367562*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {
     {RGBColor[0., 1., 0.], 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{0.20771521291645612`, 1.0999139862388643`}, {
        0.207560815844381, 1.1017330943553336`}, {0.20740615589743902`, 
        1.104639036253158}, {0.20678727473573497`, 1.107848301842451}, {
        0.20647788998777392`, 1.1088831751294534`}, {0.20616868240933892`, 
        1.1097543187424204`}, {0.20493245966866444`, 1.1127292136685807`}, {
        0.2, 1.1205807465113018`}, {0.19434970709711563`, 
        1.1249356055451516`}, {0.18884777374972492`, 1.1283744336613497`}, {
        0.18348242678027837`, 1.131480202937599}, {0.1782575905812925, 
        1.1340585893479989`}, {0.17327764819529484`, 1.1366457098568228`}}]}, 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{0.17207123817288264`, 1.1372380020247557`}, {
        0.1679441684477993, 1.1392340263620673`}, {0.16299502815725708`, 
        1.1414402058646655`}, {0.15818426838418448`, 1.1433920260309738`}, {
        0.14895874958678978`, 1.1468184865285465`}, {0.14024847125195702`, 
        1.1497993060286134`}, {0.13202873965679246`, 1.1524146367520411`}, {
        0.12427486107840238`, 1.1547446309196965`}, {0.12158503518753774`, 
        1.1555144778553685`}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{0.12029286452326596`, 1.155884306114377}, {
        0.11661308283951968`, 1.1569374853044485`}, {0.10938660905594744`, 
        1.158932883429682}, {0.10259543972768558`, 1.1607308252953965`}, {
        0.09623957485473414, 1.1623313109015925`}, {0.09027297112757607, 
        1.1637782704816375`}, {0.08464958523669436, 1.1651156342688993`}, {
        0.07936941718208897, 1.166343402263378}, {0.07443246696375991, 
        1.1674615744650738`}, {0.06812884675850668, 1.1688534720236317`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.06681640827462781, 1.1691432705619296`}, {
        0.06543788819354843, 1.1694476605271877`}, {0.05751551708367754, 
        1.1711524214923135`}, {0.0503804880847642, 1.1726550894088577`}, {
        0.044045747031978194`, 1.1739718324937423`}, {0.03851129392531952, 
        1.1751026507469664`}, {0.03377712876478814, 1.1760475441685307`}, {
        0.02601600400087046, 1.177576864355041}, {0.020068714458988238`, 
        1.1787571008916344`}, {0.01415554332633738, 1.179963656563116}}]}, 
      {Arrowheads[{{0.004737057602209008, 1.}}], 
       ArrowBox[{{0.012838625589493011`, 1.1802323676368562`}, {
        0.012005548917216028`, 1.1804023531422925`}, {0.006847219714946893, 
        1.1815173358700737`}, {0.003924466548094985, 1.1821842138964227`}, {
        0.002255019551958999, 1.1825839059332712`}, {0.0012959618224347173`, 
        1.1828261278011192`}, {0.0007432768251369659, 1.1829749130765996`}, {
        0.0004262822170656901, 1.1830665834590033`}}]}}, 
     {RGBColor[0., 1., 0.], 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{0.42953356699259787`, 1.1431415603480066`}, {
        0.4292663473862132, 1.1437758125788189`}, {0.42899916066515437`, 
        1.144260715604243}, {0.4280355586500343, 1.1455697929775166`}, {
        0.4270731900294413, 1.146508749041994}, {0.42611225459389906`, 
        1.147272153405474}, {0.4222849502239935, 1.1495875593542808`}, {
        0.4184851022654681, 1.15120225781601}, {0.40915107709849935`, 
        1.1546213196559718`}, {0.4, 1.1568692740626532`}, {
        0.39244190228808473`, 1.1581008589751511`}, {0.3850222796069325, 
        1.1591565490377458`}, {0.37986238017751567`, 1.159842238074587}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.37853003993715095`, 1.1600192901874542`}, {
        0.3777351130916742, 1.1601249264756204`}, {0.3705824090305995, 
        1.1609764638803806`}, {0.3634279709531708, 1.1618505706391562`}, {
        0.35640452729721744`, 1.1626529760728475`}, {0.3495120780627397, 
        1.1633836801814554`}, {0.34275062324973743`, 1.1640426829649793`}, {
        0.3361162240805511, 1.164647384866147}, {0.32960494177752103`, 
        1.1652151863276856`}, {0.325062846278488, 1.1655926660855096`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.3237234110884834, 1.1657039824748836`}, {
        0.32321677634064755`, 1.165746087349596}, {0.3169517277699303, 
        1.166240087931877}, {0.3108056613742212, 1.16670399081335}, {
        0.30477444246237195`, 1.1671445987328353`}, {0.29885807103438256`, 
        1.1675619116903329`}, {0.293056547090253, 1.1679559296858428`}, {
        0.28622995508461524`, 1.1684053309135563`}, {0.27955023432174597`, 
        1.1688348991199304`}, {0.2730173848016453, 1.1692446343049654`}, {
        0.2700909712945329, 1.1694233093503132`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.2687494167000441, 1.1695052192811635`}, {
        0.26663140652431305`, 1.1696345364686613`}, {0.26039229948974946`, 
        1.1700046056110185`}, {0.2543000636979543, 1.170354841732036}, {
        0.24835469914892774`, 1.1706852448317144`}, {0.2425562058426697, 
        1.1709958149100537`}, {0.2368924521482718, 1.171291539314647}, {
        0.23135130643482552`, 1.1715774053930879`}, {0.22593276870233092`, 
        1.1718534131453762`}, {0.220636838950788, 1.1721195625715117`}, {
        0.21506528175987571`, 1.17239352042286}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.21372285080831413`, 1.1724595288091102`}, {
        0.2104128033905573, 1.1726222864453253`}, {0.2006791997541333, 
        1.1730855770145283`}, {0.19139459563221164`, 1.1735170823660692`}, {
        0.1825175586154879, 1.1739244505868962`}, {0.17404808870396216`, 
        1.1743076816770088`}, {0.16598618589763434`, 1.174666775636408}, {
        0.1600174129138622, 1.1749261507996676`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.15867462733862558`, 1.1749845020267533`}, {
        0.15680178253335392`, 1.1750658871671242`}, {0.14816215163695598`, 
        1.1754304811794094`}, {0.14002887137219996`, 1.175766018214847}, {
        0.13236351990284528`, 1.176077958815021}, {0.1251276753926513, 
        1.1763717635215158`}, {0.11828291600537749`, 1.1766528928759146`}, {
        0.11179081990478322`, 1.1769268074198023`}, {0.1056129652546279, 
        1.1771989676947618`}, {0.10495940923804443`, 1.1772286432671253`}}]}, 
      {Arrowheads[{{0.016432348989517804`, 1.}}], 
       ArrowBox[{{0.10361673982478353`, 1.177289608941562}, {
        0.09975079482976973, 1.177465147269634}, {0.09421801743925103, 
        1.1777181391062612`}, {0.08899461029810757, 1.1779589328357294`}, {
        0.0840605506213751, 1.178188518089126}, {0.07498038252128617, 
        1.1786180216920519`}, {0.06681733085927022, 1.1790145669637324`}, {
        0.059494324180251114`, 1.179378661952555}}]}}, 
     {RGBColor[0., 1., 0.], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.65, 1.189768500252727}, {0.6414776901547278, 
        1.188656558286273}, {0.6309762220763072, 1.1873889545153}, {
        0.6203867236380609, 1.186069683339789}, {0.6099732859194661, 
        1.1848537469733542`}, {0.6, 1.1838961476296106`}, {0.5965944299240907,
         1.1836402450048333`}}]}, 
      {Arrowheads[{{0.02000000000000002, 1.}}], 
       ArrowBox[{{0.5952541556305638, 1.1835395336108552`}, {
        0.5944111545415864, 1.1834761885066432`}, {0.5889871231577791, 
        1.1831200896425897`}, {0.5836898718313615, 1.1828131140546243`}, {
        0.5784813665451164, 1.18254052475992}, {0.5681784580242768, 
        1.182039557118991}, {0.5577741254575257, 1.1814992908571913`}, {
        0.547548432788152, 1.1809958019866653`}, {0.5415649182026602, 
        1.1807708097155298`}}]}, 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{0.5402218145686999, 1.1807203062977378`}, {
        0.537795277213414, 1.1806290635769656`}, {0.5282311364765304, 
        1.180317025351597}, {0.5185724883207196, 1.1799776370340629`}, {
        0.508859536194738, 1.1796136022437738`}, {0.4993214983851965, 
        1.1792823247844704`}, {0.48995837489209504`, 1.178983804656153}, {
        0.48649124505493846`, 1.1788835202474592`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.4851477541170665, 1.178844660671782}, {0.4807701657154335,
         1.1787180418588212`}, {0.4717568708552121, 1.1784850363924753`}, {
        0.4629184903114308, 1.1782847882571157`}, {0.4542550240840893, 
        1.1781172974527412`}, {0.4457664721731879, 1.1779825639793529`}, {
        0.4374392393166941, 1.1778696392556087`}, {0.43139667593668607`, 
        1.1777942396759677`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.430052727746641, 1.177777469785076}, {
        0.42925973025257536`, 1.1777675747001677`}, {0.4212279449808317, 
        1.177676370313029}, {0.4133438835014633, 1.1775960260941936`}, {
        0.4056075458144699, 1.1775265420436605`}, {0.3980189319198516, 
        1.1774679181614305`}, {0.3905780418176084, 1.177420154447503}, {
        0.3832848755077404, 1.1773832509018782`}, {0.3762924476305294, 
        1.1773546751011223`}}]}, 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{0.37494840352109204`, 1.1773498441659742`}, {
        0.36909909025495874`, 1.177329219144978}, {0.36219581530950246`, 
        1.1773088896410626`}, {0.35541895215133584`, 1.1772930177201701`}, {
        0.3487685007804589, 1.177281603382301}, {0.3422444611968717, 
        1.1772746466274548`}, {0.33584683340057403`, 1.1772721474556316`}, {
        0.32957561739156616`, 1.1772741058668317`}, {0.3211863941993308, 
        1.17728235518452}}]}, 
      {Arrowheads[{{0.007725886038826527, 1.}}], 
       ArrowBox[{{0.3198423420351497, 1.177283676822178}, {0.3191044195125174,
         1.1772844024385047`}, {0.30893734189503774`, 1.1773009617210937`}, {
        0.299074384539127, 1.1773237837145976`}}]}}, 
     {RGBColor[1., 0., 0.], 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{0.20977401608468996`, 1.0938850407572185`}, {
        0.2072947839411432, 1.0895188441723285`}, {0.20606497962355524`, 
        1.0877378993313678`}, {0.2048444615153014, 1.086161872448006}, {0.2, 
        1.0805807465113018`}, {0.1943258452998793, 1.0761092195010566`}, {
        0.18883431091015215`, 1.0722418134222866`}, {0.18351038297713113`, 
        1.0687808002423607`}, {0.17835906611871208`, 1.0657920893054893`}, {
        0.17007769603952905`, 1.0609356482944376`}, {0.16888485660666272`, 
        1.0603116155838304`}}]}, 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{0.1676939290475765, 1.0596885830680056`}, {
        0.16221842645613657`, 1.0568240795732955`}, {0.15475295118244714`, 
        1.0532566630937135`}, {0.1476529640323732, 1.0500326788073424`}, {
        0.14089833283544267`, 1.0470990585617443`}, {0.13446892542118347`, 
        1.0444027342044813`}, {0.12534460194987593`, 1.0407179208448483`}, {
        0.1185048763815594, 1.0380697191427002`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.11725149052549172`, 1.0375844338013025`}, {
        0.11686653235840555`, 1.037435385880717}, {0.10898651176591748`, 
        1.0344952547184858`}, {0.10165633529155682`, 1.031837652764552}, {
        0.09483637458878805, 1.0294276888255873`}, {0.08848700131107556, 
        1.0272304717082625`}, {0.08209897006253523, 1.0250614527606}, {
        0.0761507701099618, 1.0230738608785148`}, {0.07064240145335525, 
        1.0212676960620075`}, {0.06647631886262292, 1.0199322434102787`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.0651957196563815, 1.0195241613637085`}, {
        0.056511157915969897`, 1.0167958403179054`}, {0.04871752623635782, 
        1.0143905832109499`}, {0.04202094660140912, 1.0123516972125088`}, {
        0.036249396558653564`, 1.0106036925448802`}, {0.028313753548688064`, 
        1.008220733995361}, {0.022157394355948833`, 1.0063997882861548`}, {
        0.013736544794057884`, 1.0039625209875247`}}]}, 
      {Arrowheads[{{0.0046087843558992245`, 1.}}], 
       ArrowBox[{{0.012444236680477505`, 1.00359317441031}, {
        0.008491698960716474, 1.002464097651682}, {0.004862503974813271, 
        1.0014086982299581`}, {0.002814832593391229, 1.0007987402058345`}, {
        0.0016366981718703407`, 1.0004531704257869`}, {0.0009414593865305074, 
        1.0002631636594395`}, {0.0005409435111868846, 
        1.0001598552403976`}}]}}, 
     {RGBColor[1., 0., 0.], 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{0.43205296844085644`, 1.1330309620866161`}, {
        0.42732379962373235`, 1.1297444581265264`}, {0.41805439510267534`, 
        1.1246302086887379`}, {0.40891094599041233`, 1.1204884649058766`}, {
        0.4, 1.1168692740626531`}, {0.3926397326122163, 1.114212141829522}, {
        0.38543388486227587`, 1.1116996735607265`}, {0.38325355474852246`, 
        1.1109540504594335`}}]}, 
      {Arrowheads[{{0.019999999999999983`, 1.}}], 
       ArrowBox[{{0.38198181049617924`, 1.1105191429711123`}, {
        0.37837152175868494`, 1.1092845066800145`}, {0.3714562882986082, 
        1.1069824287128038`}, {0.3645371874861854, 1.1046662402739122`}, {
        0.3577574816125844, 1.1024349198051593`}, {0.3511171706778054, 
        1.1002884673065458`}, {0.3446162546818483, 1.0982268827780715`}, {
        0.3382478780255177, 1.096236207638163}, {0.3320051851096183, 
        1.094302483305248}, {0.33084066235031245`, 1.0939451934234927`}}]}, 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{0.3295557274586797, 1.0935509596209962`}, {
        0.32588817593415004`, 1.0924257097793257`}, {0.3198968504991129, 
        1.0906058870603965`}, {0.31402546690698596`, 1.0888366750208789`}, {
        0.308268283260248, 1.0871117335331908`}, {0.3026252995588993, 
        1.0854310625973325`}, {0.2970965158029396, 1.083794662213304}, {
        0.291554932737631, 1.0821624221401334`}, {0.2861176322158618, 
        1.0805662413448365`}, {0.2807846142376316, 1.079006119827413}, {
        0.2780312336023578, 1.0782035694766174`}}]}, 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{0.2767408775410126, 1.0778274588523118`}, {
        0.27555587880294063`, 1.0774820575878632`}, {0.2654112555641766, 
        1.0745421109423847`}, {0.2556837624995693, 1.0717464014084004`}, {
        0.2463387151457309, 1.0690763664830674`}, {0.23734142903927322`, 
        1.0665134436635417`}, {0.22869190418019633`, 1.0640576329498241`}, {
        0.22505573355282024`, 1.0630289034785814`}}]}, 
      {Arrowheads[{{0.020000000000000014`, 1.}}], 
       ArrowBox[{{0.22376244282676266`, 1.0626630113296367`}, {
        0.2203901405685002, 1.061708934341914}, {0.21240833113434598`, 
        1.0594565605185269`}, {0.20471866880789494`, 1.057289724158378}, {
        0.197321153589147, 1.0552084252614675`}, {0.1902157854781021, 
        1.0532126638277948`}, {0.18165236175247051`, 1.0508134666956033`}, {
        0.1735223888169367, 1.0485423346649432`}, {0.17200489971280353`, 
        1.0481193407239837`}}]}, 
      {Arrowheads[{{0.007439930818965985, 1.}}], 
       ArrowBox[{{0.17071020452670624`, 1.0477584496852166`}, {
        0.16579693701642056`, 1.0463888962686532`}, {0.1584470766958418, 
        1.0443427800395706`}, {0.15144387820012026`, 1.0423936145105341`}}]}}, 
     {RGBColor[1., 0., 0.], 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{0.65, 1.1494033479601011`}, {0.6481960657768633, 
        1.14924068850724}, {0.6427576441931204, 1.1486769564301638`}, {
        0.6319272820404368, 1.147529717207079}, {0.6210029524848173, 
        1.1464144533020302`}, {0.6102665577350693, 1.14523523876091}, {0.6, 
        1.1438961476296106`}, {0.5965845676920408, 1.1433632583403817`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.5952565815860642, 1.1431560606833029`}, {
        0.5892680754668986, 1.1422217102170533`}, {0.5790496876637896, 
        1.1404687354209362`}, {0.5690367145526776, 1.138684345671395}, {
        0.558921034095567, 1.136915663398566}, {0.548983249819035, 
        1.1351454719554175`}, {0.542304366353608, 1.133870887565067}}]}, 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{0.5409841393054658, 1.1336189381492714`}, {
        0.5395196901133261, 1.1333394656760016`}, {0.5302458202359467, 
        1.131519133462079}, {0.5208771054444025, 1.1297059642154097`}, {
        0.5114531704482689, 1.1279041038812023`}, {0.5022033297854503, 
        1.126103372470158}, {0.493127583455947, 1.1243037699822767`}, {
        0.48821949442584367`, 1.1233121486093334`}}]}, 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{0.4869020611163502, 1.1230459767817424`}, {
        0.4842259314597587, 1.1225052964175586`}, {0.4754983737968855, 
        1.120707951776004}, {0.4669449104673274, 1.1189117360576124`}, {
        0.45856554147108436`, 1.1171166492623836`}, {0.45036026680815644`, 
        1.1153226913903183`}, {0.4423153526106719, 1.1135390867360482`}, {
        0.43441706501075905`, 1.1117750595942053`}, {0.43433955957717485`, 
        1.11175761761308}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.43302830034661305`, 1.1114625291567954`}, {
        0.4266654040084178, 1.1100306099647894`}, {0.4190603696036484, 
        1.1083057378478012`}, {0.4116019617964505, 1.10660044324324}, {
        0.4042901805868244, 1.1049147261511063`}, {0.39712502597476984`, 
        1.1032485865713995`}, {0.39010649796028696`, 1.10160202450412}, {
        0.3832229974220926, 1.0999768317841299`}, {0.3806451179864426, 
        1.0993659146156818`}}]}, 
      {Arrowheads[{{0.0010989058838078152`, 1.}}], 
       ArrowBox[{{0.37933728842940223`, 1.0990559794345593`}, {
        0.3764629252389033, 1.0983748002462903`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{0.65, 1.0656102710885322`}, {0.6448209316529148, 
        1.065516483549523}, {0.6382344232483697, 1.0653919568178851`}, {
        0.6318107145746911, 1.0652628754805364`}, {0.6255986455511392, 
        1.065127873155764}, {0.6194564228302291, 1.0649910365277035`}, {
        0.613239552258593, 1.0648564594010654`}, {0.6069928225466664, 
        1.0647227860749955`}, {0.600761022404885, 1.0645886608486412`}, {
        0.5962496249275511, 1.0644893026371296`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.5949058979605737, 1.064459708634635}, {0.5945889405436845,
         1.0644527280211498`}, {0.5885213656735004, 1.0643136318916677`}, {
        0.5826030865047683, 1.0641700167593422`}, {0.576878891747924, 
        1.0640205269233198`}, {0.5660435360793368, 1.0637051882495008`}, {
        0.5557163911643501, 1.063374865622656}, {0.5455925305508035, 
        1.063038549414601}, {0.54116695472465, 1.06289428948037}}]}, 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{0.5398236154079114, 1.0628505008189402`}, {
        0.5353670277865369, 1.0627052299971511`}, {0.5253209670841154, 
        1.0623661035980667`}, {0.5157490567930154, 1.062012259816779}, {
        0.5063668066664443, 1.0616525290826102`}, {0.4968897264576088, 
        1.0612957418248818`}, {0.4873584466687263, 1.0609403334962617`}, {
        0.4860973028888416, 1.0608916033847964`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.48475425230156266`, 1.0608397084257397`}, {
        0.4780032579665428, 1.0605788525965358`}, {0.46882416035105834`, 
        1.060211299125704}, {0.45982115382227273`, 1.0598376730837664`}, {
        0.4509942383801864, 1.0594579744707233`}, {0.4423434140247988, 
        1.0590722032865745`}, {0.4338686807561104, 1.05868035953132}, {
        0.4310413452005316, 1.0585447900064515`}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{0.4296988348244256, 1.0584804172108488`}, {
        0.42557003857412096`, 1.0582824432049593`}, {0.41743431097988504`, 
        1.057878962666541}, {0.4094483214744571, 1.0574704262751125`}, {
        0.40161207005783717`, 1.057056834030674}, {0.39392555673002516`, 
        1.0566381859332254`}, {0.38638878149102107`, 1.0562144819827666`}, {
        0.3790017443408251, 1.055785722179298}, {0.3760139030946606, 
        1.0556066260412684`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.37467225838530466`, 1.0555262056419712`}, {
        0.37176444527943703`, 1.0553519065228192`}, {0.36467688430685696`, 
        1.05491303501333}, {0.357728008202539, 1.0544697631634277`}, {
        0.35090676374593727`, 1.0540227464857086`}, {0.34421315093705174`, 
        1.053571984980173}, {0.33764716977588244`, 1.0531174786468205`}, {
        0.33120882026242937`, 1.0526592274856512`}, {0.3248981023966925, 
        1.0521972314966654`}, {0.32103269376134763`, 1.0519060696865883`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.31969243777631345`, 1.0518051149375869`}, {
        0.3187150161786718, 1.0517314906798627`}, {0.3126595616083674, 
        1.0512620050352435`}, {0.3050337680821525, 1.0506513449678552`}, {
        0.29761136482701184`, 1.0500358373279275`}, {0.290386075830178, 
        1.0494159487322}, {0.2833516250788833, 1.048792145797412}, {
        0.27650173656036026`, 1.0481648951403049`}, {0.2698301342618412, 
        1.0475346633776175`}, {0.2661311495698374, 1.047174560979582}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.2647934208693577, 1.0470443308345356`}, {
        0.2633305421705587, 1.0469019171260898`}, {0.2569966842737449, 
        1.0462671230024623`}, {0.25082228455863254`, 1.0456307476234745`}, {
        0.2448010670124538, 1.044993257605867}, {0.2389267556224412, 
        1.0443551195663787`}, {0.2331930743758272, 1.0437168001217503`}, {
        0.22759374725984421`, 1.0430787658887215`}, {0.22212249826172462`, 
        1.0424414834840323`}, {0.21677305136870081`, 1.0418054195244228`}, {
        0.21153913056800525`, 1.0411710406266328`}, {0.21135692761602778`, 
        1.041148252241447}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.2100232654729071, 1.0409814491995903`}, {
        0.20144255366798042`, 1.0399082472363037`}, {0.19184767008125417`, 
        1.0386555844622078`}, {0.18272725192512518`, 1.0374163434318793`}, {
        0.17405407131689213`, 1.0361938152728534`}, {0.16580090037385367`, 
        1.0349912911126644`}, {0.15794051121330857`, 1.0338120620788471`}, {
        0.15676787027604727`, 1.0336317197413925`}}]}, 
      {Arrowheads[{{0.016236790390030738`, 1.}}], 
       ArrowBox[{{0.15543943562677565`, 1.0334274176381715`}, {
        0.15044567595255542`, 1.0326594192989365`}, {0.14328916670889294`, 
        1.031536653900467}, {0.1364667845401082, 1.0304412175396775`}, {
        0.1299814163318308, 1.029368765112409}, {0.12381646294312337`, 
        1.0283198926055983`}, {0.11795532523304839`, 1.0272951960061818`}, {
        0.11238140406066849`, 1.0262952713010967`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{0.06889859092080557, 1.0622570852766744`}, {
        0.06886578501174544, 1.063742559296652}, {0.0688329673548915, 
        1.0648348318302414`}, {0.06840804393777304, 1.0706315248370732`}, {
        0.06798420380501073, 1.0735962332069466`}, {0.06756195296082011, 
        1.0759342449990437`}, {0.06672291430324673, 1.0797697365448404`}, {
        0.0658916269185929, 1.082936316080782}, {0.06506841063360123, 
        1.085701805266741}, {0.06343013071157634, 1.09090691773735}, {
        0.06182555576435592, 1.0952604694309174`}, {0.05836556016082217, 
        1.1025512692365627`}, {0.0550895967766781, 1.1086347680020268`}, {
        0.052723557118792806`, 1.1128556330117843`}}]}, 
      {Arrowheads[{{0.02000000000000003, 1.}}], 
       ArrowBox[{{0.05206635041648222, 1.1140280481759663`}, {
        0.051975570835867665`, 1.1141899932026016`}, {0.049030847263742884`, 
        1.118990602346524}, {0.04348129544062084, 1.128134859221703}, {
        0.03852482046990241, 1.1355829310060939`}, {0.034108878204952175`, 
        1.1417366980561157`}, {0.030180924499134728`, 1.1469980407281881`}, {
        0.02359686934105126, 1.1554302978897426`}, {0.021415767469170115`, 
        1.1581204444716175`}}]}, 
      {Arrowheads[{{0.003300484491991437, 1.}}], 
       ArrowBox[{{0.020569303335901488`, 1.159164463838227}, {
        0.01876087496334703, 1.1613949591065644`}, {0.014910040716773532`, 
        1.1659968789362851`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{0.4585198707392395, 1.3}, {0.44875040269434047`, 
        1.2968345086250253`}, {0.4391536305386228, 1.2937337783680882`}, {
        0.4297964584059636, 1.2907194874267907`}, {0.42067888629636285`, 
        1.287791635801132}, {0.4117770531992242, 1.2849426604517113`}, {
        0.40734317900845957`, 1.2835286687356882`}}]}, 
      {Arrowheads[{{0.020000000000000014`, 1.}}], 
       ArrowBox[{{0.406062664861898, 1.2831203043307486`}, {
        0.40306709810395114`, 1.2821649983391277`}, {0.3945490210105436, 
        1.2794586494633804`}, {0.3862228219190016, 1.2768236138244693`}, {
        0.3780885008293252, 1.274259891422395}, {0.37014605774151443`, 
        1.2717674822571574`}, {0.36239549265556914`, 1.2693463863287564`}, {
        0.35483680557148944`, 1.2669966036371916`}, {0.35478094093962953`, 
        1.2669792171822913`}}]}, 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{0.35349760436914845`, 1.2665798111061837`}, {
        0.34724701241746603`, 1.2646344723211789`}, {0.33957252254952486`, 
        1.262240337509922}, {0.3320674261094191, 1.2599102096891535`}, {
        0.3249858132389018, 1.2577400993446062`}, {0.3180861236505982, 
        1.2556386276952491`}, {0.3111100905846291, 1.2535082403537823`}, {
        0.30428674447399096`, 1.2514356843965353`}, {0.30210869245837607`, 
        1.2507837940977042`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.3008210754282966, 1.2503984107163613`}, {
        0.29784511575168005`, 1.2495077068998361`}, {0.2900032186570092, 
        1.2471751631536638`}, {0.28205696754002907`, 1.244803457434108}, {
        0.27431942446766744`, 1.2425100756613192`}, {0.26710365150685195`, 
        1.240412503755447}, {0.26054809491417635`, 1.2385581689791625`}, {
        0.2544046299004947, 1.236852843147541}, {0.24919021141931463`, 
        1.2354174830638482`}}]}, 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{0.2478945170748028, 1.2350601966069463`}, {
        0.24236495482052772`, 1.2335315968510958`}, {0.23644184162315085`, 
        1.2319049345940885`}, {0.23089238696035125`, 1.2304119358643377`}, {
        0.22549239571138271`, 1.2289724025454904`}, {0.22001767275549863`, 
        1.227506136521192}, {0.21449792173407112`, 1.2260233139741046`}, {
        0.2091123097023032, 1.2245875764977947`}, {0.20386083666019475`, 
        1.2231989240922618`}, {0.19874350260774584`, 1.2218573567575066`}, {
        0.1959664888627425, 1.2211394302020162`}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{0.19466521799816275`, 1.2208030195842263`}, {
        0.18891125147182677`, 1.219315477300328}, {0.17961555629454584`, 
        1.2169619381262586`}, {0.1708000865827638, 1.2147720015579064`}, {
        0.16240851184334132`, 1.21272092991788}, {0.15444083207627848`, 
        1.210808723206179}, {0.1468970472815752, 1.2090353814228034`}, {
        0.14244928470360685`, 1.208009185911232}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.14113963784859032`, 1.2077070219128616`}, {
        0.13973489807327807`, 1.2073829179106623`}, {0.13291212506543354`, 
        1.2058333460126645`}, {0.1264287282580417, 1.20438666572881}, {
        0.12028470765110245`, 1.2030428770590988`}, {0.11401898421336637`, 
        1.2017043119793251`}, {0.10811808967758645`, 1.200474723256164}, {
        0.10255435112806666`, 1.1993427811321213`}, {0.09730009564911085, 
        1.198297155849704}, {0.08854090416282466, 1.1966000303241942`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.08722111450694264, 1.1963458098133308`}, {
        0.07882444612500634, 1.1947512279864165`}, {0.07086210602129941, 
        1.1932663674954926`}, {0.06371792467108234, 1.1919761082390248`}, {
        0.057288874785694485`, 1.1908453345163221`}, {0.05147192907647519, 
        1.189838930626694}, {0.04151256741991842, 1.1881742035960032`}, {
        0.0342720590332022, 1.1870492912017772`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.65, 1.2800830301115982`}, {0.6487681419475108, 
        1.2797938451292143`}, {0.6429914172918885, 1.2784412032239343`}, {
        0.6372689046269173, 1.2771047616334057`}, {0.6316006039525973, 
        1.275784520357629}, {0.6259865152689286, 1.2744804793966042`}, {
        0.620426638575911, 1.2731926387503314`}, {0.6149209738735445, 
        1.27192099841881}, {0.6094695211618291, 1.2706655584020408`}, {
        0.6040722804407651, 1.2694263187000234`}, {0.5976243371839198, 
        1.2679526593552144`}}]}, 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{0.5963140689679173, 1.267653201229762}, {0.5934404349705904,
         1.266996440240244}, {0.5830254374630204, 1.264631363039472}, {
        0.572827287918055, 1.2623310870977076`}, {0.5625916712706037, 
        1.260018083537494}, {0.5522587939006268, 1.257674994478645}, {
        0.5438776864633343, 1.2557877672313171`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.5425664649666245, 1.2554925111503772`}, {
        0.5421204379757011, 1.2553920764170663`}, {0.5324683856634032, 
        1.2532595858486641`}, {0.5230248351131542, 1.2511912649672317`}, {
        0.5134933440517117, 1.2490955243802968`}, {0.5041377340126564, 
        1.2470546232043669`}, {0.49522182652956925`, 1.245150820555949}, {
        0.49003051897774347`, 1.2440780256510704`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.48871427746854057`, 1.243806021503644}, {
        0.48568704064544055`, 1.2431804364834422`}, {0.4766352886935482, 
        1.241357302903791}, {0.4677767503145504, 1.239593069521282}, {
        0.45882160514910536`, 1.2377993860402017`}, {0.45003217961746017`, 
        1.2360558585790842`}, {0.4416865109622018, 1.234447089929137}, {
        0.4359771675512817, 1.233360278145122}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.43465682364710906`, 1.2331089418336187`}, {
        0.4335183450574982, 1.2328922248036585`}, {0.4252614277775171, 
        1.2313104079159451`}, {0.41695230736244776`, 1.2297124615472792`}, {
        0.4088050348030341, 1.22816311150341}, {0.4008196100992759, 
        1.226662357784337}, {0.3929960332511734, 1.2252102003900607`}, {
        0.3853343042587264, 1.223806639320581}, {0.3818213720091261, 
        1.2231719760156763`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.380498731229407, 1.2229330213451004`}, {
        0.37783442312193505`, 1.2224516745758978`}, {0.3704963898407992, 
        1.221145306156011}, {0.363320204415319, 1.2198875340609208`}, {
        0.3562917632373595, 1.2186727156446144`}, {0.3493969626987861, 
        1.21749520826108}, {0.3426358027995987, 1.2163550119103166`}, {
        0.3360082835397974, 1.2152521265923248`}, {0.32951440491938205`, 
        1.2141865523071047`}, {0.32750806002252, 1.2138621853989269`}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{0.3261812352169314, 1.2136476768861804`}, {
        0.32315416693835275`, 1.213158289054656}, {0.31692756959670937`, 
        1.2121673368349786`}, {0.31083461289445213`, 1.2112136956480728`}, {
        0.3048643012362016, 1.210292828286449}, {0.29900563902657884`, 
        1.2094001975426174`}, {0.29325862626558363`, 1.2085358034165785`}, {
        0.28762326295321594`, 1.2076996459083316`}, {0.2820995490894759, 
        1.2068917250178774`}, {0.2766874846743635, 1.2061120407452155`}, {
        0.2730267671560629, 1.2055930554182814`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.2716960212422398, 1.2054043936054812`}, {
        0.2713870697078787, 1.2053605930903457`}, {0.26619830419002144`, 
        1.2046373820532683`}, {0.2603421703639209, 1.2038367331948039`}, {
        0.2546290754753474, 1.2030717679996983`}, {0.24905459425438242`, 
        1.2023407111292004`}, {0.24361430143110727`, 1.2016417872445604`}, {
        0.2331185798979516, 1.200333237077848}, {0.22310650871653107`, 
        1.1991319147895547`}, {0.21836983527187126`, 1.1985830086102425`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.21703471732756016`, 1.1984282893756772`}, {
        0.21354268572749643`, 1.1980236176696744`}, {0.2043917087714982, 
        1.1969941430082005`}, {0.1956181756891871, 1.1960292880951258`}, {
        0.18718668432121385`, 1.1951148502204454`}, {0.17910008317202158`, 
        1.1942549386451926`}, {0.17137299018106664`, 1.193459297083031}, {
        0.16398765734151924`, 1.192722174502895}, {0.16358108316541048`, 
        1.1926827709788885`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.16224329837440207`, 1.1925531182900908`}, {
        0.15692633664654973`, 1.1920378198737205`}, {0.15017128008932845`, 
        1.1914004821644437`}, {0.14370473966302566`, 1.1908044103439996`}, {
        0.13750896736081167`, 1.1902438533813238`}, {0.13156621517585673`, 
        1.1897130602453518`}, {0.1258735479273113, 1.189213942515169}, {
        0.120432588226935, 1.1887507694960604`}, {0.11523242475681206`, 
        1.188321326746261}, {0.11026214619902666`, 1.1879233998240064`}, {
        0.10869217490585159`, 1.1878034437661298`}}]}, 
      {Arrowheads[{{0.002381989211651697, 1.}}], 
       ArrowBox[{{0.1073520282589078, 1.187701047811858}, {
        0.10096759854880522`, 1.187213235695073}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999973`, 1.}}], 
       ArrowBox[{{0.08525877247599851, 1.3}, {0.08344809298027434, 
        1.2974761341813619`}, {0.07918866975571583, 1.2915328996405582`}, {
        0.0751580493130558, 1.2859024688201495`}, {0.07135623165229424, 
        1.280584841720136}, {0.06778321677343116, 1.2755800183405182`}, {
        0.06443900467646656, 1.2708879986812953`}, {0.06048389103948999, 
        1.2653331429946517`}, {0.056771037104997, 1.2601198845826176`}, {
        0.054014146495071004`, 1.256249187074211}}]}, 
      {Arrowheads[{{0.02000000000000003, 1.}}], 
       ArrowBox[{{0.05323436622090634, 1.2551544630605058`}, {
        0.0500721083434617, 1.2507181595823773`}, {0.045760444858928245`, 
        1.2446919172177755`}, {0.04185009563457488, 1.2392372568978753`}, {
        0.03826162487985768, 1.2342452085498818`}, {0.03502151119162462, 
        1.2297520955313936`}, {0.028776655438308905`, 1.221106536773343}, {
        0.023699257064262312`, 1.2141401832321543`}, {0.02179046699477504, 
        1.2115471333420993`}}]}, 
      {Arrowheads[{{0.006144321638587479, 1.}}], 
       ArrowBox[{{0.020993684396237385`, 1.2104647214715836`}, {
        0.01957436191169863, 1.2085366026745938`}, {0.016187015822831663`, 
        1.2039793628674285`}, {0.011105385601067694`, 1.197235425746212}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.18155480587616762`, 1.3}, {0.18083094573980774`, 
        1.2994967525893075`}, {0.17363889826215262`, 1.294499971578027}, {
        0.1667698102981194, 1.2897310484321332`}, {0.1602236818477081, 
        1.285189983151627}, {0.15400051291091868`, 1.2808767757365074`}, {
        0.14942654937041747`, 1.2777046518814008`}, {0.14478300149009518`, 
        1.2744820043529117`}, {0.13737824693606293`, 1.269360237155914}}]}, 
      {Arrowheads[{{0.019999999999999987`, 1.}}], 
       ArrowBox[{{0.13627285583846335`, 1.2685956532899363`}, {
        0.13612216478784, 1.2684914223563744`}, {0.12805953910931764`, 
        1.2629340892267193`}, {0.12047051553903453`, 1.2577228265244729`}, {
        0.11495338150060097`, 1.2539784689708693`}, {0.10971340657159753`, 
        1.2504358918265108`}, {0.10471266718239597`, 1.2470680112015546`}, {
        0.0999638045228724, 1.2438838550592823`}, {0.09520231864552939, 
        1.2406906218456757`}, {0.09178588256398054, 1.2384096635011175`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.0906680667896874, 1.23766336204627}, {0.0906674630622255, 
        1.2376629589720842`}, {0.08635923777296076, 1.2348008664385084`}, {
        0.08227764277773511, 1.2321043442449473`}, {0.07470209514574261, 
        1.2271374982698224`}, {0.06784857164258946, 1.2226919084386614`}, {
        0.06164703981349656, 1.2187134284821943`}, {0.05602746720368485, 
        1.2151479121311513`}, {0.049429055813046616`, 1.211025585079367}, {
        0.045452107484207735`, 1.208585224693655}}]}, 
      {Arrowheads[{{0.010203138649156432`, 1.}}], 
       ArrowBox[{{0.044306535621355364`, 1.207882271584403}, {
        0.04369688142554117, 1.2075081716903564`}, {0.03866681985542632, 
        1.2044689711567398`}, {0.03417474691695983, 1.2017812826711354`}, {
        0.026628212394504296`, 1.1973338444785364`}, {0.020704568777239155`, 
        1.1939126623817027`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.003770721836543486, 1.}}], 
       ArrowBox[{{0.26010058770420624`, 1.1124451433983966`}, {
        0.2600930114911568, 1.1126478520378726`}, {0.26008543105650644`, 
        1.113014333658617}, {0.25991424710602223`, 1.1153195176670647`}, {
        0.2597429840109923, 1.116206490294635}, {0.25957171050927025`, 
        1.1168764832914733`}, {0.2588529824102341, 1.118946700408047}, {
        0.2581351352404082, 1.1204028149564988`}, {0.25741843677729875`, 
        1.121592736360896}, {0.25727524640265254`, 1.1218084513980107`}, {
        0.25716430985006533`, 1.121971709986986}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.012744792955678604`, 1.}}], 
       ArrowBox[{{0.65, 1.2347081687819526`}, {0.6483202379172184, 
        1.2343959639882536`}, {0.6428356021156727, 1.2333733990145874`}, {
        0.6373627987188202, 1.2323546216451517`}, {0.6265946779955148, 
        1.2303738809697375`}, {0.6162998534599415, 1.2285446444635415`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{0.6341609760478282, 1.2326377328803941`}, {
        0.6286207133730093, 1.2316149030694927`}, {0.6179605719328232, 
        1.2297034608391757`}, {0.6075184770354132, 1.2278610412829132`}, {
        0.5969839535813759, 1.225988715893968}, {0.5866342872405931, 
        1.2241762021703881`}, {0.5812224111998208, 1.2232659776591779`}}]}, 
      {Arrowheads[{{0.0011883672435828434`, 1.}}], 
       ArrowBox[{{0.5798969745882406, 1.223043052210992}, {0.5767467636829461,
         1.2225132176102218`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{0.6010267209049294, 1.2275364432719036`}, {
        0.5902618441230145, 1.2256248933263578`}, {0.579996062645513, 
        1.2238746839571242`}, {0.5699439756880665, 1.222193703059879}, {
        0.5598014406019305, 1.2204835822083464`}, {0.5498398017731736, 
        1.2188317412653884`}, {0.5480225601579849, 1.2185439183809215`}}]}, 
      {Arrowheads[{{0.0023972225818886745`, 1.}}], 
       ArrowBox[{{0.5466950548744409, 1.218333662135048}, {0.5403304035878648,
         1.2173256000938657`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.010378453631682997`, 1.}}], 
       ArrowBox[{{0.03076276250496069, 1.3}, {0.030531993196902394`, 
        1.2991416627197923`}, {0.02860710810539976, 1.2919664598343128`}, {
        0.026804643874473927`, 1.2852253825533013`}, {0.025134225917988043`, 
        1.278949321307759}, {0.02356697799435265, 1.273045604804682}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.013223931668013935`, 1.}}], 
       ArrowBox[{{0.05600369955220734, 1.3}, {0.055385055611909775`, 
        1.2987145007801317`}, {0.05260416987057489, 1.2929093187958272`}, {
        0.049314752303309076`, 1.2860317212693364`}, {0.0462325469739044, 
        1.2795743866198461`}, {0.043373664344594, 1.2735673108458008`}, {
        0.0406897730286785, 1.2679205059518666`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{0.5652611998722252, 1.2227064487490567`}, {
        0.5548743678017869, 1.2209421325146954`}, {0.5449773333327135, 
        1.2193357527612778`}, {0.5352901242898064, 1.2177979028954047`}, {
        0.525514226650373, 1.2162320359301202`}, {0.5159157062039921, 
        1.2147222031636582`}, {0.5121828745247075, 1.2141637113300177`}}]}, 
      {Arrowheads[{{0.0015395769788992327`, 1.}}], 
       ArrowBox[{{0.5108536170755988, 1.2139648329733392`}, {
        0.5067606287402429, 1.2133524558942526`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{0.5322956078014722, 1.2179943714207737`}, {
        0.522259907981139, 1.2163775409678672`}, {0.5127056738669151, 
        1.2149140261484477`}, {0.5033577993840161, 1.2135177981870957`}, {
        0.4939228139924827, 1.2120948808354945`}, {0.48466205041821825`, 
        1.2107253422643915`}, {0.47913936332555834`, 1.209951814157547}}]}, 
      {Arrowheads[{{0.0007405609179953335, 1.}}], 
       ArrowBox[{{0.4778083033628727, 1.2097653809456417`}, {
        0.4758368413871262, 1.2094892506445347`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0001258331056264037, 1.}}], 
       ArrowBox[{{0.4653286395167748, 1.148314451227031}, {
        0.46517268142304247`, 1.1486146044347978`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.5019877611726489, 1.2142511347277734`}, {
        0.49228114578024407`, 1.2127649812726546`}, {0.48304851457035436`, 
        1.2114261755086804`}, {0.4740191372581304, 1.210152691164559}, {
        0.4649040699258433, 1.2088539921778052`}, {0.45596038263368255`, 
        1.2076057224763164`}, {0.4487656394989116, 1.206657549771511}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.00013796610180665054`, 1.}}], 
       ArrowBox[{{0.49264761036215393`, 1.151373450785461}, {
        0.492503738496281, 1.1517152746512034`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0001481451586126328, 1.}}], 
       ArrowBox[{{0.5178105873109381, 1.154375849022195}, {0.5176675082909888,
         1.1547474878189223`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.007081579767744854, 1.}}], 
       ArrowBox[{{0.01985371987750053, 1.26628317723425}, {
        0.017481743202474875`, 1.256424857067565}, {0.015409227552714597`, 
        1.2477732608319518`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.00632735639864909, 1.}}], 
       ArrowBox[{{0.4382399195820783, 1.2060401811870436`}, {
        0.42959344336801575`, 1.2049017035708856`}, {0.42136896071573077`, 
        1.203881660407433}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0027461697487641164`, 1.}}], 
       ArrowBox[{{0.18254489406423033`, 1.094067345364296}, {
        0.18248568917212274`, 1.0950694537016883`}, {0.1824263997835756, 
        1.0968623498324788`}, {0.18236710614759213`, 1.0978705822082153`}, {
        0.18225882636656965`, 1.0991846989750529`}, {0.18215051109528643`, 
        1.0999949435922989`}, {0.18204218885627205`, 1.1006417808351265`}, {
        0.1819988607695555, 1.1008718445400343`}, {0.18195553417492336`, 
        1.101090128824331}, {0.1818883818699187, 1.1014089025007254`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.006049522562939391, 1.}}], 
       ArrowBox[{{0.13367791774025334`, 1.0834294914729679`}, {
        0.13363629058835677`, 1.0831717842246236`}, {0.1334718419262941, 
        1.087389365247302}, {0.13330730030281548`, 1.0887457779679504`}, {
        0.13314277774539968`, 1.0897710428596432`}, {0.13251692879338814`, 
        1.0926969136061742`}, {0.13189260474805015`, 1.0948181384101423`}, {
        0.13127012513949093`, 1.0965777426040302`}, {0.13102168600230107`, 
        1.09721294364667}, {0.13077357691260977`, 1.097818776510292}, {
        0.13047629013449555`, 1.098512110970912}, {0.13038967174873667`, 
        1.0987081932114722`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.01750041681985122, 1.}}], 
       ArrowBox[{{0.11577391565776926`, 1.0790721391250107`}, {
        0.11575799277946257`, 1.0795782815830581`}, {0.11565598270128959`, 
        1.0815860834234379`}, {0.11421395665493705`, 1.0902947540362204`}, {
        0.11278254476579068`, 1.094502343949069}, {0.11136413665046445`, 
        1.0977562731358956`}, {0.10856997835056317`, 1.1031284214369768`}, {
        0.10583428428946011`, 1.1075064900641907`}, {0.1005406771317595, 
        1.114444672430288}, {0.09795353191576288, 1.1175018260061054`}, {
        0.09542606382536942, 1.12027897207496}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.009279869317653369, 1.}}], 
       ArrowBox[{{0.08956446924904903, 1.1204503700963815`}, {
        0.0847627332565556, 1.1256886970192026`}, {0.08018852682745366, 
        1.1303343026515111`}, {0.0758508396343551, 1.1342702623272074`}, {
        0.07172270265942407, 1.13784735004459}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.007490791681558382, 1.}}], 
       ArrowBox[{{0.16140418306218166`, 1.0899230597757126`}, {
        0.16138114799804873`, 1.0907584758180473`}, {0.1613580897947145, 
        1.0921103501311022`}, {0.16128843909874757`, 1.0935417451146408`}, {
        0.16121875611073772`, 1.094283961083421}, {0.16114906095449744`, 
        1.0948621494913853`}, {0.160956496816358, 1.0961178221408983`}, {
        0.16076396857887335`, 1.0970901569667453`}, {0.16057150831948433`, 
        1.0979116617557048`}, {0.1598026793575319, 1.1005006603895229`}, {
        0.15675130473379673`, 1.1072396640176259`}, {0.1564484435146043, 
        1.107727885774613}, {0.15614603637793242`, 1.1082010875560706`}, {
        0.1557837521257715, 1.1087508199724303`}, {0.1556782078622103, 
        1.1089077443651683`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.005962736304746695, 1.}}], 
       ArrowBox[{{0.14736554205443736`, 1.0855398878650124`}, {
        0.14735449934985964`, 1.0860330963984355`}, {0.14730984721316837`, 
        1.087533150847299}, {0.1472652032315298, 1.087893744710969}, {
        0.14722050412750265`, 1.0892780590102198`}, {0.14655446706964903`, 
        1.0945150372026504`}, {0.14588942111546738`, 1.0969870193278077`}, {
        0.14522608108711124`, 1.0988993393372841`}, {0.14496127986209867`, 
        1.0995720365895545`}, {0.14469680429697157`, 1.1002078366010306`}, {
        0.14437987481665585`, 1.1009295468350957`}, {0.1442875270672367, 
        1.1011326405525408`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.007672226330464041, 1.}}], 
       ArrowBox[{{0.14731043592168547`, 1.1099021735244239`}, {
        0.14363862174907155`, 1.1145077002151582`}, {0.14004512942844966`, 
        1.1183137198531434`}, {0.1364907980338237, 1.121719985964754}, {
        0.13301618786564032`, 1.1246981256921609`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0061654407362974955`, 1.}}], 
       ArrowBox[{{0.12577980232929192`, 1.1244169556663552`}, {
        0.1191285057995781, 1.129917448498495}, {0.112785805822441, 
        1.1346976419312538`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.427610044909656, 1.2053174154331834`}, {
        0.4171787960309421, 1.2039601845257326`}, {0.4069894031368266, 
        1.2026680502657991`}, {0.3974046502042071, 1.2015386576246594`}, {
        0.3888582333231503, 1.200629008574235}, {0.38077439839247096`, 
        1.199824414541372}, {0.374202541388884, 1.1991899494397975`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.3728647103362041, 1.1990607751058238`}, {
        0.36488427770133885`, 1.1982782594861814`}, {0.35705207263983224`, 
        1.197525393142589}, {0.34964542195576914`, 1.1968614313576071`}, {
        0.34240899302268346`, 1.1962330313960694`}, {0.335087453214109, 
        1.195586850522809}, {0.32771603078209194`, 1.1949283820426992`}, {
        0.3205001757296556, 1.1942986810840555`}, {0.3193233952618561, 
        1.1941985199059157`}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{0.3179841846442881, 1.194084533553403}, {0.3134398880568001,
         1.1936977476468782`}, {0.3065351677635254, 1.1931255817311668`}, {
        0.2997860148498315, 1.192582183336922}, {0.2931924293157184, 
        1.1920675524641433`}, {0.28675441116118605`, 1.191581689112831}, {
        0.2804719603862345, 1.1911245932829846`}, {0.2743311544676015, 
        1.190690990335583}, {0.2683180708820246, 1.190275605631604}, {
        0.26437755837861315`, 1.1900096849282507`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.26303655560056116`, 1.1899191889834644`}, {
        0.2624327096295038, 1.1898784391710475`}, {0.25667507071003925`, 
        1.189499490953914}, {0.25104515412363093`, 1.1891387609802033`}, {
        0.24554295987027874`, 1.1887962492499153`}, {0.2401684879499827, 
        1.1884719557630496`}, {0.2349217383627428, 1.188165880519607}, {
        0.22476773001755526`, 1.1875956346340961`}, {0.21503725866483994`, 
        1.187072761464489}, {0.20936659810153566`, 1.1867830418246723`}}]}, 
      {Arrowheads[{{0.007725607928959466, 1.}}], 
       ArrowBox[{{0.20802429604385791`, 1.1867144622889492`}, {
        0.20573032430459678`, 1.186597261010786}, {0.1968469269368257, 
        1.1861691332729865`}, {0.18727989848016874`, 1.1857415584856534`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0002492328214083578, 1.}}], 
       ArrowBox[{{0.5412774082381514, 1.1566790489776295`}, {
        0.5411557911455457, 1.1573378822227964`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.010262021306164913`, 1.}}], 
       ArrowBox[{{0.5768003564303803, 1.1595184006067059`}, {
        0.5764299199360311, 1.1591374085675854`}, {0.5749516196244935, 
        1.1579737470076732`}, {0.569086973259312, 1.1548253401752369`}, {
        0.5661735234603233, 1.1535746454820939`}, {0.5632781120929146, 
        1.1524414852887752`}, {0.5574892035923611, 1.1502865652192527`}, {
        0.5517687848370371, 1.1482878476134615`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0058591293911510285`, 1.}}], 
       ArrowBox[{{0.65, 1.2204413558543539`}, {0.6449566006522027, 
        1.2195751019190741`}, {0.6344661210032279, 1.2178418165181302`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.005062345411818065, 1.}}], 
       ArrowBox[{{0.65, 1.2572257665949311`}, {0.6471415826394087, 
        1.256619965454844}, {0.6366807925852338, 1.2544366224473076`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.007966809236133392, 1.}}], 
       ArrowBox[{{0.6369458350259383, 1.2550180712439252`}, {
        0.6262255607458824, 1.252764775023163}, {0.6159796363738984, 
        1.2506539374169605`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.6053504480374405, 1.2494435003229152`}, {
        0.5947188483756635, 1.2472789157697133`}, {0.5839882297054357, 
        1.2450838351285565`}, {0.5734556490521096, 1.2429497466633097`}, {
        0.5634181634410376, 1.2409681386378386`}, {0.5535927364281419, 
        1.2390515857497024`}, {0.5526397569930492, 1.2388647074986283`}}]}, 
      {Arrowheads[{{0.010102592134820199`, 1.}}], 
       ArrowBox[{{0.5513208245925479, 1.2386060662612475`}, {
        0.5436776374609782, 1.2371072454145606`}, {0.5339418824023503, 
        1.2352184799734296`}, {0.5246544871150612, 1.2334686517673257`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.007927942412076134, 1.}}], 
       ArrowBox[{{0.6369487119269653, 1.210301431666518}, {0.6261822896089151,
         1.2085971562542617`}, {0.6158841581538645, 1.207070550461415}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.005114612734706053, 1.}}], 
       ArrowBox[{{0.09871348388321591, 1.072725418637225}, {
        0.09815716855107923, 1.0663000841074346`}, {0.09788042891294231, 
        1.064753327914294}, {0.0976048621710202, 1.06349409689836}, {
        0.09702296378708292, 1.0612012553871315`}, {0.09644523566473343, 
        1.0592100022468844`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0049699011299932086`, 1.}}], 
       ArrowBox[{{0.0856775724600557, 1.0585486977491863`}, {
        0.08515229256431772, 1.056472205067968}, {0.08306963935038715, 
        1.050137498203765}, {0.08104895319620732, 1.0460614443222542`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.006020465034459933, 1.}}], 
       ArrowBox[{{0.09115814618839711, 1.0774974834934392`}, {
        0.09087925348063874, 1.0793562403294363`}, {0.09060076795736252, 
        1.0808650989916904`}, {0.09004423537429382, 1.083629820351383}, {
        0.08948973800254983, 1.0858336887291387`}, {0.08727977751403751, 
        1.0931857286788365`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.006069336805779467, 1.}}], 
       ArrowBox[{{0.06048320025966358, 1.0577852211511982`}, {
        0.0602985038636436, 1.0538712522908804`}, {0.06020643759953624, 
        1.0528087364740177`}, {0.06011460334504444, 1.051937575104096}, {
        0.0597482301386187, 1.049053940851609}, {0.058296406301992974`, 
        1.0416475009050128`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.013037445519324871`, 1.}}], 
       ArrowBox[{{0.0307321116153167, 1.044239864708557}, {
        0.03073058987164106, 1.044034766452066}, {0.030725259658375994`, 
        1.0434018850237183`}, {0.03063164293215466, 1.0472902109595719`}, {
        0.030538155540596242`, 1.0497498624362434`}, {0.030305138359337003`, 
        1.053180047851367}, {0.029566638731621398`, 1.0616791902794445`}, {
        0.028841577411711092`, 1.0679042805378607`}, {0.02812323524570343, 
        1.0729923447114462`}, {0.027419477874579407`, 
        1.0774189401116827`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.009482182452069233, 1.}}], 
       ArrowBox[{{0.024524439510773603`, 1.0827169001701409`}, {
        0.023243981048925017`, 1.09009010321142}, {0.022020406025822115`, 
        1.0967202156345006`}, {0.020855442172030017`, 1.1024605731352075`}, {
        0.01974390629585333, 1.1077511686260646`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.005668951798624825, 1.}}], 
       ArrowBox[{{0.015692004357081183`, 1.1157666458991444`}, {
        0.01403643060828703, 1.1237487730415616`}, {0.012545023440566171`, 
        1.130676792570075}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.009243118593387393, 1.}}], 
       ArrowBox[{{0.01000946404401214, 1.0235802708694313`}, {
        0.010002350973370943`, 1.0231270221256914`}, {0.009973990963036191, 
        1.0218808852638508`}, {0.009860975180678477, 1.0251568517637077`}, {
        0.009748568060145587, 1.032778734784567}, {0.009690619849549121, 
        1.0355648278402325`}, {0.00963286627571104, 1.0377246328602256`}, {
        0.00940265003532651, 1.045019816389841}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.007762471362993801, 1.}}], 
       ArrowBox[{{0.61549037508454, 1.2076637658091869`}, {0.6049352086359644,
         1.2060703351060746`}, {0.5948428495165009, 1.2046516758241146`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.005097891740437853, 1.}}], 
       ArrowBox[{{0.45819995715075507`, 1.1511211175121712`}, {
        0.4557176693799258, 1.1527245249116873`}, {0.44582369639012964`, 
        1.1569246318964816`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{0.27493495338359986`, 1.3}, {0.27187153951796095`, 
        1.2985066378671979`}, {0.26536327632257045`, 1.2953380966546326`}, {
        0.25925715495563156`, 1.292375908618969}, {0.25332510984757106`, 
        1.2895022973438217`}, {0.24732144939215175`, 1.286591439093131}, {
        0.24146101963144992`, 1.2837550747935274`}, {0.23595866660754128`, 
        1.2811049453716388`}, {0.22936935754403828`, 1.2779370947049353`}, {
        0.22654368977635161`, 1.276576899713172}}]}, 
      {Arrowheads[{{0.006256223599438448, 1.}}], 
       ArrowBox[{{0.22533264373326686`, 1.2759939370657452`}, {
        0.22268607241001065`, 1.2747199539384986`}, {0.21619073941703232`, 
        1.2716013933715282`}, {0.21016528677667726`, 1.2687292833032229`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0021633059221173585`, 1.}}], 
       ArrowBox[{{0.30110266696091165`, 1.1211989459846776`}, {
        0.3009681320277674, 1.1218207434685135`}, {0.30010942509401856`, 
        1.1238658158009907`}, {0.299254732181033, 1.1260374366122934`}, {
        0.2991693114044983, 1.1261979559819204`}, {0.299083903022093, 
        1.12635367444443}, {0.29895154524238216`, 1.1265864498262943`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.020000000000000014`, 1.}}], ArrowBox[CompressedData["
1:eJwBsQFO/iFib1JlAgAAABoAAAACAAAAbKPdlFf00T91xFwBg93xPx5bND9K
9NE/tlYPVofe8T8QIvIjQfTRP2s+jT7P3/E/X5DhJiP00T8Q99jw1eDxP3pL
Wm7989E/MTIetaDh8T+Lhh/r0PPRP53PFatX4vE/O3pa4Xfz0T937NfHcOPx
P5Fzgdvr8tE/Z3lZd8fk8T+AjnXQX/LRP3BgQq7a5fE/roflwdPx0T8p2qX1
x+bxPw2DNFo/8NE/u/WkwgHp8T+yFqToqu7RP4RP5EjN6vE/YDAtdRbt0T+/
yP7jWezxP8bVqGFj6NE/Jr4TiCzw8T/md1CisOPRP5LRLjY98/E/kFfiYP7e
0T/mFBvq3/XxP1Mp0/wM0dE/oF5vJVf88T+pYrb6IcPRP/KXrYJ9AfI/Ljws
MD610T/lMlcB5QXyP8YOQV7Fi9E/HgVvA7MQ8j/iDsS9l2LRP0uzkr4vGfI/
8a76Rrk50T84LDkVXSDyP+yeELJPwdA/3d+d3KEx8j8Q6ahgzkvQPyaSIYbX
PvI/tjCTH3ayzz/B5OEZwknyPxa84BjSlc4/xKYpKZ5V8j+MjuVZ
        "]]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.23766915695003069`, 1.1463184085878835`}, {
        0.22853402079519344`, 1.148961796092328}, {0.21951208659361532`, 
        1.1512691774460704`}, {0.2108304181762823, 1.1532992408901777`}, {
        0.20247850987101149`, 1.1551012834779235`}, {0.19444585600561995`, 
        1.1567246022625808`}, {0.18532518763034125`, 1.15846315234851}}]}, 
      {Arrowheads[{{0.01766794317006245, 1.}}], 
       ArrowBox[{{0.1840032435153466, 1.1587058818866591`}, {
        0.17603301765132923`, 1.1601530990619915`}, {0.16746339712207975`, 
        1.1616240215005291`}, {0.15931830902476082`, 1.1629327266316218`}, {
        0.15156260705000116`, 1.1641176696909237`}, {0.1441611448884294, 
        1.1652173059140893`}, {0.1371139225400455, 1.1662316353011184`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0007862224611420192, 1.}}], 
       ArrowBox[{{0.3329802712610791, 1.1262701187543283`}, {
        0.3329611613004789, 1.126474697553598}, {0.3329396390756064, 
        1.126887590499746}, {0.33291811242136743`, 1.1271257449801624`}, {
        0.33289658307826925`, 1.1273134152504112`}, {0.3328425779931025, 
        1.1276884821512474`}, {0.33278856570160426`, 1.1279840843180016`}, {
        0.3327048387051568, 1.128361988708676}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.00039152031015237727`, 1.}}], 
       ArrowBox[{{0.3607082230641867, 1.1318640234464177`}, {
        0.360647356956739, 1.1322330978275872`}, {0.3605864835076581, 
        1.1325231590271037`}, {0.3604921221589508, 1.132893329735706}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.00045891001059700394`, 1.}}], 
       ArrowBox[{{0.3469238650471015, 1.1282563617913048`}, {
        0.3468944048599012, 1.1285257556661903`}, {0.3468649539954809, 
        1.1289305101117786`}, {0.34681930681020745`, 1.129485409926319}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0006047511201732787, 1.}}], 
       ArrowBox[{{0.3839336751139295, 1.1342083933443707`}, {
        0.38391537845414303`, 1.134407609133825}, {0.38386619650764753`, 
        1.1349077740827416`}, {0.38381701882816804`, 1.1353872081305598`}, {
        0.3837407757345389, 1.135821622058771}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.012418972148842094`, 1.}}], 
       ArrowBox[{{0.32328834244244714`, 1.1309761887693677`}, {
        0.32168034207998714`, 1.1329873592001058`}, {0.3200778334385995, 
        1.1345244805995025`}, {0.31634213221167856`, 1.137330371031419}, {
        0.31264205874154966`, 1.139482600589518}, {0.30897877483391384`, 
        1.141264646585074}, {0.30168923887076987`, 1.1445326531394637`}, {
        0.2945518037998797, 1.14706425058024}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.012861637478271754`, 1.}}], 
       ArrowBox[{{0.65, 1.1070355850895621`}, {0.6477942166923063, 
        1.1069268921939905`}, {0.6411011914889193, 1.1065950735162624`}, {
        0.6344737313772472, 1.106258441680145}, {0.627961010176076, 
        1.1059133868168467`}, {0.6216122017041916, 1.1055562990575756`}, {
        0.6154764797803803, 1.10518356853354}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.01268799949011834, 1.}}], 
       ArrowBox[{{0.65, 1.0861419387826132`}, {0.6478762529677583, 
        1.0860723770795673`}, {0.6412616809278777, 1.0858544972233066`}, {
        0.6347106196621545, 1.0856337990978675`}, {0.628270702251206, 
        1.0854081690013662`}, {0.6219895617756503, 1.0851754932319184`}, {
        0.6159148313161052, 1.084933658087641}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.012211962968176247`, 1.}}], 
       ArrowBox[{{0.65, 1.0268222476641562`}, {0.6480679105639132, 
        1.0268222610269753`}, {0.6416852980191645, 1.0268221902442067`}, {
        0.6353608630628559, 1.0268216593529438`}, {0.6291382388863174, 
        1.0268203232718152`}, {0.6230610586808789, 1.0268178369194505`}, {
        0.6171729556378709, 1.0268138552144785`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999987`, 1.}}], 
       ArrowBox[{{0.6459076521806812, 1.0263939498529977`}, {
        0.6394783228093354, 1.026394109575581}, {0.6332023287043497, 
        1.0263931167899878`}, {0.6271256704456324, 1.0263906257437654`}, {
        0.6211146513315194, 1.0263876924939968`}, {0.615033114638598, 
        1.0263853623550654`}, {0.608923370914153, 1.0263832734604685`}, {
        0.6028277307054699, 1.0263810639437045`}, {0.5967885045598336, 
        1.0263783719382709`}, {0.5921455435548826, 1.0263756079991835`}}]}, 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{0.5908014909863653, 1.026374797541895}, {0.5850485366468413,
         1.0263700929953852`}, {0.5794324159740558, 1.0263637823249288`}, {
        0.5684852308212632, 1.026345619720574}, {0.5580468532778341, 
        1.0263226545322701`}, {0.5478119987781503, 1.0262977683103864`}, {
        0.5374753827565939, 1.0262738426052926`}, {0.5370394835990588, 
        1.0262727268868388`}}]}, 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{0.5356954351878026, 1.0262692866883674`}, {
        0.5273188772441263, 1.0262478462241758`}, {0.5176377328629409, 
        1.02621683348419}, {0.5081467329342688, 1.0261838142006567`}, {
        0.4985606607793402, 1.0261517981888972`}, {0.4889204625400144, 
        1.0261201720046298`}, {0.4819336072342754, 1.0260951753293177`}}]}, 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{0.4805895630219738, 1.0260903667802195`}, {
        0.4794572288106641, 1.026086315660025}, {0.47017095959128896`, 
        1.026050229155083}, {0.4610616548818891, 1.0260119124898037`}, {
        0.45212931468246476`, 1.0259713656641871`}, {0.4433739389930157, 
        1.0259285886782334`}, {0.4347955278135419, 1.0258835815319423`}, {
        0.4268280489391037, 1.025838784218164}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{0.4254840194233156, 1.025830874225476}, {0.4181565193161246,
         1.0257868316913399`}, {0.41006976266138917`, 1.025734998863011}, {
        0.4021338111798374, 1.025680845740327}, {0.394348664871469, 
        1.0256243723232878`}, {0.38671432373628434`, 1.0255655786118945`}, {
        0.3792307877742832, 1.025504464606146}, {0.37189805698546563`, 
        1.0254410303060426`}, {0.37172335254757494`, 1.0254394307880195`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.3703793560622579, 1.025427125739405}, {
        0.36471613136983155`, 1.0253752757115844`}, {0.35767404626289484`, 
        1.025307182801579}, {0.35076083700016936`, 1.025236733554834}, {
        0.34397650358165494`, 1.0251639279713491`}, {0.3373210460073517, 
        1.025088766051125}, {0.33079446427725967`, 1.0250112477941609`}, {
        0.3243967583913787, 1.0249313732004575`}, {0.31812792834970893`, 
        1.0248491422700141`}, {0.31662062531554724`, 1.024828376863567}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.3152767000291865, 1.02480986223567}, {
        0.31198797415225027`, 1.0247645550028313`}, {0.3042455555172918, 
        1.0246518997614493`}, {0.296709134267412, 1.0245355018242037`}, {
        0.2893724576643474, 1.0244153735146133`}, {0.28222927296983485`, 
        1.0242915271561965`}, {0.27527332744561117`, 1.0241639750724711`}, {
        0.26849836835341306`, 1.0240327295869562`}, {0.26189814295497726`, 
        1.02389780302317}, {0.2615225815106399, 1.0238897101863866`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.2601788406392598, 1.023860754403744}, {
        0.25546639851204045`, 1.0237592077046307`}, {0.24919688228633957`, 
        1.0236169559548571`}, {0.24308334153961136`, 1.0234710600973673`}, {
        0.2371195235335924, 1.0233215324556797`}, {0.23129917553001955`, 
        1.0231683853533131`}, {0.22561604479062963`, 1.0230116311137856`}, {
        0.2200638785771592, 1.0228512820606155`}, {0.21463642415134523`, 
        1.0226873505173213`}, {0.20932742877492438`, 1.0225198488074219`}, {
        0.20643629415775916`, 1.0224225759252168`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.20509300143331705`, 1.022377380535775}, {
        0.19908879676846272`, 1.0221753677032932`}, {0.18936202783407685`, 
        1.0218194850182252`}, {0.18011971201239335`, 1.0214528455810177`}, {
        0.17133443934403858`, 1.0210760942204704`}, {0.16297879986963915`, 
        1.0206898757653835`}, {0.1550253836298215, 1.020294835044556}, {
        0.1513800204707505, 1.0201008841773238`}}]}, 
      {Arrowheads[{{0.008665815795201278, 1.}}], 
       ArrowBox[{{0.15003786596770513`, 1.0200294750972223`}, {
        0.14744678066521208`, 1.0198916168867882`}, {0.14021558101643744`, 
        1.0194808661208798`}, {0.13332738924915669`, 1.019063351625102}, {
        0.1267848913213467, 1.0186398804467944`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.01149771581148188, 1.}}], 
       ArrowBox[{{0.6086234283261978, 1.1037473957418518`}, {
        0.6022306815394816, 1.1033860188150815`}, {0.5959016335722795, 
        1.1030199464651085`}, {0.5896840585392269, 1.1026456571245307`}, {
        0.5836257305549594, 1.1022596292259463`}, {0.5777744237341125, 
        1.1018583412019536`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.010976415421455258`, 1.}}], 
       ArrowBox[{{0.5721197066599488, 1.1002132484510683`}, {
        0.5660161134848395, 1.099826109531001}, {0.5599743073009558, 
        1.0994345372397747`}, {0.5540406283517172, 1.099035206549021}, {
        0.5482614168805431, 1.0986247924303707`}, {0.5426830131308528, 
        1.0981999698554545`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.010477186974770252`, 1.}}], 
       ArrowBox[{{0.5382246481741603, 1.0964145959768519`}, {
        0.5323983483957758, 1.0960066578179948`}, {0.5266318881798874, 
        1.0955946599442612`}, {0.520970147198367, 1.095175557569494}, {
        0.5101403416259185, 1.09430386017223}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0100053894248368, 1.}}], 
       ArrowBox[{{0.5068767409170034, 1.0929894692683977`}, {
        0.5013130630728364, 1.0925607333736216`}, {0.49040296633922065`, 
        1.0916895424069304`}, {0.48007222681818656`, 1.0907817669678685`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.01547916076849794, 1.}}], 
       ArrowBox[{{0.4937494821012444, 1.0910457151147048`}, {
        0.4832189186850412, 1.09014503890661}, {0.47257624808813414`, 
        1.0892507899010342`}, {0.4621577918526347, 1.0883436864904203`}, {
        0.4522998715206546, 1.0874044470672115`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.014797496747716656`, 1.}}], 
       ArrowBox[{{0.4665006349568701, 1.0876215844621568`}, {
        0.45643773084985334`, 1.0866970490647152`}, {0.4462664746561602, 
        1.0857779858869532`}, {0.43631192263581964`, 1.0848479782698317`}, {
        0.4268991310488605, 1.0838906095543113`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.65, 1.1240745110178718`}, {0.6461509694954132, 
        1.1237937918784655`}, {0.6365272880166081, 1.1230620060625998`}, {
        0.6270702711280443, 1.1223124681387628`}, {0.6205573593385584, 
        1.1217979258096344`}, {0.6139580164138556, 1.1212941187662022`}, {
        0.607324101035066, 1.1207946058370486`}, {0.6007074718833196, 
        1.1202929458507556`}, {0.5963958884341608, 1.1199569423299731`}}]}, 
      {Arrowheads[{{0.020000000000000014`, 1.}}], 
       ArrowBox[{{0.5950558984416245, 1.1198525163434152`}, {
        0.5941599876397472, 1.119782697635906}, {0.5877335069854783, 
        1.1192574200210814`}, {0.5814798886016432, 1.118710671834864}, {
        0.5754509911693725, 1.118136011905837}, {0.5694965642125099, 
        1.1175513315586807`}, {0.5634633140736228, 1.1169753405121183`}, {
        0.557398534661926, 1.116402825185793}, {0.5513495198866339, 
        1.1158285719993488`}, {0.5453635636569616, 1.1152473673724301`}, {
        0.5415270075310563, 1.1148599185170889`}}]}, 
      {Arrowheads[{{0.004466017275348605, 1.}}], 
       ArrowBox[{{0.5401897565425384, 1.1147248712643438`}, {
        0.5394879598821236, 1.1146539977246805`}, {0.5337700024713347, 
        1.1140432494757442`}, {0.5282569853338095, 1.1134099090452645`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.01415532301907896, 1.}}], 
       ArrowBox[{{0.44141354212700706`, 1.0843603158144086`}, {
        0.4317914354946699, 1.0834168253374787`}, {0.42206464421989276`, 
        1.0824778592431479`}, {0.41254722222999574`, 1.081529844383619}, {
        0.4035532234522991, 1.0805592076110941`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.013552068937025175`, 1.}}], 
       ArrowBox[{{0.4183328884176047, 1.0813145527803965`}, {
        0.40912517321598085`, 1.080355170294468}, {0.39981632669383005`, 
        1.0793993863231726`}, {0.39070974281273313`, 1.078436405322611}, {
        0.38210881553427095`, 1.0774554317488836`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.006326441156216445, 1.}}], 
       ArrowBox[{{0.3754450714087626, 1.0802295730036895`}, {
        0.3667715221794004, 1.079108876569152}, {0.35858850555803023`, 
        1.0779801840585572`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.015536083885788081`, 1.}}], 
       ArrowBox[{{0.37931716981551944`, 1.0796777429210784`}, {
        0.3707457729285752, 1.0785778450052945`}, {0.3623993509146438, 
        1.0774677646844424`}, {0.35395885255406345`, 1.0763582000014327`}, {
        0.34570650688678123`, 1.0752476040427377`}, {0.33792454295274493`, 
        1.07413442989483}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999983`, 1.}}], 
       ArrowBox[{{0.23283410551326264`, 1.2798566049840228`}, {
        0.22466706469269365`, 1.2759418797459783`}, {0.2182507014419954, 
        1.2728646736399776`}, {0.21174020964776313`, 1.2697377659980356`}, {
        0.20541797494059885`, 1.2667102614279762`}, {0.19956638295110432`, 
        1.2639312645376215`}, {0.19392342704617116`, 1.2612623081120515`}, {
        0.18819992859603296`, 1.258550741745808}, {0.18430847338916376`, 
        1.2567133540792081`}}]}, 
      {Arrowheads[{{0.0023064507387908113`, 1.}}], 
       ArrowBox[{{0.18309308603264782`, 1.256139497354592}, {
        0.18263751523630478`, 1.255924395260911}, {0.17747781460260167`, 
        1.253511098479378}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019500512880479572`, 1.}}], 
       ArrowBox[{{0.19703554858541855`, 1.263225796422889}, {
        0.18971482223729688`, 1.2597678262914096`}, {0.18425630736264473`, 
        1.2571892583863742`}, {0.17871799370145183`, 1.2545682164298322`}, {
        0.17333927761334045`, 1.2520321225763031`}, {0.16835955545793285`, 
        1.2497083989803055`}, {0.1586848190790802, 1.2452133377147971`}, {
        0.1495578498478731, 1.2410081413174032`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.016616111828712712`, 1.}}], 
       ArrowBox[{{0.16667913918135402`, 1.249175465814212}, {
        0.16011479515526503`, 1.2461402173240377`}, {0.150793099063604, 
        1.241827643023392}, {0.14200977074781873`, 1.2378005533235665`}, {
        0.13380233862292812`, 1.2340804209076182`}, {0.12605821744387563`, 
        1.2306028277263743`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019321830710980363`, 1.}}], 
       ArrowBox[{{0.15357471723642335`, 1.24327827646949}, {
        0.14705551209418752`, 1.2402894461795468`}, {0.14085395912341991`, 
        1.2374687133294646`}, {0.13497005832412048`, 1.2348160779192436`}, {
        0.12709423227013267`, 1.2312656685220809`}, {0.11967059706671346`, 
        1.227951889324241}, {0.11273010883437556`, 1.2248928359692814`}, {
        0.10617989921158094`, 1.2220342215265292`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{0.34882035283994006`, 1.3}, {0.3475955571043911, 
        1.2995102518323045`}, {0.3400947599892735, 1.2965165980679372`}, {
        0.3327828199142546, 1.293604084093282}, {0.32565973687933436`, 
        1.2907727099083388`}, {0.318506930939368, 1.287927269519891}, {
        0.3112713573826712, 1.2850454050658693`}, {0.3042013190594351, 
        1.2822363887429948`}, {0.2988648034905901, 1.2801303115712601`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.29761459037613003`, 1.279636909974994}, {
        0.2975451188198507, 1.2796094927479893`}, {0.29106724758880836`, 
        1.2770605618454416`}, {0.2845151379244232, 1.2744786181848613`}, {
        0.2781115051267236, 1.271962700040347}, {0.2720790644957375, 
        1.2696118456859982`}, {0.26470809459084205`, 1.266748610608733}, {
        0.2572353714134944, 1.2638399768691722`}, {0.24996615478105116`, 
        1.2610221404542024`}, {0.24753224827689557`, 1.2600893815951288`}}]}, 
      {Arrowheads[{{0.0012236605113287963`, 1.}}], 
       ArrowBox[{{0.24627720305842296`, 1.259608403979896}, {
        0.24320570451086906`, 1.2584312973507092`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.3445439771878086, 1.2983348687844594`}, {
        0.3367756506910625, 1.29523573762456}, {0.32919455041949924`, 
        1.292218064236574}, {0.3218006763731186, 1.2892818486205009`}, {
        0.31459402855192076`, 1.2864270907763415`}, {0.30757460695590555`, 
        1.283653790704095}, {0.3007424115850731, 1.2809619484037622`}, {
        0.29456440223693087`, 1.2785257744993577`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.29331416440667546`, 1.2780324356511474`}, {
        0.286937978923518, 1.2755143735328294`}, {0.28015848814714284`, 
        1.2728450916131806`}, {0.27378808255210874`, 1.2703574947462575`}, {
        0.2675943449002533, 1.2679480186496845`}, {0.26132747945922435`, 
        1.2655058367087395`}, {0.25520686959654243`, 1.263129066456539}, {
        0.24945189867972764`, 1.2609158254261974`}, {0.24321547482981964`, 
        1.2585271929731745`}}]}, 
      {Arrowheads[{{0.007657258193962802, 1.}}], 
       ArrowBox[{{0.241960530817501, 1.2580459516260882`}, {
        0.23571129081335987`, 1.2556469750626582`}, {0.22898270729507955`, 
        1.253075855596496}, {0.22272652515981112`, 1.2507157551823593`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.007309473083683569, 1.}}], 
       ArrowBox[{{0.22229582038745466`, 1.2508247927545737`}, {
        0.2159023090572072, 1.2484036125676203`}, {0.2096838764776306, 
        1.246060555368176}, {0.20390314077473107`, 1.2439128056375053`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.009169266132755356, 1.}}], 
       ArrowBox[{{0.39007560540783526`, 1.3}, {0.38959532933238883`, 
        1.2998234986387438`}, {0.38180322100673125`, 1.2969571140231098`}, {
        0.37417023667104776`, 1.2941547801840516`}, {0.36693506231029954`, 
        1.2915125732864339`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.011430699320047618`, 1.}}], 
       ArrowBox[{{0.2154572741510145, 1.2482344488807775`}, {
        0.20943125314550695`, 1.2459829142231422`}, {0.20361259430390344`, 
        1.2438248868563229`}, {0.19771303940434104`, 1.2416310003313493`}, {
        0.19197527662069636`, 1.2395088321226846`}, {0.18664199412684604`, 
        1.2375659597047919`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.011941167417243407`, 1.}}], 
       ArrowBox[{{0.11856394155546751`, 1.227629088888535}, {
        0.1133027347477122, 1.2253235411797594`}, {0.10668553004226597`, 
        1.2224261474792193`}, {0.10044591263939173`, 1.2197221589486422`}, {
        0.09460928230943039, 1.2172265084211957`}, {0.08909943974135913, 
        1.2148943973973765`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{0.5658068927873143, 1.3}, {0.559308179976322, 
        1.298176211979503}, {0.5493207831709357, 1.2953705200243992`}, {
        0.5392370785831146, 1.29253349518042}, {0.5293459895601631, 
        1.289759136114191}, {0.5199364394493844, 1.2871414414923341`}, {
        0.5140355364292254, 1.2855056492417072`}}]}, 
      {Arrowheads[{{0.011228564497157006`, 1.}}], 
       ArrowBox[{{0.5127403281744005, 1.2851466039194992`}, {
        0.5107336088236537, 1.2845903202537754`}, {0.501443873028941, 
        1.2820104711967075`}, {0.4923279475721925, 1.2794880777766573`}, {
        0.48364654796035444`, 1.277109323449151}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.020000000000000025`, 1.}}], 
       ArrowBox[{{0.6444231667780594, 1.3}, {0.644173115601669, 
        1.299935170501095}, {0.6384204261769605, 1.2984461497162847`}, {
        0.6327217085871398, 1.2969735717289779`}, {0.6270769628322072, 
        1.2955174365391744`}, {0.6214861889121621, 1.2940777441468743`}, {
        0.6159493868270053, 1.2926544945520781`}, {0.6104665565767362, 
        1.2912476877547847`}, {0.6050376981613551, 1.2898573237549948`}, {
        0.599662811580862, 1.288483402552709}, {0.5943418968352567, 
        1.2871259241479263`}, {0.5923526862443981, 1.2866199566099}}]}, 
      {Arrowheads[{{0.020000000000000018`, 1.}}], 
       ArrowBox[{{0.5910501094699494, 1.286288638464558}, {0.5838619828487097,
         1.284460295730871}, {0.5735979562017145, 1.2818604385038295`}, {
        0.5635498168942709, 1.279326352466802}, {0.5534646123093404, 
        1.2767794126036807`}, {0.5432827350929015, 1.2742019797931587`}, {
        0.538929465549401, 1.2731052448808486`}}]}, 
      {Arrowheads[{{0.019353645799915047`, 1.}}], 
       ArrowBox[{{0.5376261379205978, 1.2727768928460381`}, {
        0.5332942031394794, 1.2716855328774381`}, {0.5237890343435996, 
        1.269321550698719}, {0.514491243442063, 1.2670224594901534`}, {
        0.5051061349965689, 1.2646954787177558`}, {0.49589566163898985`, 
        1.2624242770730216`}, {0.4871217760011983, 1.2602925232474471`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{0.5089356735702018, 1.2820990082860209`}, {
        0.49936884829350425`, 1.2794740026534122`}, {0.4902754461945319, 
        1.2770046219258437`}, {0.4813854376194974, 1.274601571846577}, {
        0.47241009391081634`, 1.2721701172438253`}, {0.46360542046942854`, 
        1.269795471688043}, {0.4570426909137178, 1.2680465931443807`}}]}, 
      {Arrowheads[{{0.00019886333573536344`, 1.}}], 
       ArrowBox[{{0.45574396187427413`, 1.2677004994448258`}, {
        0.4552274226962738, 1.2675628487496848`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.016395883453594228`, 1.}}], 
       ArrowBox[{{0.4705078551279945, 1.2718610577758573`}, {
        0.46172846580448107`, 1.2695086410317231`}, {0.4531493163065772, 
        1.2672224763267637`}, {0.4444863478341201, 1.2649081738194927`}, {
        0.4359910173107693, 1.2626501469168445`}, {0.42791478166018443`, 
        1.2605328090257522`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.005580918423193035, 1.}}], 
       ArrowBox[{{0.24349415895588036`, 1.1094070957755977`}, {
        0.24297056897869546`, 1.1072283496539874`}, {0.23906159772216465`, 
        1.0974515921937922`}, {0.2386756711026038, 1.0969310222136526`}, {
        0.2382905467436569, 1.0964299348632078`}, {0.23782944492621144`, 
        1.0958514950205585`}, {0.237695165614645, 1.0956870178066331`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.005329869616229776, 1.}}], 
       ArrowBox[{{0.23553427970235952`, 1.091531328956488}, {
        0.2299795455415214, 1.086396014274472}, {0.22458054823384252`, 
        1.0823240003322208`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.005283576374365251, 1.}}], 
       ArrowBox[{{0.2338976771160923, 1.1139528411556257`}, {
        0.23288040589882267`, 1.1162530767485355`}, {0.23186574584360428`, 
        1.1179862909967868`}, {0.23085404632317214`, 1.1194305875318251`}, {
        0.22684062627458507`, 1.1239345537205405`}, {0.22644229538848662`, 
        1.1242971735310936`}, {0.22604453745990338`, 1.1246504678168017`}, {
        0.22556798788714952`, 1.1250629549327567`}, {0.22542914731571023`, 
        1.1251810733423375`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.004846504748940588, 1.}}], 
       ArrowBox[{{0.011738612174417887`, 1.2411611317776492`}, {
        0.010361008111133118`, 1.2343691279853537`}, {0.009151651734422672, 
        1.228392645562998}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.003714001072292696, 1.}}], 
       ArrowBox[{{0.5846569845829501, 1.203717654423187}, {0.5747602891338178,
         1.202403032443413}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.003707900157468351, 1.}}], 
       ArrowBox[{{0.3251246412108013, 1.11889795646913}, {0.3203744832778036, 
        1.1128001699118122`}, {0.3199046212514202, 1.1123635288773224`}, {
        0.31943562966767075`, 1.1119394845158808`}, {0.3188739792040654, 
        1.1114457262077537`}, {0.31871039193199835`, 1.1113045475550154`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.01392783673881862, 1.}}], 
       ArrowBox[{{0.22060187652937457`, 1.3}, {0.21712938515852354`, 
        1.2979598814110709`}, {0.21200999179163496`, 1.2949582867860738`}, {
        0.20594832485106293`, 1.2914061792604499`}, {0.19979777447052252`, 
        1.2877995722324482`}, {0.19382499096991881`, 1.2843019642092017`}, {
        0.1882966246691568, 1.2810768536978427`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.004913520535987726, 1.}}], 
       ArrowBox[{{0.10629246533097968`, 1.1357603868328152`}, {
        0.10056373941221199`, 1.1394568259693996`}, {0.09511186830477159, 
        1.14279043650118}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.011454467950332552`, 1.}}], 
       ArrowBox[{{0.04949752491590499, 1.0561032857182557`}, {
        0.049423584311090125`, 1.0581949770563597`}, {0.049349640885446085`, 
        1.0595009207000767`}, {0.04927572399747509, 1.0605509688472015`}, {
        0.04898056377577361, 1.0638135430727143`}, {0.04868639055992421, 
        1.0662578626156431`}, {0.048085441001459284`, 1.0703013773787835`}, {
        0.04748988810389227, 1.073601568543361}, {0.0468999920085687, 
        1.0764770972591093`}, {0.045725922936635494`, 1.0818886123821971`}, {
        0.044575576369141785`, 1.0864302259794991`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019128733123365656`, 1.}}], 
       ArrowBox[{{0.6066146106315676, 1.2075377202236002`}, {
        0.5961454073252908, 1.2060374858911551`}, {0.5858907322327016, 
        1.2046190050134347`}, {0.575545366471316, 1.2031675093764278`}, {
        0.5653813820475233, 1.2017820432579942`}, {0.555670850967713, 
        1.200561650935993}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.011750445744009913`, 1.}}], 
       ArrowBox[{{0.3505919958625855, 1.0750493563353507`}, {
        0.34263679292708443`, 1.0739503846095666`}, {0.33459130935286435`, 
        1.072850993201522}, {0.3267263870560822, 1.071752441157998}, {
        0.3193128679528947, 1.0706559875257753`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.005328571175591461, 1.}}], 
       ArrowBox[{{0.2898072361008781, 1.1463696630750022`}, {
        0.28285497225308903`, 1.1485251786547328`}, {0.2760568178196446, 
        1.1503737659128694`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.012610324378746507`, 1.}}], 
       ArrowBox[{{0.2746954362408779, 1.1093229913740204`}, {
        0.2683023727171862, 1.1006746348113823`}, {0.2620932818897015, 
        1.0948148817800754`}, {0.25597617741032025`, 1.0903494305144343`}, {
        0.2500257924558293, 1.0866022112596234`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{0.46129289984129956`, 1.269525749605665}, {
        0.4521717366936665, 1.267074063325686}, {0.4432339772426927, 
        1.2646839643644834`}, {0.43475472703336643`, 1.262447833700219}, {
        0.426472819976783, 1.260277774190738}, {0.41810850404259225`, 
        1.2580799102458748`}, {0.4099090058636159, 1.2559376551717767`}, {
        0.40931653980598764`, 1.2557852500944602`}}]}, 
      {Arrowheads[{{0.002263740683113334, 1.}}], 
       ArrowBox[{{0.4080148641861883, 1.2554504090163559`}, {
        0.40212155207267536`, 1.2539344222745918`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.018568849900465863`, 1.}}], 
       ArrowBox[{{0.42606722254952656`, 1.260237345670602}, {
        0.41742368259868545`, 1.2579633212771684`}, {0.4092320519124196, 
        1.2558419782283103`}, {0.4012351113857491, 1.2537864095094717`}, {
        0.39315707330867344`, 1.251703439049844}, {0.38524123033240787`, 
        1.2496752720717945`}, {0.37773087510816755`, 1.2477841137976908`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.00870233130242786, 1.}}], 
       ArrowBox[{{0.3774625204616846, 1.247922191625658}, {
        0.36965850890904106`, 1.2459486080859423`}, {0.3620142616372307, 
        1.2440289192517044`}, {0.3547694250675032, 1.2422439671811616`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.014189458218184597`, 1.}}], 
       ArrowBox[{{0.370260716574248, 1.2463212358887303`}, {
        0.3626067488597551, 1.244414070781895}, {0.35514288837203445`, 
        1.2425717754257901`}, {0.3476002660920334, 1.24070304122131}, {
        0.340215167396593, 1.23888718471358}, {0.33322387766255396`, 
        1.2372035224477256`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.009864332910245605, 1.}}], 
       ArrowBox[{{0.3387508654401651, 1.2387774363986683`}, {
        0.32981906396610655`, 1.2365927869756472`}, {0.32111340955307566`, 
        1.2344836147953826`}, {0.3129731227926138, 1.2325631357220088`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.01256384486722614, 1.}}], 
       ArrowBox[{{0.3269267203652213, 1.2359172002198568`}, {
        0.31854604657726626`, 1.233929471028734}, {0.3100573436927732, 
        1.231906138008295}, {0.3017846990013562, 1.229954012646488}, {
        0.2940521997926294, 1.2281799064312608`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.014448581535814032`, 1.}}], 
       ArrowBox[{{0.3140538993244653, 1.2330754089929736`}, {
        0.30741993000153633`, 1.231523836890063}, {0.29946177375573857`, 
        1.2296818144378872`}, {0.29140049535152707`, 1.227806288439703}, {
        0.28354546126414276`, 1.2259977695335342`}, {0.2762060379688261, 
        1.2243567683574026`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.013742511087471418`, 1.}}], 
       ArrowBox[{{0.2957078082969013, 1.2288318657387685`}, {
        0.28929391711942476`, 1.2273714610743844`}, {0.28173795642725186`, 
        1.2256705578595934`}, {0.2740836332192752, 1.2239382877080742`}, {
        0.2666260350429061, 1.2222687514300115`}, {0.25966024944555605`, 
        1.2207560498355903`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.016553615708198608`, 1.}}], 
       ArrowBox[{{0.28743209414381243`, 1.2272208611075688`}, {
        0.279491124926053, 1.225393545441584}, {0.2720880339034301, 
        1.2237416903459024`}, {0.2649208626877019, 1.222168683120606}, {
        0.25765996151883974`, 1.2205663595427576`}, {0.25058652025624545`, 
        1.2190226686700125`}, {0.24398172875932095`, 1.2176255595600247`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.009548014513371878, 1.}}], 
       ArrowBox[{{0.005279304825428737, 1.1315258271694146`}, {
        0.004584865117744046, 1.1386670670230212`}, {0.003975653009796212, 
        1.1448491012892092`}, {0.003451668501585233, 1.150071929967978}, {
        0.003075656349768028, 1.153776996646707}, {0.002739530328972343, 
        1.1570658868469734`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{0.2860488697951864, 1.227021720070073}, {
        0.27841142439373523`, 1.2253000879006053`}, {0.27067156669518233`, 
        1.223545635522561}, {0.26313653359083283`, 1.2218568235616698`}, {
        0.2561135619719917, 1.2203321126436604`}, {0.24931513452506035`, 
        1.2188813417453743`}, {0.24242744116616488`, 1.2174032837068924`}, {
        0.23571827963119757`, 1.2159797999488022`}, {0.2335302475665491, 
        1.2155301467521533`}}]}, 
      {Arrowheads[{{0.0010475414432454173`, 1.}}], 
       ArrowBox[{{0.23221370773225783`, 1.2152595902303502`}, {
        0.22945544765605067`, 1.2146927518916921`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.572828019138002, 1.2812089725937021`}, {
        0.5674532897117929, 1.2798557252621654`}, {0.556860342063506, 
        1.2771983987977797`}, {0.5464760760207267, 1.2746066299316454`}, {
        0.5363004915834552, 1.272080418663762}, {0.5263335887516916, 
        1.26961976499413}, {0.520657049949222, 1.2682264930576161`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.5193517398886043, 1.2679061126393378`}, {
        0.5165753675254358, 1.267224668922749}, {0.5070258279046876, 
        1.264895130449619}, {0.4976849698894474, 1.2626311495747402`}, {
        0.48830859305027374`, 1.2603548836208236`}, {0.4788389764599751, 
        1.2580485750814643`}, {0.46955583937192635`, 1.25580235171299}, {
        0.46710777649061375`, 1.2552203849160544`}}]}, 
      {Arrowheads[{{0.01491233613965987, 1.}}], 
       ArrowBox[{{0.4658001646820127, 1.2549095323388204`}, {
        0.460738901039502, 1.253706341271727}, {0.4521223279457527, 
        1.2516748121625094`}, {0.44342177225849533`, 1.2496161712419567`}, {
        0.4348891817582541, 1.2476117539440743`}, {0.42677650422555324`, 
        1.2457428957028684`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{0.509528633326839, 1.3}, {0.5084105918571584, 
        1.2996630183284208`}, {0.49904031174072583`, 1.2968460012497969`}, {
        0.4898777966404531, 1.294098823928159}, {0.48068038533559304`, 
        1.2913384567360287`}, {0.47139045488895454`, 1.2885460163779079`}, {
        0.46228556272587273`, 1.2858177223517682`}, {0.45803310987123075`, 
        1.284554170048711}}]}, 
      {Arrowheads[{{0.014109941241542363`, 1.}}], 
       ArrowBox[{{0.456744729259009, 1.2841713471590912`}, {
        0.45364326627168233`, 1.2832497941555805`}, {0.44520004965414905`, 
        1.2807503384344368`}, {0.4366736749302377, 1.2782216936426782`}, {
        0.4283136164190824, 1.2757514269921497`}, {0.42036934843981716`, 
        1.2734271056946973`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.2692382178680818, 1.2233195124058158`}, {
        0.26200080281095767`, 1.2217326523353924`}, {0.25466605059962133`, 
        1.2201152422708936`}, {0.2475259726967094, 1.2185589321945454`}, {
        0.24087258056485844`, 1.2171553720885717`}, {0.23443255207836775`, 
        1.215820802492295}, {0.2279076459956221, 1.2144609432496405`}, {
        0.22155249510538638`, 1.2131516632997408`}, {0.21664545293856224`, 
        1.2121730025092758`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{0.5033923201111373, 1.297709974189899}, {
        0.49397002141448076`, 1.2948886042573853`}, {0.4847540043962521, 
        1.2921370102551433`}, {0.4757442690564515, 1.2894551921831732`}, {
        0.4666999705938586, 1.2867602888165135`}, {0.4575638694899279, 
        1.284033403276636}, {0.45187382596160686`, 1.2823408989956286`}}]}, 
      {Arrowheads[{{0.01673054989687538, 1.}}], 
       ArrowBox[{{0.45058555627444385`, 1.2819577029884692`}, {
        0.44861137366867265`, 1.2813704820831937`}, {0.44011789105410537`, 
        1.2788674717558373`}, {0.43182203875882086`, 1.2764328431841896`}, {
        0.4234437338466036, 1.273969177378841}, {0.41523033416825184`, 
        1.2715635860408945`}, {0.40742919757456353`, 1.2693031808714532`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{0.4978814759100693, 1.2961793210781498`}, {
        0.48841648841786145`, 1.2933480414759297`}, {0.47915628451657316`, 
        1.2905865467246083`}, {0.4701008642062046, 1.287894836824185}, {
        0.4612502274867558, 1.2852729117746609`}, {0.4523653759168584, 
        1.2826380043393482`}, {0.446350845295786, 1.2808510354604654`}}]}, 
      {Arrowheads[{{0.0197210951490092, 1.}}], 
       ArrowBox[{{0.4450624554263039, 1.2804682437272974`}, {
        0.4433894532496886, 1.2799711803632103`}, {0.43459567277706357`, 
        1.2773681894687232`}, {0.4262572477908001, 1.2749247812783615`}, {
        0.4181149807527163, 1.2725497245131243`}, {0.409890986453117, 
        1.270145763436044}, {0.4018304466765489, 1.2677996109826493`}, {
        0.39417854320755885`, 1.265597980088468}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{0.562437908979286, 1.2787371580335016`}, {
        0.5518056298520764, 1.276074213276084}, {0.5413805079583894, 
        1.2734767239537477`}, {0.5311625432982252, 1.2709446900664925`}, {
        0.5211517358715836, 1.2684781116143182`}, {0.5113480856784648, 
        1.2660769885972256`}, {0.510253092004707, 1.2658104806930286`}}]}, 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{0.5089471627410894, 1.2654926336776373`}, {
        0.5017515927188687, 1.263741321015214}, {0.4923622569927951, 
        1.2614711088682835`}, {0.48318007850024436`, 1.2592663521564342`}, {
        0.4739627205238703, 1.2570494807811519`}, {0.46465285714710636`, 
        1.25480271448522}, {0.45668248768502195`, 1.2528924359132483`}}]}, 
      {Arrowheads[{{0.015989149533968638`, 1.}}], 
       ArrowBox[{{0.4553752977766179, 1.252579819226351}, {
        0.44686567899708657`, 1.2505782361791997`}, {0.4384022291799293, 
        1.2486050422699178`}, {0.4298555172664481, 1.2466049655071911`}, {
        0.42147532954561484`, 1.2446586544513536`}, {0.41351145230640124`, 
        1.2428467576627382`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{0.0029485362852157593`, 1.053737551412112}, {
        0.002780717833207962, 1.0622366951438473`}, {0.0026212004981791374`, 
        1.0700421521167085`}, {0.00246980191839196, 1.0772619095575418`}, {
        0.0023262394575001774`, 1.0839635464285133`}, {0.002190230479157537, 
        1.0902146416917895`}, {0.002061498244682651, 1.0960513645998813`}, {
        0.001939766015394131, 1.1015098844052993`}, {0.0018056438343489127`, 
        1.107487492108637}}]}, 
      {Arrowheads[{{0.0036029219466351863`, 1.}}], 
       ArrowBox[{{0.0017754943256865663`, 1.1088312067263641`}, {
        0.0017377984056716192`, 1.1105112526375605`}, {0.0015553895091700851`,
         1.1185137399950509`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0023254122897323035`, 1.}}], 
       ArrowBox[{{0.016879129114787585`, 1.050761923027892}, {
        0.016469107877886673`, 1.0569994150549065`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019172321741773277`, 1.}}], 
       ArrowBox[{{0.45045635156748176`, 1.2518022928965205`}, {
        0.4414915767640507, 1.2496719714152074`}, {0.43298569113766516`, 
        1.2476903282852818`}, {0.4246772113996961, 1.2457727976928614`}, {
        0.41628618730471667`, 1.2438286255614632`}, {0.40806025192375794`, 
        1.2419377365080202`}, {0.4002470383278509, 1.240180055149466}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{0.5013749204887699, 1.2634862105416371`}, {
        0.49168586722909435`, 1.2611460136566335`}, {0.48220108523188077`, 
        1.2588709158830809`}, {0.47292057449712893`, 1.256660917220979}, {
        0.46384433502483885`, 1.2545160176703276`}, {0.45497236681501063`, 
        1.2524362172311272`}, {0.4490710176184167, 1.2510504075887778`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.447762558060581, 1.2507431429597131`}, {
        0.44606586928247244`, 1.2503447107384633`}, {0.4370682617806403, 
        1.2482237005063404`}, {0.4282528742173961, 1.2461616977531356`}, {
        0.4198930365006213, 1.2442472136972267`}, {0.4117292547820918, 
        1.2423965099231822`}, {0.4034835871340401, 1.2405194842783098`}, {
        0.39540169134503295`, 1.238695102375094}, {0.3953697922323924, 
        1.2386880644890712`}}]}, 
      {Arrowheads[{{0.0024107185352888116`, 1.}}], 
       ArrowBox[{{0.3940573041068449, 1.2383984908592933`}, {
        0.3877292252036374, 1.23700232982602}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.005962795791405325, 1.}}], 
       ArrowBox[{{0.3027792172708184, 1.1131246702151778`}, {
        0.30191436204597194`, 1.1119338616569705`}, {0.3001881083232621, 
        1.1097071853937048`}, {0.2984751104455648, 1.1078635895033409`}, {
        0.29167659800750806`, 1.1016313159566768`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.014903767726683292`, 1.}}], 
       ArrowBox[{{0.5769809702061303, 1.2042185996177406`}, {
        0.5669125598432618, 1.202892136629675}, {0.556754265278952, 
        1.2015339979538688`}, {0.5467757391175251, 1.200239210653544}, {
        0.5372466339633057, 1.1991028017919227`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999983`, 1.}}], 
       ArrowBox[{{0.21938465580763278`, 1.2990754481593016`}, {
        0.21300653905462627`, 1.295338465748032}, {0.20653217489930853`, 
        1.2915427073863612`}, {0.20025030554861317`, 1.2878645009254925`}, {
        0.1944496732094738, 1.284480174216627}, {0.18886322009359063`, 
        1.2812257688405966`}, {0.18319497585448558`, 1.2779208338021877`}, {
        0.17769031386182438`, 1.2747169580885354`}, {0.17295354772325133`, 
        1.2719736143809357`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0047280998214052974`, 1.}}], 
       ArrowBox[{{0.2212180077098278, 1.1284973487069776`}, {
        0.2157880542101285, 1.1322398427368545`}, {0.2104741248172869, 
        1.1352654003581868`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.00532635585967486, 1.}}], 
       ArrowBox[{{0.18012277737166996`, 1.1045520682255274`}, {
        0.1795765821366547, 1.1059222191068725`}, {0.1784851246373972, 
        1.1084319944237393`}, {0.1773978929431652, 1.110417493989463}, {
        0.17306556480471372`, 1.1169544893033196`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.008205117714822293, 1.}}], 
       ArrowBox[{{0.008107859599163596, 1.3}, {0.007934891974664335, 
        1.297610393697025}, {0.007431924249035547, 1.2906299041965983`}, {
        0.006966113476566773, 1.2841246415734622`}, {0.0065292708469024685`, 
        1.2780003415120245`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0071756829312042145`, 1.}}], 
       ArrowBox[{{0.5388737880433587, 1.199795974619997}, {0.5290728451997075,
         1.1985917907039525`}, {0.5197175377082567, 1.1975390544895148`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0058380285157332195`, 1.}}], 
       ArrowBox[{{0.042846038289313645`, 1.0878428949473553`}, {
        0.04060895792218773, 1.0958741025321785`}, {0.03847028110330731, 
        1.10291263549859}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0061723763355210634`, 1.}}], 
       ArrowBox[{{0.18581166268090615`, 1.2377488066820426`}, {
        0.18039072020146857`, 1.23576009531888}, {0.17021885333420858`, 
        1.2320780403845886`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.014349022541549164`, 1.}}], 
       ArrowBox[{{0.5408056547713649, 1.2006923402425507`}, {
        0.5310940161963134, 1.1995422276770515`}, {0.5212939804149255, 
        1.198363347105094}, {0.5116707390462102, 1.197242002546054}, {
        0.5024894837091763, 1.1962644980193076`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.011225564072306583`, 1.}}], 
       ArrowBox[{{0.3323514390542379, 1.0719143366379131`}, {
        0.3247563250898754, 1.0708249920315183`}, {0.3170744840849379, 
        1.069734381342902}, {0.3095660971611503, 1.0686463028187283`}, {
        0.30249134544023754`, 1.067564554705661}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0027949577622513777`, 1.}}], 
       ArrowBox[{{0.3593720862642615, 1.2860176630761193`}, {
        0.3522955408044626, 1.283493816325887}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.004173734179951285, 1.}}], 
       ArrowBox[{{0.16688981288368435`, 1.1177522206393466`}, {
        0.16271654153380685`, 1.1219144496871654`}, {0.15863271200148793`, 
        1.1253322894117623`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.010941160704190324`, 1.}}], 
       ArrowBox[{{0.18357801140870414`, 1.2782234304247755`}, {
        0.1782406039714585, 1.2751231985301463`}, {0.1730994079150607, 
        1.2721434724779486`}, {0.16788308036891436`, 1.2691170176879913`}, {
        0.16281701580226504`, 1.266184020373552}, {0.1581266086843582, 
        1.2634846667479063`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.6138548691545892, 1.251726991512667}, {0.608461919728222, 
        1.2506267077708118`}, {0.5978397556737346, 1.2484750752889335`}, {
        0.5874359046835773, 1.2463886894761658`}, {0.5769941064877512, 
        1.2442894090782315`}, {0.5664542391333691, 1.2421597834004827`}, {
        0.5611536454362975, 1.2410995676497374`}}]}, 
      {Arrowheads[{{0.01955334802004648, 1.}}], 
       ArrowBox[{{0.5598356978586675, 1.2408359540131684`}, {
        0.5561105100960989, 1.240090848282363}, {0.5462571268516077, 
        1.2381736395633138`}, {0.5366138406741934, 1.236321379221275}, {
        0.5268817911715336, 1.2344416121443433`}, {0.5173272683193648, 
        1.2326168585371975`}, {0.5082165620934241, 1.2309296386045163`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{0.65, 1.0041098111407532`}, {0.6436417944461433, 
        1.0041174087686242`}, {0.6350335872279295, 1.004127816755703}, {
        0.626541161266577, 1.0041382047512393`}, {0.6181628360814206, 
        1.0041485713639706`}, {0.6098969311917948, 1.004158915202635}, {
        0.6017417661170338, 1.0041692348759699`}, {0.5962379285447358, 
        1.004176276437233}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{0.594893876830756, 1.0041779960051456`}, {0.593695660376472,
         1.0041795289927127`}, {0.585756933489444, 1.0041897961616015`}, {
        0.5779239049752842, 1.004200034991374}, {0.570194894353327, 
        1.0042102440907674`}, {0.5625682211429068, 1.0042204220685198`}, {
        0.5550422048633581, 1.0042305675333687`}, {0.5476151650340152, 
        1.0042406790940517`}, {0.5411318119648392, 1.0042495918182226`}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{0.5397877604308912, 1.0042514467490542`}, {
        0.529478519310029, 1.0042657691638996`}, {0.5188609062094314, 
        1.004280693959118}, {0.5084325818724196, 1.0042955297449614`}, {
        0.4981935462989936, 1.00431027652143}, {0.48814379948915354`, 
        1.0043249342885237`}, {0.4860257024839879, 1.0043280637620176`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.48468165113703005`, 1.0043300495884715`}, {
        0.47828334144289936`, 1.0043395030462423`}, {0.4686121721602311, 
        1.0043539827945858`}, {0.4591302916411487, 1.0043683735335547`}, {
        0.4498376998856522, 1.0043826752631486`}, {0.4407343968937415, 
        1.0043968879833673`}, {0.4318203826654168, 1.0044110116942115`}, {
        0.4309196017765887, 1.0044124607015086`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.4295755507015642, 1.0044146227587187`}, {
        0.4230956572006778, 1.0044250463956803`}, {0.41456022049952485`, 
        1.0044389920877748`}, {0.4062140725619577, 1.004452848770494}, {
        0.3980572133879764, 1.0044666164438383`}, {0.3900896429775811, 
        1.0044802951078076`}, {0.382284979366064, 1.0044938524895466`}, {
        0.3758135144440915, 1.0045051645427747`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.37446946368638206`, 1.0045075155944896`}, {
        0.36708522664554144`, 1.0045205065877685`}, {0.3596901375365361, 
        1.004533603304251}, {0.35243157326170127`, 1.0045465464656478`}, {
        0.34530953382103713`, 1.0045593360719594`}, {0.33832401921454347`, 
        1.0045719721231852`}, {0.3314750294422204, 1.0045844546193257`}, {
        0.32476256450406793`, 1.0045967835603806`}, {0.3207074382517905, 
        1.0046042916469045`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.31936338774155926`, 1.0046067801631418`}, {
        0.31818662440008605`, 1.00460895894635}, {0.31174720913027476`, 
        1.0046209807772337`}, {0.305444318694634, 1.0046328490530319`}, {
        0.29927795309316385`, 1.0046445637737444`}, {0.29324811232586434`, 
        1.0046561249393717`}, {0.2873547963927353, 1.0046675325499133`}, {
        0.281598005293777, 1.0046787866053692`}, {0.2759588888051776, 
        1.0046898472610153`}, {0.2704185967031257, 1.0047006746721272`}, {
        0.2656013743689362, 1.0047100352323535`}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{0.26425732409239466`, 1.0047126469165748`}, {
        0.25963448565866387`, 1.004721629760748}, {0.24924567216039167`, 
        1.004741651871231}, {0.23925215620830909`, 1.0047607410035773`}, {
        0.22965393780241616`, 1.004778897157786}, {0.2204510169427128, 
        1.0047961203338576`}, {0.21164339362919904`, 1.0048124105317917`}, {
        0.21049530805292016`, 1.0048145064328573`}}]}, 
      {Arrowheads[{{0.015347390331033392`, 1.}}], 
       ArrowBox[{{0.20915125747858115`, 1.0048169600801196`}, {
        0.2032310678618749, 1.0048277677515887`}, {0.1937653062005511, 
        1.0048453123286136`}, {0.18472085997112897`, 1.004861321173302}, {
        0.17611819472267118`, 1.0048758591895153`}, {0.16789591380798963`, 
        1.0048887316656687`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.007916096253766899, 1.}}], 
       ArrowBox[{{0.3472437400795447, 1.1400478772743683`}, {
        0.3436882055674933, 1.1421049847580262`}, {0.3357431373357568, 
        1.146120767755495}, {0.3279559544454034, 1.1489029995318176`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.007737420394583642, 1.}}], 
       ArrowBox[{{0.12196631440985645`, 1.3}, {0.12161897297396697`, 
        1.2996531558090774`}, {0.11421168979472698`, 1.2922478995910065`}, {
        0.107257516563491, 1.2852945656256494`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.013592456860941748`, 1.}}], 
       ArrowBox[{{0.11750830773278834`, 1.2926922780500445`}, {
        0.11030572507221638`, 1.2856485790424985`}, {0.1035497732139807, 
        1.279044256282735}, {0.0972748087754369, 1.27291088144984}, {
        0.09137776190451809, 1.2671537395065564`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.013689241384643057`, 1.}}], 
       ArrowBox[{{0.10307577988091848`, 1.2785414676076572`}, {
        0.09852911197779998, 1.274105873638944}, {0.09252734587900795, 
        1.2682456275788339`}, {0.08689180729215255, 1.26275154149761}, {
        0.08164986426284386, 1.2576499339603435`}, {0.0767194126542517, 
        1.2528618492718213`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.018641743145236235`, 1.}}], 
       ArrowBox[{{0.10022473205711817`, 1.275803864122511}, {
        0.09538796496317213, 1.271089665278827}, {0.09080956174056408, 
        1.2666312301451381`}, {0.08648952238929404, 1.2624285587214443`}, {
        0.08242784690936202, 1.2584816510077457`}, {0.07743919118156925, 
        1.2536310698277369`}, {0.07275034674073295, 1.2490833842399598`}, {
        0.0683831072743892, 1.2448603577330049`}, {0.06427209171992979, 
        1.2408966998411}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.007140530560449633, 1.}}], 
       ArrowBox[{{0.1486394688013742, 1.3}, {0.14702904227362248`, 
        1.2986570038909895`}, {0.14244517075713806`, 1.2948339451032915`}, {
        0.13799899748730132`, 1.2911265051049616`}, {0.1338970698340838, 
        1.287708112080052}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.009613958696798753, 1.}}], 
       ArrowBox[{{0.17998198529176973`, 1.2353792642532713`}, {
        0.17489101348710734`, 1.2335465931522724`}, {0.1649902353892806, 
        1.230008158830081}, {0.15563713865026443`, 1.2267073313168815`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.010466554141617667`, 1.}}], 
       ArrowBox[{{0.5103740775472461, 1.1977537914741139`}, {
        0.5007864180178275, 1.1966753182313672`}, {0.49137384993452293`, 
        1.1956505955158514`}, {0.4823990104665032, 1.1947602491184135`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.011459078041491565`, 1.}}], 
       ArrowBox[{{0.36615248383654614`, 1.288483487202092}, {
        0.35878261012610113`, 1.2858480597988566`}, {0.35133471110986936`, 
        1.283181131140481}, {0.34404286270521117`, 1.2805772049923863`}, {
        0.3371411408294868, 1.2781307851199932`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{0.6015141383101243, 1.2499705047419876`}, {
        0.5908611719059533, 1.2478144113563057`}, {0.5804246025855887, 
        1.2457234850133656`}, {0.5702044303490307, 1.2436977257131683`}, {
        0.5599467077677903, 1.2416593224257584`}, {0.5495918192621595, 
        1.239590767465959}, {0.5487948347644671, 1.2394332421001064`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.5474762904691041, 1.2391726295372254`}, {
        0.5394312626053095, 1.2375825158509386`}, {0.5297565355704111, 
        1.2357250225978635`}, {0.5202900433317484, 1.23393227557893}, {
        0.5107356538003321, 1.2321123388138486`}, {0.5013570588544232, 
        1.2303467815410625`}, {0.4946616503435176, 1.2291262017792575`}}]}, 
      {Arrowheads[{{0.00034843333793095784`, 1.}}], 
       ArrowBox[{{0.4933393897303819, 1.228885152328489}, {
        0.49241795037228286`, 1.2287171729990134`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.31795053989514194`, 1.004457259997367}, {
        0.3113374829051405, 1.0044694627161133`}, {0.3048571351636454, 
        1.0044814951831191`}, {0.29850949667065674`, 1.004493357398385}, {
        0.29229456742617427`, 1.0045050493619105`}, {0.2862123474301983, 
        1.0045165710736963`}, {0.28026283668272867`, 1.004527922533742}, {
        0.2744460351837654, 1.0045391037420472`}, {0.2687619429333085, 
        1.0045501146986127`}, {0.2641885237928699, 1.0045590827052069`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.2628444735629048, 1.0045617182500706`}, {
        0.2577918861779138, 1.0045716258565232`}, {0.24727762032070527`, 
        1.0045922832801286`}, {0.23714409926584368`, 1.0046119142420848`}, {
        0.22739132301332884`, 1.0046305187423912`}, {0.2180192915631609, 
        1.0046480967810483`}, {0.2090824593970611, 1.0046645481157233`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.20773840877154395`, 1.0046669735460936`}, {
        0.2004174630698656, 1.0046801734734139`}, {0.19218766602673826`, 
        1.0046946721271224`}, {0.18433861378595776`, 1.0047081443191814`}, {
        0.17569418594181813`, 1.0047232495564864`}, {0.1674370462861065, 
        1.0047367428195257`}, {0.15958613994130122`, 1.0047486880203897`}, {
        0.15397637094649871`, 1.0047563198121567`}}]}, 
      {Arrowheads[{{0.00020374509747122623`, 1.}}], 
       ArrowBox[{{0.15263231937631433`, 1.0047581483226922`}, {
        0.15208463153996718`, 1.0047588934228067`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0009486763855603868, 1.}}], 
       ArrowBox[{{0.22364631937644583`, 1.1047577942995679`}, {
        0.2235927855281381, 1.104007811996021}, {0.22353929359805458`, 
        1.1035161017140855`}, {0.22348583592191976`, 1.103118243795756}, {
        0.2234430473576789, 1.102839845610892}, {0.22340027730183734`, 
        1.1025860977843915`}, {0.2233340182786628, 1.1022289796245657`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.004020530450330049, 1.}}], 
       ArrowBox[{{0.03593906018239424, 1.1071319440718987`}, {
        0.03219140408139673, 1.1172689810717589`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.010736801792032787`, 1.}}], 
       ArrowBox[{{0.31565631552955736`, 1.069007164594386}, {
        0.30839642829777764`, 1.067929357483287}, {0.3010531887425112, 
        1.0668495415403403`}, {0.293876653834218, 1.0657737432610894`}, {
        0.2871168805433579, 1.0647079891410782`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.01027580177719004, 1.}}], 
       ArrowBox[{{0.49434525189516465`, 1.196133087223492}, {
        0.48492315620820503`, 1.1951387556697592`}, {0.47567483828654883`, 
        1.1941950252359816`}, {0.46686096477815103`, 1.1933777976020927`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.013867597111476991`, 1.}}], 
       ArrowBox[{{0.5138055320894536, 1.2325314870966253`}, {
        0.5045082069023429, 1.230811500738263}, {0.4951238088628228, 
        1.2290646833268593`}, {0.48591355652812174`, 1.2273715280215387`}, {
        0.4771386684554679, 1.2258125279814258`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.010865146355735565`, 1.}}], 
       ArrowBox[{{0.2890802754882715, 1.146245225524587}, {
        0.28195895356964906`, 1.1484576843087633`}, {0.2747582580900888, 
        1.1507724609052654`}, {0.26771630973240423`, 1.1528826018771157`}, {
        0.26107122917940856`, 1.1544811537873356`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0007758098037700205, 1.}}], 
       ArrowBox[{{0.65, 1.2031817146134107`}, {0.6479376720210832, 
        1.2028719706938622`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.008788361055254228, 1.}}], 
       ArrowBox[{{0.10189296457514306`, 1.1382706077549118`}, {
        0.09635491521967741, 1.1416806786810287`}, {0.09108973071537971, 
        1.144766996409945}, {0.08611028375742616, 1.1474796906517688`}, {
        0.08137795626028804, 1.1499683722761738`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0033597946350789132`, 1.}}], 
       ArrowBox[{{0.07302991992544032, 1.1485146709539562`}, {
        0.06517386791683413, 1.1529700193826602`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.008808658707848587, 1.}}], 
       ArrowBox[{{0.06588178871972776, 1.1404521829892236`}, {
        0.059065483326943634`, 1.1460007057224018`}, {0.05269259033557228, 
        1.1507047208102135`}, {0.04698419623903371, 1.1547016013480982`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.014093107488539817`, 1.}}], 
       ArrowBox[{{0.35825491067046866`, 1.2856848067108735`}, {
        0.35087206486357914`, 1.2830516586229348`}, {0.34367700143271035`, 
        1.2804935380167222`}, {0.3364046794699285, 1.2779040612909895`}, {
        0.3292868745709728, 1.275377296804297}, {0.3225553623315821, 
        1.273007312915205}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.003196134426070944, 1.}}], 
       ArrowBox[{{0.005555415391243308, 1.2222935435182771`}, {
        0.004912649735596313, 1.2177746741881816`}, {0.004346328096885848, 
        1.2137874994335693`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.00037518190452416134`, 1.}}], 
       ArrowBox[{{0.4451049585126869, 1.1425520391447164`}, {
        0.4450268619146168, 1.142206548178075}, {0.44494880000810927`, 
        1.141933996825843}, {0.4448278642956024, 1.1415834610894067`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.004312153412737728, 1.}}], 
       ArrowBox[{{0.4688059170095502, 1.1393533401993499`}, {
        0.4638090816320607, 1.1361640702624483`}, {0.4588762607763644, 
        1.1333812485039965`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0044898858285519665`, 1.}}], 
       ArrowBox[{{0.49474234425307867`, 1.1442955402556365`}, {
        0.4895263665486803, 1.140979515239934}, {0.48437669535694794`, 
        1.1381238155370612`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.19147737584298313`, 1.2828884233038091`}, {
        0.1843936795042028, 1.2787723789228411`}, {0.17900427026218552`, 
        1.2756390779219127`}, {0.17353408202861548`, 1.2724555464471563`}, {
        0.168225451778151, 1.2693724759200555`}, {0.1633207164854503, 
        1.2665405577620938`}, {0.1538011490511067, 1.2610562370363563`}, {
        0.14493654086380262`, 1.2559756371710669`}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{0.14376647408211923`, 1.2553142632805794`}, {
        0.1390608965487973, 1.252658077007402}, {0.13354092853488345`, 
        1.249556270431181}, {0.12824191236551707`, 1.2465916472749283`}, {
        0.12317413630374079`, 1.2437705557920595`}, {0.1180960862433777, 
        1.2409430991657944`}, {0.11322872829343103`, 1.2382464439261198`}, {
        0.1085720624539009, 1.2356805900730363`}, {0.10412608872478718`, 
        1.2332455376065439`}, {0.09675142027361867, 1.229239917451085}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.01642612883280385, 1.}}], 
       ArrowBox[{{0.18097469571060726`, 1.0041182884172193`}, {
        0.17331797883883812`, 1.0041320329561683`}, {0.1660274115370086, 
        1.0041448404495554`}, {0.1581962293350136, 1.004158836919222}, {
        0.15071786481317873`, 1.0041714186058563`}, {0.14360968203026508`, 
        1.004182643096207}, {0.13681958880998915`, 1.004192337630027}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.1471045944850138, 1.0039324065789828`}, {
        0.14012448849537198`, 1.0039440004260376`}, {0.13346066754212096`, 
        1.0039541584874074`}, {0.12712879406998698`, 1.0039629354910926`}, {
        0.1210818807447912, 1.0039701672530923`}, {0.11525103023987948`, 
        1.003972889344591}, {0.10971097105459464`, 1.0039737727260747`}, {
        0.09940780638106311, 1.0039694599958955`}, {0.09334251382275846, 
        1.0039639419771578`}}]}, 
      {Arrowheads[{{0.016919728963612983`, 1.}}], 
       ArrowBox[{{0.09199846156500202, 1.0039627191992833`}, {
        0.08959134282518241, 1.0039605292758487`}, {0.08074828150460335, 
        1.0039423625760666`}, {0.07278446066823424, 1.0039146329403237`}, {
        0.06560571856498343, 1.0038770134123938`}, {0.05913770128016374, 
        1.003829375115337}, {0.05330605489908801, 1.003771589172214}, {
        0.046517689043033036`, 1.0036799952080537`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.013683450061987464`, 1.}}], 
       ArrowBox[{{0.4916127607768788, 1.159944938459523}, {0.4862929680294734,
         1.1611946814839391`}, {0.4758119797489978, 1.1630126609844635`}, {
        0.46543672294474553`, 1.1643763027861158`}, {0.4552760332786425, 
        1.1654375973736895`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0041434906163437275`, 1.}}], 
       ArrowBox[{{0.5170508748261994, 1.1626390086942024`}, {
        0.5115462227718188, 1.1637271797184081`}, {0.5060954094105514, 
        1.1646414857826428`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.013789160228595887`, 1.}}], 
       ArrowBox[{{0.08133932960583999, 1.0936192247485947`}, {
        0.07810859058081264, 1.1004465659985045`}, {0.07399054972322379, 
        1.1085194127352458`}, {0.07005735419559411, 1.1153973503307222`}, {
        0.06631384063330818, 1.1207604248262348`}, {0.06274549913021225, 
        1.1255684980978788`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.005178538504402182, 1.}}], 
       ArrowBox[{{0.34843076794593825`, 1.122201280234366}, {
        0.34648421297171234`, 1.1195812564097387`}, {0.3387648949520392, 
        1.1122346553697149`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0037798410245818105`, 1.}}], 
       ArrowBox[{{0.13077326368779993`, 1.2836740611538047`}, {
        0.12292727389535187`, 1.2772181739964477`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0014734541253926057`, 1.}}], 
       ArrowBox[{{0.21920236139331942`, 1.1120751800210797`}, {
        0.21843248228174159`, 1.1137619255561937`}, {0.2176642522711751, 
        1.1151498003420564`}, {0.2175108180734434, 1.1154021294695013`}, {
        0.21739195725308363`, 1.1155932165758982`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.005976595661612633, 1.}}], 
       ArrowBox[{{0.08984313147610481, 1.2155816887683586`}, {
        0.08458625791844572, 1.213357022387555}, {0.07502131913591746, 
        1.2093834084238235`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.003936432478677667, 1.}}], 
       ArrowBox[{{0.004579850234127812, 1.2737311006608791`}, {
        0.004029817196559944, 1.2631638594997763`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.006978962768693166, 1.}}], 
       ArrowBox[{{0.0027541324764390395`, 1.2688985821727188`}, {
        0.0024241829801077966`, 1.258925204776231}, {0.0021360188737098848`, 
        1.2501485788387054`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.013952060334889485`, 1.}}], 
       ArrowBox[{{0.22847922307603005`, 1.1219222678961283`}, {
        0.22290376351045194`, 1.12710593964725}, {0.21744368925469892`, 
        1.131013326321016}, {0.21210053464212025`, 1.1340669453644525`}, {
        0.2068758340060652, 1.1366893142245869`}, {0.20171036035827197`, 
        1.1390960579930698`}, {0.19666324317359146`, 1.1412278052760316`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.010123815682565696`, 1.}}], 
       ArrowBox[{{0.12196193143527023`, 1.0724211185468153`}, {
        0.12046758738537941`, 1.0677492702884341`}, {0.11899710172643978`, 
        1.064543478432261}, {0.1133227438714898, 1.0556441839339306`}, {
        0.11056642022220099`, 1.0523021709671914`}, {0.10788554859240522`, 
        1.0494759334511992`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.006209412094615563, 1.}}], 
       ArrowBox[{{0.14573277825992, 1.080929651682444}, {0.14397755149441008`,
         1.0753335194730906`}, {0.1431074128387281, 1.0733355657267927`}, {
        0.14224412689248647`, 1.0716354742737195`}, {0.13881878913682685`, 
        1.065829966329043}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0037378160187585647`, 1.}}], 
       ArrowBox[{{0.16527830028781923`, 1.0824605681472121`}, {
        0.16448184784689268`, 1.080702844145435}, {0.16134441127677399`, 
        1.0752812915169807`}, {0.16103482214588286`, 1.0748464830215838`}, {
        0.16072595032602843`, 1.074422716232624}, {0.16035624417426106`, 
        1.0739277402421827`}, {0.16024860098425095`, 1.0737859554907034`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.005685348446638538, 1.}}], 
       ArrowBox[{{0.036660622502683524`, 1.2626830198615666`}, {
        0.034403214492954144`, 1.257727558862113}, {0.030330241625447524`, 
        1.2487729242304413`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0077826654240875665`, 1.}}], 
       ArrowBox[{{0.06882448861636455, 1.2453917348601051`}, {
        0.06468538068458839, 1.2413943568429993`}, {0.06079156797556098, 
        1.2376459549462102`}, {0.05373982822575236, 1.2308960795135824`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0038241216768684864`, 1.}}], 
       ArrowBox[{{0.24744857794946698`, 1.123442335781979}, {
        0.24597271845778448`, 1.125093983591827}, {0.24009351130728437`, 
        1.1306142950735945`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{0.5250227888371007, 1.1104195559244554`}, {
        0.5191383424006493, 1.1098059627894328`}, {0.5132698626012582, 
        1.1091909021008555`}, {0.5074652493501091, 1.1085699711980583`}, {
        0.5017724025583836, 1.1079387674203767`}, {0.4909136079979288, 
        1.1066279305976991`}, {0.48032840969122964`, 1.1052862453125762`}, {
        0.4716237163734023, 1.104200394839853}}]}, 
      {Arrowheads[{{0.007890724364086023, 1.}}], 
       ArrowBox[{{0.47029000037439894`, 1.104034022964921}, {
        0.46962756499523806`, 1.1039513887188486`}, {0.459158013077831, 
        1.1026028747423302`}, {0.4492666931068852, 1.1012202173088341`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.020000000000000018`, 1.}}], 
       ArrowBox[{{0.65, 1.0455724206498265`}, {0.6473515822513716, 
        1.0455544036798858`}, {0.6407691051403961, 1.0455081367480583`}, {
        0.6342966939069605, 1.045460016550836}, {0.6279815196414387, 
        1.045409248831621}, {0.6218707534342052, 1.0453550393338158`}, {
        0.6158273727406199, 1.0452997851884085`}, {0.6097117888866246, 
        1.0452458753199898`}, {0.603567323768465, 1.0451925031623668`}, {
        0.5974372992823876, 1.0451388621493458`}, {0.5962397399999962, 
        1.045128071084233}}]}, 
      {Arrowheads[{{0.00780057100699896, 1.}}], 
       ArrowBox[{{0.5948957417485439, 1.0451159604748825`}, {
        0.5913650373246384, 1.045084145714734}, {0.5853938597914633, 
        1.0450275472923378`}, {0.5795670885791087, 1.0449682603159642`}, {
        0.5739280455838204, 1.0449054782194196`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.00449443035311309, 1.}}], 
       ArrowBox[{{0.6093397476959175, 1.0834880118525132`}, {
        0.6032021874559048, 1.0832518183954696`}, {0.5972678508137009, 
        1.083006617310928}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.006681913464895876, 1.}}], 
       ArrowBox[{{0.5965102068559563, 1.0834023477119306`}, {
        0.5903586000152619, 1.0831598124548512`}, {0.584361198133473, 
        1.0829102077200714`}, {0.5785642626982613, 1.0826514126642814`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.6464609374860081, 1.0455944014599268`}, {
        0.6399837745692041, 1.045545089600535}, {0.6334756306392025, 
        1.0454963232088583`}, {0.6269829772157998, 1.045447284083324}, {
        0.6205522858187924, 1.045397154022359}, {0.6142300279679772, 
        1.0453451148243904`}, {0.6080626751831506, 1.0452903482878453`}, {
        0.6020966989841092, 1.0452320362111502`}, {0.5961971487848662, 
        1.0451726448928131`}, {0.5927007821859211, 1.0451386739928832`}}]}, 
      {Arrowheads[{{0.013414820012122929`, 1.}}], 
       ArrowBox[{{0.5913567928079387, 1.0451256157144178`}, {
        0.5902265231574901, 1.0451146339491757`}, {0.5842274673588607, 
        1.0450571751554185`}, {0.578242626645858, 1.0449994402867213`}, {
        0.5723146462753617, 1.044940601118264}, {0.5664861715042517, 
        1.0448798294252266`}, {0.560799847589408, 1.0448162969827892`}, {
        0.5552983197877103, 1.0447491755661316`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0042869150171087125`, 1.}}], 
       ArrowBox[{{0.5718174283678815, 1.0816348647927678`}, {
        0.5659628363919201, 1.0813790760599247`}, {0.5603055302531643, 
        1.0811142039309212`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{0.641994524209407, 1.0455704703357411`}, {
        0.6322660359753556, 1.04548528492299}, {0.6260171675015116, 
        1.0454307630168334`}, {0.6196920369436076, 1.0453776420684762`}, {
        0.6133364015520795, 1.0453250815032382`}, {0.6069960185773635, 
        1.0452722407464408`}, {0.6007166452698954, 1.0452182792234037`}, {
        0.5945440388801114, 1.0451623563594477`}, {0.5885239566584475, 
        1.0451036315798932`}, {0.5882344712267356, 1.045100530406108}}]}, 
      {Arrowheads[{{0.018544944987227533`, 1.}}], 
       ArrowBox[{{0.5868904955293329, 1.0450861327827947`}, {
        0.5827021558553394, 1.0450412643100602`}, {0.5769457994468145, 
        1.0449777849326505`}, {0.571119516278994, 1.0449157188825586`}, {
        0.5652652624074556, 1.0448542181633937`}, {0.559424993887776, 
        1.0447924347787652`}, {0.5536406667755329, 1.0447295207322826`}, {
        0.5479542371263035, 1.0446646280275556`}, {0.5370428944391946, 
        1.0445255146578052`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.6309648249535836, 1.0454380146583238`}, {
        0.621322999035656, 1.0453494795882396`}, {0.6118466063126492, 
        1.045258458107099}, {0.6057496415099813, 1.0452000946321067`}, {
        0.5995776427941777, 1.045143166907087}, {0.5933756305131195, 
        1.0450868134820568`}, {0.5871886250146885, 1.045030172907032}, {
        0.5810616466467664, 1.0449723837320288`}, {0.577205075806917, 
        1.0449340870541894`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.5758610892563502, 1.0449207409438532`}, {
        0.5750397157572346, 1.0449125845070633`}, {0.5691678526939745, 
        1.0448499137821514`}, {0.5634910778048681, 1.0447835101073097`}, {
        0.5578787325677436, 1.0447159630477885`}, {0.5521976427338731, 
        1.0446498591886668`}, {0.5464890550613044, 1.0445843326097048`}, {
        0.5407942163080849, 1.0445185173906633`}, {0.5351543732322621, 
        1.0444515476113019`}, {0.5296107725918832, 1.0443825573513805`}, {
        0.5221028365973348, 1.044278408737798}}]}, 
      {Arrowheads[{{0.0006628455447601324, 1.}}], 
       ArrowBox[{{0.5207589130806773, 1.0442597660947173`}, {
        0.5189772856496478, 1.0442350517088999`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.00007202320478496737, 1.}}], 
       ArrowBox[{{0.4017365884369921, 1.1371763998606266`}, {
        0.4017341552058413, 1.1369828091694734`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.018189350875490826`, 1.}}], 
       ArrowBox[{{0.5499631133991825, 1.0445344366949614`}, {
        0.5444324791094506, 1.0444640036078956`}, {0.5389652235483753, 
        1.0443923974574811`}, {0.5334304422162227, 1.0443222612149665`}, {
        0.5278686505756394, 1.0442527129356116`}, {0.5223203640892713, 
        1.0441828706746767`}, {0.5114263684297671, 1.0440387764291084`}, {
        0.5010725789388805, 1.0438829229203435`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.01569773484075203, 1.}}], 
       ArrowBox[{{0.5254280564605903, 1.0441382379945983`}, {
        0.5147208495022721, 1.0439878910683469`}, {0.5039076136868177, 
        1.0438399373611464`}, {0.49330643558563564`, 1.0436871972158444`}, {
        0.48323540177013435`, 1.0435224909752876`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019227228996612993`, 1.}}], 
       ArrowBox[{{0.5174201302336464, 1.0437804938548587`}, {
        0.5067659191733114, 1.0436277534859417`}, {0.49635389011419884`, 
        1.0434701136183406`}, {0.4858379119327007, 1.0433148925053386`}, {
        0.47552983199597376`, 1.043154833883138}, {0.4657414976711748, 
        1.0429826814879402`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.00418850493501183, 1.}}], 
       ArrowBox[{{0.5544464095741575, 1.0805490729957405`}, {
        0.5487260943022826, 1.0802848961542093`}, {0.5432001127845276, 
        1.0800116811384703`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{0.5099145922338051, 1.0436134174908638`}, {
        0.49899676246129165`, 1.0434639434598778`}, {0.4886368573312186, 
        1.043302047261361}, {0.4785146665605782, 1.043135136377817}, {
        0.46829058719642047`, 1.0429706793824352`}, {0.4582702850192971, 
        1.0428013146107284`}, {0.4561592825236225, 1.042760999612106}}]}, 
      {Arrowheads[{{0.002253316662861039, 1.}}], 
       ArrowBox[{{0.45481547474196077`, 1.042735336161221}, {
        0.4487594258097594, 1.0426196803982088`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.004091864868470136, 1.}}], 
       ArrowBox[{{0.537580283974161, 1.0795107479371842`}, {
        0.5265949180726743, 1.0789559813079674`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{0.4916493083266699, 1.0432716343797854`}, {
        0.48103409601883007`, 1.0431131884119973`}, {0.47096584040408107`, 
        1.0429421071449774`}, {0.46113075326679104`, 1.0427659048262696`}, {
        0.4511958653243644, 1.042592184946078}, {0.4414605789922108, 
        1.0424135001888537`}, {0.4378953312771734, 1.0423397358818483`}}]}, 
      {Arrowheads[{{0.0016101284851912354`, 1.}}], 
       ArrowBox[{{0.4365515660441005, 1.042311933631032}, {
        0.43222429668573986`, 1.0422224032390488`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{0.4737965764376282, 1.042899581426263}, {
        0.46348217692138527`, 1.0427320688982284`}, {0.4537035723182452, 
        1.0425517355913587`}, {0.44415350207508564`, 1.0423661839537894`}, {
        0.4345057504457983, 1.0421831364592093`}, {0.4250533615887665, 
        1.0419950806786504`}, {0.4200441498044527, 1.0418829954297957`}}]}, 
      {Arrowheads[{{0.0009715790962200356, 1.}}], 
       ArrowBox[{{0.41870043333272605`, 1.0418529286644824`}, {
        0.41608937966237375`, 1.0417945041831436`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0039955759479438, 1.}}], 
       ArrowBox[{{0.5212769013145226, 1.0778448061234267`}, {
        0.5105510915969028, 1.0772826720471953`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0007977793439071359, 1.}}], 
       ArrowBox[{{0.3726739179224548, 1.1440704975666707`}, {
        0.3721365084390662, 1.1443604642107361`}, {0.3715997404458193, 
        1.144640094131375}, {0.3709564712981202, 1.1449632182422946`}, {
        0.37076902301999975`, 1.1450551232403412`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{0.4563301057614588, 1.042504894909099}, {0.4463149881212862,
         1.0423281482939806`}, {0.4368243027856674, 1.0421384231072208`}, {
        0.42755742645368566`, 1.041943391250862}, {0.41819502104866996`, 
        1.0417508782815368`}, {0.40902367378972193`, 1.0415533275381446`}, {
        0.4025794897630691, 1.0413975579684607`}}]}, 
      {Arrowheads[{{0.0003370857657305827, 1.}}], 
       ArrowBox[{{0.4012358294362429, 1.0413650788539528`}, {
        0.4003299718959429, 1.0413431823595847`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{0.4392283487121671, 1.042092208552745}, {0.429511211096407, 
        1.0419060068442578`}, {0.4203069347285444, 1.0417066979865515`}, {
        0.41132164743151156`, 1.0415020035192732`}, {0.40224301759934633`, 
        1.0412998353152496`}, {0.3933510728374459, 1.0410926145847168`}, {
        0.3854798532902323, 1.04088721920681}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.002283576204355509, 1.}}], 
       ArrowBox[{{0.3774270678867203, 1.1280120379984029`}, {
        0.3762680089895462, 1.1265006944784643`}, {0.3751139269431478, 
        1.1252338961160142`}, {0.3745970547166675, 1.1247176024650498`}, {
        0.37408112587345554`, 1.1242254520447408`}, {0.37346323960082795`, 
        1.1236620433113218`}, {0.37328326715829524`, 1.1235026138064266`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019577922658116, 1.}}], 
       ArrowBox[{{0.4224588565299491, 1.0416663396205337`}, {
        0.4130388268002519, 1.0414703834276455`}, {0.40411986345191236`, 
        1.0412612224007867`}, {0.3954149681185998, 1.0410466066751547`}, {
        0.3866189538173382, 1.0408345167395265`}, {0.3780051774519745, 
        1.0406173752238905`}, {0.3698469959263555, 1.0403876047582357`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.010122431532495244`, 1.}}], 
       ArrowBox[{{0.5228033420205966, 1.0776008898976088`}, {
        0.5171688918228606, 1.077330681358101}, {0.5115914768543774, 
        1.0770578191783546`}, {0.5061138735370867, 1.0767803131281917`}, {
        0.4956292075438415, 1.0762034084958998`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.009891638087718665, 1.}}], 
       ArrowBox[{{0.5071919547194441, 1.0768039290330111`}, {
        0.5016853760769288, 1.076523617832979}, {0.49088279117539146`, 
        1.0759531740481871`}, {0.48064173262983595`, 1.0753565399041238`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.018951531537365108`, 1.}}], 
       ArrowBox[{{0.40600919266083235`, 1.0411884251691905`}, {
        0.39688581785151456`, 1.0409828805040497`}, {0.3882514437198045, 
        1.040764083314094}, {0.3798260943723105, 1.0405397806340586`}, {
        0.37131189456474345`, 1.0403179921388832`}, {0.36297539567732234`, 
        1.0400911752739874`}, {0.35508314909026617`, 1.0398517874847903`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.018330800943764703`, 1.}}], 
       ArrowBox[{{0.39002628963010944`, 1.0405112726683612`}, {
        0.38119739759165583`, 1.0402984378175475`}, {0.3728451330274194, 
        1.0400724119385274`}, {0.36469670784337355`, 1.0398408763220777`}, {
        0.35646174942482, 1.0396118233605045`}, {0.34839985747528174`, 
        1.039377805089178}, {0.34077063169828176`, 1.0391313735434682`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.007626201932113903, 1.}}], 
       ArrowBox[{{0.48422551904029487`, 1.074771105412991}, {
        0.4737175256203313, 1.0741909858600076`}, {0.4637598676730444, 
        1.0735856306622347`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.004883072579303621, 1.}}], 
       ArrowBox[{{0.0289125023684356, 1.039041651413489}, {
        0.028562870094469006`, 1.0332694660264392`}, {0.02838953822175543, 
        1.0316111517867874`}, {0.028217530837547862`, 1.0302778733228182`}, {
        0.027534874600056047`, 1.0260002284116665`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.004070761699468038, 1.}}], 
       ArrowBox[{{0.04830980102397281, 1.0411428667359273`}, {
        0.04782972212101513, 1.0390609969881457`}, {0.04735534476197655, 
        1.0373426863772006`}, {0.04620155386356413, 1.0335154181415827`}, {
        0.04507984998132228, 1.0307048471011266`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.007427989387431332, 1.}}], 
       ArrowBox[{{0.2970721189396678, 1.1041860661966898`}, {
        0.29366380628258804`, 1.1017587438628527`}, {0.28689454175421236`, 
        1.097192614471343}, {0.2803082245245013, 1.093365343087016}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0007489189690208602, 1.}}], 
       ArrowBox[{{0.2886785289350006, 1.132555355215511}, {
        0.28821856167241544`, 1.1329013718769791`}, {0.2877591893397414, 
        1.1332364712911291`}, {0.2872087330304302, 1.1336253603261088`}, {
        0.2870483426636143, 1.1337362836338272`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0021223426462888438`, 1.}}], 
       ArrowBox[{{0.5361803988969969, 1.1656812959956393`}, {
        0.530532514606458, 1.1664871214578725`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.017723407156077946`, 1.}}], 
       ArrowBox[{{0.3745755847003568, 1.039954759846959}, {
        0.36603516485837895`, 1.03973302332599}, {0.3579590832387724, 
        1.0394981500806413`}, {0.3500816862352375, 1.039257755504253}, {
        0.342120054471977, 1.0390198105118813`}, {0.3343268922281677, 
        1.0387769663514759`}, {0.3269549037829867, 1.0385218742709852`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0063923063581820625`, 1.}}], 
       ArrowBox[{{0.10344279736740644`, 1.3}, {0.09829214584288921, 
        1.2940018145391288`}, {0.09225126791218057, 1.2869611412928685`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0033893663084329346`, 1.}}], 
       ArrowBox[{{0.36595264972135305`, 1.1452777397125464`}, {
        0.3576347754253755, 1.1489956458772366`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0026151048361860336`, 1.}}], 
       ArrowBox[{{0.10012841079250437`, 1.0491203211102251`}, {
        0.09769281385483446, 1.0463805546113951`}, {0.09532262280768425, 
        1.0439936033258113`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.007039424217849913, 1.}}], 
       ArrowBox[{{0.12559134386719306`, 1.2794791302082558`}, {
        0.11805711023846274`, 1.2732803839239546`}, {0.11097299976376913`, 
        1.2674635942073051`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.006585791173024445, 1.}}], 
       ArrowBox[{{0.03266090833094423, 1.1135234919554804`}, {
        0.02922731862834451, 1.122469273673996}, {0.026130361093328735`, 
        1.129976793819711}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0004463462252408111, 1.}}], 
       ArrowBox[{{0.41542664619867564`, 1.139125939286769}, {
        0.41537745451210295`, 1.138385186995243}, {0.41530125298323417`, 
        1.1379341365928413`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019231819813580988`, 1.}}], 
       ArrowBox[{{0.48731862000113985`, 1.1050574322091913`}, {
        0.4767152723346779, 1.1037470437432644`}, {0.4663807974438632, 
        1.1024088086286246`}, {0.4559328805471183, 1.1010762036148813`}, {
        0.4457118476622336, 1.0997323383993451`}, {0.43605802480699957`, 
        1.0983603226793268`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.007457608497314895, 1.}}], 
       ArrowBox[{{0.4703078557550858, 1.0741461584908334`}, {
        0.4600323244655938, 1.0735442980819685`}, {0.45029877702215176`, 
        1.0729176722196352`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.000822451414942657, 1.}}], 
       ArrowBox[{{0.36294516775167424`, 1.1189558646913906`}, {
        0.3624318402936104, 1.1185925539803545`}, {0.36191940350969426`, 
        1.1182366255439327`}, {0.36130564812595156`, 1.1178185823217541`}, {
        0.36112686981202097`, 1.117698385150704}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.00418909993804071, 1.}}], 
       ArrowBox[{{0.18301976053087105`, 1.091582743153096}, {
        0.17976055143189767`, 1.0830293967146916`}, {0.17943905234113844`, 
        1.0825069450718638`}, {0.17911828016449483`, 1.0820033689578672`}, {
        0.1787343031537051, 1.0814214389618126`}, {0.17862249915254985`, 
        1.0812558761121946`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.008989348500606514, 1.}}], 
       ArrowBox[{{0.3384552220992014, 1.14624601185497}, {
        0.33061788818911464`, 1.148920657825699}, {0.3228628134340313, 
        1.1511605109905216`}, {0.31527504707940124`, 1.153015007194646}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.01712977590857122, 1.}}], 
       ArrowBox[{{0.3596693047006345, 1.03947228529797}, {0.3514111699238607, 
        1.0392405133213196`}, {0.34360515397849656`, 1.038995675729694}, {
        0.33599269162417034`, 1.0387453081531268`}, {0.3282982762092115, 
        1.0384973512069198`}, {0.3207677669155179, 1.038244572999992}, {
        0.31364702292498775`, 1.0379797416412626`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0065936851555305175`, 1.}}], 
       ArrowBox[{{0.5667931720514953, 1.1651739999016377`}, {0.56385334727802,
         1.165785516267354}, {0.5609272547966815, 1.1662728051523097`}, {
        0.5550736559080829, 1.167130096559634}, {0.5492771485855793, 
        1.167836040643973}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.004334402786449335, 1.}}], 
       ArrowBox[{{0.07651512042786966, 1.0436224628845736`}, {
        0.07287373321870444, 1.0385146264011018`}, {0.07110188599722317, 
        1.0363441824919988`}, {0.06937671297890025, 1.0344304245157854`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.007425941776200407, 1.}}], 
       ArrowBox[{{0.4508998836064612, 1.1589738456369676`}, {
        0.44096159016263764`, 1.1608889411020549`}, {0.4312267298124555, 
        1.1623275618195235`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.006042352476314077, 1.}}], 
       ArrowBox[{{0.4611394933841422, 1.1350883729871846`}, {
        0.456174085610693, 1.1324460315075033`}, {0.44643809602086104`, 
        1.1282095461068493`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0072151595961930295`, 1.}}], 
       ArrowBox[{{0.43730201813695185`, 1.162494158392119}, {
        0.4275619130194536, 1.1636768377786924`}, {0.4180291520339159, 
        1.1646613631467486`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.018763018412662057`, 1.}}], 
       ArrowBox[{{0.48756115285950197`, 1.0744485921066456`}, {
        0.47716390027357025`, 1.073857503024573}, {0.4670170395099359, 
        1.0732544908360877`}, {0.456763648300906, 1.0726562423993928`}, {
        0.44672331798266723`, 1.0720484664591172`}, {0.43721563989140644`, 
        1.07141687175989}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0035621772581343435`, 1.}}], 
       ArrowBox[{{0.13597041288202716`, 1.0635916206206584`}, {
        0.13267301127979306`, 1.0597593673967085`}, {0.1294669827043717, 
        1.0565733012216239`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.016532605648431824`, 1.}}], 
       ArrowBox[{{0.3449580549266174, 1.0387791116588008`}, {
        0.33698436052633124`, 1.0385398779289798`}, {0.3294500896223117, 
        1.0382877621669533`}, {0.32210402797441834`, 1.0380301570894037`}, {
        0.3146783748656847, 1.037774904083201}, {0.30741190467863166`, 
        1.0375149469343046`}, {0.3005433917957803, 1.0372432294286746`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.006374193138461475, 1.}}], 
       ArrowBox[{{0.031123798241547724`, 1.2528614761269918`}, {
        0.027445604320185772`, 1.2445032885530578`}, {0.024223485741288586`, 
        1.237177824522246}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.004081471532021847, 1.}}], 
       ArrowBox[{{0.1944606450400718, 1.1411785647872703`}, {
        0.1843887119124783, 1.1455292388287859`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0039041532434429998`, 1.}}], 
       ArrowBox[{{0.19594320214620312`, 1.1003323156896982`}, {
        0.1959359562712338, 1.100073806983668}, {0.19592051375668076`, 
        1.0988619578981829`}, {0.1959050793934737, 1.0985250250574512`}, {
        0.19588965067901412`, 1.09827430433937}, {0.19580225181597125`, 
        1.097267411331179}, {0.1957149569048998, 1.0965936564623995`}, {
        0.19562774926823834`, 1.0960462791335486`}, {0.195584726959507, 
        1.0958056732439778`}, {0.19554172327705732`, 1.0955791744875951`}, {
        0.19547510310230976`, 1.0952509350395618`}, {0.19539749714432758`, 
        1.094896724987746}, {0.1953474579812064, 1.0946813977734522`}, {
        0.19529744126770612`, 1.094474957261436}, {0.19479843122842797`, 
        1.092710276836237}, {0.19430141463391656`, 1.0913271432795748`}, {
        0.19380624362038906`, 1.0901448481761933`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.005231229505792649, 1.}}], 
       ArrowBox[{{0.016771431755094008`, 1.055896089718559}, {
        0.016361723252975986`, 1.0610490645488546`}, {0.015956030030271184`, 
        1.0657033095526203`}, {0.015558668663800658`, 
        1.0699055317481272`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.003093095745223621, 1.}}], 
       ArrowBox[{{0.316639278825217, 1.1050307409204407`}, {
        0.3094619226055845, 1.1008334084267466`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.018799758983652024`, 1.}}], 
       ArrowBox[{{0.47348278823342904`, 1.1030248969418501`}, {
        0.46312193697986964`, 1.1016926472829291`}, {0.45302579651098784`, 
        1.1003348683151288`}, {0.4428181942188685, 1.098981499080133}, {
        0.43283351557322414`, 1.0976193103795284`}, {0.42340614604376703`, 
        1.0962350730149022`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{0.4982162278811836, 1.2304287640537201`}, {
        0.48866268409019814`, 1.2287103855308872`}, {0.4793149599324185, 
        1.2270550595335035`}, {0.4701730554078447, 1.225462786061568}, {
        0.4609958037845672, 1.223860187151057}, {0.4517263808844187, 
        1.222229687106346}, {0.44526797395222106`, 1.2211102650817887`}}]}, 
      {Arrowheads[{{0.016256634071858688`, 1.}}], 
       ArrowBox[{{0.443943666720981, 1.2208807257081484`}, {
        0.44264130053801237`, 1.2206549893300354`}, {0.4340170765759612, 
        1.2192197972247245`}, {0.42559083305473533`, 1.2178460421509931`}, {
        0.41708151018136047`, 1.2164481424518483`}, {0.4087383460122836, 
        1.2150985320035308`}, {0.4008105786039516, 1.2138696446822812`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.006902417916698904, 1.}}], 
       ArrowBox[{{0.08040168415228277, 1.2116767299822755`}, {
        0.07128120836284357, 1.2079175367810964`}, {0.06322006155128986, 
        1.204672962659976}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.001503072580131728, 1.}}], 
       ArrowBox[{{0.3953854446190354, 1.1431101620675883`}, {
        0.3940120214212128, 1.1441713285647237`}, {0.39346364601113565`, 
        1.1445449226069664`}, {0.3929158602330172, 1.1448973273442062`}, {
        0.3922593082174262, 1.1452961873790715`}, {0.3920679742787484, 
        1.1454081708651984`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.002498696245098795, 1.}}], 
       ArrowBox[{{0.19358781164571537`, 1.1058305112159095`}, {
        0.19275756188069668`, 1.1080987133066322`}, {0.19192938352462838`, 
        1.1098550232516113`}, {0.19159858635616805`, 1.1104723505021625`}, {
        0.1912681809779205, 1.1110552509005538`}, {0.19087222472274015`, 
        1.111716175427119}, {0.190756845584258, 1.1119020161773774`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.00007285282562193115, 1.}}], 
       ArrowBox[{{0.5053045535663747, 1.15180197390556}, {0.5053008680197292, 
        1.1519977753128954`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0065971704111957375`, 1.}}], 
       ArrowBox[{{0.530350175398042, 1.1481534728411142`}, {
        0.5275938659067358, 1.1468760832832845`}, {0.5248549227372165, 
        1.1457035002486198`}, {0.5193788570793245, 1.143454611649592}, {
        0.5139688739382307, 1.1413727863344354`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.00774390464708852, 1.}}], 
       ArrowBox[{{0.30869249928922515`, 1.0378152084631467`}, {
        0.30152730617564705`, 1.0375443223724234`}, {0.29451675512072856`, 
        1.0372688350968182`}, {0.287892809212459, 1.0369818448590087`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.003609686058619217, 1.}}], 
       ArrowBox[{{0.004398128244505625, 1.1601234543929198`}, {
        0.0032918531515422726`, 1.166033151427195}, {0.0029281854793478516`, 
        1.1679542995463355`}, {0.0026041611921590853`, 
        1.1696593854893658`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.010867907409190957`, 1.}}], 
       ArrowBox[{{0.43993242597940063`, 1.098156933293778}, {
        0.4299641754322811, 1.096789380044815}, {0.4202147720563452, 
        1.09541534339691}, {0.4110124866083685, 1.094025098251651}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0001565286635712426, 1.}}], 
       ArrowBox[{{0.1947565384855493, 1.3}, {0.19440449287641137`, 
        1.2997695492164318`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0035809979789911055`, 1.}}], 
       ArrowBox[{{0.65, 1.1364825406902304`}, {0.646812731321031, 
        1.1362368446653828`}, {0.6404072137083134, 1.135683470737431}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0023582079964658133`, 1.}}], 
       ArrowBox[{{0.633800130989045, 1.1358208888219277`}, {
        0.6274883943431424, 1.1352323959718078`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0031486276736898636`, 1.}}], 
       ArrowBox[{{0.36935427756117556`, 1.0919804244611646`}, {
        0.36105779879275923`, 1.0903055837499154`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0023243869841016226`, 1.}}], 
       ArrowBox[{{0.6213149185962898, 1.1343385819259255`}, {
        0.6150969331468389, 1.1337248785223566`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.010903431554070017`, 1.}}], 
       ArrowBox[{{0.3362332757839254, 1.277834749777505}, {0.3292073413451189,
         1.275353454443834}, {0.3221048713587663, 1.2728409703636467`}, {
        0.3151554724675059, 1.2703908637764918`}, {0.308588751313976, 
        1.2680967009219164`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.004268987710579766, 1.}}], 
       ArrowBox[{{0.12492981478666626`, 1.1028817398586863`}, {
        0.12179604052368957`, 1.1082835583685886`}, {0.1187263219626869, 
        1.1125184986269374`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{0.5076310065859337, 1.1982294707160355`}, {
        0.4977773593894392, 1.1971002285155756`}, {0.48840017066645025`, 
        1.196121831178418}, {0.479227131920141, 1.1952132436307918`}, {
        0.4699678458706488, 1.194280801673312}, {0.46088105442752253`, 
        1.1933960685355394`}, {0.45414527064176186`, 1.1928003839801375`}}]}, 
      {Arrowheads[{{0.00021695980385382795`, 1.}}], 
       ArrowBox[{{0.45280644304561807`, 1.192681983665232}, {
        0.45222549950031116`, 1.1926306074470359`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0034495315147696063`, 1.}}], 
       ArrowBox[{{0.15382333303716408`, 1.1275020870353234`}, {
        0.14990689181833147`, 1.1301894479185377`}, {0.1460810983424481, 
        1.1326019457423266`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.015814009756321627`, 1.}}], 
       ArrowBox[{{0.31490670165184315`, 1.068571765236158}, {
        0.3073210958329781, 1.0674989771479793`}, {0.3001829943255392, 
        1.0664298724617152`}, {0.29323791914849306`, 1.0653592200071298`}, {
        0.2862126928463765, 1.0642858167861036`}, {0.27934776879440065`, 
        1.0632179150979593`}, {0.2728836003677765, 1.0621637672420199`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0030596174866906137`, 1.}}], 
       ArrowBox[{{0.412014089869703, 1.3}, {0.41193257055484, 
        1.299971177339517}, {0.40425582751797096`, 1.2972699821683515`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0044806190057806936`, 1.}}], 
       ArrowBox[{{0.2232301868893236, 1.0800357177469166`}, {
        0.21795528429460387`, 1.0768527587595231`}, {0.21282013679482945`, 
        1.0739811062113638`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.010798739931621403`, 1.}}], 
       ArrowBox[{{0.16940825592121586`, 1.2321027999865422`}, {
        0.15970283804893315`, 1.2286246796514768`}, {0.15061855956639691`, 
        1.2254224664224376`}, {0.1420371070129352, 1.2224362697520286`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.007932035335370433, 1.}}], 
       ArrowBox[{{0.3152906263587446, 1.2704907407246215`}, {
        0.30835347206708513`, 1.2680533718182367`}, {0.30156801750083434`, 
        1.2656780211459937`}, {0.29516181224810534`, 1.2634577160591054`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.007885000035129134, 1.}}], 
       ArrowBox[{{0.45925532381393674`, 1.193874522403102}, {
        0.4483906550157154, 1.1928271466436005`}, {0.43814779646591145`, 
        1.191946149889942}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0024574796974761747`, 1.}}], 
       ArrowBox[{{0.28838206009842077`, 1.260821314348405}, {
        0.2821325567471486, 1.2586806412031666`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0024175908079804545`, 1.}}], 
       ArrowBox[{{0.253793045598398, 1.1555807062913486`}, {
        0.24742171200108348`, 1.1568612228754418`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0009692712827379134, 1.}}], 
       ArrowBox[{{0.65, 1.1766890275856539`}, {0.6474107377427141, 
        1.1763985625769844`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0003407906696317594, 1.}}], 
       ArrowBox[{{0.6098431747209604, 1.165958498771935}, {0.6098402027092003,
         1.1650424222759534`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.001450061361363523, 1.}}], 
       ArrowBox[{{0.5962192134792117, 1.1648266943440098`}, {
        0.5956642881302029, 1.165182135536505}, {0.5951097301927677, 
        1.1654563753808198`}, {0.5944100992575556, 1.1657404133842968`}, {
        0.5937111342955212, 1.165979530383742}, {0.593012857422268, 
        1.1661879240091264`}, {0.5928035106685879, 1.1662456067444897`}, {
        0.5926290992614777, 1.1662923779942416`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0026308010450150137`, 1.}}], 
       ArrowBox[{{0.65, 1.1637906643725842`}, {0.6429857184209959, 
        1.162889989782742}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.010092258103614379`, 1.}}], 
       ArrowBox[{{0.05760442890845144, 1.146182611415064}, {
        0.05074681384882505, 1.1514837490864138`}, {0.04474692908180993, 
        1.1557539610291683`}, {0.03986492903167181, 1.1590443255292573`}, {
        0.03550325981019454, 1.1618933682712753`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.011754808500534366`, 1.}}], 
       ArrowBox[{{0.4561460998848941, 1.1935312907806859`}, {
        0.44528817839477447`, 1.1925156962807049`}, {0.4346742083749677, 
        1.1915615161145767`}, {0.42467011703094304`, 1.1907608717830815`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0032860218715650997`, 1.}}], 
       ArrowBox[{{0.1413369408507702, 1.1333363049817127`}, {
        0.13386424505535943`, 1.1380462708477541`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.010232674129228868`, 1.}}], 
       ArrowBox[{{0.10241408578224412`, 1.0779200097057053`}, {
        0.10230620637299166`, 1.0791460861171873`}, {0.10219833147250387`, 
        1.080089831168109}, {0.10188215920124818`, 1.0822461833066397`}, {
        0.10156641464072029`, 1.0839003159278437`}, {0.10125119660199113`, 
        1.0852981590544086`}, {0.09999670944194369, 1.089760758448467}, {
        0.0987531867793351, 1.093139872407579}, {0.09627751874155818, 
        1.0991992023010797`}, {0.09385099624513434, 1.1038521477042262`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.012309784790396986`, 1.}}], 
       ArrowBox[{{0.3009925305566618, 1.2655043031718884`}, {
        0.2930108334747231, 1.2627389432512706`}, {0.2849212161399217, 
        1.2599293184561398`}, {0.2770474393108457, 1.257208223410034}, {
        0.2697132637460832, 1.25470845273649}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.011486609672767028`, 1.}}], 
       ArrowBox[{{0.44241488935986156`, 1.193133929333416}, {
        0.4318001791357722, 1.1921722315290306`}, {0.42142529464089634`, 
        1.1912681228602475`}, {0.41164997446905455`, 1.1905079870304696`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0023356492573702063`, 1.}}], 
       ArrowBox[{{0.26633478050357307`, 1.0605463672453197`}, {
        0.2601408986248666, 1.0595192173811652`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.006377013797883746, 1.}}], 
       ArrowBox[{{0.14607422116017948`, 1.2238772664400317`}, {
        0.1377351915409764, 1.2210018486887901`}, {0.12985758307666515`, 
        1.2183211361078823`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.5030620823026314, 1.2976515403817364`}, {
        0.4933424230703374, 1.2947404924680703`}, {0.48382618398695254`, 
        1.2918991944341986`}, {0.4745133650524771, 1.2891276462801218`}, {
        0.46540396626691094`, 1.286425848005839}, {0.45649798763025423`, 
        1.2837937996113509`}, {0.45152923235053516`, 1.2823308465854073`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.4502399036892422, 1.2819512289225747`}, {
        0.44779542914250664`, 1.281231501096657}, {0.43905897586896586`, 
        1.2786563348272248`}, {0.4302321193552596, 1.2760493400947017`}, {
        0.42158606932188414`, 1.27350600228836}, {0.4133920354893351, 
        1.2711218067974703`}, {0.4053928194401176, 1.2688058861946518`}, {
        0.3986431613490418, 1.26684732451167}}]}, 
      {Arrowheads[{{0.005987837137911517, 1.}}], 
       ArrowBox[{{0.3973523532640743, 1.2664727681680468`}, {
        0.3973125410194021, 1.2664612157700028`}, {0.38939438734168264`, 
        1.2641740449890149`}, {0.38188154552145326`, 1.2620306233171779`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.006767220891648911, 1.}}], 
       ArrowBox[{{0.22082215700128027`, 1.2133153651406317`}, {
        0.21463392204525641`, 1.212055543030666}, {0.20860726682109504`, 
        1.2108427748089434`}, {0.20298456092658992`, 1.2097476413078279`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.011972576898006316`, 1.}}], 
       ArrowBox[{{0.40054344609681586`, 1.2678395100337614`}, {
        0.39268962807246516`, 1.2655754650359003`}, {0.38475541473374053`, 
        1.2632827968497171`}, {0.3769819920237638, 1.2610473750401783`}, {
        0.3696105458856569, 1.2589550691722506`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.008813247881376702, 1.}}], 
       ArrowBox[{{0.2801734857675336, 1.2584843921058633`}, {
        0.2723891306896251, 1.2558005292036227`}, {0.2648130156811054, 
        1.2532021624663285`}, {0.25775750084605764`, 1.2508175361414005`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.01203647302035603, 1.}}], 
       ArrowBox[{{0.4069506143085236, 1.2418125451648916`}, {
        0.3989341487374642, 1.2400117684197864`}, {0.39083645774210146`, 
        1.2381849325266627`}, {0.38290121759534534`, 1.2364102149295766`}, {
        0.37537210457010595`, 1.2347657930725846`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.002906480385685901, 1.}}], 
       ArrowBox[{{0.08104172484611015, 1.066806598820036}, {
        0.08104149434012821, 1.0670925946708523`}, {0.0810389992870293, 
        1.067521219766952}, {0.08103004076108977, 1.0678354598177644`}, {
        0.0810202411023518, 1.0684843745106662`}, {0.08101043819586691, 
        1.068864541479208}, {0.08100063336263799, 1.069166255174988}, {
        0.08098776776429847, 1.06950037937655}, {0.08097490046376994, 
        1.0697897767505877`}, {0.08095495378464562, 1.070181593260445}, {
        0.08094320261010064, 1.0703875723360967`}, {0.08092851304143599, 
        1.07062915961941}, {0.08086387550030238, 1.0715440260072948`}, {
        0.08080511517730031, 1.0722311276129242`}, {0.08074636226586027, 
        1.0728352659808191`}, {0.08054112158886884, 1.0745976592355948`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0001044901556174102, 1.}}], 
       ArrowBox[{{0.31344252595930866`, 1.1235782359554665`}, {
        0.31342490938671297`, 1.123297908372099}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.00044741508572670785`, 1.}}], 
       ArrowBox[{{0.5894146493725915, 1.1549515563407522`}, {
        0.5892035941411484, 1.1548935092300256`}, {0.588992625078702, 
        1.1548355374821833`}, {0.5886763221830471, 1.1547487103206484`}, {
        0.5884655468236439, 1.1546909055005816`}, {0.5882548574754266, 
        1.154633173689426}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.0003367277397196973, 1.}}], 
       ArrowBox[{{0.06931782944006017, 1.3}, {0.06885761948296894, 
        1.299220563706102}}]}}}}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV0nk4lfsWB3BF5KR0otKgzjbEIZrYIvqWPKiOjBEOhTiK4kaJ2qVI7G0o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        "]]},
      Annotation[#, "Charting`Private`Tag$24095#1"]& ]}, {}, {}}},
  AspectRatio->1,
  AxesStyle->Directive[
    RGBColor[1, 0, 0], 15],
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{
    FormBox[
     StyleBox[
     "\"\\!\\(\\*\\nStyleBox[\\\"J\\\",\\nFontSlant->\\\"Italic\\\"]\\)/\\!\\(\
\\*\\nStyleBox[\\\"h\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"", FontSize -> 16, 
      StripOnInput -> False], TraditionalForm], 
    FormBox[
     StyleBox[
     "\"\\!\\(\\*\\nStyleBox[\\\"H\\\",\\nFontSlant->\\\"Italic\\\"]\\)/\\!\\(\
\\*\\nStyleBox[\\\"h\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"", FontSize -> 16, 
      StripOnInput -> False], TraditionalForm]},
  FrameStyle->Automatic,
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{{0}, {0}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[
    RGBColor[1, 0, 0], 15],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "TransparentPolygonMesh" -> True},
  PlotRange->{{0, 0.65}, {1, 1.3}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  RotateLabel->False,
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.7997777369886093`*^9, 3.7997777838291583`*^9}, 
   3.799777827967094*^9, 3.799917107544817*^9, 3.7999276266274548`*^9, {
   3.799928338279245*^9, 3.7999283475428267`*^9}, 3.7999283863797593`*^9, {
   3.7999285847636557`*^9, 3.79992860506138*^9}, {3.7999286365398893`*^9, 
   3.799928655612119*^9}, 3.800449880260871*^9, 3.800523719448903*^9, 
   3.800524726923156*^9, 3.8187713941955786`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["4.3(a) Multiple cosmic fluids", "Subsubsection",
 CellChangeTimes->{{3.7992319771057873`*^9, 3.799231985918316*^9}, {
  3.799232017693398*^9, 3.7992320177920322`*^9}, {3.800536164899555*^9, 
  3.8005361680932465`*^9}}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"SetDirectory", "[", 
    RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";", 
   "\[IndentingNewLine]", 
   RowBox[{"Get", "[", "\"\<self_tuning_GCCG.m\>\"", "]"}]}], "*)"}]], "Input",
 CellChangeTimes->{{3.801028784938676*^9, 3.801028787495489*^9}, {
  3.801031757840335*^9, 3.8010317595994844`*^9}, {3.818771422886247*^9, 
  3.8187714262049665`*^9}}],

Cell[TextData[{
 "In this section, we finally consider the more realistic case in which there \
is a nontrivial mixture of cosmic fluids. We add matter and vacuum-energy, \
with the abundances ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[CapitalOmega]", "i"], "=", 
    RowBox[{
     SubscriptBox["\[Rho]", "i"], 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["a", "0"], 
       RowBox[{
        RowBox[{"-", "3"}], 
        RowBox[{"(", 
         RowBox[{"1", "+", "w"}], ")"}]}]], "/", 
      RowBox[{"(", 
       RowBox[{"3", 
        SuperscriptBox[
         SubscriptBox["H", "0"], "2"]}], ")"}]}]}]}], TraditionalForm]]],
 " where ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "0"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["H", "0"], TraditionalForm]]],
 " are the present day scale factor and Hubble parameter, respectively,..."
}], "Text",
 CellChangeTimes->{{3.7984606407169886`*^9, 3.7984607025169163`*^9}, {
  3.7985632541699514`*^9, 3.7985632785071697`*^9}, {3.7985650840134373`*^9, 
  3.7985651042640886`*^9}, {3.7985651720501785`*^9, 3.798565202266637*^9}, {
  3.7985653338133783`*^9, 3.7985653668462267`*^9}, {3.7985673498698225`*^9, 
  3.7985673539997644`*^9}, {3.800240980002781*^9, 3.8002410241363688`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"addmat", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"P", "\[Rule]", 
      RowBox[{"Function", "[", 
       RowBox[{"t", ",", 
        RowBox[{
         RowBox[{"P", "[", "t", "]"}], "+", 
         RowBox[{"0", " ", 
          RowBox[{"(", 
           FractionBox[
            RowBox[{"\[Rho]m", " "}], 
            SuperscriptBox[
             RowBox[{"a", "[", "t", "]"}], "3"]], ")"}]}]}]}], "]"}]}], ",", 
     RowBox[{"\[Rho]", "\[Rule]", 
      RowBox[{"Function", "[", 
       RowBox[{"t", ",", 
        RowBox[{
         RowBox[{"\[Rho]", "[", "t", "]"}], "+", 
         RowBox[{"(", 
          FractionBox[
           RowBox[{"\[Rho]m", " "}], 
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "3"]], ")"}]}]}], "]"}]}]}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"addrad", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"P", "\[Rule]", 
      RowBox[{"Function", "[", 
       RowBox[{"t", ",", 
        RowBox[{
         RowBox[{"P", "[", "t", "]"}], "+", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          RowBox[{"(", 
           FractionBox[
            RowBox[{"\[Rho]r", " "}], 
            SuperscriptBox[
             RowBox[{"a", "[", "t", "]"}], "4"]], ")"}]}]}]}], "]"}]}], ",", 
     RowBox[{"\[Rho]", "\[Rule]", 
      RowBox[{"Function", "[", 
       RowBox[{"t", ",", 
        RowBox[{
         RowBox[{"\[Rho]", "[", "t", "]"}], "+", 
         RowBox[{"(", 
          FractionBox[
           RowBox[{"\[Rho]r", " "}], 
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "4"]], ")"}]}]}], "]"}]}]}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"addvac", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"P", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{"t", ",", 
         RowBox[{
          RowBox[{"P", "[", "t", "]"}], "-", "\[Rho]\[CapitalLambda]"}]}], 
        "]"}]}], ",", 
      RowBox[{"\[Rho]", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{"t", ",", 
         RowBox[{
          RowBox[{"\[Rho]", "[", "t", "]"}], "+", 
          "\[Rho]\[CapitalLambda]"}]}], "]"}]}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\[Rho]\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Rho]", "[", "t", "]"}], "/.", "addmat"}], "/.", "addrad"}], 
     "/.", "addvac"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Rho]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"P", "[", "t", "]"}], "\[Rule]", "0"}]}], "}"}]}], 
   ")"}]}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\[Rho]+\!\(\*
StyleBox[\"P\",
FontSlant->\"Italic\"]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Rho]", "[", "t", "]"}], "+", 
        RowBox[{"P", "[", "t", "]"}]}], "/.", "addmat"}], "/.", "addrad"}], "/.",
      "addvac"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Rho]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"P", "[", "t", "]"}], "\[Rule]", "0"}]}], "}"}]}], 
   ")"}]}]}], "Input",
 CellChangeTimes->{{3.798564232593154*^9, 3.7985642869699874`*^9}, {
  3.7985643979914303`*^9, 3.7985644062468605`*^9}, {3.798564443255087*^9, 
  3.798564631220664*^9}, {3.7985653710702643`*^9, 3.798565421597988*^9}, {
  3.79856547324614*^9, 3.7985654805761156`*^9}, {3.7985655279480333`*^9, 
  3.7985655517578783`*^9}, {3.798565632769765*^9, 3.7985656339603186`*^9}, {
  3.7985673412442603`*^9, 3.7985673714928246`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\[Rho]\"\>", "\[Equal]", 
  RowBox[{"\[Rho]\[CapitalLambda]", "+", 
   FractionBox["\[Rho]r", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "4"]], "+", 
   FractionBox["\[Rho]m", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "3"]]}]}]], "Output",
 CellChangeTimes->{
  3.7985654830196967`*^9, {3.79856553057798*^9, 3.7985655521396427`*^9}, 
   3.798565635944093*^9, 3.798567373873185*^9, 3.7985731462248235`*^9, 
   3.798579574911482*^9, 3.7989389357332754`*^9, 3.8000943533613634`*^9, 
   3.80024104094116*^9, 3.8002746679666257`*^9, 3.800276211707365*^9, 
   3.8003173782834153`*^9, 3.800319443680036*^9, 3.800319841085305*^9, 
   3.80033795884899*^9, 3.8004508854386997`*^9, 3.800590472933649*^9, 
   3.800593590846396*^9, 3.8005987968704095`*^9, 3.8006744996524353`*^9, 
   3.8010180494736853`*^9, 3.8010182062647533`*^9, 3.80102545491938*^9, 
   3.8010287701673036`*^9, 3.8010317398126965`*^9, 3.801031771682822*^9, 
   3.8011421706050515`*^9, 3.8187714585520296`*^9}],

Cell[BoxData[
 RowBox[{"\<\"\[Rho]+\\!\\(\\*\\nStyleBox[\\\"P\\\",\\nFontSlant->\\\"Italic\\\
\"]\\)\"\>", "\[Equal]", 
  RowBox[{
   FractionBox[
    RowBox[{"4", " ", "\[Rho]r"}], 
    RowBox[{"3", " ", 
     SuperscriptBox[
      RowBox[{"a", "[", "t", "]"}], "4"]}]], "+", 
   FractionBox["\[Rho]m", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "3"]]}]}]], "Output",
 CellChangeTimes->{
  3.7985654830196967`*^9, {3.79856553057798*^9, 3.7985655521396427`*^9}, 
   3.798565635944093*^9, 3.798567373873185*^9, 3.7985731462248235`*^9, 
   3.798579574911482*^9, 3.7989389357332754`*^9, 3.8000943533613634`*^9, 
   3.80024104094116*^9, 3.8002746679666257`*^9, 3.800276211707365*^9, 
   3.8003173782834153`*^9, 3.800319443680036*^9, 3.800319841085305*^9, 
   3.80033795884899*^9, 3.8004508854386997`*^9, 3.800590472933649*^9, 
   3.800593590846396*^9, 3.8005987968704095`*^9, 3.8006744996524353`*^9, 
   3.8010180494736853`*^9, 3.8010182062647533`*^9, 3.80102545491938*^9, 
   3.8010287701673036`*^9, 3.8010317398126965`*^9, 3.801031771682822*^9, 
   3.8011421706050515`*^9, 3.818771458560013*^9}]
}, Open  ]],

Cell["The field equations become (Eqs. (4.24-26))...", "Text",
 CellChangeTimes->{{3.798565644098567*^9, 3.7985656508822813`*^9}, {
  3.818771463723979*^9, 3.8187714877639713`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"$Assumptions", "=", 
   RowBox[{
    RowBox[{"h", "\[NotEqual]", "0"}], "&&", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], "\[NotEqual]", "0"}], "&&", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "\[NotEqual]", "0"}], "&&", 
    RowBox[{"c", "\[NotEqual]", "0"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Feq1", "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"FeqGCCG", "/.", "addmat"}], "/.", "addrad"}], "/.", 
        "addvac"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Rho]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"P", "[", "t", "]"}], "\[Rule]", "0"}]}], "}"}]}], "/.", 
      RowBox[{"H", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{"t", ",", 
         FractionBox[
          RowBox[{
           RowBox[{"a", "'"}], "[", "t", "]"}], 
          RowBox[{"a", "[", "t", "]"}]]}], "]"}]}]}], "//", "FullSimplify"}], 
    ")"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Heq1", "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"HeqGCCG", "/.", "addmat"}], "/.", "addrad"}], "/.", 
        "addvac"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Rho]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"P", "[", "t", "]"}], "\[Rule]", "0"}]}], "}"}]}], "/.", 
      RowBox[{"H", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{"t", ",", 
         FractionBox[
          RowBox[{
           RowBox[{"a", "'"}], "[", "t", "]"}], 
          RowBox[{"a", "[", "t", "]"}]]}], "]"}]}]}], "//", "FullSimplify"}], 
    ")"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Seq1", "=", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"SeqGCCG", "/.", "addmat"}], "/.", "addrad"}], "/.", 
         "addvac"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Rho]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
          RowBox[{
           RowBox[{"P", "[", "t", "]"}], "\[Rule]", "0"}]}], "}"}]}], "/.", 
       RowBox[{"H", "\[Rule]", 
        RowBox[{"Function", "[", 
         RowBox[{"t", ",", 
          FractionBox[
           RowBox[{
            RowBox[{"a", "'"}], "[", "t", "]"}], 
           RowBox[{"a", "[", "t", "]"}]]}], "]"}]}]}], "//", "FullSimplify"}],
      ")"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "Feq1", \
"\[IndentingNewLine]", "Heq1", "\[IndentingNewLine]", "Seq1"}], "Input",
 CellChangeTimes->{{3.7985656565039735`*^9, 3.798565792096311*^9}, {
  3.7985658835574584`*^9, 3.798565902092617*^9}, {3.798566124429867*^9, 
  3.798566127130617*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox["2", "n"], " ", "h", " ", 
    RowBox[{"(", 
     RowBox[{"\[Rho]r", "+", 
      RowBox[{
       RowBox[{"a", "[", "t", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Rho]m", "+", 
         RowBox[{"\[Rho]\[CapitalLambda]", " ", 
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "3"]}], "-", 
         RowBox[{"3", " ", 
          RowBox[{"a", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["a", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}]}], ")"}]}]}], 
     ")"}]}], "+", 
   RowBox[{"c", " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"h", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"2", " ", "n"}]}], ")"}], " ", 
       RowBox[{"a", "[", "t", "]"}]}], "-", 
      RowBox[{"2", " ", "n", " ", 
       RowBox[{
        SuperscriptBox["a", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"], ")"}], "n"]}]}], 
  "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{{3.7985657705330863`*^9, 3.798565799171567*^9}, 
   3.7985659075458946`*^9, 3.798566132900451*^9, 3.7985673816379967`*^9, 
   3.7985731502399397`*^9, 3.798579578960146*^9, 3.7989389397635484`*^9, 
   3.8000943628078127`*^9, 3.8002410740099726`*^9, 3.8002746714917707`*^9, 
   3.8002762154015512`*^9, 3.8003173828062086`*^9, 3.800319447531867*^9, 
   3.8003198452743516`*^9, 3.8003379630349007`*^9, 3.800450894719181*^9, 
   3.800590476545993*^9, 3.8005935955019226`*^9, 3.800598800944311*^9, 
   3.8006745032490644`*^9, 3.8010180520199585`*^9, 3.8010182087798214`*^9, 
   3.8010254619221783`*^9, 3.801028772854831*^9, 3.8010317398412256`*^9, 
   3.8010317743143597`*^9, 3.80114217393787*^9, 3.818771470516532*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox["2", "n"], " ", "h", " ", 
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", " ", "\[Rho]r"}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"a", "[", "t", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Rho]m", "-", 
         RowBox[{"2", " ", 
          RowBox[{"a", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["a", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox["a", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], ")"}]}],
    "+", 
   RowBox[{"2", " ", "c", " ", "n", " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"], ")"}], "n"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"h", " ", 
          RowBox[{"a", "[", "t", "]"}]}], "-", 
         RowBox[{
          SuperscriptBox["a", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], ")"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{"a", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], "\[Equal]",
   "0"}]], "Output",
 CellChangeTimes->{{3.7985657705330863`*^9, 3.798565799171567*^9}, 
   3.7985659075458946`*^9, 3.798566132900451*^9, 3.7985673816379967`*^9, 
   3.7985731502399397`*^9, 3.798579578960146*^9, 3.7989389397635484`*^9, 
   3.8000943628078127`*^9, 3.8002410740099726`*^9, 3.8002746714917707`*^9, 
   3.8002762154015512`*^9, 3.8003173828062086`*^9, 3.800319447531867*^9, 
   3.8003198452743516`*^9, 3.8003379630349007`*^9, 3.800450894719181*^9, 
   3.800590476545993*^9, 3.8005935955019226`*^9, 3.800598800944311*^9, 
   3.8006745032490644`*^9, 3.8010180520199585`*^9, 3.8010182087798214`*^9, 
   3.8010254619221783`*^9, 3.801028772854831*^9, 3.8010317398412256`*^9, 
   3.8010317743143597`*^9, 3.80114217393787*^9, 3.818771470516532*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"n", " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["a", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
     RowBox[{
      RowBox[{"a", "[", "t", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "3"}], " ", "h", " ", 
         RowBox[{
          SuperscriptBox["a", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["a", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], ")"}]}]}], ")"}]}], 
  "\[Equal]", 
  RowBox[{"n", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"2", " ", "n"}]}], ")"}], " ", 
   RowBox[{"a", "[", "t", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"h", " ", 
      RowBox[{"a", "[", "t", "]"}]}], "-", 
     RowBox[{
      SuperscriptBox["a", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], ")"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.7985657705330863`*^9, 3.798565799171567*^9}, 
   3.7985659075458946`*^9, 3.798566132900451*^9, 3.7985673816379967`*^9, 
   3.7985731502399397`*^9, 3.798579578960146*^9, 3.7989389397635484`*^9, 
   3.8000943628078127`*^9, 3.8002410740099726`*^9, 3.8002746714917707`*^9, 
   3.8002762154015512`*^9, 3.8003173828062086`*^9, 3.800319447531867*^9, 
   3.8003198452743516`*^9, 3.8003379630349007`*^9, 3.800450894719181*^9, 
   3.800590476545993*^9, 3.8005935955019226`*^9, 3.800598800944311*^9, 
   3.8006745032490644`*^9, 3.8010180520199585`*^9, 3.8010182087798214`*^9, 
   3.8010254619221783`*^9, 3.801028772854831*^9, 3.8010317398412256`*^9, 
   3.8010317743143597`*^9, 3.80114217393787*^9, 3.818771470532153*^9}]
}, Open  ]],

Cell[TextData[{
 "We nondimensionalize the field equations. We set ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"[", "c", "]"}], "=", 
    SuperscriptBox[
     RowBox[{"[", "T", "]"}], 
     RowBox[{
      RowBox[{"2", "n"}], "-", "2"}]]}], TraditionalForm]]],
 " where ",
 Cell[BoxData[
  FormBox[
   RowBox[{"[", "T", "]"}], TraditionalForm]]],
 " denotes a unit of time ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"[", "T", "]"}], "~", 
     SuperscriptBox["h", 
      RowBox[{"-", "1"}]]}], ")"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ". Using the coordinate ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Tau]", "=", 
    RowBox[{"h", " ", "t"}]}], TraditionalForm]]],
 " as a time variable, we obtain..."
}], "Text",
 CellChangeTimes->{{3.798568547855607*^9, 3.7985686713806763`*^9}, {
  3.798568775437311*^9, 3.7985687924668083`*^9}, {3.8002411323987703`*^9, 
  3.800241161877706*^9}, {3.800241202532099*^9, 3.800241281638708*^9}, {
  3.818771542598629*^9, 3.818771625091525*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"cto\[Beta]", "=", 
   RowBox[{"c", "\[Rule]", 
    RowBox[{"\[Beta]", " ", 
     SuperscriptBox["h", 
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "n"}], "-", "2"}], ")"}]}]]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nondim", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "\[Rule]", 
       RowBox[{"h", " ", 
        RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Phi]", "''"}], "[", "t", "]"}], "\[Rule]", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"h", " "}], "2"], 
        RowBox[{
         RowBox[{"\[CapitalPsi]", "'"}], "[", "\[Tau]", "]"}]}]}], ",", 
      RowBox[{
       RowBox[{"a", "[", "t", "]"}], "\[Rule]", 
       RowBox[{"a", "[", "\[Tau]", "]"}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"a", "'"}], "[", "t", "]"}], "\[Rule]", 
       RowBox[{"h", " ", 
        RowBox[{
         RowBox[{"a", "'"}], "[", "\[Tau]", "]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"a", "''"}], "[", "t", "]"}], "\[Rule]", 
       RowBox[{
        SuperscriptBox["h", "2"], 
        RowBox[{
         RowBox[{"a", "''"}], "[", "\[Tau]", "]"}]}]}], ",", 
      RowBox[{"\[Rho]m", "\[Rule]", 
       RowBox[{"3", 
        SuperscriptBox["h", "2"], "\[Alpha]m"}]}], ",", 
      RowBox[{"\[Rho]r", "\[Rule]", 
       RowBox[{"3", 
        SuperscriptBox["h", "2"], "\[Alpha]r"}]}], ",", 
      RowBox[{"\[Rho]\[CapitalLambda]", "\[Rule]", 
       RowBox[{"3", 
        SuperscriptBox["h", "2"], "\[Alpha]\[CapitalLambda]"}]}]}], "}"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Feq2", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Feq1", "/.", "cto\[Beta]"}], "/.", "nondim"}], ",", 
     RowBox[{"Assumptions", "\[Rule]", 
      RowBox[{
       RowBox[{"h", ">", "0"}], "&&", 
       RowBox[{"n", "\[NotEqual]", "0"}]}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Heq2", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Heq1", "/.", "cto\[Beta]"}], "/.", "nondim"}], ",", 
     RowBox[{"Assumptions", "\[Rule]", 
      RowBox[{
       RowBox[{"h", ">", "0"}], "&&", 
       RowBox[{"n", "\[NotEqual]", "0"}]}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Seq2", "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Seq1", "/.", "cto\[Beta]"}], "/.", "nondim"}], ",", 
      RowBox[{"Assumptions", "\[Rule]", 
       RowBox[{
        RowBox[{"h", ">", "0"}], "&&", 
        RowBox[{"n", "\[NotEqual]", "0"}]}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "Feq2", \
"\[IndentingNewLine]", "Heq2", "\[IndentingNewLine]", "Seq2"}], "Input",
 CellChangeTimes->{{3.798568684360604*^9, 3.7985687586628275`*^9}, {
   3.798568810025428*^9, 3.798568820866804*^9}, {3.7985688518096266`*^9, 
   3.79856886414454*^9}, {3.79856889428576*^9, 3.7985689047425165`*^9}, {
   3.798569072173347*^9, 3.7985692240387707`*^9}, {3.798569659073512*^9, 
   3.7985697381178465`*^9}, {3.7985698268156214`*^9, 3.798569868309585*^9}, {
   3.7985713909215345`*^9, 3.798571535050118*^9}, {3.7985721151918993`*^9, 
   3.798572124910884*^9}, {3.798572166158984*^9, 3.798572167948719*^9}, {
   3.798572255486295*^9, 3.798572272738431*^9}, {3.7985723111771097`*^9, 
   3.798572312800749*^9}, {3.798581080118021*^9, 3.7985810873868923`*^9}, 
   3.818771507528236*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Beta]", " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "\[Tau]", "]"}], "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      SuperscriptBox[
       RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}], "2"], ")"}], "n"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"2", " ", "n"}]}], ")"}], " ", 
       RowBox[{"a", "[", "\[Tau]", "]"}]}], "-", 
      RowBox[{"2", " ", "n", " ", 
       RowBox[{
        SuperscriptBox["a", "\[Prime]",
         MultilineFunction->None], "[", "\[Tau]", "]"}]}]}], ")"}]}], "+", 
   RowBox[{"3", " ", 
    SuperscriptBox["2", "n"], " ", 
    RowBox[{"(", 
     RowBox[{"\[Alpha]r", "+", 
      RowBox[{
       RowBox[{"a", "[", "\[Tau]", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Alpha]m", "+", 
         RowBox[{"\[Alpha]\[CapitalLambda]", " ", 
          SuperscriptBox[
           RowBox[{"a", "[", "\[Tau]", "]"}], "3"]}], "-", 
         RowBox[{
          RowBox[{"a", "[", "\[Tau]", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["a", "\[Prime]",
             MultilineFunction->None], "[", "\[Tau]", "]"}], "2"]}]}], 
        ")"}]}]}], ")"}]}]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.79856923007863*^9, 3.7985697460617013`*^9, 
  3.7985698708089952`*^9, 3.798571539205935*^9, 3.7985721274149127`*^9, 
  3.798572169892164*^9, 3.7985722680442314`*^9, 3.7985723770079904`*^9, 
  3.798573205486527*^9, 3.798579598634997*^9, 3.798581091247504*^9, 
  3.798939001547166*^9, 3.8000944087929068`*^9, 3.8002412906451373`*^9, 
  3.800274673026965*^9, 3.8002762169744296`*^9, 3.800317385217908*^9, 
  3.800319449323801*^9, 3.800319847109143*^9, 3.8003379645619154`*^9, 
  3.8004508995193357`*^9, 3.800590478082383*^9, 3.800593597435796*^9, 
  3.800598803104494*^9, 3.800674504874202*^9, 3.8010180535350904`*^9, 
  3.801018210091981*^9, 3.801025467003372*^9, 3.801028774170611*^9, 
  3.8010317398729205`*^9, 3.8010317757521057`*^9, 3.801142175634787*^9, 
  3.818771628673154*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"2", " ", "n", " ", "\[Beta]", " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "\[Tau]", "]"}], "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      SuperscriptBox[
       RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}], "2"], ")"}], "n"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", 
       RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}], " ", 
       RowBox[{
        SuperscriptBox["a", "\[Prime]",
         MultilineFunction->None], "[", "\[Tau]", "]"}]}], "+", 
      RowBox[{
       RowBox[{"a", "[", "\[Tau]", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[CapitalPsi]", "\[Prime]",
           MultilineFunction->None], "[", "\[Tau]", "]"}]}], ")"}]}]}], 
     ")"}]}], "+", 
   RowBox[{"3", " ", 
    SuperscriptBox["2", "n"], " ", 
    RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", " ", "\[Alpha]r"}], "+", 
      RowBox[{"3", " ", "\[Alpha]m", " ", 
       RowBox[{"a", "[", "\[Tau]", "]"}]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"a", "[", "\[Tau]", "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["a", "\[Prime]",
          MultilineFunction->None], "[", "\[Tau]", "]"}], "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"a", "[", "\[Tau]", "]"}], "3"], " ", 
       RowBox[{
        SuperscriptBox["a", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "\[Tau]", "]"}]}]}], ")"}]}]}], 
  "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.79856923007863*^9, 3.7985697460617013`*^9, 
  3.7985698708089952`*^9, 3.798571539205935*^9, 3.7985721274149127`*^9, 
  3.798572169892164*^9, 3.7985722680442314`*^9, 3.7985723770079904`*^9, 
  3.798573205486527*^9, 3.798579598634997*^9, 3.798581091247504*^9, 
  3.798939001547166*^9, 3.8000944087929068`*^9, 3.8002412906451373`*^9, 
  3.800274673026965*^9, 3.8002762169744296`*^9, 3.800317385217908*^9, 
  3.800319449323801*^9, 3.800319847109143*^9, 3.8003379645619154`*^9, 
  3.8004508995193357`*^9, 3.800590478082383*^9, 3.800593597435796*^9, 
  3.800598803104494*^9, 3.800674504874202*^9, 3.8010180535350904`*^9, 
  3.801018210091981*^9, 3.801025467003372*^9, 3.801028774170611*^9, 
  3.8010317398729205`*^9, 3.8010317757521057`*^9, 3.801142175634787*^9, 
  3.818771628673154*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["h", "3"], " ", "n", " ", 
   RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["a", "\[Prime]",
         MultilineFunction->None], "[", "\[Tau]", "]"}], "2"]}], "+", 
     RowBox[{
      RowBox[{"a", "[", "\[Tau]", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "3"}], " ", 
         RowBox[{
          SuperscriptBox["a", "\[Prime]",
           MultilineFunction->None], "[", "\[Tau]", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["a", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "\[Tau]", "]"}]}], ")"}]}]}], 
    ")"}]}], "\[Equal]", 
  RowBox[{
   SuperscriptBox["h", "3"], " ", "n", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"2", " ", "n"}]}], ")"}], " ", 
   RowBox[{"a", "[", "\[Tau]", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"a", "[", "\[Tau]", "]"}], "-", 
     RowBox[{
      SuperscriptBox["a", "\[Prime]",
       MultilineFunction->None], "[", "\[Tau]", "]"}]}], ")"}], " ", 
   RowBox[{
    SuperscriptBox["\[CapitalPsi]", "\[Prime]",
     MultilineFunction->None], "[", "\[Tau]", "]"}]}]}]], "Output",
 CellChangeTimes->{3.79856923007863*^9, 3.7985697460617013`*^9, 
  3.7985698708089952`*^9, 3.798571539205935*^9, 3.7985721274149127`*^9, 
  3.798572169892164*^9, 3.7985722680442314`*^9, 3.7985723770079904`*^9, 
  3.798573205486527*^9, 3.798579598634997*^9, 3.798581091247504*^9, 
  3.798939001547166*^9, 3.8000944087929068`*^9, 3.8002412906451373`*^9, 
  3.800274673026965*^9, 3.8002762169744296`*^9, 3.800317385217908*^9, 
  3.800319449323801*^9, 3.800319847109143*^9, 3.8003379645619154`*^9, 
  3.8004508995193357`*^9, 3.800590478082383*^9, 3.800593597435796*^9, 
  3.800598803104494*^9, 3.800674504874202*^9, 3.8010180535350904`*^9, 
  3.801018210091981*^9, 3.801025467003372*^9, 3.801028774170611*^9, 
  3.8010317398729205`*^9, 3.8010317757521057`*^9, 3.801142175634787*^9, 
  3.8187716286888065`*^9}]
}, Open  ]],

Cell["\<\
These are Eqs. (4.34-36). Integration proceeds by integrating the Hubble and \
scalar field equations subject to the Friedmann constraint. We recast the \
Hubble and scalar field equations as...\
\>", "Text",
 CellChangeTimes->{{3.7985725557861214`*^9, 3.7985725593168507`*^9}, {
  3.798572616253296*^9, 3.798572636514657*^9}, {3.8187716408611608`*^9, 
  3.818771665632017*^9}, {3.818771700857467*^9, 3.818771705394391*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sola\[Psi]", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Heq2", ",", "Seq2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"a", "''"}], "[", "\[Tau]", "]"}], ",", 
         RowBox[{
          RowBox[{"\[CapitalPsi]", "'"}], "[", "\[Tau]", "]"}]}], "}"}]}], 
      "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ode1", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"a", "''"}], "[", "\[Tau]", "]"}], "-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"a", "''"}], "[", "\[Tau]", "]"}], "/.", "sola\[Psi]"}], 
      ")"}]}], "\[Equal]", "0"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ode2", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[CapitalPsi]", "'"}], "[", "\[Tau]", "]"}], "-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"\[CapitalPsi]", "'"}], "[", "\[Tau]", "]"}], "/.", 
        "sola\[Psi]"}], ")"}]}], "\[Equal]", "0"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "ode1", \
"\[IndentingNewLine]", "ode2"}], "Input",
 CellChangeTimes->{{3.798572380219301*^9, 3.7985725181281238`*^9}, {
  3.79857255059733*^9, 3.7985725940997405`*^9}, {3.7985728551045136`*^9, 
  3.7985728630912933`*^9}, {3.7985729050245113`*^9, 3.7985729132836003`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "n", " ", "\[Beta]", " ", 
       SuperscriptBox[
        RowBox[{"a", "[", "\[Tau]", "]"}], "3"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         SuperscriptBox[
          RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}], "2"], ")"}], "n"], 
       " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          RowBox[{"a", "[", "\[Tau]", "]"}]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{
           SuperscriptBox["a", "\[Prime]",
            MultilineFunction->None], "[", "\[Tau]", "]"}]}]}], ")"}], " ", 
       RowBox[{
        SuperscriptBox["a", "\[Prime]",
         MultilineFunction->None], "[", "\[Tau]", "]"}]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"2", " ", "n"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a", "[", "\[Tau]", "]"}], "-", 
         RowBox[{
          SuperscriptBox["a", "\[Prime]",
           MultilineFunction->None], "[", "\[Tau]", "]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["2", 
           RowBox[{"2", "+", "n"}]], " ", "\[Alpha]r"}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["2", "n"], " ", "\[Alpha]m", " ", 
          RowBox[{"a", "[", "\[Tau]", "]"}]}], "+", 
         RowBox[{"2", " ", "n", " ", "\[Beta]", " ", 
          SuperscriptBox[
           RowBox[{"a", "[", "\[Tau]", "]"}], "4"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            SuperscriptBox[
             RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}], "2"], ")"}], 
           "n"]}], "-", 
         RowBox[{"2", " ", "n", " ", "\[Beta]", " ", 
          SuperscriptBox[
           RowBox[{"a", "[", "\[Tau]", "]"}], "3"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            SuperscriptBox[
             RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}], "2"], ")"}], "n"],
           " ", 
          RowBox[{
           SuperscriptBox["a", "\[Prime]",
            MultilineFunction->None], "[", "\[Tau]", "]"}]}], "-", 
         RowBox[{
          SuperscriptBox["2", 
           RowBox[{"1", "+", "n"}]], " ", 
          SuperscriptBox[
           RowBox[{"a", "[", "\[Tau]", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["a", "\[Prime]",
             MultilineFunction->None], "[", "\[Tau]", "]"}], "2"]}]}], 
        ")"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"a", "[", "\[Tau]", "]"}], "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"n", " ", "\[Beta]", " ", 
         RowBox[{"a", "[", "\[Tau]", "]"}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           SuperscriptBox[
            RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}], "2"], ")"}], 
          "n"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["2", "n"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"2", " ", "n"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"a", "[", "\[Tau]", "]"}], "-", 
           RowBox[{
            SuperscriptBox["a", "\[Prime]",
             MultilineFunction->None], "[", "\[Tau]", "]"}]}], ")"}]}]}], 
       ")"}]}], ")"}]}], "+", 
   RowBox[{
    SuperscriptBox["a", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "\[Tau]", "]"}]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{
  3.798572417498353*^9, 3.798572596541362*^9, {3.7985728442694397`*^9, 
   3.7985728640465655`*^9}, 3.7985729138106184`*^9, 3.7985732097938004`*^9, 
   3.798579617169777*^9, 3.7985810973570113`*^9, 3.798939001859593*^9, 
   3.8000944141588073`*^9, 3.800241304349704*^9, 3.800274673296464*^9, 
   3.8002762172595563`*^9, 3.8003173855693927`*^9, 3.8003194497414675`*^9, 
   3.8003198475018377`*^9, 3.8003379648543615`*^9, 3.800450900163129*^9, 
   3.800590478361003*^9, 3.800593597794816*^9, 3.8005988033971825`*^9, 
   3.8006745051949697`*^9, 3.801018053847546*^9, 3.8010182104044085`*^9, 
   3.80102547177017*^9, 3.8010287744315443`*^9, 3.8010317399698706`*^9, 
   3.8010317760631123`*^9, 3.801142175947004*^9, 3.818771708538576*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"3", " ", 
      RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["2", 
          RowBox[{"2", "+", "n"}]], " ", "\[Alpha]r"}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["2", "n"], " ", "\[Alpha]m", " ", 
         RowBox[{"a", "[", "\[Tau]", "]"}]}], "+", 
        RowBox[{"2", " ", "n", " ", "\[Beta]", " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "\[Tau]", "]"}], "4"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           SuperscriptBox[
            RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}], "2"], ")"}], 
          "n"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "\[Tau]", "]"}], "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["2", "n"]}], "-", 
           RowBox[{"n", " ", "\[Beta]", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              SuperscriptBox[
               RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}], "2"], ")"}], 
             "n"]}]}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["a", "\[Prime]",
           MultilineFunction->None], "[", "\[Tau]", "]"}]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["2", 
          RowBox[{"1", "+", "n"}]], " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "\[Tau]", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["a", "\[Prime]",
            MultilineFunction->None], "[", "\[Tau]", "]"}], "2"]}]}], ")"}]}],
      ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"a", "[", "\[Tau]", "]"}], "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"a", "[", "\[Tau]", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "3"}], " ", 
            SuperscriptBox["2", "n"]}], "+", 
           RowBox[{"3", " ", 
            SuperscriptBox["2", 
             RowBox[{"1", "+", "n"}]], " ", "n"}], "+", 
           RowBox[{"n", " ", "\[Beta]", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              SuperscriptBox[
               RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}], "2"], ")"}], 
             "n"]}]}], ")"}]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["2", "n"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"2", " ", "n"}]}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["a", "\[Prime]",
           MultilineFunction->None], "[", "\[Tau]", "]"}]}]}], ")"}]}], 
     ")"}]}], "+", 
   RowBox[{
    SuperscriptBox["\[CapitalPsi]", "\[Prime]",
     MultilineFunction->None], "[", "\[Tau]", "]"}]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{
  3.798572417498353*^9, 3.798572596541362*^9, {3.7985728442694397`*^9, 
   3.7985728640465655`*^9}, 3.7985729138106184`*^9, 3.7985732097938004`*^9, 
   3.798579617169777*^9, 3.7985810973570113`*^9, 3.798939001859593*^9, 
   3.8000944141588073`*^9, 3.800241304349704*^9, 3.800274673296464*^9, 
   3.8002762172595563`*^9, 3.8003173855693927`*^9, 3.8003194497414675`*^9, 
   3.8003198475018377`*^9, 3.8003379648543615`*^9, 3.800450900163129*^9, 
   3.800590478361003*^9, 3.800593597794816*^9, 3.8005988033971825`*^9, 
   3.8006745051949697`*^9, 3.801018053847546*^9, 3.8010182104044085`*^9, 
   3.80102547177017*^9, 3.8010287744315443`*^9, 3.8010317399698706`*^9, 
   3.8010317760631123`*^9, 3.801142175947004*^9, 3.8187717085541964`*^9}]
}, Open  ]],

Cell[TextData[{
 "Provided the four theory parameters ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"n", ",", 
     SubscriptBox["\[Alpha]", "i"]}], "}"}], TraditionalForm]]],
 " and the initial conditions ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "(", 
      SubscriptBox["t", "i"], ")"}], ",", 
     RowBox[{
      RowBox[{"a", "'"}], 
      RowBox[{"(", 
       SubscriptBox["t", "i"], ")"}]}]}], "}"}], TraditionalForm]]],
 ", ode1 and ode2 are ready for numerical integration. The initial condition ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalPsi]", "(", 
    SubscriptBox["t", "i"], ")"}], TraditionalForm]]],
 " of the scalar field can be determined using the Friedmann constraint, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"F", "[", 
    RowBox[{
     RowBox[{"a", "(", 
      SubscriptBox["t", "i"], ")"}], ",", 
     RowBox[{
      RowBox[{"a", "'"}], 
      RowBox[{"(", 
       SubscriptBox["t", "i"], ")"}]}], ",", 
     RowBox[{"\[CapitalPsi]", "(", 
      SubscriptBox["t", "i"], ")"}]}], "]"}], TraditionalForm]]],
 ".\n\nHere is also the dark energy equation of state (Eq. (4.37))..."
}], "Text",
 CellChangeTimes->{{3.8002413321652503`*^9, 3.800241483004369*^9}, {
  3.8002415134554386`*^9, 3.8002415787246284`*^9}, {3.800243083682583*^9, 
  3.8002430875667706`*^9}, {3.8010255218404303`*^9, 3.80102553231229*^9}, {
  3.818771746029557*^9, 3.8187717472150373`*^9}, {3.8187717795903716`*^9, 
  3.8187717854733095`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[Rho]DEnd", "[", "\[Tau]_", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Rho]DEGCCG", "[", "t", "]"}], "/.", "cto\[Beta]"}], "/.", 
      "nondim"}], "/.", 
     RowBox[{
      RowBox[{"H", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"h", " ", 
       RowBox[{"H", "[", "\[Tau]", "]"}]}]}]}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"PDEnd", "[", "\[Tau]_", "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"PDEGCCG", "[", "t", "]"}], "/.", "cto\[Beta]"}], "/.", 
       "nondim"}], "/.", 
      RowBox[{
       RowBox[{"H", "[", "t", "]"}], "\[Rule]", 
       RowBox[{"h", " ", 
        RowBox[{"H", "[", "\[Tau]", "]"}]}]}]}], "//", "Simplify"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"wDE", "[", "\[Tau]_", "]"}], "=", 
    RowBox[{
     FractionBox[
      RowBox[{"PDEnd", "[", "\[Tau]", "]"}], 
      RowBox[{"\[Rho]DEnd", "[", "\[Tau]", "]"}]], "//", "Simplify"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SubscriptBox[
StyleBox[\"w\",
FontSlant->\"Italic\"], \"DE\"]\)\>\"", "\[Equal]", 
  RowBox[{"wDE", "[", "\[Tau]", "]"}]}]}], "Input",
 CellChangeTimes->{{3.80102554588861*^9, 3.801025554413232*^9}, {
  3.801025588170575*^9, 3.801025632917495*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\n \
StyleBox[\\\"w\\\",\\nFontSlant->\\\"Italic\\\"], \\\"DE\\\"]\\)\"\>", 
  "\[Equal]", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     RowBox[{"3", " ", 
      RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}]}], "+", 
     RowBox[{"2", " ", "n", " ", 
      RowBox[{
       SuperscriptBox["\[CapitalPsi]", "\[Prime]",
        MultilineFunction->None], "[", "\[Tau]", "]"}]}]}], 
    RowBox[{
     RowBox[{"3", " ", 
      RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}]}], "-", 
     RowBox[{"6", " ", "n", " ", 
      RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}]}], "+", 
     RowBox[{"6", " ", "n", " ", 
      RowBox[{"H", "[", "\[Tau]", "]"}], " ", 
      RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}]}]}]]}]}]], "Output",
 CellChangeTimes->{3.801025557284157*^9, 3.8010256347740793`*^9, 
  3.801028774489443*^9, 3.801031739997281*^9, 3.8010317761151295`*^9, 
  3.801142176008315*^9, 3.818771759105085*^9}]
}, Open  ]],

Cell[TextData[{
 "...where ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"H", "(", "\[Tau]", ")"}], "=", 
    RowBox[{
     RowBox[{"a", "'"}], 
     RowBox[{
      RowBox[{"(", "\[Tau]", ")"}], "/", 
      RowBox[{"a", "(", "\[Tau]", ")"}]}]}]}], TraditionalForm]]],
 ".\n\nWe compute the analytical expressions for the dark energy equations of \
state at the two attractors (in the variables of this section: ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"H", "(", "\[Tau]", ")"}], "=", "1"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"H", "(", "\[Tau]", ")"}], "=", 
    SqrtBox[
     SubscriptBox["\[Alpha]", "\[CapitalLambda]"]]}], TraditionalForm]]],
 "). We start with the unhealthy de Sitter state..."
}], "Text",
 CellChangeTimes->{{3.801025653389202*^9, 3.8010256850674934`*^9}, {
  3.801032269456009*^9, 3.801032405558061*^9}, {3.801032572881876*^9, 
  3.8010325915419044`*^9}, {3.801033041553616*^9, 3.801033052909635*^9}, {
  3.818771797382383*^9, 3.818771848437894*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"atoH", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"H", "[", "\[Tau]", "]"}], "\[Equal]", 
         FractionBox[
          RowBox[{
           RowBox[{"a", "'"}], "[", "\[Tau]", "]"}], 
          RowBox[{"a", "[", "\[Tau]", "]"}]]}], ",", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"H", "[", "\[Tau]", "]"}], "\[Equal]", 
           FractionBox[
            RowBox[{
             RowBox[{"a", "'"}], "[", "\[Tau]", "]"}], 
            RowBox[{"a", "[", "\[Tau]", "]"}]]}], ",", "\[Tau]"}], "]"}]}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"a", "'"}], "[", "\[Tau]", "]"}], ",", 
        RowBox[{
         RowBox[{"a", "''"}], "[", "\[Tau]", "]"}]}], "}"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dPsi", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Seq2", "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\[Alpha]r", "\[Rule]", "0"}], ",", 
            RowBox[{"\[Alpha]m", "\[Rule]", "0"}]}], "}"}]}], "/.", "atoH"}], 
        "/.", 
        RowBox[{"H", "\[Rule]", 
         RowBox[{"Function", "[", 
          RowBox[{"\[Tau]", ",", 
           SqrtBox["\[Alpha]\[CapitalLambda]"]}], "]"}]}]}], "//", 
       "Simplify"}], ",", 
      RowBox[{
       RowBox[{"\[CapitalPsi]", "'"}], "[", "\[Tau]", "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*SubscriptBox[\(w\), \(DE\)]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"wDE", "[", "\[Tau]", "]"}], "/.", 
      RowBox[{"H", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{"\[Tau]", ",", 
         SqrtBox["\[Alpha]\[CapitalLambda]"]}], "]"}]}]}], "/.", "dPsi"}], "//",
     "Simplify"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.8010324067219996`*^9, 3.8010325313560734`*^9}, {
  3.801032584831946*^9, 3.8010326005273457`*^9}, {3.8010326554669266`*^9, 
  3.8010326558835635`*^9}, {3.8010327044172735`*^9, 3.8010327847229843`*^9}, {
  3.801032915637783*^9, 3.8010329358690987`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(w\\), \\(DE\\)]\\)\"\>", "\[Equal]", 
  FractionBox["1", 
   RowBox[{
    RowBox[{"-", "1"}], "+", 
    RowBox[{"2", " ", "n"}]}]]}]], "Output",
 CellChangeTimes->{
  3.801032408855282*^9, {3.801032521134494*^9, 3.801032531802887*^9}, 
   3.8010326020944076`*^9, 3.8010329363792105`*^9, 3.8011421761028557`*^9, 
   3.818771835258651*^9}]
}, Open  ]],

Cell["For the self-tuning vacuum, we get...", "Text",
 CellChangeTimes->{{3.801032944250927*^9, 3.801032951243089*^9}, {
  3.8187718540817175`*^9, 3.818771855760418*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["w", "DE"], "\[Equal]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"wDE", "[", "\[Tau]", "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"H", "\[Rule]", 
        RowBox[{"Function", "[", 
         RowBox[{"\[Tau]", ",", "1"}], "]"}]}], ",", 
       RowBox[{"\[CapitalPsi]", "\[Rule]", 
        RowBox[{"Function", "[", 
         RowBox[{"\[Tau]", ",", "q"}], "]"}]}]}], "}"}]}], "//", "Simplify"}],
    ")"}]}]], "Input",
 CellChangeTimes->{{3.8010329761965528`*^9, 3.801033008690075*^9}}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["w", "DE"], "\[Equal]", 
  RowBox[{"-", "1"}]}]], "Output",
 CellChangeTimes->{{3.8010329932079287`*^9, 3.8010330090688334`*^9}, 
   3.8011421761193895`*^9, 3.818771858143354*^9}]
}, Open  ]],

Cell["We\[CloseCurlyQuote]ll see these limits in action in the next \
section.", "Text",
 CellChangeTimes->{{3.801033065443965*^9, 3.801033073602293*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["4.3(b) Numerical experiments with multiple cosmic fluids", \
"Subsubsection",
 CellChangeTimes->{{3.7989389856142025`*^9, 3.7989389895507793`*^9}, {
  3.7992320242434916`*^9, 3.799232037881857*^9}, {3.8005362073049564`*^9, 
  3.8005362081394777`*^9}}],

Cell[TextData[{
 "We investigate the self-tuning theories with ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"n", "=", 
     RowBox[{"-", "1"}]}], ",", 
    RowBox[{"-", "2"}]}], TraditionalForm]]],
 " explored in Sec. 4.2 with a nontrivial mixture of cosmic fluids with ",
 Cell[BoxData[
  FormBox[
   RowBox[{"w", "=", "0"}], TraditionalForm]]],
 " (dust) and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"w", "=", 
    RowBox[{"1", "/", "3"}]}], TraditionalForm]]],
 " (radiation).\n\nRecall also the gradient stability constraint becomes ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"-", "1"}], "/", 
     RowBox[{"(", 
      RowBox[{"k", "-", "1"}], ")"}]}], "<", "n", "<", "0"}], 
   TraditionalForm]]],
 " where ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Alpha]", "\[CapitalLambda]"], "=", 
    RowBox[{"k", ">", "1"}]}], TraditionalForm]]],
 ".\n\n",
 StyleBox["[Case 1: ",
  FontColor->RGBColor[1, 0.5, 0.5]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"n", "=", 
     RowBox[{"-", "1"}]}], ",", " ", 
    RowBox[{"\[Lambda]", "=", "1.9"}], ",", 
    RowBox[{"\[Beta]", "=", "1"}]}], TraditionalForm]],
  FontColor->RGBColor[1, 0.5, 0.5]],
 StyleBox["]",
  FontColor->RGBColor[1, 0.5, 0.5]],
 "\n\nSetting up the parameters..."
}], "Text",
 CellChangeTimes->{{3.7985699535572243`*^9, 3.7985699565619926`*^9}, {
   3.798570970854624*^9, 3.7985710738477125`*^9}, {3.798939101480612*^9, 
   3.7989391081663713`*^9}, {3.798939240620304*^9, 3.798939247525119*^9}, {
   3.800241593383546*^9, 3.800241593852815*^9}, {3.800243109919299*^9, 
   3.8002432225395784`*^9}, {3.800243280288788*^9, 3.8002433116938868`*^9}, {
   3.800243361974061*^9, 3.8002434930084105`*^9}, {3.800243527536825*^9, 
   3.8002435278394237`*^9}, 3.8002459411205826`*^9, {3.800266829202751*^9, 
   3.800266829843343*^9}, {3.800275486033921*^9, 3.800275512852973*^9}, {
   3.8005361985151825`*^9, 3.8005362018638415`*^9}, {3.8187719052052794`*^9, 
   3.818771969157293*^9}, {3.8187720223110695`*^9, 3.818772025889325*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"param", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Beta]", "\[Rule]", "1"}], ",", 
     RowBox[{"n", "\[Rule]", 
      RowBox[{"-", "1"}]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"abun", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Alpha]r", "\[Rule]", 
       FractionBox["1", "10"]}], ",", 
      RowBox[{"\[Alpha]m", "\[Rule]", 
       FractionBox["8", "10"]}], ",", 
      RowBox[{"\[Alpha]\[CapitalLambda]", "\[Rule]", 
       FractionBox["19", "10"]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"no", "-", 
    RowBox[{"ghost", " ", "condition"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ngc", "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", 
      RowBox[{"\[Alpha]\[CapitalLambda]", "-", "1"}]]}], "<", "n", "<", 
    "0"}]}], ";", 
  RowBox[{
   RowBox[{"ngc", "/.", "abun"}], "/.", "param"}]}], "\[IndentingNewLine]", 
 RowBox[{
  StyleBox["n",
   FontSlant->"Italic"], "\[Equal]", 
  RowBox[{"(", 
   RowBox[{"n", "/.", "param"}], ")"}]}], "\[IndentingNewLine]", 
 RowBox[{
  FractionBox["1", 
   RowBox[{
    SubscriptBox["\[Alpha]", "\[CapitalLambda]"], "-", "1"}]], "\[Equal]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     FractionBox["1", 
      RowBox[{"\[Alpha]\[CapitalLambda]", "-", "1"}]], "/.", "abun"}], "/.", 
    "param"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.798939263484589*^9, 3.798939287931798*^9}, {
   3.8000942734432383`*^9, 3.8000942768110723`*^9}, {3.8000944607934217`*^9, 
   3.800094493473833*^9}, 3.8000945450925417`*^9, {3.800243554135852*^9, 
   3.8002435549892273`*^9}, {3.8002447581755867`*^9, 3.800244758371747*^9}, {
   3.8002448158009048`*^9, 3.8002448302882833`*^9}, {3.800245581464873*^9, 
   3.800245615453844*^9}, {3.800245995631798*^9, 3.800246029936612*^9}, {
   3.8187720284625273`*^9, 3.8187720288266263`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.7989392885410604`*^9, 3.7989455895862923`*^9, 3.7989465364817114`*^9, 
   3.800094430085563*^9, 3.800094568694209*^9, 3.8002435647280807`*^9, 
   3.800244759544059*^9, 3.8002448261253104`*^9, 3.8002456638062534`*^9, {
   3.8002460173147755`*^9, 3.8002460365062065`*^9}, 3.800274673349989*^9, 
   3.8003194710700135`*^9, 3.8003198628853397`*^9, 3.800450900259828*^9, 
   3.800590478411232*^9, 3.8005936289446898`*^9, 3.8005988499788046`*^9, 
   3.8006745052472544`*^9, 3.8010181538906574`*^9, 3.8010182230420628`*^9, 
   3.801025795266999*^9, 3.801028795175341*^9, 3.801031746061991*^9, 
   3.8010317793689203`*^9, 3.81877203081318*^9}],

Cell[BoxData[
 RowBox[{"n", "\[Equal]", 
  RowBox[{"-", "1"}]}]], "Output",
 CellChangeTimes->{
  3.7989392885410604`*^9, 3.7989455895862923`*^9, 3.7989465364817114`*^9, 
   3.800094430085563*^9, 3.800094568694209*^9, 3.8002435647280807`*^9, 
   3.800244759544059*^9, 3.8002448261253104`*^9, 3.8002456638062534`*^9, {
   3.8002460173147755`*^9, 3.8002460365062065`*^9}, 3.800274673349989*^9, 
   3.8003194710700135`*^9, 3.8003198628853397`*^9, 3.800450900259828*^9, 
   3.800590478411232*^9, 3.8005936289446898`*^9, 3.8005988499788046`*^9, 
   3.8006745052472544`*^9, 3.8010181538906574`*^9, 3.8010182230420628`*^9, 
   3.801025795266999*^9, 3.801028795175341*^9, 3.801031746061991*^9, 
   3.8010317793689203`*^9, 3.8187720308181677`*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{
    RowBox[{"-", "1"}], "+", 
    SubscriptBox["\[Alpha]", "\[CapitalLambda]"]}]], "\[Equal]", 
  FractionBox["10", "9"]}]], "Output",
 CellChangeTimes->{
  3.7989392885410604`*^9, 3.7989455895862923`*^9, 3.7989465364817114`*^9, 
   3.800094430085563*^9, 3.800094568694209*^9, 3.8002435647280807`*^9, 
   3.800244759544059*^9, 3.8002448261253104`*^9, 3.8002456638062534`*^9, {
   3.8002460173147755`*^9, 3.8002460365062065`*^9}, 3.800274673349989*^9, 
   3.8003194710700135`*^9, 3.8003198628853397`*^9, 3.800450900259828*^9, 
   3.800590478411232*^9, 3.8005936289446898`*^9, 3.8005988499788046`*^9, 
   3.8006745052472544`*^9, 3.8010181538906574`*^9, 3.8010182230420628`*^9, 
   3.801025795266999*^9, 3.801028795175341*^9, 3.801031746061991*^9, 
   3.8010317793689203`*^9, 3.8187720308231554`*^9}]
}, Open  ]],

Cell["\<\
We consider a set of initial conditions that end up on the self-tuning de \
Sitter state...\
\>", "Text",
 CellChangeTimes->{{3.800245947734703*^9, 3.8002459580169473`*^9}, {
  3.8187720373176055`*^9, 3.818772038393677*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"initial", " ", "conditions"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"ainit", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ai", "\[Rule]", "1"}], ",", 
       RowBox[{"dai", "\[Rule]", 
        FractionBox["6", "5"]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"cons", "=", 
     RowBox[{
      RowBox[{"NSolve", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Feq2", "/.", "param"}], "/.", "abun"}], "/.", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"a", "[", "\[Tau]", "]"}], "\[Rule]", "ai"}], ",", 
              RowBox[{
               RowBox[{
                RowBox[{"a", "'"}], "[", "\[Tau]", "]"}], "\[Rule]", "dai"}], 
              ",", 
              RowBox[{
               RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}], "\[Rule]", 
               "d\[CapitalPsi]"}]}], "}"}]}], "/.", "ainit"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"Re", "[", "d\[CapitalPsi]", "]"}], ">", "0"}], "&&", 
           RowBox[{
            RowBox[{"Im", "[", "d\[CapitalPsi]", "]"}], "\[Equal]", "0"}]}]}],
          "}"}], ",", "d\[CapitalPsi]", ",", 
        RowBox[{"WorkingPrecision", "\[Rule]", "50"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"init", "=", 
     RowBox[{"Union", "[", 
      RowBox[{"ainit", ",", "cons"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"a", "[", 
     SubscriptBox["\[Tau]", "0"], "]"}], "\[Equal]", 
    RowBox[{"(", 
     RowBox[{"ai", "/.", "init"}], ")"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"a", "'"}], "[", 
     SubscriptBox["\[Tau]", "0"], "]"}], "\[Equal]", 
    RowBox[{"(", 
     RowBox[{"dai", "/.", "init"}], ")"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[CapitalPsi]", "[", 
     SubscriptBox["\[Tau]", "0"], "]"}], "\[Equal]", 
    RowBox[{"(", 
     RowBox[{"d\[CapitalPsi]", "/.", "init"}], ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.800246011893676*^9, 3.8002460122905116`*^9}, {
  3.8002470126507645`*^9, 3.8002471549738455`*^9}, {3.8002476024711685`*^9, 
  3.8002476029448156`*^9}, {3.8002477551371655`*^9, 3.800247782234279*^9}, {
  3.8002478792366056`*^9, 3.800247884123073*^9}, {3.800675034520174*^9, 
  3.8006750386056547`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a", "[", 
   SubscriptBox["\[Tau]", "0"], "]"}], "\[Equal]", "1"}]], "Output",
 CellChangeTimes->{
  3.80024608368729*^9, 3.800247106315192*^9, {3.800247145366255*^9, 
   3.800247156364049*^9}, 3.800247620025158*^9, {3.800247869736657*^9, 
   3.800247885232692*^9}, 3.8002746813400517`*^9, 3.8003194764630632`*^9, 
   3.8003198653796725`*^9, 3.800450900632968*^9, 3.8005904788330097`*^9, {
   3.8005936380648413`*^9, 3.800593666900035*^9}, 3.800598853293068*^9, 
   3.8006745055496273`*^9, 3.8010181569367857`*^9, 3.8010182257289343`*^9, 
   3.801025799216047*^9, 3.8010287972836494`*^9, 3.801031748430193*^9, 
   3.801031782306752*^9, 3.818772044680559*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["a", "\[Prime]",
    MultilineFunction->None], "[", 
   SubscriptBox["\[Tau]", "0"], "]"}], "\[Equal]", 
  FractionBox["6", "5"]}]], "Output",
 CellChangeTimes->{
  3.80024608368729*^9, 3.800247106315192*^9, {3.800247145366255*^9, 
   3.800247156364049*^9}, 3.800247620025158*^9, {3.800247869736657*^9, 
   3.800247885232692*^9}, 3.8002746813400517`*^9, 3.8003194764630632`*^9, 
   3.8003198653796725`*^9, 3.800450900632968*^9, 3.8005904788330097`*^9, {
   3.8005936380648413`*^9, 3.800593666900035*^9}, 3.800598853293068*^9, 
   3.8006745055496273`*^9, 3.8010181569367857`*^9, 3.8010182257289343`*^9, 
   3.801025799216047*^9, 3.8010287972836494`*^9, 3.801031748430193*^9, 
   3.801031782306752*^9, 3.818772044696144*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalPsi]", "[", 
   SubscriptBox["\[Tau]", "0"], "]"}], "\[Equal]", 
  "0.5423261445466404300001337812801643033674591205130861181182600489347404583\
3278`50."}]], "Output",
 CellChangeTimes->{
  3.80024608368729*^9, 3.800247106315192*^9, {3.800247145366255*^9, 
   3.800247156364049*^9}, 3.800247620025158*^9, {3.800247869736657*^9, 
   3.800247885232692*^9}, 3.8002746813400517`*^9, 3.8003194764630632`*^9, 
   3.8003198653796725`*^9, 3.800450900632968*^9, 3.8005904788330097`*^9, {
   3.8005936380648413`*^9, 3.800593666900035*^9}, 3.800598853293068*^9, 
   3.8006745055496273`*^9, 3.8010181569367857`*^9, 3.8010182257289343`*^9, 
   3.801025799216047*^9, 3.8010287972836494`*^9, 3.801031748430193*^9, 
   3.801031782306752*^9, 3.818772044696144*^9}]
}, Open  ]],

Cell[TextData[{
 "We integrate ",
 StyleBox["ode1",
  FontSlant->"Italic"],
 " and ",
 StyleBox["ode2",
  FontSlant->"Italic"],
 " using the following function..."
}], "Text",
 CellChangeTimes->{{3.79893925250393*^9, 3.7989392549877186`*^9}, {
   3.8002435987926607`*^9, 3.800243619405242*^9}, {3.800246099156426*^9, 
   3.800246103928334*^9}, 3.8187720527099347`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"cosmogccg", "[", 
    RowBox[{
    "ai_", ",", "dai_", ",", "d\[CapitalPsi]_", ",", "\[Tau]0_", ",", 
     "\[Tau]i_", ",", "\[Tau]f_"}], "]"}], ":=", 
   RowBox[{"NDSolve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"ode1", "/.", "abun"}], "/.", "param"}], ",", 
       RowBox[{
        RowBox[{"ode2", "/.", "abun"}], "/.", "param"}], ",", 
       RowBox[{
        RowBox[{"a", "[", "\[Tau]0", "]"}], "\[Equal]", "ai"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"a", "'"}], "[", "\[Tau]0", "]"}], "\[Equal]", "dai"}], ",", 
       RowBox[{
        RowBox[{"\[CapitalPsi]", "[", "\[Tau]0", "]"}], "\[Equal]", 
        "d\[CapitalPsi]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", "\[CapitalPsi]"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Tau]", ",", "\[Tau]i", ",", "\[Tau]f"}], "}"}], ",", 
     RowBox[{"WorkingPrecision", "\[Rule]", "50"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8002457117282643`*^9, 3.800245772421632*^9}, {
  3.800245818407202*^9, 3.800245826114381*^9}, {3.800245860551331*^9, 
  3.8002459047799797`*^9}, {3.800246425696772*^9, 3.8002464267464256`*^9}}],

Cell[TextData[{
 "Testing this function for ",
 StyleBox["init",
  FontSlant->"Italic"],
 "..."
}], "Text",
 CellChangeTimes->{{3.800246115465528*^9, 3.800246145870097*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dom", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Tau]0", "\[Rule]", "1"}], ",", 
     RowBox[{"\[Tau]i", "\[Rule]", "1"}], ",", 
     RowBox[{"\[Tau]f", "\[Rule]", "5"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"int", "=", 
   RowBox[{"cosmogccg", "[", 
    RowBox[{
     RowBox[{"ai", "/.", "init"}], ",", 
     RowBox[{"dai", "/.", "init"}], ",", 
     RowBox[{"d\[CapitalPsi]", "/.", "init"}], ",", 
     RowBox[{"\[Tau]0", "/.", "dom"}], ",", 
     RowBox[{"\[Tau]i", "/.", "dom"}], ",", 
     RowBox[{"\[Tau]f", "/.", "dom"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.800246149699422*^9, 3.8002462385315676`*^9}, {
   3.8002463787372694`*^9, 3.800246423477397*^9}, {3.800246871786807*^9, 
   3.8002469503898473`*^9}, {3.8002475455199614`*^9, 
   3.8002475641720223`*^9}, {3.8002748281960735`*^9, 3.8002748536634903`*^9}, 
   3.800319667209755*^9}],

Cell["Here is a plot of the solution.", "Text",
 CellChangeTimes->{{3.800243629693841*^9, 3.8002436360356636`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"scalar", " ", "field", " ", "derivative"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"p\[CapitalPsi]1", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}], "]"}], "/.", 
         RowBox[{"int", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], 
        RowBox[{"(*", 
         RowBox[{",", 
          RowBox[{
           RowBox[{"Im", "[", 
            RowBox[{
             RowBox[{"\[CapitalPsi]", "'"}], "[", "\[Tau]", "]"}], "]"}], "/.", 
           RowBox[{"int", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}]}], "*)"}], "}"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\[Tau]", ",", "\[Tau]i", ",", "\[Tau]f"}], "}"}], "/.", 
        "dom"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
       RowBox[{"AxesStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", 
        RowBox[{"Directive", "[", "Red", "]"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"TicksStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", "0.007", "]"}], ",", "Pink"}], "}"}], 
         "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<\[Tau]\>\"", ",", "\"\<\[CapitalPsi](\[Tau])\>\""}], 
         "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"acceleration", " ", "of", " ", "scalar", " ", "field"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pd\[CapitalPsi]1", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"Log", "[", 
           RowBox[{
            RowBox[{"\[CapitalPsi]", "'"}], "[", "\[Tau]", "]"}], "]"}], 
          "]"}], "/.", 
         RowBox[{"int", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], 
        RowBox[{"(*", 
         RowBox[{",", 
          RowBox[{
           RowBox[{"Im", "[", 
            RowBox[{
             RowBox[{"\[CapitalPsi]", "'"}], "[", "\[Tau]", "]"}], "]"}], "/.", 
           RowBox[{"int", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}]}], "*)"}], "}"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\[Tau]", ",", "\[Tau]i", ",", "\[Tau]f"}], "}"}], "/.", 
        "dom"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
       RowBox[{"AxesStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", 
        RowBox[{"Directive", "[", "Red", "]"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"TicksStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", "0.007", "]"}], ",", "Pink"}], "}"}], 
         "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\[Tau]\>\"", ",", "\"\<ln(\[CapitalPsi]'(\[Tau]))\>\""}], 
         "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Hubble", " ", "parameter"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pH1", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          FractionBox[
           RowBox[{
            RowBox[{"a", "'"}], "[", "\[Tau]", "]"}], 
           RowBox[{"a", "[", "\[Tau]", "]"}]], "]"}], "/.", 
         RowBox[{"int", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\[Tau]", ",", "\[Tau]i", ",", "\[Tau]f"}], "}"}], "/.", 
        "dom"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"AxesStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", 
        RowBox[{"Directive", "[", "Red", "]"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"TicksStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", "0.007", "]"}], ",", "Pink"}], "}"}], 
         "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<\[Tau]\>\"", ",", "\"\<\!\(\*
StyleBox[\"H\",
FontSlant->\"Italic\"]\)(\[Tau])\>\""}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Hubble", " ", "parameter", " ", "time", " ", "derivative"}], 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pdH1", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Log", "[", 
          RowBox[{"Abs", "[", 
           RowBox[{"Re", "[", 
            RowBox[{
             FractionBox[
              RowBox[{
               RowBox[{"a", "''"}], "[", "\[Tau]", "]"}], 
              RowBox[{"a", "[", "\[Tau]", "]"}]], "-", 
             SuperscriptBox[
              RowBox[{"(", 
               FractionBox[
                RowBox[{
                 RowBox[{"a", "'"}], "[", "\[Tau]", "]"}], 
                RowBox[{"a", "[", "\[Tau]", "]"}]], ")"}], "2"]}], "]"}], 
           "]"}], "]"}], "/.", 
         RowBox[{"int", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], 
        RowBox[{"(*", 
         RowBox[{",", 
          RowBox[{
           RowBox[{"Im", "[", 
            RowBox[{
             FractionBox[
              RowBox[{
               RowBox[{"a", "''"}], "[", "\[Tau]", "]"}], 
              RowBox[{"a", "[", "\[Tau]", "]"}]], "-", 
             SuperscriptBox[
              RowBox[{"(", 
               FractionBox[
                RowBox[{
                 RowBox[{"a", "'"}], "[", "\[Tau]", "]"}], 
                RowBox[{"a", "[", "\[Tau]", "]"}]], ")"}], "2"]}], "]"}], "/.", 
           RowBox[{"int", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}]}], "*)"}], "}"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\[Tau]", ",", "\[Tau]i", ",", "\[Tau]f"}], "}"}], "/.", 
        "dom"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"AxesStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", 
        RowBox[{"Directive", "[", "Red", "]"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"TicksStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", "0.007", "]"}], ",", "Pink"}], "}"}], 
         "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<\[Tau]\>\"", ",", "\"\<ln(\!\(\*
StyleBox[\"H\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"'\",
FontSlant->\"Italic\"]\)(\[Tau]))\>\""}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"constraint", " ", "equation"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pF1", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"Log", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Abs", "[", 
            RowBox[{"Feq2", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "]"}], "/.", "param"}], "/.", 
          "abun"}], "/.", 
         RowBox[{"int", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\[Tau]", ",", "\[Tau]i", ",", "\[Tau]f"}], "}"}], "/.", 
        "dom"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"AxesStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", 
        RowBox[{"Directive", "[", "Red", "]"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"TicksStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", "0.007", "]"}], ",", "Pink"}], "}"}], 
         "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<\[Tau]\>\"", ",", "\"\<\>\""}], "}"}]}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"energy", " ", "budget", " ", "in", " ", "units", " ", "of", " ", 
     SuperscriptBox[
      StyleBox["h",
       FontSlant->"Italic"], "2"]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Log", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"3", 
              FractionBox["\[Alpha]r", 
               SuperscriptBox[
                RowBox[{"a", "[", "\[Tau]", "]"}], "4"]]}], ")"}], 
            RowBox[{"(", 
             FractionBox[
              SuperscriptBox[
               RowBox[{"a", "[", "\[Tau]", "]"}], "2"], 
              RowBox[{"3", 
               SuperscriptBox[
                RowBox[{
                 RowBox[{"a", "'"}], "[", "\[Tau]", "]"}], "2"]}]], ")"}]}], 
           "]"}], "/.", "abun"}], "/.", 
         RowBox[{"int", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Log", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"3", 
              FractionBox["\[Alpha]m", 
               SuperscriptBox[
                RowBox[{"a", "[", "\[Tau]", "]"}], "3"]]}], ")"}], 
            RowBox[{"(", 
             FractionBox[
              SuperscriptBox[
               RowBox[{"a", "[", "\[Tau]", "]"}], "2"], 
              RowBox[{"3", 
               SuperscriptBox[
                RowBox[{
                 RowBox[{"a", "'"}], "[", "\[Tau]", "]"}], "2"]}]], ")"}]}], 
           "]"}], "/.", "abun"}], "/.", 
         RowBox[{"int", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Log", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"3", "\[Alpha]\[CapitalLambda]"}], ")"}], 
            RowBox[{"(", 
             FractionBox[
              SuperscriptBox[
               RowBox[{"a", "[", "\[Tau]", "]"}], "2"], 
              RowBox[{"3", 
               SuperscriptBox[
                RowBox[{
                 RowBox[{"a", "'"}], "[", "\[Tau]", "]"}], "2"]}]], ")"}]}], 
           "]"}], "/.", "abun"}], "/.", 
         RowBox[{"int", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}]}], 
       RowBox[{"(*", 
        RowBox[{",", 
         RowBox[{
          RowBox[{
           RowBox[{"1", "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", 
                FractionBox["\[Alpha]r", 
                 SuperscriptBox[
                  RowBox[{"a", "[", "\[Tau]", "]"}], "4"]]}], "+", 
               RowBox[{"3", 
                FractionBox["\[Alpha]m", 
                 SuperscriptBox[
                  RowBox[{"a", "[", "\[Tau]", "]"}], "3"]]}], "+", 
               RowBox[{"3", "\[Alpha]\[CapitalLambda]"}]}], ")"}], 
             FractionBox[
              SuperscriptBox[
               RowBox[{"a", "[", "\[Tau]", "]"}], "2"], 
              RowBox[{"3", 
               SuperscriptBox[
                RowBox[{
                 RowBox[{"a", "'"}], "[", "\[Tau]", "]"}], "2"]}]]}]}], "/.", 
           "abun"}], "/.", 
          RowBox[{"int", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}]}], "*)"}], "}"}], ",", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[Tau]", ",", "\[Tau]i", ",", "\[Tau]f"}], "}"}], "/.", 
       "dom"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "Automatic"}], ",", 
      RowBox[{"AxesStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
      RowBox[{"LabelStyle", "\[Rule]", 
       RowBox[{"Directive", "[", "Red", "]"}]}], ",", 
      RowBox[{"Ticks", "\[Rule]", "Automatic"}], ",", 
      RowBox[{"TicksStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Thickness", "[", "0.007", "]"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Dashing", "[", "Large", "]"}], ",", 
           RowBox[{"Thickness", "[", "0.01", "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Dashing", "[", "Medium", "]"}], ",", 
           RowBox[{"Thickness", "[", "0.012", "]"}]}], "}"}]}], "}"}]}], ",", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<rad\>\"", ",", "\"\<mat\>\"", ",", "\"\<vac\>\""}], 
        RowBox[{"(*", 
         RowBox[{",", "\"\<\[Phi]\>\""}], "*)"}], "}"}]}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<\[Tau]\>\"", ",", 
         "\"\<ln(\!\(\*SubscriptBox[\(\[CapitalOmega]\), \(i\)]\))\>\""}], 
        "}"}]}]}], "]"}], "*)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"log", " ", "plot", " ", "of", " ", "energy", " ", "budget"}], 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pbud1", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"Log", "[", 
             RowBox[{"a", "[", "\[Tau]", "]"}], "]"}], "/.", 
            RowBox[{"int", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"Log", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"3", 
                 FractionBox["\[Alpha]r", 
                  SuperscriptBox[
                   RowBox[{"a", "[", "\[Tau]", "]"}], "4"]]}], ")"}], 
               RowBox[{"(", 
                FractionBox[
                 SuperscriptBox[
                  RowBox[{"a", "[", "\[Tau]", "]"}], "2"], 
                 RowBox[{"3", 
                  SuperscriptBox[
                   RowBox[{
                    RowBox[{"a", "'"}], "[", "\[Tau]", "]"}], "2"]}]], 
                ")"}]}], "]"}], "/.", "abun"}], "/.", 
            RowBox[{"int", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"Log", "[", 
             RowBox[{"a", "[", "\[Tau]", "]"}], "]"}], "/.", 
            RowBox[{"int", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"Log", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"3", 
                 FractionBox["\[Alpha]m", 
                  SuperscriptBox[
                   RowBox[{"a", "[", "\[Tau]", "]"}], "3"]]}], ")"}], 
               RowBox[{"(", 
                FractionBox[
                 SuperscriptBox[
                  RowBox[{"a", "[", "\[Tau]", "]"}], "2"], 
                 RowBox[{"3", 
                  SuperscriptBox[
                   RowBox[{
                    RowBox[{"a", "'"}], "[", "\[Tau]", "]"}], "2"]}]], 
                ")"}]}], "]"}], "/.", "abun"}], "/.", 
            RowBox[{"int", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"Log", "[", 
             RowBox[{"a", "[", "\[Tau]", "]"}], "]"}], "/.", 
            RowBox[{"int", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"Log", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"3", "\[Alpha]\[CapitalLambda]"}], ")"}], 
               RowBox[{"(", 
                FractionBox[
                 SuperscriptBox[
                  RowBox[{"a", "[", "\[Tau]", "]"}], "2"], 
                 RowBox[{"3", 
                  SuperscriptBox[
                   RowBox[{
                    RowBox[{"a", "'"}], "[", "\[Tau]", "]"}], "2"]}]], 
                ")"}]}], "]"}], "/.", "abun"}], "/.", 
            RowBox[{"int", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Tau]", ",", "1", ",", "5"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"AxesStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", 
        RowBox[{"Directive", "[", "Red", "]"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"TicksStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Thickness", "[", "0.01", "]"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Dashing", "[", "Large", "]"}], ",", 
            RowBox[{"Thickness", "[", "0.01", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Dashing", "[", "Medium", "]"}], ",", 
            RowBox[{"Thickness", "[", "0.01", "]"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotLegends", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<rad\>\"", ",", "\"\<mat\>\"", ",", "\"\<vac\>\"", ",", 
          "\"\<\[Phi]\>\""}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", 
        RowBox[{"1", "/", "2"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<ln \!\(\*
StyleBox[\"a\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"(\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"\[Tau]\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\")\",
FontSlant->\"Italic\"]\)\>\"", ",", 
          "\"\<ln \!\(\*SubscriptBox[\(\[CapitalOmega]\), \(i\)]\)\>\""}], 
         "}"}]}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "450"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"dark", " ", "energy", " ", "equation", " ", "of", " ", "state"}],
     "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pw1", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"wDE", "[", "\[Tau]", "]"}], "/.", 
          RowBox[{
           RowBox[{"H", "[", "\[Tau]", "]"}], "\[Rule]", 
           FractionBox[
            RowBox[{
             RowBox[{"a", "'"}], "[", "\[Tau]", "]"}], 
            RowBox[{"a", "[", "\[Tau]", "]"}]]}]}], "/.", "param"}], "/.", 
        RowBox[{"int", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\[Tau]", ",", "\[Tau]i", ",", "\[Tau]f"}], "}"}], "/.", 
        "dom"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
       RowBox[{"AxesStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", 
        RowBox[{"Directive", "[", "Red", "]"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"TicksStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", "0.007", "]"}], ",", "Pink"}], "}"}], 
         "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<\[Tau]\>\"", ",", "\"\<\!\(\*SubscriptBox[
StyleBox[\"w\",
FontSlant->\"Italic\"], \"\[Phi]\"]\)(\[Tau])\>\""}], "}"}]}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Show", "[", "p\[CapitalPsi]1", "]"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", "pd\[CapitalPsi]1", "]"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", "pH1", "]"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", "pdH1", "]"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", "pF1", "]"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", "pbud1", "]"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", "pw1", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.798573976644096*^9, 3.7985740380125246`*^9}, {
   3.798574166987529*^9, 3.7985741773307457`*^9}, {3.798574293265134*^9, 
   3.798574302756437*^9}, 3.798580070368439*^9, {3.79858010151388*^9, 
   3.7985801115128727`*^9}, {3.798939503312642*^9, 3.7989395112214937`*^9}, 
   3.800094649040639*^9, {3.8000947490195284`*^9, 3.80009475106246*^9}, {
   3.8000948038631935`*^9, 3.8000948864494314`*^9}, {3.80009597857439*^9, 
   3.8000959994272895`*^9}, {3.8000960751165257`*^9, 3.800096103242265*^9}, {
   3.8000961404352655`*^9, 3.800096174779834*^9}, {3.800096226346475*^9, 
   3.800096290054216*^9}, 3.8000963636251144`*^9, {3.8000965369331083`*^9, 
   3.8000966139557724`*^9}, {3.8000968116765*^9, 3.80009681234544*^9}, {
   3.800097105680295*^9, 3.800097152743515*^9}, {3.8002436573631735`*^9, 
   3.800243776982565*^9}, {3.800244673967579*^9, 3.800244677959628*^9}, {
   3.800247949451173*^9, 3.800247960412363*^9}, {3.8002488611662326`*^9, 
   3.800248981537126*^9}, {3.80024901336371*^9, 3.800249014566428*^9}, {
   3.800274739944709*^9, 3.8002748265932145`*^9}, {3.800319893772828*^9, 
   3.800319917523326*^9}, {3.8003199730691557`*^9, 3.8003199801444273`*^9}, {
   3.8003200303015876`*^9, 3.800320061383198*^9}, {3.801025868566504*^9, 
   3.8010259603884525`*^9}, {3.8010260375156317`*^9, 3.801026070975464*^9}, {
   3.8010285020126047`*^9, 3.801028502397826*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[1, 0.5, 0.5], Thickness[0.007], Opacity[1.], 
      LineBox[CompressedData["
1:eJwd1nc8ld8fAPBrX/sODTMRWaWUMsr5UCQ7UiLZEpHMKKKMiFLJV1YUkgoJ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       "]]},
     Annotation[#, "Charting`Private`Tag$33875#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"\[Tau]\"", TraditionalForm], 
    FormBox["\"\[CapitalPsi](\[Tau])\"", TraditionalForm]},
  AxesOrigin->{1.000000081632653, 0.5423261987349842},
  AxesStyle->Directive[
    RGBColor[1, 0, 0], 15],
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[
    RGBColor[1, 0, 0]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic},
  TicksStyle->Directive[
    RGBColor[1, 0, 0], 15]]], "Output",
 CellChangeTimes->{
  3.80009627060848*^9, 3.800097155498377*^9, 3.8002437855425205`*^9, 
   3.8002447702649016`*^9, 3.800246493547531*^9, 3.800246957971347*^9, 
   3.8002476439802876`*^9, 3.8002479623539224`*^9, 3.8002490185072365`*^9, 
   3.800274702062547*^9, 3.800274762098792*^9, 3.8002748599649725`*^9, 
   3.8003194919624414`*^9, 3.8003196742178125`*^9, 3.8003198789487357`*^9, {
   3.8003199579992127`*^9, 3.8003199857193937`*^9}, 3.8003200762013097`*^9, 
   3.8004509075125427`*^9, 3.8005904828903303`*^9, 3.8006745092513533`*^9, 
   3.8010260440000677`*^9, 3.8010260744968204`*^9, 3.8010285082756824`*^9, 
   3.801028813787381*^9, 3.818772162819541*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[1, 0.5, 0.5], Thickness[0.007], Opacity[1.], 
      LineBox[CompressedData["
1:eJwVknk41N0bxmVIlsIMQl5LtmnBhBZU5/BassybyhIiJRUlkrK0UFkToaLS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       "]]},
     Annotation[#, "Charting`Private`Tag$33929#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"\[Tau]\"", TraditionalForm], 
    FormBox["\"ln(\[CapitalPsi]'(\[Tau]))\"", TraditionalForm]},
  AxesOrigin->{1.000000081632653, -12.454028904651496`},
  AxesStyle->Directive[
    RGBColor[1, 0, 0], 15],
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[
    RGBColor[1, 0, 0]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic},
  TicksStyle->Directive[
    RGBColor[1, 0, 0], 15]]], "Output",
 CellChangeTimes->{
  3.80009627060848*^9, 3.800097155498377*^9, 3.8002437855425205`*^9, 
   3.8002447702649016`*^9, 3.800246493547531*^9, 3.800246957971347*^9, 
   3.8002476439802876`*^9, 3.8002479623539224`*^9, 3.8002490185072365`*^9, 
   3.800274702062547*^9, 3.800274762098792*^9, 3.8002748599649725`*^9, 
   3.8003194919624414`*^9, 3.8003196742178125`*^9, 3.8003198789487357`*^9, {
   3.8003199579992127`*^9, 3.8003199857193937`*^9}, 3.8003200762013097`*^9, 
   3.8004509075125427`*^9, 3.8005904828903303`*^9, 3.8006745092513533`*^9, 
   3.8010260440000677`*^9, 3.8010260744968204`*^9, 3.8010285082756824`*^9, 
   3.801028813787381*^9, 3.818772162835189*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[1, 0.5, 0.5], Thickness[0.007], Opacity[1.], 
      LineBox[CompressedData["
1:eJwd13c8ld8fAPDrWte+Q0aUkFWijG9GOh+KFFqUnS2Z2WmIQqgkoUGhYTSM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       "]]},
     Annotation[#, "Charting`Private`Tag$33969#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"\[Tau]\"", TraditionalForm], 
    FormBox[
    "\"\\!\\(\\*\\nStyleBox[\\\"H\\\",\\nFontSlant->\\\"Italic\\\"]\\)(\[Tau])\
\"", TraditionalForm]},
  AxesOrigin->{1.000000081632653, 1.0000033854666457`},
  AxesStyle->Directive[
    RGBColor[1, 0, 0], 15],
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[
    RGBColor[1, 0, 0]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{1.000000081632653, 4.999999918367347}, {1.0000033854666457`, 
   1.2001601620678422`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic},
  TicksStyle->Directive[
    RGBColor[1, 0, 0], 15]]], "Output",
 CellChangeTimes->{
  3.80009627060848*^9, 3.800097155498377*^9, 3.8002437855425205`*^9, 
   3.8002447702649016`*^9, 3.800246493547531*^9, 3.800246957971347*^9, 
   3.8002476439802876`*^9, 3.8002479623539224`*^9, 3.8002490185072365`*^9, 
   3.800274702062547*^9, 3.800274762098792*^9, 3.8002748599649725`*^9, 
   3.8003194919624414`*^9, 3.8003196742178125`*^9, 3.8003198789487357`*^9, {
   3.8003199579992127`*^9, 3.8003199857193937`*^9}, 3.8003200762013097`*^9, 
   3.8004509075125427`*^9, 3.8005904828903303`*^9, 3.8006745092513533`*^9, 
   3.8010260440000677`*^9, 3.8010260744968204`*^9, 3.8010285082756824`*^9, 
   3.801028813787381*^9, 3.8187721628507786`*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[1, 0.5, 0.5], Thickness[0.007], Opacity[1.], 
      LineBox[CompressedData["
1:eJwVlXk81N/3x0eyjQoz1ixZaiJrlhTqvJOtKEWSpQ2lJEoK9YmIUtkrfMjS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       "]]},
     Annotation[#, "Charting`Private`Tag$34008#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"\[Tau]\"", TraditionalForm], 
    FormBox[
    "\"ln(\\!\\(\\*\\nStyleBox[\\\"H\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\\
(\\*\\nStyleBox[\\\"'\\\",\\nFontSlant->\\\"Italic\\\"]\\)(\[Tau]))\"", 
     TraditionalForm]},
  AxesOrigin->{1.000000081632653, 0},
  AxesStyle->Directive[
    RGBColor[1, 0, 0], 15],
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[
    RGBColor[1, 0, 0]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{1.000000081632653, 4.999999918367347}, {-11.497407663828112`, 
   0.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic},
  TicksStyle->Directive[
    RGBColor[1, 0, 0], 15]]], "Output",
 CellChangeTimes->{
  3.80009627060848*^9, 3.800097155498377*^9, 3.8002437855425205`*^9, 
   3.8002447702649016`*^9, 3.800246493547531*^9, 3.800246957971347*^9, 
   3.8002476439802876`*^9, 3.8002479623539224`*^9, 3.8002490185072365`*^9, 
   3.800274702062547*^9, 3.800274762098792*^9, 3.8002748599649725`*^9, 
   3.8003194919624414`*^9, 3.8003196742178125`*^9, 3.8003198789487357`*^9, {
   3.8003199579992127`*^9, 3.8003199857193937`*^9}, 3.8003200762013097`*^9, 
   3.8004509075125427`*^9, 3.8005904828903303`*^9, 3.8006745092513533`*^9, 
   3.8010260440000677`*^9, 3.8010260744968204`*^9, 3.8010285082756824`*^9, 
   3.801028813787381*^9, 3.8187721628507786`*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[1, 0.5, 0.5], Thickness[0.007], Opacity[1.], 
      LineBox[CompressedData["
1:eJxEenk4lG/Y9syIRCRFthBZkhbV7MP9KKJSyk6WhCiyFypbpVJkKRKSJEUS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       "]]},
     Annotation[#, "Charting`Private`Tag$34046#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"\[Tau]\"", TraditionalForm], 
    FormBox["\"\"", TraditionalForm]},
  AxesOrigin->{1.000000081632653, -35.35050620855721},
  AxesStyle->Directive[
    RGBColor[1, 0, 0], 15],
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[
    RGBColor[1, 0, 0]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{1.000000081632653, 
   4.999999918367347}, {-35.35050620855721, -14.364695938759223`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic},
  TicksStyle->Directive[
    RGBColor[1, 0, 0], 15]]], "Output",
 CellChangeTimes->{
  3.80009627060848*^9, 3.800097155498377*^9, 3.8002437855425205`*^9, 
   3.8002447702649016`*^9, 3.800246493547531*^9, 3.800246957971347*^9, 
   3.8002476439802876`*^9, 3.8002479623539224`*^9, 3.8002490185072365`*^9, 
   3.800274702062547*^9, 3.800274762098792*^9, 3.8002748599649725`*^9, 
   3.8003194919624414`*^9, 3.8003196742178125`*^9, 3.8003198789487357`*^9, {
   3.8003199579992127`*^9, 3.8003199857193937`*^9}, 3.8003200762013097`*^9, 
   3.8004509075125427`*^9, 3.8005904828903303`*^9, 3.8006745092513533`*^9, 
   3.8010260440000677`*^9, 3.8010260744968204`*^9, 3.8010285082756824`*^9, 
   3.801028813787381*^9, 3.818772162866401*^9}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, 
      TagBox[{
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.368417, 0.506779, 0.709798], 
         Thickness[0.01]], 
        LineBox[CompressedData["
1:eJwljns01GkcxgczGBPeyuRSjVzGtWH8NqJW77uydFPtsNWubiRCmWaUS5KZ
bFadTVsYSeXSRYumO1LqO63KNK3Wpm2ypDBIWZlcukxr7dnnnM95zuc8/zx2
kULBZn0ajRYywX/9f0pudvcO1aetYsDk8OPr5Zw12MdPYXMskgGxavOI65wt
2EJXer4mgQFBF/scmjgpODTcTvg2iwGS6haZlpONH3GSvlhTw4B87sY2J9uj
2Hx17/JxS0OoleXx59mewwVnH2qK1YbQrB9wZWRmLS42ScP3VhlDm71rm42l
ErvOLvTjSlkwxhKHOOT9gb3pC/Pb1piBKGzpmbA4NWaefbLtjRRBAS9O9LD0
Od7WGCQt0kyGttL9gUKXTlzZ0p68yWUqSNkHp7J4Gpx4ecTPU2oBYo9V9Gh2
H36VYzTU0cyGQ98wraYp+jHn05xwNcsSVlxfcHHk+ACOHD5yaWijFdxwaR+S
zHqLI3SXtvuVWIOm/IKPR+wQ9tFFbWG12sDLZ8lZUSotVs/JU27ynAFCTt3r
GRbD+HTuuQZZwkzo7Dr1tCdpBO+OHXvsp+QA7X7/AV3zKE7J0HYams+CkIas
1BaL99jxgLSHK58Fcpfx0gDxB/xrq8ninu/toIquL+qo+YiHMqcXBOomvFhY
4W+lw8HP87+cX2kPuaqGSU9En7HFg4Ryq9UOMHxwZeenK//glcUzzqePOcDf
GwJxljGNsAtED0RnHCF7/pKY6EoayQnPvasJ5kIlI7GdvlSPPAuLieP3cuFW
nmCP3Xs9Ency5RIjzwnu2soHTxXqk9AT/vph3s6A1N4F5YsMyCGjzmT3bmf4
OW7vY/GwAXkTWM98csgFVgYVXajIo5N5vrVBw56u4LHjgSw6gEGi3T0Citpd
oV6eG3G4m0FOHN3RWJ3hBu/kY+nZmYakbNlcVMZxB+8X07V0vhF5pTAQWajc
Aa6yiPZ3I+LLWxL5MX42DFf/KdicYUy8xT4+MTY8KPphYGCxPZN81SRZGFzP
g1PxfTt1CiZptbT+enStBwyahTh7C03IKw/HMXcTT9hn+stYB2IR7r1FBS2V
nrBDHj5lMrDIo8vVr6U8PqT3mu5BWycRWu/AG0kmH14sMhLsnWRKlH0dguuP
J7y5M2dXnSnZ8M5T75qbF0R/WL9Ms9aM2DQ6mvWneQH0qQ5ydGaEaZgpzFJ5
gSDOOuj5OXMi6b7N7rGjoKuKtcSYiwi/YR07Q0wBc0oob7sTIjdlzPc9iRQg
k2NI7YxIV/G11uU7Kci86vS03A0Rg2/NSjgpFEjG50UF8xExCbzjdiudgqZH
K/ZkzUdklD6HfM6mgCvgXaYLEGHn+8enFVOg6ovJ3xqKSHfTYEhXCQVK27KU
ljBEfvQt4y8toyByOxufXo2I6JjRqM0ZCgbPjqkWrkPku9wWSV0FBetvV2j2
bkFE5Zks+3CNgmf7Oxr7YxHJXTE7NaKGgvsfp1YJ4hGxPf4yXFlLgag5TWyf
gEh73TK7whsU+K8NHlckIvIbk1vlq6BgX1Rqp+tORG4c+Cun5M7E32mVdw8n
IaL1OSIybqDgRZLpTxGpiMgQba76HgUXnRYIlbsQuepfY00aKQiQJgi8diOS
kp+gK1dSoM066V2YPrFbOnWYqyiw8W2y0stAhGpoVyQ/pOBf3Lc7eA==
         "]]}, Annotation[#, "Charting`Private`Tag$34088#1"]& ], 
      TagBox[{
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.880722, 0.611041, 0.142051], 
         Dashing[Large], 
         Thickness[0.01]], 
        LineBox[CompressedData["
1:eJwliQ0w1Hkchxfr/e3nXV7Wy9r1/+sY1xwJ9fudilJOVqqZ6EoSalokb+U9
puQll5dScyWVQpvURSr/L2kkUjoXNd5ahz2FiFaSvW7uM/PMM898rIKFgn3y
LBbL5zv/+f9detg03bvAeyFmdHZe2CXi7MD9klHD05/ETHiv9p77nDBcucKF
JTUaZjxrJNxOTjzmTP7CfbB7mEm91108wzmBCxPzlMxmhpki3u4+vsVZ/PPN
dmU3/RGmvrjQ0dXiOrYud5U2B4wxXfIed+bM6/F29yLvgo73TJ813Wdi1Ia1
+53OyZfOMFL1aB9u4Suc6VDbu6n1MxO1ddPVrRG92PJgjnZ9xQJTYh8R1VE2
gMPwxoji60tMX9nJdUJKjA8UBQ3Oc+UgzSBXT91+BOvGdAjD9RUg2mEbO9RA
gptHH1nd/cqGfD9VY8OmcRz6efl0fYsS+N5fUzN3YQIv5r2t+1SnAg+o/ulU
y494un4VnZqrBiMVt5wdwqexUoJz7PNADXj3Ji4rpH0G+3TVoL3btEDIaXhv
pj+LfZ3NIpyNEYiHy3tGY+fws9LIJb6JDrBax7MXuz7juLicDCdjXfBpyUro
1p/HR3MV8h8p6oGIkpV5RH/Blw3m28TK+lDNlo8arFvASzU7Vrh8+d4XhZWr
jRfx+NL0pKbMAM60t2j8FfUNZ5/S+hDMMoLZ3C3ir3eWcPh6ZY/yj0Yw+es6
nKXCIvFUeYDXnDGccPPeH1rFIhcfD69kJMugSvFwP3uTHOH6xXlm9phAY6Eg
2Wpejjw0szte9tYUnliIpsrPyRO1AKWJYx1mgHqdSio2KJAgn1PsylfmcDoi
/c/oWQXSk2yabdTNgS2e529VFrLJb1K2oWuLBTjEPCsO9VAkyeXVGgEhlvBI
dGZPwd+KRKeZDI30W8InkTTpRIYSUYkd360XYAVOQ6YzbEdlIhu4eSX0tRXA
XXUy81KZLA+I99DxtYbZe68F+1JUyPk3t/3edVnD+eMTExutVcmadGcXlc1c
KD8gObLYpEr0dV+WPHvMhSktH1snoRrZwko3r11vA5maN6SDSJ2MleSrfmy0
gRjRTl0dUCfcfGUFfw8eJI1pJqODGmRt+Ek7v8c8GNqgLEjX0CRJ+sK0q258
GOoS5yU2aJJwr95OTiMfQr/s2jwSqEW+jQavmlxpCyBpz+UsahEl25aqHbds
QRCxzHPgujbJy7BTkzhSMFyt7q3CQ0S3dfTI8xsUqOr620fyESm+X7rxnyoK
kFop6rVFROzra64ooiDjLr+nwg6RsZCGFvdaClJlriFejojEmZ/Vq26goPOF
b3KWGyLUyqjb2e0U8AT2tWwBIm7FRRNeExS0S/YXHfRHJKsxsGnvFAVtFpfj
u7ci4hNrU5QyTUFwpAG+sh2R7oI/3OvmKJi6Jm1fG4RIUNjAKf4SBbuYypH0
METUDbztFLVpeHNy8Ol4+Pd/atmSpQ4NrQt61YIDiMh8x7vc9WiI6joabX0I
Ed7lnIQYIxpWB3rJmg4jcimx5+mwBQ2ZIQli+ggi2+OrLsisaOAZVj0piEVk
VpoSaWpDw1CsZs6eBEQGE+2M/SkaavhrhG2JiPyUxPpwyI4Gj7RDgh+PIRIt
e81k/0DDTNbvTueSENGRE5255kCDiUunsVwKIkfTMvc3O9LwL/HHO/Q=
         "]]}, Annotation[#, "Charting`Private`Tag$34088#2"]& ], 
      TagBox[{
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.560181, 0.691569, 0.194885], 
         Dashing[Medium], 
         Thickness[0.01]], 
        LineBox[CompressedData["
1:eJwl13c8ld8fAHDj2uuqZGVERiolkZE+h4ZZSRqISETIipCdZISEhki+MspI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         "]]}, Annotation[#, "Charting`Private`Tag$34088#3"]& ]}}, {
    DisplayFunction -> Identity, AspectRatio -> NCache[
       Rational[1, 2], 0.5], Axes -> {True, True}, AxesLabel -> {
       FormBox[
       "\"ln \\!\\(\\*\\nStyleBox[\\\"a\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\\
!\\(\\*\\nStyleBox[\\\"(\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\\
nStyleBox[\\\"\[Tau]\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\
\\\")\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"", TraditionalForm], 
       FormBox[
       "\"ln \\!\\(\\*SubscriptBox[\\(\[CapitalOmega]\\), \\(i\\)]\\)\"", 
        TraditionalForm]}, AxesOrigin -> {0, 0}, AxesStyle -> Directive[
       RGBColor[1, 0, 0], 15], DisplayFunction :> Identity, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 450, LabelStyle -> Directive[
       RGBColor[1, 0, 0]], Method -> {"ScalingFunctions" -> None}, 
     PlotRange -> {{-1.1102230246251565`*^-16, 
      4.124027621828668}, {-18.79870235122889, 0.6418471152522228}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.05], 
        Scaled[0.05]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}, TicksStyle -> 
     Directive[
       RGBColor[1, 0, 0], 15]}],FormBox[
    FormBox[
     TemplateBox[{"\"rad\"", "\"mat\"", "\"vac\"", "\"\[Phi]\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    Thickness[0.09]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    Thickness[0.09]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #, 
                   GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    Dashing[Large], 
                    Thickness[0.09]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    Dashing[Large], 
                    Thickness[0.09]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2, 
                   GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    Dashing[Medium], 
                    Thickness[0.09]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    Dashing[Medium], 
                    Thickness[0.09]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxDividers -> {"Columns" -> {{None}}, "Rows" -> {{None}}}, 
             GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
             GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          Directive[
           RGBColor[1, 0, 0]], FontFamily -> "Arial"}, Background -> 
         Automatic, StripOnInput -> False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"Thickness", "[", "0.01`", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"Dashing", "[", "Large", "]"}], ",", 
                   RowBox[{"Thickness", "[", "0.01`", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"Dashing", "[", "Medium", "]"}], ",", 
                   RowBox[{"Thickness", "[", "0.01`", "]"}]}], "]"}]}], "}"}],
            ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"Directive", "[", 
               InterpretationBox[
                ButtonBox[
                 TooltipBox[
                  GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                   True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                   FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                   Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                  "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {}, 
                 BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                 ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                   If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                 Automatic, Method -> "Preemptive"], 
                RGBColor[1, 0, 0], Editable -> False, Selectable -> False], 
               "]"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"]}, {
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "Below"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.80009627060848*^9, 3.800097155498377*^9, 3.8002437855425205`*^9, 
   3.8002447702649016`*^9, 3.800246493547531*^9, 3.800246957971347*^9, 
   3.8002476439802876`*^9, 3.8002479623539224`*^9, 3.8002490185072365`*^9, 
   3.800274702062547*^9, 3.800274762098792*^9, 3.8002748599649725`*^9, 
   3.8003194919624414`*^9, 3.8003196742178125`*^9, 3.8003198789487357`*^9, {
   3.8003199579992127`*^9, 3.8003199857193937`*^9}, 3.8003200762013097`*^9, 
   3.8004509075125427`*^9, 3.8005904828903303`*^9, 3.8006745092513533`*^9, 
   3.8010260440000677`*^9, 3.8010260744968204`*^9, 3.8010285082756824`*^9, 
   3.801028813787381*^9, 3.8187721629171715`*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[1, 0.5, 0.5], Thickness[0.007], Opacity[1.], 
      LineBox[CompressedData["
1:eJwd13lcTc0bAPD25bbdpVKUVyullBZUNI+klYqi0iKVRCUSyauIdiLavBUt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       "]]},
     Annotation[#, "Charting`Private`Tag$34189#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"\[Tau]\"", TraditionalForm], 
    FormBox[
    "\"\\!\\(\\*SubscriptBox[\\n \
StyleBox[\\\"w\\\",\\nFontSlant->\\\"Italic\\\"], \
\\\"\[Phi]\\\"]\\)(\[Tau])\"", TraditionalForm]},
  AxesOrigin->{1.000000081632653, -1.0548284683067286`},
  AxesStyle->Directive[
    RGBColor[1, 0, 0], 15],
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[
    RGBColor[1, 0, 0]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic},
  TicksStyle->Directive[
    RGBColor[1, 0, 0], 15]]], "Output",
 CellChangeTimes->{
  3.80009627060848*^9, 3.800097155498377*^9, 3.8002437855425205`*^9, 
   3.8002447702649016`*^9, 3.800246493547531*^9, 3.800246957971347*^9, 
   3.8002476439802876`*^9, 3.8002479623539224`*^9, 3.8002490185072365`*^9, 
   3.800274702062547*^9, 3.800274762098792*^9, 3.8002748599649725`*^9, 
   3.8003194919624414`*^9, 3.8003196742178125`*^9, 3.8003198789487357`*^9, {
   3.8003199579992127`*^9, 3.8003199857193937`*^9}, 3.8003200762013097`*^9, 
   3.8004509075125427`*^9, 3.8005904828903303`*^9, 3.8006745092513533`*^9, 
   3.8010260440000677`*^9, 3.8010260744968204`*^9, 3.8010285082756824`*^9, 
   3.801028813787381*^9, 3.8187721629484124`*^9}]
}, Open  ]],

Cell["\<\
We overlap the above results with another one with initial conditions ending \
up on the unhealthy late-time state...\
\>", "Text",
 CellChangeTimes->{{3.8002490369725747`*^9, 3.8002491267512465`*^9}, {
  3.8002748728694763`*^9, 3.800274890128032*^9}, {3.818772175802851*^9, 
  3.8187721994729776`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"initial", " ", "conditions"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"ainit2", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ai", "\[Rule]", "100"}], ",", 
       RowBox[{"dai", "\[Rule]", "125"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"cons2", "=", 
     RowBox[{
      RowBox[{"NSolve", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Feq2", "/.", "param"}], "/.", "abun"}], "/.", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"a", "[", "\[Tau]", "]"}], "\[Rule]", "ai"}], ",", 
              RowBox[{
               RowBox[{
                RowBox[{"a", "'"}], "[", "\[Tau]", "]"}], "\[Rule]", "dai"}], 
              ",", 
              RowBox[{
               RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}], "\[Rule]", 
               "d\[CapitalPsi]"}]}], "}"}]}], "/.", "ainit2"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"Re", "[", "d\[CapitalPsi]", "]"}], ">", "0"}], "&&", 
           RowBox[{
            RowBox[{"Im", "[", "d\[CapitalPsi]", "]"}], "\[Equal]", "0"}]}]}],
          "}"}], ",", "d\[CapitalPsi]", ",", 
        RowBox[{"WorkingPrecision", "\[Rule]", "50"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"init2", "=", 
     RowBox[{"Union", "[", 
      RowBox[{"ainit2", ",", "cons2"}], "]"}]}], ";"}], "\[IndentingNewLine]",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"a", "[", 
     SubscriptBox["\[Tau]", "0"], "]"}], "\[Equal]", 
    RowBox[{"(", 
     RowBox[{"ai", "/.", "init2"}], ")"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"a", "'"}], "[", 
     SubscriptBox["\[Tau]", "0"], "]"}], "\[Equal]", 
    RowBox[{"(", 
     RowBox[{"dai", "/.", "init2"}], ")"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[CapitalPsi]", "[", 
     SubscriptBox["\[Tau]", "0"], "]"}], "\[Equal]", 
    RowBox[{"(", 
     RowBox[{"d\[CapitalPsi]", "/.", "init2"}], ")"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"int2", "=", 
     RowBox[{"cosmogccg", "[", 
      RowBox[{
       RowBox[{"ai", "/.", "init2"}], ",", 
       RowBox[{"dai", "/.", "init2"}], ",", 
       RowBox[{"d\[CapitalPsi]", "/.", "init2"}], ",", 
       RowBox[{"\[Tau]0", "/.", "dom"}], ",", 
       RowBox[{"\[Tau]i", "/.", "dom"}], ",", 
       RowBox[{"\[Tau]f", "/.", "dom"}]}], "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8002491341729145`*^9, 3.8002491412528305`*^9}, {
   3.800319518891185*^9, 3.8003195334941664`*^9}, {3.8003195849275084`*^9, 
   3.8003196303755817`*^9}, 3.8003197915868907`*^9, {3.8005936877852077`*^9, 
   3.800593693628647*^9}, {3.80059888263259*^9, 3.800598883934107*^9}, {
   3.800675004049929*^9, 3.8006750189207277`*^9}, {3.8010188067907877`*^9, 
   3.801018845949769*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a", "[", 
   SubscriptBox["\[Tau]", "0"], "]"}], "\[Equal]", "100"}]], "Output",
 CellChangeTimes->{
  3.8002491419822016`*^9, 3.8002749029870405`*^9, 3.800319535957636*^9, 
   3.800319586306094*^9, {3.8003196172315674`*^9, 3.8003196323965893`*^9}, 
   3.800319700433832*^9, 3.800319994124179*^9, 3.800320086611953*^9, 
   3.8004509083444614`*^9, 3.8005904831857243`*^9, 3.800593697936757*^9, 
   3.8005988761344185`*^9, 3.800674509552676*^9, 3.801018388864119*^9, {
   3.801018817319555*^9, 3.8010188464496374`*^9}, 3.8010260871868963`*^9, 
   3.801028819896618*^9, 3.8010317947260785`*^9, 3.818772204099638*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["a", "\[Prime]",
    MultilineFunction->None], "[", 
   SubscriptBox["\[Tau]", "0"], "]"}], "\[Equal]", "125"}]], "Output",
 CellChangeTimes->{
  3.8002491419822016`*^9, 3.8002749029870405`*^9, 3.800319535957636*^9, 
   3.800319586306094*^9, {3.8003196172315674`*^9, 3.8003196323965893`*^9}, 
   3.800319700433832*^9, 3.800319994124179*^9, 3.800320086611953*^9, 
   3.8004509083444614`*^9, 3.8005904831857243`*^9, 3.800593697936757*^9, 
   3.8005988761344185`*^9, 3.800674509552676*^9, 3.801018388864119*^9, {
   3.801018817319555*^9, 3.8010188464496374`*^9}, 3.8010260871868963`*^9, 
   3.801028819896618*^9, 3.8010317947260785`*^9, 3.818772204099638*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalPsi]", "[", 
   SubscriptBox["\[Tau]", "0"], "]"}], "\[Equal]", 
  "0.9938068106831909151869522455546799649989243173360312642381105820687013722\
2557`50."}]], "Output",
 CellChangeTimes->{
  3.8002491419822016`*^9, 3.8002749029870405`*^9, 3.800319535957636*^9, 
   3.800319586306094*^9, {3.8003196172315674`*^9, 3.8003196323965893`*^9}, 
   3.800319700433832*^9, 3.800319994124179*^9, 3.800320086611953*^9, 
   3.8004509083444614`*^9, 3.8005904831857243`*^9, 3.800593697936757*^9, 
   3.8005988761344185`*^9, 3.800674509552676*^9, 3.801018388864119*^9, {
   3.801018817319555*^9, 3.8010188464496374`*^9}, 3.8010260871868963`*^9, 
   3.801028819896618*^9, 3.8010317947260785`*^9, 3.818772204115257*^9}]
}, Open  ]],

Cell["Here are the overlaped plots.", "Text",
 CellChangeTimes->{{3.800274917347632*^9, 3.800274921137065*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"scalar", " ", "field", " ", "derivative"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"p\[CapitalPsi]2", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}], "]"}], "/.", 
         RowBox[{"int2", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], 
        RowBox[{"(*", 
         RowBox[{",", 
          RowBox[{
           RowBox[{"Im", "[", 
            RowBox[{
             RowBox[{"\[CapitalPsi]", "'"}], "[", "\[Tau]", "]"}], "]"}], "/.", 
           RowBox[{"int", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}]}], "*)"}], "}"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\[Tau]", ",", "\[Tau]i", ",", "\[Tau]f"}], "}"}], "/.", 
        "dom"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
       RowBox[{"AxesStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", 
        RowBox[{"Directive", "[", "Red", "]"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"TicksStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Dashing", "[", "Large", "]"}], ",", 
           RowBox[{"Thickness", "[", "0.007", "]"}], ",", "Green"}], "}"}], 
         "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<\[Tau]\>\"", ",", "\"\<\[CapitalPsi](\[Tau])\>\""}], 
         "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"acceleration", " ", "of", " ", "scalar", " ", "field"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pd\[CapitalPsi]2", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"Log", "[", 
           RowBox[{
            RowBox[{"\[CapitalPsi]", "'"}], "[", "\[Tau]", "]"}], "]"}], 
          "]"}], "/.", 
         RowBox[{"int2", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], 
        RowBox[{"(*", 
         RowBox[{",", 
          RowBox[{
           RowBox[{"Im", "[", 
            RowBox[{
             RowBox[{"\[CapitalPsi]", "'"}], "[", "\[Tau]", "]"}], "]"}], "/.", 
           RowBox[{"int", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}]}], "*)"}], "}"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\[Tau]", ",", "\[Tau]i", ",", "\[Tau]f"}], "}"}], "/.", 
        "dom"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
       RowBox[{"AxesStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", 
        RowBox[{"Directive", "[", "Red", "]"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"TicksStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Dashing", "[", "Large", "]"}], ",", 
           RowBox[{"Thickness", "[", "0.007", "]"}], ",", "Green"}], "}"}], 
         "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\[Tau]\>\"", ",", "\"\<ln(\[CapitalPsi]'(\[Tau]))\>\""}], 
         "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Hubble", " ", "parameter"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pH2", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          FractionBox[
           RowBox[{
            RowBox[{"a", "'"}], "[", "\[Tau]", "]"}], 
           RowBox[{"a", "[", "\[Tau]", "]"}]], "]"}], "/.", 
         RowBox[{"int2", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\[Tau]", ",", "\[Tau]i", ",", "\[Tau]f"}], "}"}], "/.", 
        "dom"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
       RowBox[{"AxesStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", 
        RowBox[{"Directive", "[", "Red", "]"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"TicksStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Dashing", "[", "Large", "]"}], ",", 
           RowBox[{"Thickness", "[", "0.007", "]"}], ",", "Green"}], "}"}], 
         "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<\[Tau]\>\"", ",", "\"\<\!\(\*
StyleBox[\"H\",
FontSlant->\"Italic\"]\)(\[Tau])\>\""}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Hubble", " ", "parameter", " ", "time", " ", "derivative"}], 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pdH2", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Log", "[", 
          RowBox[{"Abs", "[", 
           RowBox[{"Re", "[", 
            RowBox[{
             FractionBox[
              RowBox[{
               RowBox[{"a", "''"}], "[", "\[Tau]", "]"}], 
              RowBox[{"a", "[", "\[Tau]", "]"}]], "-", 
             SuperscriptBox[
              RowBox[{"(", 
               FractionBox[
                RowBox[{
                 RowBox[{"a", "'"}], "[", "\[Tau]", "]"}], 
                RowBox[{"a", "[", "\[Tau]", "]"}]], ")"}], "2"]}], "]"}], 
           "]"}], "]"}], "/.", 
         RowBox[{"int2", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], 
        RowBox[{"(*", 
         RowBox[{",", 
          RowBox[{
           RowBox[{"Im", "[", 
            RowBox[{
             FractionBox[
              RowBox[{
               RowBox[{"a", "''"}], "[", "\[Tau]", "]"}], 
              RowBox[{"a", "[", "\[Tau]", "]"}]], "-", 
             SuperscriptBox[
              RowBox[{"(", 
               FractionBox[
                RowBox[{
                 RowBox[{"a", "'"}], "[", "\[Tau]", "]"}], 
                RowBox[{"a", "[", "\[Tau]", "]"}]], ")"}], "2"]}], "]"}], "/.", 
           RowBox[{"int", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}]}], "*)"}], "}"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\[Tau]", ",", "\[Tau]i", ",", "\[Tau]f"}], "}"}], "/.", 
        "dom"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"AxesStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", 
        RowBox[{"Directive", "[", "Red", "]"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"TicksStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Dashing", "[", "Large", "]"}], ",", 
           RowBox[{"Thickness", "[", "0.007", "]"}], ",", "Green"}], "}"}], 
         "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<\[Tau]\>\"", ",", "\"\<ln(\!\(\*
StyleBox[\"H\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"'\",
FontSlant->\"Italic\"]\)(\[Tau]))\>\""}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"dark", " ", "energy", " ", "equation", " ", "of", " ", "state"}],
     "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pw2", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"wDE", "[", "\[Tau]", "]"}], "/.", 
          RowBox[{
           RowBox[{"H", "[", "\[Tau]", "]"}], "\[Rule]", 
           FractionBox[
            RowBox[{
             RowBox[{"a", "'"}], "[", "\[Tau]", "]"}], 
            RowBox[{"a", "[", "\[Tau]", "]"}]]}]}], "/.", "param"}], "/.", 
        RowBox[{"int2", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\[Tau]", ",", "\[Tau]i", ",", "\[Tau]f"}], "}"}], "/.", 
        "dom"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
       RowBox[{"AxesStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", 
        RowBox[{"Directive", "[", "Red", "]"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"TicksStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Dashing", "[", "Large", "]"}], ",", 
           RowBox[{"Thickness", "[", "0.007", "]"}], ",", "Green"}], "}"}], 
         "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<\[Tau]\>\"", ",", "\"\<\!\(\*SubscriptBox[
StyleBox[\"w\",
FontSlant->\"Italic\"], \"\[Phi]\"]\)(\[Tau])\>\""}], "}"}]}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"p\[CapitalPsi]1", ",", "p\[CapitalPsi]2", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0.6", ",", "2"}], "}"}]}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"pd\[CapitalPsi]1", ",", "pd\[CapitalPsi]2", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "5"}], "}"}], ",", "Automatic"}], "}"}]}]}], "]"}],
    "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"pH1", ",", "pH2", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "5"}], "}"}], ",", "Automatic"}], "}"}]}]}], "]"}],
    "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"pdH1", ",", "pdH2", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "5"}], "}"}], ",", "Automatic"}], "}"}]}]}], "]"}],
    "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"pw1", ",", "pw2", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "5"}], "}"}], ",", "Automatic"}], "}"}]}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.800249177923099*^9, 3.8002493300343437`*^9}, {
  3.800249363637926*^9, 3.800249378940669*^9}, {3.800249455047841*^9, 
  3.8002494796708994`*^9}, {3.8002495763125963`*^9, 3.800249636019928*^9}, {
  3.800249767363082*^9, 3.800249767483715*^9}, {3.800249803769656*^9, 
  3.8002498173376184`*^9}, {3.8002498481887035`*^9, 3.800249849545936*^9}, {
  3.800249906818431*^9, 3.8002499154768896`*^9}, {3.8002500759805374`*^9, 
  3.8002500817953205`*^9}, {3.8003197240127664`*^9, 3.8003197424498005`*^9}, {
  3.8010261083711395`*^9, 3.8010261503203*^9}, {3.8010283977399583`*^9, 
  3.8010284050235343`*^9}, {3.8010285226473675`*^9, 3.8010285230685244`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[1, 0.5, 0.5], Thickness[0.007], Opacity[1.], 
       LineBox[CompressedData["
1:eJwd1nc8ld8fAPBrX/sODTMRWaWUMsr5UCQ7UiLZEpHMKKKMiFLJV1YUkgoJ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        "]]},
      Annotation[#, "Charting`Private`Tag$33875#1"]& ]}, {}, {}}, {{{}, {}, 
     TagBox[
      {RGBColor[0, 1, 0], Thickness[0.007], Opacity[1.], Dashing[Large], 
       LineBox[CompressedData["
1:eJwVjXs81HsexodpcmfMzyUqk0o3OTSxNjo+H5YhDVHkctY9TnKZGdWyq6g2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        "]]},
      Annotation[#, "Charting`Private`Tag$34778#1"]& ]}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"\[Tau]\"", TraditionalForm], 
    FormBox["\"\[CapitalPsi](\[Tau])\"", TraditionalForm]},
  AxesOrigin->{1.000000081632653, 0.5423261987349842},
  AxesStyle->Directive[
    RGBColor[1, 0, 0], 15],
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[
    RGBColor[1, 0, 0]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{1, 5}, {0.6, 2}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic},
  TicksStyle->Directive[
    RGBColor[1, 0, 0], 15]]], "Output",
 CellChangeTimes->{
  3.8002493307622166`*^9, 3.8002493850977864`*^9, 3.8002497698501005`*^9, {
   3.8002498069798837`*^9, 3.800249819706459*^9}, 3.8002499189624453`*^9, 
   3.800250084507069*^9, 3.800274925394416*^9, 3.800319547516687*^9, 
   3.800319637178213*^9, {3.800319703721695*^9, 3.800319743774502*^9}, 
   3.8003199986848946`*^9, 3.800320097683634*^9, 3.800450910736374*^9, 
   3.8005904842740817`*^9, 3.8006745106594553`*^9, 3.801026166172425*^9, 
   3.8010284315394278`*^9, 3.801028525011439*^9, 3.8010288242718844`*^9, 
   3.818772210227338*^9}],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[1, 0.5, 0.5], Thickness[0.007], Opacity[1.], 
       LineBox[CompressedData["
1:eJwVknk41N0bxmVIlsIMQl5LtmnBhBZU5/BassybyhIiJRUlkrK0UFkToaLS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        "]]},
      Annotation[#, "Charting`Private`Tag$33929#1"]& ]}, {}, {}}, {{{}, {}, 
     TagBox[
      {RGBColor[0, 1, 0], Thickness[0.007], Opacity[1.], Dashing[Large], 
       LineBox[CompressedData["
1:eJwVVHk4ldsXNnQyT+fgoDpuNBhSxozdtetKZCgyhZMIRQnH7VIylCEpQqJS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        "]]},
      Annotation[#, "Charting`Private`Tag$34818#1"]& ]}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"\[Tau]\"", TraditionalForm], 
    FormBox["\"ln(\[CapitalPsi]'(\[Tau]))\"", TraditionalForm]},
  AxesOrigin->{1.000000081632653, -12.454028904651496`},
  AxesStyle->Directive[
    RGBColor[1, 0, 0], 15],
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[
    RGBColor[1, 0, 0]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{1, 5}, Automatic},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic},
  TicksStyle->Directive[
    RGBColor[1, 0, 0], 15]]], "Output",
 CellChangeTimes->{
  3.8002493307622166`*^9, 3.8002493850977864`*^9, 3.8002497698501005`*^9, {
   3.8002498069798837`*^9, 3.800249819706459*^9}, 3.8002499189624453`*^9, 
   3.800250084507069*^9, 3.800274925394416*^9, 3.800319547516687*^9, 
   3.800319637178213*^9, {3.800319703721695*^9, 3.800319743774502*^9}, 
   3.8003199986848946`*^9, 3.800320097683634*^9, 3.800450910736374*^9, 
   3.8005904842740817`*^9, 3.8006745106594553`*^9, 3.801026166172425*^9, 
   3.8010284315394278`*^9, 3.801028525011439*^9, 3.8010288242718844`*^9, 
   3.8187722102429676`*^9}],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[1, 0.5, 0.5], Thickness[0.007], Opacity[1.], 
       LineBox[CompressedData["
1:eJwd13c8ld8fAPDrWte+Q0aUkFWijG9GOh+KFFqUnS2Z2WmIQqgkoUGhYTSM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        "]]},
      Annotation[#, "Charting`Private`Tag$33969#1"]& ]}, {}, {}}, {{{}, {}, 
     TagBox[
      {RGBColor[0, 1, 0], Thickness[0.007], Opacity[1.], Dashing[Large], 
       LineBox[CompressedData["
1:eJwd1nk4lF8bB/CxjH0ZMyKpbCW0kKWFch8SKkQSKhLSouyhTcgSyU8SCqEi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        "]]},
      Annotation[#, "Charting`Private`Tag$34858#1"]& ]}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"\[Tau]\"", TraditionalForm], 
    FormBox[
    "\"\\!\\(\\*\\nStyleBox[\\\"H\\\",\\nFontSlant->\\\"Italic\\\"]\\)(\[Tau])\
\"", TraditionalForm]},
  AxesOrigin->{1.000000081632653, 1.0000033854666457`},
  AxesStyle->Directive[
    RGBColor[1, 0, 0], 15],
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[
    RGBColor[1, 0, 0]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{1, 5}, Automatic},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic},
  TicksStyle->Directive[
    RGBColor[1, 0, 0], 15]]], "Output",
 CellChangeTimes->{
  3.8002493307622166`*^9, 3.8002493850977864`*^9, 3.8002497698501005`*^9, {
   3.8002498069798837`*^9, 3.800249819706459*^9}, 3.8002499189624453`*^9, 
   3.800250084507069*^9, 3.800274925394416*^9, 3.800319547516687*^9, 
   3.800319637178213*^9, {3.800319703721695*^9, 3.800319743774502*^9}, 
   3.8003199986848946`*^9, 3.800320097683634*^9, 3.800450910736374*^9, 
   3.8005904842740817`*^9, 3.8006745106594553`*^9, 3.801026166172425*^9, 
   3.8010284315394278`*^9, 3.801028525011439*^9, 3.8010288242718844`*^9, 
   3.8187722102429676`*^9}],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[1, 0.5, 0.5], Thickness[0.007], Opacity[1.], 
       LineBox[CompressedData["
1:eJwVlXk81N/3x0eyjQoz1ixZaiJrlhTqvJOtKEWSpQ2lJEoK9YmIUtkrfMjS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        "]]},
      Annotation[#, "Charting`Private`Tag$34008#1"]& ]}, {}, {}}, {{{}, {}, 
     TagBox[
      {RGBColor[0, 1, 0], Thickness[0.007], Opacity[1.], Dashing[Large], 
       LineBox[CompressedData["
1:eJwVkHk81OkDx8c9aB3zdeRuiDVDZR3ZTHoelrE6NUiEdZSKyrEVrcpZtKWM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        "]]},
      Annotation[#, "Charting`Private`Tag$34898#1"]& ]}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"\[Tau]\"", TraditionalForm], 
    FormBox[
    "\"ln(\\!\\(\\*\\nStyleBox[\\\"H\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\\
(\\*\\nStyleBox[\\\"'\\\",\\nFontSlant->\\\"Italic\\\"]\\)(\[Tau]))\"", 
     TraditionalForm]},
  AxesOrigin->{1.000000081632653, 0},
  AxesStyle->Directive[
    RGBColor[1, 0, 0], 15],
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[
    RGBColor[1, 0, 0]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{1, 5}, Automatic},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic},
  TicksStyle->Directive[
    RGBColor[1, 0, 0], 15]]], "Output",
 CellChangeTimes->{
  3.8002493307622166`*^9, 3.8002493850977864`*^9, 3.8002497698501005`*^9, {
   3.8002498069798837`*^9, 3.800249819706459*^9}, 3.8002499189624453`*^9, 
   3.800250084507069*^9, 3.800274925394416*^9, 3.800319547516687*^9, 
   3.800319637178213*^9, {3.800319703721695*^9, 3.800319743774502*^9}, 
   3.8003199986848946`*^9, 3.800320097683634*^9, 3.800450910736374*^9, 
   3.8005904842740817`*^9, 3.8006745106594553`*^9, 3.801026166172425*^9, 
   3.8010284315394278`*^9, 3.801028525011439*^9, 3.8010288242718844`*^9, 
   3.8187722102585816`*^9}],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[1, 0.5, 0.5], Thickness[0.007], Opacity[1.], 
       LineBox[CompressedData["
1:eJwd13lcTc0bAPD25bbdpVKUVyullBZUNI+klYqi0iKVRCUSyauIdiLavBUt
ilQqJGk7KBItkhaJEKH1tHdv6Dfn98+9n+/nzpnzzMwzz8xV8AzcuZ+Hi4vL
FH9Q32+f/JLi4iJRD++67IDsDuKKQF+IAD+JyrgnVEcedRB221rfi9JI1L9+
3DK6rYNo7b5/XVaSRCUfLn4SW+wgmsb+VdFdRSKf/Z2XA/a+I57Iiev72JEo
oE/zd6xKJ1FyUsehOZtExxrWfZ9u7CIC6pQr3uaT6Oyrh2nLB7oIDb4lMu8L
SXRj1Gbngb9dROHlhQ/fy0nEH29stFu/m8i/1eC1+BL7Y7hhcV43kflu9zGd
CRLlGXbKW8X1EHHa/169tnkCaR72/af6UC8RLBm3SsR8Asny+e+JvdhLuM+n
1oVtm0C5K42Wny7pJfSe3B/ydJxAvjeabLone4lPtkMmmgETiOeiraFr2AdC
J9B56uk1/DsZZZv5Xx/Re3e9w/D4BNqbWasRM/aJ0Fg9LWV8YxJFXP1S7Mn1
lRhAicMvB6bQv9HdWyxX/SD0Rl9deP5zCkWNDNjFbPxBRKfzazwbnULuRH99
nd0PQn3mlH/13BRa3FCdLBP6gzhSuH/0rsg04vjbjx9u+kH8kTQav6o7jarM
NBfdfX8SS4a+T7qen0Y6pyR2Lr/+i/BNW5HkHDuNrrcfShgt/UVUmbro7k6Y
RitfPfEufvaLcM96c8w2bRrJKJi2zP34ReQ5VE9vLppGuY7d7Nq1Q8RaInFW
tWMaVTzT9G59OkRYJxtxSMUZVFf60s3r7TDxsv9Kq/OqGbSzuC1D/NswYbb6
Z+4zzRmUsKLF4MbMMAHPkq2TN8ygwYwtLQdlRoh15GjmepsZpOp0fM1d1xFi
xbZsFB46g77tWDb8pH+EuJE2y/oRPoMqrY6OXB8fIZYNbPtpGzmDVo6pf3Vd
HCGkT7ETFS7PICv/KLOzy0cJkYKdXxvyZlBewZoLe1xGiVle/iiRNzOo2cWr
waZtlDhm6+Ic3DmDpioSg0w+jhJk+j3Nj70zyHr9PZ0lw6PE8Fr3rpLvM0hz
Nvarl8AY8Xnvo5U7F2bQo0vGK+KNxojX1QdfXVOdRZmcnbsksseI7GOtEqph
s6io8rGv985xIto6IFTn3Cz6bnm544vLOOGnJDpgHDOL/j47J2W2f5xY12FZ
4XhlFtna68TWh4wTLTrPXePyZ1HJkhaNlIxxgjNRfWekZRblMJnqdz+NE5+b
9rDYb2eRCLPjZP7gOPE8h32av2cWiW11DY8eGycSd6y3W/51Fn3eTtfj/TtO
rLx3f9Z2dhYtl+REzoiRhMORO1seLJ9DvU+bcprUSMLQwuIuoTSH5PZx32Vp
ksQ/K35IN6+aQ+1GTtr22iQx1KY89E1nDq2y8R+6v44kIrSyE6XN59Ceb9xG
cyYkUTKW+jE0cA4pn52auelMEskv9M2jg+eQ+Y6D+21cSSL0xruyq6Fz6Dv5
K2zcnSRMbZiRRefn0FFgzEl5k8SHuwnqH9Pm0OO3McqzASQhFBAZAk/m0NSd
YF3JsyQhO2As9fj5HJL1z9fde44k1J3Z99e+nkMlXHfzsiNJYvvWw2OKXXNI
4s38BsE4krgq77Sff2QOLU5erN9/hSTykpi84RNzyOEmOeCTRBIPhVuyZ2fx
ePyRzt4UkuiZ2dz3g3sepZ4591D/P5KQb11t/2rJPFI1vdpzOpsk1pgOkiby
8yg3WXHEIJckoCr7UrXiPLrcZv9t7CZJeN6SelWsOY8sZjU+wG2SKAhfhMtb
5lGWTsS2mLskoaPVscYhcB519X2XvFeJx5+f0NwcPI8ed1lcn31MEruWWRza
emoeXeu03atfTRInBWvz10XNo48Vnz/fqCWJ2v5bcrIZ80hXu5ZH+RlJtO7a
V3Ulex7J7jtxXr+eJD6/XuZEuzWPSj6+6oUGkuCpTExaKJtHZWXrnba+IAmL
xFO0Ty/m0duDEWmCr0jCWUC/YHfzPBJYdO38hX3o9PjWtvZ5lNfJE/biNUkk
+HpHPOmbR7cPbLELbCGJt2AznzuJ47P5OXT2DUl8qxBKXTY/j9gmq902tJPE
jEa9bvKfebTIvv1sCFtGdkNglBAbWY2lFUAHSbhNKAweWM5GC27WN+93ksTh
vCfzL5TYqORfl/fQRRLhjntFVNXYaNPlNcWvsG/UZmp/02WjMwabPNq7cX4d
MdqyxYCNbAwq3W16SKJOqXdXrjEb5Wto6DRif4pb8q+HJRtliqteLX5PEmMb
KxIIGzb68V7eQLaXJP6OO2Qvd2Cjqx4CoxHYy3dffd7nzkb8nokl5h/w+gqv
7THyZqMyc6fuPGzjmrah9INs5Ht+AP5iuyuK0Z2D2ejOhTDarT4cf2eRYmUo
G1WuqTk/jR0ea6W/5AwbpSUdPYI+4vjHYvZ0xrHRYf7+rlfYJTmqAXqX2Ui0
fImvyCccv8PzM0nJbFSzSuOGBXZ/FU/+jiw2qooVUnmMTQbkPCrLYyPBrZsu
jWBzKcAriUI2UsvNaZLrJwn6u099h0tx/3PqA5bYK2LCxlvK2chJ4OrgMWxt
QzkezSo2+qj0/GM6NoxWSV4k2OhZ2Il3ddh22c4rhxvY6FL1x85+bA/7eQOr
V2zUE541/Af7iEDatjttbKRuvFJB9jNJnH2sv1eok41y5tUi1mIn+r87eqCX
jWpdxKTMsbP/ORb5op+N9k1N/nDGLnvLSFP5zkYVNSJ8h7CfRJXdiRxio/GJ
2KAQ7DcbbGsGxtnoNj8yPof9ZXi01WQGP8/TeyQee/LGxS85HBxPpAcrEZtn
5+ppLi4O4mg7aidhM/lfCXjwc9Bus29vKCtW+soSNA66Hzj65wq2jp+gxnI6
B10Yvfk0Adtk+S3jMCkO+rmxUDkGe2e76Y6+pRw0nfBaKxzbM3LAy2gFBx0O
/TwShB20/tyJdBUOkplheu/HPje0Io6tzkEpzfQbu7CvXicynLQ5aM1tx7wt
2Ll27iWP9DlI6mVeuBb2fd4/T6SNOGhmIFKfmr9nFRkdx4GDDLpl3nJhD8i9
n9e15iCU0tPbhOd7ui1EJMmOg9IEtZyKsPnOSy+f3MVBFmPPe+OxlX/Zbynz
4KC+xW66KbZe5uQuCR8O6g060iGPbWp7xfewH25vVF01g/PF+2FrgsYJDnL8
80MqG7tv+qG+1r8cJHt7tPw49i696x/XnuUgvxzxN5bYZg/8NNfHc9DRzm2J
ozhfV94Tatl8g4MuFTN6lbCzyfFg05t4vlr550Zxvstod8uZF3CQtUVKTQW2
UGm+/7b7HHRLsny3KfZQsYmo4wsOCmTYOtnh/eM5olbu/JqDzqqobKNjf1jN
cHV9w0GFNRsYbXg/Nhf2F+3r5aAcsQYlS+ySgtPW/mMcVE7TH9XC+/loXkV8
hPQCGpELFGnG9WFo4LpO5LIF5FzPu/lfbE+lqN7oFQvo8uuFS2rYO3Pt1S+q
L6BM0jT6PK43etlkU6rxAjp2N2675juSmM9QFy72WUDFootRLrhehSfdiOmq
WEDrvjplGeL6p3g0x2trzQIaj3q69jWujy9s8lD50wW0rPGtrgu2OK1w7krz
Amptv3sltIkkss4+PLD96wKKEYyQKmvE+R7QbN4g9hvJ87nTBKl6bMERvO/9
G2UeePH+SA1JRP3eFZvA/IMEyi2vPirGz5/R/qDm+Bdd1a/oIS6ThJ/J0gNe
KYso5t63HbQTOL9i9ke8TF9EVdEF/rnH8XnVXJahmb2I76MPmw2xzRzN38wV
LiLy12UX/2Acv3+wwcUni0j7OU/l2yDcPqVV5OHwIrL9cORUcSBJ3Aze7MSr
wAVCf+97JR8kCcbLmd8OIVyg91/8Fn18Pn8uIxzeh3LBij+Bkd/c8H7+L67Y
7TQXJGbc4krGtvOTd/WJ4AIJ14LCKXy+XxLfWh1ygQtOJ0TUP3QhCdqu5ND0
LC54fpacM8X3Ab6vOrP9jVxQrRX77pIDScwtBI4fkuEGhqAb12trnJ8PzPep
LOMG1WeRreewn/n909Evzw1y4c4fDLEvfmitcFDihpvmp0qLrPD4qjXDjddw
Q8t7S5RoSRI2p4ZFmabcoLfnYK+3OUnkz/uoPw7kBpX/mJOGW0jCfsZtv2Aj
NwS0FNGuGpFE5evbjIdN3ODyJcTeGVsud6LWs5kbNjkqtK3AHrSJkq5r54Yt
m/91LzMkiVMFxY3Bfbh9cmx3uwHeDy4Lal8ncPz3/SWXb8DnzdNrYzVyPPA1
K/xhrx5JxF7qCAkK4oHFzoL0vjUkoVD0dGwimAf4jCzC7mNXNZbuPxrCA0sf
e0TGYo9wXbQ/cpoHdn+lLeph2x0z1ToczQN7tk7mXsb3MRmnh4MH03lgxLQh
wVoD3y8U0nbte8YD5pGH1n7E97fG8j26dkxeEOfoju1TIYkT2bsb+KV4YeKU
pf4mbOWLO3dVL+GFS3+1s2Swz3lZhajK84Ki4OsPbcr4vGMaVv9eyQvSR25N
IezyQNktdzbxQuGyB+dVlXD+qffs5DnIC031MQ6iCiRxOntXUDnBC1lLJkL1
5Eli79uZFqNnvPDJ+m60LLYJX6pafQMvyK1sLvorh+uDb9fn9iZe4HYMM27C
TtZytB3v4IU3d0Ii92IX1zlpqP/khfOxq88mLsP50OcymEXngyuERCHvUpIg
xH9vXsniA5/v4unDsjgeyLxeIsUHp57+zerA9s3rc6hdygf53xRHb2JP+7nV
9yrzwQNX6fit2KIL7tlSBnxgVj1Zd1GGJIxkPfdc2McHQx9nk9WX4PqwlP7G
wpsP/HgrdrCwNZbVbRU4wAdGW11Vfkvj+4L80rUR/nwQ9/4UoxWbR+GtYEgI
H+z7HscOwn65yuShZwIfnN3/ZvaJFEns3qBIN3zMB4MP77ICJEnC1uBN1Fw1
H1TmP412wrYwDF8or+MDmSglcVNsg429g1oNfOA2UOu8DFsOrtaqtOH2piZf
X7HweWHO48f4zgffNh6+rYl9xPHr8590fmCfPXGGm0kSP0/wnPiPxQ+rdQ6X
jDPweZ6qqGolzQ/vwj6NfcTe0ekZXbSMHwq8r9+swtaxHzA7rMoPDo+MPgRj
T9t8a5wy4ocog5TgETpJhJgNNv314YcdTNUvPyRwfdQfapGs5YdzE757RMXx
/TujxCKN4IeR41LOi/j/RDfXsXrZZ/yQeabWaxJbu3mhcnkjP4hUFWT2YH/x
FMtb1c4PcXvzM/KxTRO1T238zg+KLbufb8amDZ9Q9RYTgLS/BmfPiZJEhZ1R
zqCEAMReOvjzBLZXxeKyg0wB+KSt6+KHXRMRyzi8RABur030cMAOkEn/HaIg
AEvXXvqliv1ma+3bC/oCIC3CO9IiQhKp2bxnHrgJgEnVsiAlbKfOTpa/hwDY
Mh4by2AvpRUUKHsJwNELsdJi2FnHtr1N8RWAlsisH7M0vN/MUlROHhOAJJEv
Yq+xq0ZUmzfGCcA6s6F9x7E/brCSfVEuAL3CtP52YVwfAuRKwh8JgJJy++9G
bM/cMZP1VQIgpOynXIc9KJLkX0AIgJ/H2iuF2GOfPhDxrwTAPOla/3lsrqgA
H9vPAoAu3TbfgK3cnvigR0QQ6qeyeQuEcLzbBFle4oIgm6fen4XNaAwLGqUL
ArfZ9mdp2H9rDq3lkRaEdr31WTHY3QWmpatXCELWyh0PDmDHn50vDNcThImO
hU1q2KSWR66ymyD4uQeU3BPE83tJ68qREkEQLolJ6xLA+bJKZvVYmSDcez1v
9ga74CnXc78HgjBpv/53E3bSdPu8T6UgTN+ZCqnFPrQn2MPtmSDUnNxQnoct
o/pYy6pLEBqT2IbB2MG1Jq1KfwUhbkOR+xLsod2rfXO4hODE5je1DGwPksXz
D68QmAWoK4piWyt9118qJATO6e4cLmzFuJjrdKYQfBCc+zHEj9fbodn/j4oQ
MIoCywlszZFdIt3bhWCbXuCkP3alwzYi3k4I6LylEQewTWtNjhnbC0Htp93S
ntiul7Q+5DsJwUbRXltH7Hht4aJgLyH4u0+P1wR7MLjGihmK43Pz8JHBzv6j
GL89Twhe1pRwXvLheuEja8x9Wwh0TB5oNmA/apWYLL8jBNVup/cT2K1Zv53l
SoXAK8h/4CH2n81dasOPhcDdSlTmJvae6Lim2DYh8Pi+3SMcW1KCFGrgCMHr
ss/bNmC/q42PsfwjBMlbep30sJP9VQTaFnG8LyN8tbFZr/bw9vIJw6Dwi6ur
sJlRz/+MiwvDxl8KLFls+kL65DIlYeA7l0pweHE9/LG175i1MGg5qt97gt2c
8nkPe7sw5BW80ajFvmj67/twO2Eo31dd9BhbJLesK26XMLQZuTy4j01zW9ae
tVcYLrAzfuVhC3WQz18fEwbC9+9YHDY/kVGqlCkM53tCLXdj9240tei/IQy7
u2O/78Quqxr5nJ4jDCrh3FG22K4Vm5jM2/h5J2i1wL5/tz+Y674wVDg4xhlh
u2cqGX5sFIaycfEsBezK0KKG1ClhOKcdtpbkwfePOXu3nbPCkFKxqDeK7XX8
94wYWxisCuOMhrDFj25fGfVXGNY/z9zxDXu/73jcMWEayFqm5PRgMx11be3+
oUH2dnrrU2x/ver3wtY02BKpsDUV++mbzuLK7TRoa6CVJWFLB5BnDtjRYP9M
tPwV7Cf5KqrPd9GA/4s+10VsySWJQWc9aCD/lRyIwK5he4vMHafBFGNc8TC2
KCG+6Vs2DaLODAZYYO9zUaMn3aTBbcWdqmbYFXNbBjbfosHabQJftmB7aIfG
ZRXR4KuTsRvCLs8Z6NxTQYM0CDuyDts1svJw+2savLofz6WCXWzpmV03S4P4
huePeLH1NRSMEZsGtDLUzY1dJ/75A7FAg9/VJ+cXufH+6XBb8pRLBD7pqcFv
7Bk350v1NBG4FKf1bRrbOMju9MvlInB+4+mwQez2dGOnt2YiYJflM/QKe0/Y
n5mdliJQJ/LIuAn7296apA5rEaBJJic3Ys8qG7a9sxMBMakh0wbspaX6Zt17
RODFblplLbZ3vYZe32ERuCGdPVhGtR9eSh9MFQHphXSXa9gp1380Zv4nAkpZ
7+tSsfVsy8/YZ4rAoZoqpRTsoPvbx5/kiEC+htPkFeyxk2dbM4pF4IdVfe4F
7EH+wYs7nuHnx3Vtz2B3/XNPuHZUBPaTXq8PYB9vD3t6jBSBWKXcvT7Ykuet
QtWnRGBCdceMN/bOwYGfafMicP3TrLIndmux9MsgXlFwPaCZ4or9wuB09CpZ
UQjrgcod2BX25rzJpqKwLG7T4kbsOOvKKDlzUUgYneowwnbdoiaUbykKzY/r
7xhi8+iKiFXYiAJDvNxpA7Yts026x0kU5M/l1uti/3yzW10uQBSCF540q2Mv
s/HZkZciCmkpm/Nlsc9aRGWVD4rCCVe6EYeLJN66+7pq/xIFWLXPno2tctxa
tnhYFK6jWP957Fc5jKSbpCjQr9nnzGJLLlyPvsoRBb5vLZJT2AV3KwKOiItB
wuVniiPY7cyfRhrrxKBf8lDnJ2xltdfztzeIgelpCUHKJ1DJQyUjMZgQO2bw
EVvOP1hrGYjBuReB2R+wfZ5zKdGsxKBuektIDzYnRJb2000M5A/lmr/FVvxo
1XMzSgzeby48/AI7/plR6a5YMTh2bcvt59hTtzWiBS+IQeLZm58bsBuCxPX8
EsXg0InKXfXY+4XeXtbJEAOFCTXLJ1T8us7mT8vEIFZ3l0MV9pr4AxWfPohB
jEPVbAl2aqBTQuInMSgJ/mJGedHB0tvkixi41T5Ou4v95p/VzFuDYnCm9KRR
MfbRh2MBARNi4LV3yYU72OWfj6v8FhAHDy9vqzxso/WRybI64nAmJ840HbvH
U3bddT1xCDrc9eA/7OBLJd0r1ouDTHOhEuWS7z1LV20UhyNJg3zXsFcka+as
MxOH1pYbLSnYfBNdd+33iMNMeG3IFS7q/7FaY8I5cYjfarM6Dtu3q86XESUO
AVFZhbHY/DwOtJQYcWj6clCdsrFz+PbMi7j/ez6rY7DLBDs6ClPF4bnyqE4U
drL36c+NheKAysccI7DdlrexuTvEYSqjejYUmy4b9LC6Uxys3907RfkZS+ro
8R5xIOVXLp7EVhV2+fnzI+5vwwVhyuTUYFfbT3HYmLtC+QR2ZNPfB9f/isOO
k2pHgrALg9ccNlCXgE32zh5+2K6B7WpTGhKw7Zbi1CFsiUPB34u1JMDmmEs0
5eC9Va4r9CVAH2RKDmJvsjKzFgQJ6P6vmMf3/+vjvqpzlwS8r1kgvLFnXyV8
PRIhARs26cW6Y/eJdPr+Pi8BqyJ91lCu3yY3HhMtAZlLx965YSe2Fi7cuCAB
3t85ipTV3zZKtqRIgIUQT70Ltvt7bnO1QgloR0lMZ+zGH8eLvryVgNTh1FF7
7G08WoZqTDo8kDU8b0Xlz70L6b4sOnxpad1E+f6+n5zbknQQT8ubt8SWeZpT
rbqEDnfuMQIpfzsjuUlZjg5u8oPuFtin/7DRP6p0OPp9p5UZdtF8w1YpQzoc
bsi0MaHiKVC45WBEh7SYTjplulO4QPJGOvw5Zt6xmdp/j9Y3MhEd5Pd0OlE2
OVFoQTelw1+L6z6A3Tt12VrEhg7rQnMvGmPTxvfs4Pakg5aVErcRtkV0XZ2L
Fx2KsyKeG2JHyytqVHjTwbdBLp4yz7ZfAn4H6LD9iaAkZXZBSM07fzoUncxT
N8D+6Zm8siCEDptUXnmux37R1fLHJoEONWf1/uhS+Xx4rd+dS3SY5r3zkrIJ
f0oPbyIdlovvTKZcp+v6oPIqHdQvmmhQfpg45Kt4jQ63J9LddbDzrATfzeTS
wUnjV7M29vk6KMyspIPq9vxWTWp8J2d/9z+mQ3VJwE3KOrrFtkrVdNha636S
8tfbS2bu1NKhrOmxImWTK2Po0TM6yMzahWpQ4/PO7GxvpsOR6CHN1djnhOe5
BL/Q4ZPvswerqP7r79pbfaUDZ9g5gbJOuNethAE6RHdKHaD8dbLVWnKQDi/r
OUspm/TlpyoM4/WyC4pcSfVfaq+xcYYO7y9Pu6liRziUOh4VZsDsRn91ZWzv
Wb9HbTQGfLYP4qdsdm3VkjWiDFDWvfFZCVu0L6drSJwBwTo+aZSveSXv8pZk
wODJBwKUy4JC7R3/YcD+PeojCtifErfYbtJngPm+iPZ/sJ/qcJVmrGOA0pb5
Msp572rEOesZIJeVmEj5kMy61gpDBqxpUbajPJO1ars2MKD6zLs3y6n3l4pZ
K1kz4A73ph55bMOWbjPhfQwIOGr9dxm1n8NbtuzzZIDYjNZXyme06uGxFwMc
/9N+QbnhSonhQR8GaLGjL1G22R21psmPAcOnz62g7NWvIx13ggFb6SmWS7Ev
TiR8F7rIAGGdkFIZql7mnv/qkcCAZYt3Uym324f2V17C8/P6Txhl6Qrv975X
GOBR9GMb5ZxTRi0vUxkw0dw/vAS7gvdXeWwOA5rqdq2h3C9lGin0iAENGQUN
UtR5NXTBx7KSARnLTMsoO9V1WMQ/ZsDN9MkMym99vMREaxjQz4o9Rrnh0blU
iacMaNFIUaJc6Py0QPo1AzoC1WIkqfp13bhFuZ8BX8cIFxa1PkejS/d/ZoD+
dKYl5dGtrVdufWHAt7b49ZR9xtx2r/qGx191jUXZGYX1r/7FgPeMM81Mqp5/
qZ7QmWKARO++zZSFVQykNwsyIWRIdj2DqoefY/ivCzEh95/rKpSvZXZNzwsz
4cjHtZKUV0kGd5SJMqE+NXGCTuUXb2niCiYTjLwU7lI+90VZhEueCdtHQldS
/n2dzkXoMGFtbcoqCWq8znvHl+oxISxbS5byBamSTyf0mcBn8l6Y8tIE69o1
G7C3uwyLY284HX3qxiYmlBxYUkr5+J7f02EWTLjl52NAeUz656+N7kxwK5p0
EqPin4mti9jLhAMXLbdRvvdOLemFB26/rxhRDr7qt9HOiwnSqSmqlBfExi95
+TJBZnJmWhRbiH9WNz6ICT6ag0mUlaZ4w7ujmVCgsa5XhFrPtn+YQaVMyKA7
RNOwT9Wyz5eVMcFbPP405Yyijpmxe0x4QmsKovwpJua9XzkT7h323EvZC8az
9z9mwoNb3AaUD9+r03KuZwLtx+CoMHXeJblth24mJHFk3CnfilhPhPcw4ZS1
5y7KjYGMtbXvmfCq/sE2yrRtzyUN+/D7lAONKF/m0+zT/cKEhNVmspTTj/8+
tHKYCSIX/buEsEsdM2LFF5mg9NB/N2VXzdOCvlwsGO3ksaEsxOsW/ZSbBatO
52yl7FGyPDKYjwVfDs7rUWby557pFWbBIVkRScrB9wtO3JJkgV344w5Bar3E
KryN1VmQ/kbAmfK3r6kDaatZ8Dg+cwflxMoQzwkNFsS8NbCi/MvLwCNPiwV9
U/FGlNOralxo+iwQ44leTvn3gfqdXYgFwzFd3wWo+vPsDRzexYKZ2w9CKcdW
8+aX7WbBtFP6Mco25euEpxxZMNAbHUC5Nz+zPWQPC96uPbqP8nSsr2fEXhbs
kIu3pKxqyxWZfJAFwTteLKV88YNWY1UYC4IuWzzlx975znP1n3D8vsW+asqy
LSmX0VkWrDt1ooLyrboFx4ZzLOi6WVlEmchp/NkSw4Ir06GplCcP7KV9ucKC
28W//Ck7TV/aLniLBUTPXnnKL1pNtANvsyD/8uISynp3ZpndBSyQHshjUpZw
d++5VcQCJV0uof+3b9T0MrvHgocf2JN82PoZzSejavD7t081UWaa0PJ4O/B4
wrr/pXxWri7a7x0Lvn9ZEUJ5bPbowY5OFlSpBwZRbip6v+ZmDwuETi09+P/2
Uncem3xigdnK4t2Ux3+at0X8YoFFV7kOZdf6hXu/hljAVLFeQ/nV9dLkHSMs
yJEZVKN8a+eSPQrjLFjerKZA2b1m8NuTaRbU3f4hQbk5Nb1x1Swef1iuCGXD
ozaFiXMsWNOzT5CylGpFoAeHBX/nR//yUvWE69DOlwsskC2t4lAme+X1tf+w
oP7lhVnK7g/bl1z7i9dr075Jys2XoziLiyzQ4zMao/w/Q+zruw==
        "]]},
      Annotation[#, "Charting`Private`Tag$34189#1"]& ]}, {}, {}}, {{{}, {}, 
     TagBox[
      {RGBColor[0, 1, 0], Thickness[0.007], Opacity[1.], Dashing[Large], 
       LineBox[CompressedData["
1:eJwd13c8ld8fAHDr2uMOKiUZUUqKjKKcQyJZRQohIzQRUqmvFdIQihTJCElp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        "]]},
      Annotation[#, "Charting`Private`Tag$34936#1"]& ]}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"\[Tau]\"", TraditionalForm], 
    FormBox[
    "\"\\!\\(\\*SubscriptBox[\\n \
StyleBox[\\\"w\\\",\\nFontSlant->\\\"Italic\\\"], \
\\\"\[Phi]\\\"]\\)(\[Tau])\"", TraditionalForm]},
  AxesOrigin->{1.000000081632653, -1.0548284683067286`},
  AxesStyle->Directive[
    RGBColor[1, 0, 0], 15],
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[
    RGBColor[1, 0, 0]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{1, 5}, Automatic},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic},
  TicksStyle->Directive[
    RGBColor[1, 0, 0], 15]]], "Output",
 CellChangeTimes->{
  3.8002493307622166`*^9, 3.8002493850977864`*^9, 3.8002497698501005`*^9, {
   3.8002498069798837`*^9, 3.800249819706459*^9}, 3.8002499189624453`*^9, 
   3.800250084507069*^9, 3.800274925394416*^9, 3.800319547516687*^9, 
   3.800319637178213*^9, {3.800319703721695*^9, 3.800319743774502*^9}, 
   3.8003199986848946`*^9, 3.800320097683634*^9, 3.800450910736374*^9, 
   3.8005904842740817`*^9, 3.8006745106594553`*^9, 3.801026166172425*^9, 
   3.8010284315394278`*^9, 3.801028525011439*^9, 3.8010288242718844`*^9, 
   3.8187722102742043`*^9}]
}, Open  ]],

Cell["\<\
The first four figures above are figure 3. The last one above and the figure \
below make figure 4.

We compare the vacuum energy densities in both cases as well...\
\>", "Text",
 CellChangeTimes->{{3.800249940083309*^9, 3.8002500527176695`*^9}, {
  3.800274959736765*^9, 3.800274970220904*^9}, {3.818772258242611*^9, 
  3.8187722969700775`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Log", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"3", "\[Alpha]\[CapitalLambda]"}], ")"}], 
         RowBox[{"(", 
          FractionBox[
           SuperscriptBox[
            RowBox[{"a", "[", "\[Tau]", "]"}], "2"], 
           RowBox[{"3", 
            SuperscriptBox[
             RowBox[{
              RowBox[{"a", "'"}], "[", "\[Tau]", "]"}], "2"]}]], ")"}]}], 
        "]"}], "/.", "abun"}], "/.", 
      RowBox[{"int", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"Log", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"3", "\[Alpha]\[CapitalLambda]"}], ")"}], 
         RowBox[{"(", 
          FractionBox[
           SuperscriptBox[
            RowBox[{"a", "[", "\[Tau]", "]"}], "2"], 
           RowBox[{"3", 
            SuperscriptBox[
             RowBox[{
              RowBox[{"a", "'"}], "[", "\[Tau]", "]"}], "2"]}]], ")"}]}], 
        "]"}], "/.", "abun"}], "/.", 
      RowBox[{"int2", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\[Tau]", ",", "\[Tau]i", ",", "\[Tau]f"}], "}"}], "/.", "dom"}],
    ",", 
   RowBox[{"PlotRange", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"AxesStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"Directive", "[", "Red", "]"}]}], ",", 
   RowBox[{"Ticks", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"TicksStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Thickness", "[", "0.007", "]"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Dashing", "[", "Large", "]"}], ",", 
        RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Green"}], "}"}]}], 
     "}"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<\[Tau]\>\"", ",", 
      "\"\<ln \!\(\*SubscriptBox[\(\[CapitalOmega]\), \(\[CapitalLambda]\)]\)\
\>\""}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.800250223609403*^9, 3.8002502894043036`*^9}, {
  3.8002503794422083`*^9, 3.800250383061781*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.007], Opacity[1.], 
      LineBox[CompressedData["
1:eJwd13k8lF8XAHDbMAxjFi2WUkRIlGix3UOlsrQoOyVb/IRCabWVJSJJWoVk
iSwhkX0pLbZBUlSYSco29uzvnfefmc/38zzPufecc597Z9Y7eJk683Bxcang
D853a9WfFVxcbLQ67rJuazkD3ebv9uMnsNG3rPtUa+zDxk1fhYXY6FCxzs2B
MgYSja3SoouyUaeoSdFV7KYv+QniYmykerzgnjh21JrUZWlxNnrp6LizrJSB
jB3vnZRfy0bK4ZZJzthCz2/UKsuyUfX+uC8rsD+MXJbbpsBGWqvW9Te8YaBw
dc+wXZvZ6KAVuT0C2+CS/R+kxkaLbuefH8ImVJkaGexgoy2aFzwlsesIe7ON
tdno8iXNTSMlDHTNaIfoUT02kiQN/q7H1r+teNbKgI0+iFW+yMDm/iLZdsKI
jY66jgfFYFdJkTVcDrOR82K9VwB2gAPXvdNmbOTifsP/HLZuxvg/b2s2OqIT
VuSNvTjMsr54go0e+axe54ddtu1LWYATG8l+eVgbjH354oe1oW5sJBbg/fwu
tmZlaeBNTzYqXhL8lov9jy+nL9aHjTKNWu0Y2K8Nk/Y8uIDrq6avM4d9PiY2
LfEqG6HDXwKVcH7qHdeJacFsFKMkttUBe0LS778XYWwkbhZsnoydf9KtIf8m
G/U8zJv9jX023Ual5DYbRQ6pyW7H9d0ybBJTGY/r9T2lKxI754LasYYkNvoU
0SZ5EPfLo2JDUWsqGy019hS+wVbmW7X6aybu/+WLyyq4/5m35rt+FbLR1UTp
BpUKBnL7PKwzVILzG3964g22gmRP4ngFGyVsflxvUslAqWl1jsvv2eh7B2nn
zSoGchoqektoYqP/zCRMd1QzkIza843CbWx0gL/J8S92UnnU4OrvbGSv5X/b
tZaBHreb+6iNsdG2yI3kd+8YyEbiwOed02x0Qsn9+8t6BpKw19qB5tloq73Z
YOp7Bro3KD1vRBhD3V5N/WkfGSiW50+ws/gYMrMOMxdpZqAj+7tY7mvH0LKv
7ArtFgaiRDcaeMuOofftQ1Y+DAaKFs8XCtg8hhR/fn0w38ZAN7Zcjr2vN4Yy
eVuHfb4ykK/YDQXSvjF0X+99mEAXAx3/F19x1XgMVZ+4ejm1G/enKv+vg8UY
KviTmMDVw0A/Dv3V3+wxhkJrHIU0fjPQ+23/OhO9x9BPh8VcqT8MVLCK34t2
YQyRtrIERQfxev+5/tFM8BjSs7wsIDbKQGpeVhPV98fQyZzjDkkzDCR19NQN
9SdjKNFAnPljloEEdpyTTk8ZQ/2KYmcVFhioeynG6GbOGFJPuNXTzdWKQqPf
p5jX4fy7HXUahFrRt+wdxwZHx9CMkhxqWteK6m7v/Ws3hccrU3hQI9uKcs8d
DWyZG0NuITzPa+Rb0XUdrxevCOPoR8owtV+5Fak0pvEFSo6jw7+SxEt3taJr
Qyteie0bR1wKetvTzFqRZ4usUZjxOLrxSdnB2qoVWRZu7Z09Mo50bTZ/kbDD
z18xEflpO46a+TeVVzm1ok5SiPNz73EUohtlnuzbipQ3Ta7QfTKOPvxM3FwW
34oCHhnqHUsZR7VKVdODD1tRKyn59H8Z42g4NaRTPrEVXRgyqY3PH0e/naz+
lae3otrs9DOj78aRt5jHeu+SVmS9xeZT0ug4kmspt5760Yqyk15OF02Oo6E1
ttc7ma2Ii0qUaZwdR1lt5KV3A60obazwwizvBFrvmvfn7XgrGssny5uunkA6
C/HNRgJtKFyjJpBXbwJdlilKuaDWhrpSV78QN5hA2ZuCrak725DKSq8vqkYT
aCxUzv2VThtqn5ZUsTWbQB1HTe5KH2hD0sXnugrdJpBleWjPZfs2VKSpuN0l
dgKt+e2nbnq7DTFRzOB75gQKsOn6ajnfhtSHP0a+HZhAh1YPr9rG045CHxKU
a4Yn0Ie8oLxVgu1IaerS6dKZCeStUd6yvLIdncl0Hs4mTaIrSkXfDbe1o0Ux
rdHYbZPozxlRdq1HO1r199e47bVJdE8qKXPyTzsyitOaY8tMofCAYlHthc/o
/c/bTVYKU8g020yKwt+BDDYNPK3ZPIWcdU3Fh0Q7ENTEGcXtnELzZacCS2U7
0Hb28OMdB6dQ1K9S9MqoA60zTkL+F6eQtneQ4NLjDjTNSwghtUyhE41tz5X3
fEFJPk2i8len0QGtKRGlxE5E9LjuB1UziL9ai2dCpQvZja3vP7V2FnX37T22
ov47cnrVFKV8fg5xP3/g2Lv0E3VPvtJQvTyH1CV2ELV5e5CZesL3rYFzqLph
N4NPoAcZFLhv3hExh4I/d5ZGk3vQxpfERr0nc+iHlNi/a2t60N8X+sIW7+bQ
sROX9k5q9qCzz4oiglbOI4b/y58jPj3I/86TsI6ieWT+1OeFx48eJHM22XFv
2TwS1Yp69723B707+AwVVs+jGfUBstGvHkQWypy53TCPXKJcVNcM9aDEwFen
TPrmkWX/jrbE2R5U5dGwr05kAV3fKtIgLdaLePbPCeQ7LaD2EcGNYvt6UciC
WXgUbRG5LGVbrE/tRbEuybOJqxaR5nFxvpL0XvSkZei/fKlFpHJiMOpgZi8q
enbN5Iv8ImrxISKf3F40YPyStl5rEdXS1mqnlPQi4wThhELHRXTr0amPTxp7
EU239mVX4SJKtHoSJjLZixIDtnQpWiwhMd1gJTGtPpQpb18tY7uEZkddxWV1
+lBR4610yZNL6MePx8ZbUB9qkBz1EXFfQu86v17fu7sP/XudLTzmv4ScT9FP
2Bj1IVO2km5x2hJKGy9r0LDpQ4STcskG00vIOP2dUM7FPuSuL3HK8e4yemFb
cXvkZR96GuYc9P7hMlopEb6urKAPdTbkPdqctIx8q3iWwl71IQOLfS0zmcto
OrA8U6KkD8mc9t11s2oZvbFdHt9Uhe+/20R6NbiMFto+XVxu7EMpvnqWvOu5
wFcsgOw70Ieo76cWjvlxwbvxf3w/VjNRT17lsa8XucCpwPrZVgkmyntw44Xd
FS5IspMVuy7JRIfd19i6BHHB3UtdrnJrmSiavLfUL5ILmt3seaxlmUjILO7i
w0QuoMU4NEduZiK+PrXpn/Vc0Gex8spqPSZq/7hg4vSRC+J/qBH26zNRSsG7
1IEGLiCeELh6fjcT6YdYm40xcLyp89ote5koSCG4kKcbjyfylO5nyERLngxv
OTYXeN5+9Df2KBPNzHuN/reaG17s0TETdGai7oJ9J+UkueGcbdl6VRcmqnGX
bvu5hhsuFDc1Hj3FRDe7moqOyXJDZW7v+wduTCRTutlfV4Ubqulcrqs9mejg
pUFh2h5uiLU9uLX3PBOl/nNRKvHiBsH+tMX0MCaKyNN97OPNDb2FvEVZ4Ux0
xnUlWeUcN4Q/WfTIucFEmp1vx55e4gb+stievEgmanm9oeRmCDcIOzz++/wW
Ey2c79tn/4gbXufaO3jcY6KjU3bOAvXcoN5F3QVpTFT8KZ366gM3xDgvXV6f
zkRST8fKHRq4YYDvLpM7g4n6D4asrGBwA6Pgn2zVcya6lPGi3rebG/LOzAeo
ZTNRks28Yt8YN6i5VJiNFjDRSPX9kTIpHpguPtLVVMVE4dFtft7ePBDEoO8+
2MlE67OqR8Z8eYC+vFwxjv2mPtf5rB8P6Gv6Pov/ykRDXDePnrnCA+FKIjnd
33D/ffaoeobyQPuKOx9Pfmei1Zav+t0e8oCBE/Xx4T4mylh/z+xkDQ+oi12W
rRtkIj3dkIaeOh74fY3aYD7ERN+sfXbb1/OAwzaZkQFs4bhDW0808EBXdlwS
aQTXk58oYtfBA01DnZ8M2Uy0c/BCneVf7PenUvImmai+0HrbYRovbC/39F+z
yETnk8zrCCt4QfOtl34W9oabpmalq3jhavTqizuXmCjY0dBPfg0vPOeKgCPL
TKRL0yxd2MgLPqeHDK5ws1Chl/ju5zq8sIVByigmsNBTpU5THjde2Dg4dqxJ
hIWOrGxnvnbnheSr+meMyCzExdPi6+HJC269MeT32HZf6+M7fXiBLkfrqBRl
odXhr7/l+PPCtz3zCc+pLHTrV7yDTRwvkCJjL7msYKErSWbehZW8cCB9zYNw
KRY60TrVqFWD728JfTqKrc8Xr1hbxwteqalG5mtYiOja0cP4wAsKv138Zday
UJyqxaHRNl6YqbnvVSTNQi8qLJWVBnihrqq6oUGGhbq7bfoTKXyQQnhZ80qB
hSrJC3ob6Xywc/MPV6oizg8eJ+Ss4IO4kt0lp7Fdn3UfK5fgg2fEKSsZJRaa
dLer/baBD8oDIlNubGIh4fnjSSt28UGW8qVH+1VYSEvcwTryJB/EBjSoRmxj
4XOF0rLfiQ+42NVX+7CVJSv28p/ig8sJIt6a6iy0do3E1qDTfGDzTPTQH2ye
9a0Cfn58IMgIZulvZ6H3CvqvHKL4oL5008dfO1nIfKcMRbOEDzbOw5chHRY6
tKslZKaUD4S2L9/T1GWh/Zr+84UVfPCnP08wHHuX9rd+1To+UPqqzC2DWEgK
YsvlmvmgOVjxgCmwEHMfjzv1Fx+klh0IeqbPQmcs+t4OUAjwY+OeFOo+Fho4
z3P+AZ0AXe+udh7Dto+XkTdcSYCLbtEf72Ef+ewQmiVJAJ563X6p/SykdpRp
4ClPgFRlMd4NB3C9DrLqJ7QIIDEbRJI3YiE/g/4PSy4EMHu9hjZ/kIXYzvyX
ct0IcHPA4/j2Q7jeIfJK9qcJUHXS0+sstmWdS0T1WQIYP3bv6cfeqf/b8PoV
AsTFvOFrPsxCczoDnwRjCWB9l3QjzpSF/DX+NoqVEyCNR4Y4bcZCSo9y9t+r
JIC4v/cXeXMW+sLlUyteQ4Atp5QvWmBvaZgvXltPgI/JIerF2L0OIs8UGATo
0HW+5WfBQntitlzS/kWAjedXzQ1bspDQ4Hl5JxF+2HLnVvkbGxYqOqyV3C/K
D8I6WxT7sR2LliXdaNh82qeptixUFhRO9VzFD9n5my6ewvZY/XDBbz0/hB65
lk+1Y6GWveWtkRr80KzoUHv8OAvFJ/EGFNjxQ6D6eatue5z/58/00/b8QG37
t4P/JAtJCGVkbHDkh35nwSFV7EQf49a7rvzwOibgczB2hsFduQs+/JCe7ZQv
78BCb4bkG7Rv8AOvYXaxiyMLfd9pKP6ukB+W1VLoH5xZKMlDKsf/NT8cDiqe
GMZ2eDqiv+MNP6w545JDc2GhftKd0xmV/BCsIltogz3yo6sy4iM/uH3aSRjC
5grxcDnUww+R36R/EFxZaAMjpqCTJAB37Wucpf/D8zUWoDuSBWBF+c9iHWxq
/VXvYYoAKIXAqA32Utl/W3lWCoDph53897G/ZOzJ3bROAAqLp36S3VkoIvBf
pr+6ADDmvlnNYLNV7Z9usBOAqjdSUoUeuL7RqrfP5AiA/vqBbX1n8PpTWL1p
JE8AduzRTpvFzqjmeuteIADy+bU81LMsdGeS8c+lWADct5ZfQtj/Wfva29UI
gCT9pusj7NXyJaqGHQIQTR4wPuTNQr7l+k2ySwKA/5BVpvuw0F/zTa7JXETY
btyfUIZtz6bzSPMSYYHC58bANpL9pSFBJAJ1u8nbOWyZG2EJFBoRvGhC9419
cb+PNZxelCPCr+AHr4awNw+Zkb6YEEGgSPqA9HkWKj5mXBlxmAg+hb88t2Hv
Kdf30T1KhH3iFoH7sG2jVbtSLYkg+TvKxQs7Yotglq8jEcJeX9OvwO73LTOk
XSTCDwbZ0NIP93dRJsLkGRGOy9+S9r+A9x8XcV3udCJ8zhjouYX9ukl0vPA5
EaKPm8ckYzclLlhJ5RKh8XpRSR32ol6H4mAJERI6/XcKXWQh69AbH8KbiSAT
kjB1G1tMlE2smyNCXN3Yr7hLLNReHhF2YJEIP5+cCEzBjjstx9+8TISUUSGR
fGz6R2veb3yCwJNjstiETQt5uzhKFoSz1EFN4mUWosw/HJeUFYTBtw80LmAL
/97b7WMkCEk0voCDV1io4W6P9ayJIKzLP3TRBvvmnstf/Q8LAtXY/pQrNulp
XscNM0F447G0NhhbyE6SkXhCEE4SPRcLsYlt7LeffARh+s5k4OqrLESofJQr
+1gQchVMRjuwv2nv2f/ziSBELOZ4MrHz3gz1PEwWhB+9xr2j2LZFOjRauiC4
9J1JIvqzUH72T1+ufEEwkKkN24V9/LGs5vd6QWAU5xEeYBdfzKqLnxCEuuYV
Kw4FsFD0zFE702lBMB/RFLPGdjy3MCUyKwgj6zYQnbHJZ002hiwJAinmTNMl
bGfX0Rs+gkJgk6/akYpNs9h26LC0EGw1pHXPYp9WL/0qaCQETwrOizwMZKHq
ls8vik2EILjVPCoFe6UHO+DUYSGQCczlzcauSpWTf2smBErP2W2V2GKrYrwD
7YWgS6GU9xd22awTaeacEBS8fJixOQjXv5Ksw0oSAuu4YYNi7JM2ipQ7KUIg
UpiVXoVdNLObqZcmBJlyPFwfsO23XLyRmCUEGhkP7n3FLkxmfrYuEgLJOVvH
OWzb68WejE9CIA2uvprB+Hw+4JBUMS0E9xyuFRZiayiv10WzQiD/bPZ+KXYF
uaercl4IfDwXztdgt7TZrarmIkFTcaV0C/aUnVV0rRAJDF+wNgxi63ofvvJ+
LQlM97XyrLvGQoyHupatBiTY8vuMRgi29dXFKdMDJHA1rzCPxGadKLvTZkQC
k46D3rexpzdoNrcfJgHxysH7CdgSuRoGX6xJEHfaLukVtlOtsnq3Jwk0tpum
sjj3D0pQ+uPx8/dt0nSvs9DdhN/1jx+QgEQqurUHW/1QYcDRxyS4+B/FxxDb
O99ktCqZBDnwfaM59siFwKZHL0hQtCPQ0AO7n9B/80gNCfzerL34ELtD+qVg
+TAJpu7KPGNjn2NcrfZhk+CmN6NzClvsmuFFpQkS2F3fQZzHNu1nDtz7R4L6
fF0LQgh+n1+sfO/NKwzx/E1F4tjvdl0JVRAXhgX9kEA97KKj+3jj9gjDZ9af
k1HYN4yKQ6T2CUPHltjnt7FtdysSUw8IQyJVefguNs82kkjRQWHIGtnt+gT7
EK15ZaelMCyVearkYg+0mCtJeQhD0rO5xWZsyYMuR57dFYbfacG15FAWCtwf
kljYLwyizbTMIOzW4662W/4Ig8uR7bPXseXOGYm/GBQGjVSDveHYH5Opd1LY
wuC6aVd7NLbYfEJo7JwwXBF91fgIOyO7yOMMWQRS9l7a+gqbQRvQUt4uAkoG
e5p/YW9Q/PQvfacIFBVYVg9gn0c5r2S1RGCLU17eILbUaV9VSRAB7Tfbwsaw
Xd5yyQoZioDX1xb6Ivacn7jQgJ0I9GnFZtPD8H7+3bAzJUQEssI3TOpiR9Ro
5ZqF4+s1Tg162BPpyqECkSLgXfUueQ92nTdZ3T1GBNTvzO82xHYmtt5SeyQC
Kp8vuJhhZ2yz2ledJwI1spry7tgqEaeKfnSJgEMG8VkcdryXZVTMDxH4dYgl
dw97+dgBJ/1eEfjWtDP1AXaL9CZaWr8IEAPNHz/BPvtqxMNjDM/HJ+t0BnZh
zzm5BX4y7JL6c68UW2vH9ThxNTIo5ico9mB3OohvT1Anw9r+wF192L7ROV/W
7SDDfU+ffSzsnF+dEgraZOB+F2U3gL0ubnPydgMykNU+erOx+cY6so9a4+sz
Y/pc4Xh/zlSsjwomw2KiXOhabNeOCldqCBmqaLY267AJPMeE7oaRoUfoq4oM
tq6Vv8njm2RoJWS3yGHnCbS1ZcaTYXLr32Vl7DinKz31mWRw/i1F1sK2W9s8
y91GBhEHtUkzbIq496vSz2RYmNAptsCuoa84e66TDA+DrlyywpYXtBkY+E4G
2f4Hs7bY7In+juYBMjBqwvscsa9/WCpIWMLxL7y3P4ud6aviuUtJFKYcliQi
sW29GIoTyqIgMtyecRNb9D/fXy9URUGsZIVGNLbviTe26zREoTGie/9tbB1D
AyMBEIX44Sy7e+Gc/hxX+GwmCknbC3RSsKc/RvWdCRKFoYdSfSXY3aTPrgvX
RKGnf7ViKXatsdRoWKgo/Kr67lmGHdOUOf8kUhQsKt9OV2ArtdaLNd4VBUGa
6r9a7ONfufcpZoqC1ZxTTSN2/e9zWb2topCiJ3alB9uYR1VTkUaBvTf6Knhu
4PXzMvKhK50CS0TPUl7s/JMDc+liFHB4KfKaD3t1dXKp/CoKfB+4mcWPzQoQ
09kgha9/fnpDCPvK4iySlqfAnpN/JGjYWf/q9q7QpABKfnxvHfbxjPVpx7Qo
cDpv/4X12BRLf/44bQo8HZGxlME+/3pHPQ1RYI7gvGIDtv75zP2UPRRIH1QP
3Yj9beKWEekgBbwVsvRUsIVGrY9wO1Ag7AJJTgt7f2hFhY0jBdo6WxY5Dl0j
o1zkRIHqF28+a2PzGP/hdz9FgUi55WBd7NkMv7L20xQ44ubYpoc94BC3McOP
ArZnLYz3Y7/raFw8GEWBg//ynh3D5vPc6v48mgIBo08dzTjzI9zt5I2hwLXA
tvXm2BXbbAuKYymwK2jikQX2q5i/rjL38fg79oRZYz8zFGifeopd3axpj32t
AjIfF1PA0i9Fwp2T34XphZ8lFLDbl/KaY7VtLw7JllLgzXPysdPYfemrpp6X
U0DxmFKkB2f82yPodQ0FUi9cH/fi5Of0+DOjgQKGZO00X+xgwX9cAr0UuLXz
ROpVTvza7KOGfRSYtvyyxZ8T398xLYpJAfqTT6Uc9403GYn1U0DjhlJLACd+
d2r8+kFs6+bxIE783KPK2lMUiMqUXheKHXQs1+KsIBVW2YmvjcZ2mnZ/3SxE
hZdbLZ5xbHBfYZWKMPY1ktItbOHu5I6/ZCocaPm6LQb7vmOcmZMYFWaMpfRi
sfO8Lx61kKbCmXUv9eOxf8TsPqSjQYXVxVW/ErCr1bhyH22ngphLu80TTj3b
y8hzO6iguM6LwfF/q7c3FWlSoSNDqzQReypRwWQLUEH+tO6NZM74uSJGskZU
MIk4JpqKrdn4xUDwJBXy5v69y8K29W/cfdKBColKY8ovsANUa6HEkQo7PwXH
clx3O0fTzYUKFYs+ttnYB81DVD64U+G01YPBHGzHn2orb5ynAn1m38xL7Jtj
Ub+IN6lQkNH77jV2ztNrffZRVAhH79cVYzOOXvxZHE0FtvuxSxyvLHL66nqb
Cl0jx5VLsJMvaTW+j6fC77MGN99gF/H+KQxPpsIRvWytcuyfK/ZcJ77G+WRo
2NRgS/2NdDlQTAWVuY2pHFtWtO2PKKGCxUD7CMetLo4iwmVUOPzkRFAtJ5/X
wfGi1VQYDkcpddiZVtUZKz9RIZt88ts7bN8E3cYNP6lQEt+96hOnP2dDc517
cL02PbbieHhv0+20XirsJa99xLHLiJ25AosKy6luaxqwrdDVn5v+UEHcVV66
EVu3t3RMbYIKvMWnVjVjC8rtWqknQINrepHdrdgtPWGEBCIN6n8OSrZx1sfj
jsl/gjTYThC24VhBzLctT5gGLX8jOzk24M2NWUejQbr+7ZZ2znrv3UDiWkOD
AdG/hR3YCwkUrko1GsS6hh3+xsnX6sSohDoNtMhHwzmOXJHz47wGDaTHf1Vy
LBFlVK6ykwZzVg4qXdg7r4ReeqJDg5TeUmI39jnrhcmr+2kQBrIF37FHVg78
0T5OA7W9+j09nPlPhVcEnaDBjmxpci/2y3bFO+/saVB3jaHFsW+su/ZhRxoQ
ZAriOZ4XGY12dKXBtufehn3YRML0tghvGgzv489kYstO8Pp/CaVBqNEdw35O
P5ulad65NIAFN/FB7Evls9fy8mgw3tSlzfGjrLapkZc0sE1Stuf4R1jYV/dC
Giy8dk/j2BFGk5xLaJC6ynHrELbnywpVq1oakD4d1hvGvn7HzgS+0GCSb+rA
KHZa0I5K/04alJMD3Tiu96JuLf9Kg/Di4XCOhYzfiml202DG+mw9x7f4Nndv
66WBbrvUbjb2w3ML/20cpMHJP5IaY9i5Fo/Cycs0sKef5ZvgvG+brwi4ctEh
MZAlwzGR1y60mpsOEpt26XFsn7P2ui8fHcoKQ69yTCM8DfgmSAf9hVeTHPvm
Z5xPE6NDbGXA90lOv0SKnHSV6NB8L/rBNOd86otn3ttEB9nbjoUcxxT7OYwp
0+GN55pmjv847rJ/pkoH7f3AN8OZ75syGyENOlx13+vB8cKpWtMORAe7AifN
f5z9p6YFPM3owKufXT2LHV7Km5pnTofhH+VfOD5YuF1wwoIOtJySYY6/pT5m
+FnT4aW6j/gc9mS4q0PQCToc52F7cSx/iOt6nBvOT3+9+Dxnv+hSrX9zlQ7b
dX7ZLmCbtjtsWvSnQ0V74BmOxRvv3kKBdDAdFbzOcVrFvEVdMB3kJlmZHFcm
1w80htEhXKlqhuPxUyeEem/TIWelRPQiZ/1MRpsIpNFhQqUle4lzvjXpb/FK
p0NCgH41x+rPp2lfMujw1TKpnWPR48c707LoIL60dv7/99dvdjR4SYd73kr7
lrE1HjVcCCmjg47RzS6OafpCz3jb6PDMU2iaKwL/npeqCHVvp4OHwEoBbuyR
6bNubZ/pUJknuprjD1lfVVI66ZAe3LiL48AVz0v0f9DBTfXcFY5HB/Y1B/2h
Q1vi9SWObWvnX/75SwfPyYtkHuyPCblxR4bo8Nn/+FqO00xXWa8fpUP3hSkd
jo+X9bOqJungPGx7heOG+If1CtN0WO5ojORY8+zBzJgZOkQEqzzieIV8kZf9
HO6fQ2UJx8Fc/5m+n8f5Fo2+55j9bY3GlkU6NJApnf+P/4qx6v4S7t/ldb//
H/9WyNzyMh2MRNdPc/w/Jjur5g==
       "]]},
     Annotation[#, "Charting`Private`Tag$35279#1"]& ], 
    TagBox[
     {RGBColor[0, 1, 0], Thickness[0.01], Opacity[1.], Dashing[Large], 
      LineBox[CompressedData["
1:eJwVl3c81f8Xx69xjWtd9xrRMBOyMorG57yjjIzKpsiOhEKJpr2FRGULyUq2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       "]]},
     Annotation[#, "Charting`Private`Tag$35279#2"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"\[Tau]\"", TraditionalForm], 
    FormBox[
    "\"ln \\!\\(\\*SubscriptBox[\\(\[CapitalOmega]\\), \
\\(\[CapitalLambda]\\)]\\)\"", TraditionalForm]},
  AxesOrigin->{1.000000081632653, 0},
  AxesStyle->Directive[
    RGBColor[1, 0, 0], 15],
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[
    RGBColor[1, 0, 0]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{1.000000081632653, 4.999999918367347}, {0., 
   0.6418471152505644}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic},
  TicksStyle->Directive[
    RGBColor[1, 0, 0], 15]]], "Output",
 CellChangeTimes->{3.800250291059409*^9, 3.800250393717819*^9, 
  3.8002749965962515`*^9, 3.8003197603292427`*^9, 3.8003200043109894`*^9, 
  3.800450912001609*^9, 3.8005904849048986`*^9, 3.8006745112414265`*^9, 
  3.8010285677269897`*^9, 3.8010288477861347`*^9, 3.8187723005430555`*^9}]
}, Open  ]],

Cell[TextData[{
 "In the self-tuning vacuum (blue solid line) the late-time energy budget of \
the universe comes from a mixture of vacuum energy and the dark energy field. \
On the other hand, the unhealthy de Sitter state (green dashed line) is \
described by purely vacuum energy only, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[CapitalOmega]", "\[CapitalLambda]"], "=", "1"}], 
   TraditionalForm]]],
 ".\n\n",
 StyleBox["[Case 2: ",
  FontColor->RGBColor[1, 0.5, 0.5]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"n", "=", 
     RowBox[{"-", "2"}]}], ",", " ", 
    RowBox[{"\[Lambda]", "=", 
     RowBox[{"7", "/", "5"}]}], ",", 
    RowBox[{"\[Beta]", "=", "1"}]}], TraditionalForm]],
  FontColor->RGBColor[1, 0.5, 0.5]],
 StyleBox["]\n",
  FontColor->RGBColor[1, 0.5, 0.5]],
 StyleBox["\n",
  FontColor->GrayLevel[0.5]],
 StyleBox["Setting up the theory...",
  FontColor->RGBColor[
   0.7411764705882353, 0.7411764705882353, 0.7411764705882353]]
}], "Text",
 CellChangeTimes->{{3.800274999389027*^9, 3.8002752408840585`*^9}, {
  3.800275288597967*^9, 3.8002753657982483`*^9}, {3.800275422548128*^9, 
  3.800275437970321*^9}, {3.8002755036149535`*^9, 3.8002755225028343`*^9}, {
  3.8002755687039905`*^9, 3.800275583884454*^9}, {3.8002757469909973`*^9, 
  3.8002757502067194`*^9}, {3.8187723081399803`*^9, 3.8187723276907644`*^9}, {
  3.8187723596702085`*^9, 3.8187723899966574`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"theory", " ", "parameters"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"param2", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Beta]", "\[Rule]", "1"}], ",", 
       RowBox[{"n", "\[Rule]", 
        RowBox[{"-", "2"}]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"abun2", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Alpha]r", "\[Rule]", 
        FractionBox["1", "10"]}], ",", 
       RowBox[{"\[Alpha]m", "\[Rule]", 
        FractionBox["8", "10"]}], ",", 
       RowBox[{"\[Alpha]\[CapitalLambda]", "\[Rule]", 
        FractionBox["7", "5"]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"no", "-", 
     RowBox[{"ghost", " ", "condition"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ngc", "=", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", 
        RowBox[{"\[Alpha]\[CapitalLambda]", "-", "1"}]]}], "<", "n", "<", 
      "0"}]}], ";", 
    RowBox[{
     RowBox[{"ngc", "/.", "abun2"}], "/.", "param2"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    StyleBox["n",
     FontSlant->"Italic"], "\[Equal]", 
    RowBox[{"(", 
     RowBox[{"n", "/.", "param2"}], ")"}]}], "\[IndentingNewLine]", 
   RowBox[{
    FractionBox["1", 
     RowBox[{
      SubscriptBox["\[Alpha]", "\[CapitalLambda]"], "-", "1"}]], "\[Equal]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FractionBox["1", 
        RowBox[{"\[Alpha]\[CapitalLambda]", "-", "1"}]], "/.", "abun2"}], "/.",
       "param2"}], ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.8002756193591714`*^9, 3.8002756195587025`*^9}, {
   3.800275650924147*^9, 3.8002756698206506`*^9}, {3.8002757595754747`*^9, 
   3.8002757621832523`*^9}, {3.8002760481850324`*^9, 
   3.8002760497442455`*^9}, {3.800276127192876*^9, 3.800276127595578*^9}, 
   3.8002773752536535`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.800275628490528*^9, 3.8002756778290367`*^9, 
  3.800275791520179*^9, 3.800276050312682*^9, 3.8002761297358856`*^9, 
  3.8002773903139796`*^9, 3.8003173856205835`*^9, 3.8003379649028516`*^9, 
  3.8004509120943584`*^9, 3.8005904849295783`*^9, 3.8006745112560377`*^9, 
  3.801028570564342*^9, 3.8010288545001793`*^9, 3.8010320954379215`*^9, 
  3.8187723993781595`*^9}],

Cell[BoxData[
 RowBox[{"n", "\[Equal]", 
  RowBox[{"-", "2"}]}]], "Output",
 CellChangeTimes->{3.800275628490528*^9, 3.8002756778290367`*^9, 
  3.800275791520179*^9, 3.800276050312682*^9, 3.8002761297358856`*^9, 
  3.8002773903139796`*^9, 3.8003173856205835`*^9, 3.8003379649028516`*^9, 
  3.8004509120943584`*^9, 3.8005904849295783`*^9, 3.8006745112560377`*^9, 
  3.801028570564342*^9, 3.8010288545001793`*^9, 3.8010320954379215`*^9, 
  3.8187723993831873`*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{
    RowBox[{"-", "1"}], "+", 
    SubscriptBox["\[Alpha]", "\[CapitalLambda]"]}]], "\[Equal]", 
  FractionBox["5", "2"]}]], "Output",
 CellChangeTimes->{3.800275628490528*^9, 3.8002756778290367`*^9, 
  3.800275791520179*^9, 3.800276050312682*^9, 3.8002761297358856`*^9, 
  3.8002773903139796`*^9, 3.8003173856205835`*^9, 3.8003379649028516`*^9, 
  3.8004509120943584`*^9, 3.8005904849295783`*^9, 3.8006745112560377`*^9, 
  3.801028570564342*^9, 3.8010288545001793`*^9, 3.8010320954379215`*^9, 
  3.8187723993842382`*^9}]
}, Open  ]],

Cell["\<\
We consider two initial conditions ending up on the two de Sitter limits...\
\>", "Text",
 CellChangeTimes->{{3.800277420885996*^9, 3.800277438312361*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "initial", " ", "conditions", " ", "for", " ", "self", " ", "tuning", " ", 
    "vacuum"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"ainit3", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ai", "\[Rule]", "1"}], ",", 
       RowBox[{"dai", "\[Rule]", 
        FractionBox["11", "10"]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"cons3", "=", 
     RowBox[{
      RowBox[{"NSolve", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Feq2", "/.", "param2"}], "/.", "abun2"}], "/.", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"a", "[", "\[Tau]", "]"}], "\[Rule]", "ai"}], ",", 
              RowBox[{
               RowBox[{
                RowBox[{"a", "'"}], "[", "\[Tau]", "]"}], "\[Rule]", "dai"}], 
              ",", 
              RowBox[{
               RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}], "\[Rule]", 
               "d\[CapitalPsi]"}]}], "}"}]}], "/.", "ainit3"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"Re", "[", "d\[CapitalPsi]", "]"}], ">", "0"}], "&&", 
           RowBox[{
            RowBox[{"Im", "[", "d\[CapitalPsi]", "]"}], "\[Equal]", "0"}]}]}],
          "}"}], ",", "d\[CapitalPsi]", ",", 
        RowBox[{"WorkingPrecision", "\[Rule]", "50"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"init3", "=", 
     RowBox[{"Union", "[", 
      RowBox[{"ainit3", ",", "cons3"}], "]"}]}], ";"}], "\[IndentingNewLine]",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ainit4", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ai", "\[Rule]", "100"}], ",", 
       RowBox[{"dai", "\[Rule]", "112"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"cons4", "=", 
     RowBox[{
      RowBox[{"NSolve", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Feq2", "/.", "param2"}], "/.", "abun2"}], "/.", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"a", "[", "\[Tau]", "]"}], "\[Rule]", "ai"}], ",", 
              RowBox[{
               RowBox[{
                RowBox[{"a", "'"}], "[", "\[Tau]", "]"}], "\[Rule]", "dai"}], 
              ",", 
              RowBox[{
               RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}], "\[Rule]", 
               "d\[CapitalPsi]"}]}], "}"}]}], "/.", "ainit4"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"Re", "[", "d\[CapitalPsi]", "]"}], ">", "0"}], "&&", 
           RowBox[{
            RowBox[{"Im", "[", "d\[CapitalPsi]", "]"}], "\[Equal]", "0"}]}]}],
          "}"}], ",", "d\[CapitalPsi]", ",", 
        RowBox[{"WorkingPrecision", "\[Rule]", "50"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"init4", "=", 
     RowBox[{"Union", "[", 
      RowBox[{"ainit4", ",", "cons4"}], "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8002758775901017`*^9, 3.8002759439384704`*^9}, {
  3.800277453537751*^9, 3.800277471295958*^9}, {3.8003175611126986`*^9, 
  3.80031756288682*^9}, {3.8003175991239233`*^9, 3.800317601229878*^9}, {
  3.80031773651811*^9, 3.8003177844064727`*^9}, {3.8003179382687798`*^9, 
  3.800317939471368*^9}, {3.8003179734544067`*^9, 3.8003179822638135`*^9}, {
  3.800318020052162*^9, 3.800318067150038*^9}, {3.8003180988354855`*^9, 
  3.8003181341338577`*^9}, {3.800318175876951*^9, 3.8003181765312457`*^9}, {
  3.800318214369755*^9, 3.800318244978633*^9}, {3.8003182785979767`*^9, 
  3.800318351958626*^9}, {3.8003188585360317`*^9, 3.8003188669849467`*^9}, {
  3.8003190070818615`*^9, 3.8003190078846827`*^9}, {3.8003190450787783`*^9, 
  3.8003190452200413`*^9}, {3.8006750562094545`*^9, 3.8006750723696566`*^9}, {
  3.818772411800806*^9, 3.818772415756542*^9}}],

Cell["Preparing the integration with this function...", "Text",
 CellChangeTimes->{{3.800338011575405*^9, 3.8003380221524067`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"cosmogccg2", "[", 
    RowBox[{
    "ai_", ",", "dai_", ",", "d\[CapitalPsi]_", ",", "\[Tau]0_", ",", 
     "\[Tau]i_", ",", "\[Tau]f_"}], "]"}], ":=", 
   RowBox[{"NDSolve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"ode1", "/.", "abun2"}], "/.", "param2"}], ",", 
       RowBox[{
        RowBox[{"ode2", "/.", "abun2"}], "/.", "param2"}], ",", 
       RowBox[{
        RowBox[{"a", "[", "\[Tau]0", "]"}], "\[Equal]", "ai"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"a", "'"}], "[", "\[Tau]0", "]"}], "\[Equal]", "dai"}], ",", 
       RowBox[{
        RowBox[{"\[CapitalPsi]", "[", "\[Tau]0", "]"}], "\[Equal]", 
        "d\[CapitalPsi]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", "\[CapitalPsi]"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Tau]", ",", "\[Tau]i", ",", "\[Tau]f"}], "}"}], ",", 
     RowBox[{"WorkingPrecision", "\[Rule]", "50"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.800275969388454*^9, 3.800275978413422*^9}}],

Cell["Integrating the field equations...", "Text",
 CellChangeTimes->{{3.800338028980335*^9, 3.8003380419734335`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dom2", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Tau]0", "\[Rule]", "1"}], ",", 
     RowBox[{"\[Tau]i", "\[Rule]", "1"}], ",", 
     RowBox[{"\[Tau]f", "\[Rule]", "5"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"int3", "=", 
   RowBox[{"cosmogccg2", "[", 
    RowBox[{
     RowBox[{"ai", "/.", "init3"}], ",", 
     RowBox[{"dai", "/.", "init3"}], ",", 
     RowBox[{"d\[CapitalPsi]", "/.", "init3"}], ",", 
     RowBox[{"\[Tau]0", "/.", "dom2"}], ",", 
     RowBox[{"\[Tau]i", "/.", "dom2"}], ",", 
     RowBox[{"\[Tau]f", "/.", "dom2"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"int4", "=", 
   RowBox[{"cosmogccg2", "[", 
    RowBox[{
     RowBox[{"ai", "/.", "init4"}], ",", 
     RowBox[{"dai", "/.", "init4"}], ",", 
     RowBox[{"d\[CapitalPsi]", "/.", "init4"}], ",", 
     RowBox[{"\[Tau]0", "/.", "dom2"}], ",", 
     RowBox[{"\[Tau]i", "/.", "dom2"}], ",", 
     RowBox[{"\[Tau]f", "/.", "dom2"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.8002759966757092`*^9, 3.800276020703151*^9}, {
   3.8002761053391447`*^9, 3.800276113419131*^9}, 3.800317581589014*^9, {
   3.8003181967886515`*^9, 3.8003182238285446`*^9}, {3.800318362678379*^9, 
   3.8003183746907783`*^9}}],

Cell["Plotting the results...", "Text",
 CellChangeTimes->{{3.800338061665134*^9, 3.800338064548525*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"scalar", " ", "field", " ", "derivative"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"p\[CapitalPsi]3", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}], "]"}], "/.", 
         RowBox[{"int3", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], 
        RowBox[{"(*", 
         RowBox[{",", 
          RowBox[{
           RowBox[{"Im", "[", 
            RowBox[{
             RowBox[{"\[CapitalPsi]", "'"}], "[", "\[Tau]", "]"}], "]"}], "/.", 
           RowBox[{"int", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}]}], "*)"}], "}"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\[Tau]", ",", "\[Tau]i", ",", "\[Tau]f"}], "}"}], "/.", 
        "dom2"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
       RowBox[{"AxesStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", 
        RowBox[{"Directive", "[", "Red", "]"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"TicksStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", "0.007", "]"}], ",", "Pink"}], "}"}], 
         "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<\[Tau]\>\"", ",", "\"\<\[CapitalPsi](\[Tau])\>\""}], 
         "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p\[CapitalPsi]4", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}], "]"}], "/.", 
         RowBox[{"int4", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], 
        RowBox[{"(*", 
         RowBox[{",", 
          RowBox[{
           RowBox[{"Im", "[", 
            RowBox[{
             RowBox[{"\[CapitalPsi]", "'"}], "[", "\[Tau]", "]"}], "]"}], "/.", 
           RowBox[{"int", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}]}], "*)"}], "}"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\[Tau]", ",", "\[Tau]i", ",", "\[Tau]f"}], "}"}], "/.", 
        "dom2"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
       RowBox[{"AxesStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", 
        RowBox[{"Directive", "[", "Red", "]"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"TicksStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Dashing", "[", "Large", "]"}], ",", 
           RowBox[{"Thickness", "[", "0.007", "]"}], ",", "Green"}], "}"}], 
         "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<\[Tau]\>\"", ",", "\"\<\[CapitalPsi](\[Tau])\>\""}], 
         "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"acceleration", " ", "of", " ", "scalar", " ", "field"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pd\[CapitalPsi]3", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"Log", "[", 
           RowBox[{
            RowBox[{"\[CapitalPsi]", "'"}], "[", "\[Tau]", "]"}], "]"}], 
          "]"}], "/.", 
         RowBox[{"int3", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], 
        RowBox[{"(*", 
         RowBox[{",", 
          RowBox[{
           RowBox[{"Im", "[", 
            RowBox[{
             RowBox[{"\[CapitalPsi]", "'"}], "[", "\[Tau]", "]"}], "]"}], "/.", 
           RowBox[{"int", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}]}], "*)"}], "}"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\[Tau]", ",", "\[Tau]i", ",", "\[Tau]f"}], "}"}], "/.", 
        "dom2"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
       RowBox[{"AxesStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", 
        RowBox[{"Directive", "[", "Red", "]"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"TicksStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", "0.007", "]"}], ",", "Pink"}], "}"}], 
         "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\[Tau]\>\"", ",", "\"\<ln(\[CapitalPsi]'(\[Tau]))\>\""}], 
         "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pd\[CapitalPsi]4", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"Log", "[", 
           RowBox[{
            RowBox[{"\[CapitalPsi]", "'"}], "[", "\[Tau]", "]"}], "]"}], 
          "]"}], "/.", 
         RowBox[{"int4", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], 
        RowBox[{"(*", 
         RowBox[{",", 
          RowBox[{
           RowBox[{"Im", "[", 
            RowBox[{
             RowBox[{"\[CapitalPsi]", "'"}], "[", "\[Tau]", "]"}], "]"}], "/.", 
           RowBox[{"int", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}]}], "*)"}], "}"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\[Tau]", ",", "\[Tau]i", ",", "\[Tau]f"}], "}"}], "/.", 
        "dom2"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
       RowBox[{"AxesStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", 
        RowBox[{"Directive", "[", "Red", "]"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"TicksStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Dashing", "[", "Large", "]"}], ",", 
           RowBox[{"Thickness", "[", "0.007", "]"}], ",", "Green"}], "}"}], 
         "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\[Tau]\>\"", ",", "\"\<ln(\[CapitalPsi]'(\[Tau]))\>\""}], 
         "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Hubble", " ", "parameter"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pH3", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          FractionBox[
           RowBox[{
            RowBox[{"a", "'"}], "[", "\[Tau]", "]"}], 
           RowBox[{"a", "[", "\[Tau]", "]"}]], "]"}], "/.", 
         RowBox[{"int3", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\[Tau]", ",", "\[Tau]i", ",", "\[Tau]f"}], "}"}], "/.", 
        "dom2"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
       RowBox[{"AxesStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", 
        RowBox[{"Directive", "[", "Red", "]"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"TicksStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", "0.007", "]"}], ",", "Pink"}], "}"}], 
         "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<\[Tau]\>\"", ",", "\"\<\!\(\*
StyleBox[\"H\",
FontSlant->\"Italic\"]\)(\[Tau])\>\""}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pH4", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          FractionBox[
           RowBox[{
            RowBox[{"a", "'"}], "[", "\[Tau]", "]"}], 
           RowBox[{"a", "[", "\[Tau]", "]"}]], "]"}], "/.", 
         RowBox[{"int4", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\[Tau]", ",", "\[Tau]i", ",", "\[Tau]f"}], "}"}], "/.", 
        "dom2"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
       RowBox[{"AxesStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", 
        RowBox[{"Directive", "[", "Red", "]"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"TicksStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Dashing", "[", "Large", "]"}], ",", 
           RowBox[{"Thickness", "[", "0.007", "]"}], ",", "Green"}], "}"}], 
         "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<\[Tau]\>\"", ",", "\"\<\!\(\*
StyleBox[\"H\",
FontSlant->\"Italic\"]\)(\[Tau])\>\""}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Hubble", " ", "parameter", " ", "time", " ", "derivative"}], 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pdH3", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Log", "[", 
          RowBox[{"Abs", "[", 
           RowBox[{"Re", "[", 
            RowBox[{
             FractionBox[
              RowBox[{
               RowBox[{"a", "''"}], "[", "\[Tau]", "]"}], 
              RowBox[{"a", "[", "\[Tau]", "]"}]], "-", 
             SuperscriptBox[
              RowBox[{"(", 
               FractionBox[
                RowBox[{
                 RowBox[{"a", "'"}], "[", "\[Tau]", "]"}], 
                RowBox[{"a", "[", "\[Tau]", "]"}]], ")"}], "2"]}], "]"}], 
           "]"}], "]"}], "/.", 
         RowBox[{"int3", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], 
        RowBox[{"(*", 
         RowBox[{",", 
          RowBox[{
           RowBox[{"Im", "[", 
            RowBox[{
             FractionBox[
              RowBox[{
               RowBox[{"a", "''"}], "[", "\[Tau]", "]"}], 
              RowBox[{"a", "[", "\[Tau]", "]"}]], "-", 
             SuperscriptBox[
              RowBox[{"(", 
               FractionBox[
                RowBox[{
                 RowBox[{"a", "'"}], "[", "\[Tau]", "]"}], 
                RowBox[{"a", "[", "\[Tau]", "]"}]], ")"}], "2"]}], "]"}], "/.", 
           RowBox[{"int", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}]}], "*)"}], "}"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\[Tau]", ",", "\[Tau]i", ",", "\[Tau]f"}], "}"}], "/.", 
        "dom2"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"AxesStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", 
        RowBox[{"Directive", "[", "Red", "]"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"TicksStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", "0.007", "]"}], ",", "Pink"}], "}"}], 
         "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<\[Tau]\>\"", ",", "\"\<ln(\!\(\*
StyleBox[\"H\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"'\",
FontSlant->\"Italic\"]\)(\[Tau]))\>\""}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pdH4", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Log", "[", 
          RowBox[{"Abs", "[", 
           RowBox[{"Re", "[", 
            RowBox[{
             FractionBox[
              RowBox[{
               RowBox[{"a", "''"}], "[", "\[Tau]", "]"}], 
              RowBox[{"a", "[", "\[Tau]", "]"}]], "-", 
             SuperscriptBox[
              RowBox[{"(", 
               FractionBox[
                RowBox[{
                 RowBox[{"a", "'"}], "[", "\[Tau]", "]"}], 
                RowBox[{"a", "[", "\[Tau]", "]"}]], ")"}], "2"]}], "]"}], 
           "]"}], "]"}], "/.", 
         RowBox[{"int4", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], 
        RowBox[{"(*", 
         RowBox[{",", 
          RowBox[{
           RowBox[{"Im", "[", 
            RowBox[{
             FractionBox[
              RowBox[{
               RowBox[{"a", "''"}], "[", "\[Tau]", "]"}], 
              RowBox[{"a", "[", "\[Tau]", "]"}]], "-", 
             SuperscriptBox[
              RowBox[{"(", 
               FractionBox[
                RowBox[{
                 RowBox[{"a", "'"}], "[", "\[Tau]", "]"}], 
                RowBox[{"a", "[", "\[Tau]", "]"}]], ")"}], "2"]}], "]"}], "/.", 
           RowBox[{"int", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}]}], "*)"}], "}"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\[Tau]", ",", "\[Tau]i", ",", "\[Tau]f"}], "}"}], "/.", 
        "dom2"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"AxesStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", 
        RowBox[{"Directive", "[", "Red", "]"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"TicksStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Dashing", "[", "Large", "]"}], ",", 
           RowBox[{"Thickness", "[", "0.007", "]"}], ",", "Green"}], "}"}], 
         "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<\[Tau]\>\"", ",", "\"\<ln(\!\(\*
StyleBox[\"H\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"'\",
FontSlant->\"Italic\"]\)(\[Tau]))\>\""}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"dark", " ", "energy", " ", "equation", " ", "of", " ", "state"}],
     "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pw3", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"wDE", "[", "\[Tau]", "]"}], "/.", 
          RowBox[{
           RowBox[{"H", "[", "\[Tau]", "]"}], "\[Rule]", 
           FractionBox[
            RowBox[{
             RowBox[{"a", "'"}], "[", "\[Tau]", "]"}], 
            RowBox[{"a", "[", "\[Tau]", "]"}]]}]}], "/.", "param2"}], "/.", 
        RowBox[{"int3", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\[Tau]", ",", "\[Tau]i", ",", "\[Tau]f"}], "}"}], "/.", 
        "dom"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
       RowBox[{"AxesStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", 
        RowBox[{"Directive", "[", "Red", "]"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"TicksStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", "0.007", "]"}], ",", "Pink"}], "}"}], 
         "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<\[Tau]\>\"", ",", "\"\<\!\(\*SubscriptBox[
StyleBox[\"w\",
FontSlant->\"Italic\"], \"\[Phi]\"]\)(\[Tau])\>\""}], "}"}]}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pw4", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"wDE", "[", "\[Tau]", "]"}], "/.", 
          RowBox[{
           RowBox[{"H", "[", "\[Tau]", "]"}], "\[Rule]", 
           FractionBox[
            RowBox[{
             RowBox[{"a", "'"}], "[", "\[Tau]", "]"}], 
            RowBox[{"a", "[", "\[Tau]", "]"}]]}]}], "/.", "param2"}], "/.", 
        RowBox[{"int4", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\[Tau]", ",", "\[Tau]i", ",", "\[Tau]f"}], "}"}], "/.", 
        "dom"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
       RowBox[{"AxesStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", 
        RowBox[{"Directive", "[", "Red", "]"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"TicksStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Dashing", "[", "Large", "]"}], ",", 
           RowBox[{"Thickness", "[", "0.007", "]"}], ",", "Green"}], "}"}], 
         "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<\[Tau]\>\"", ",", "\"\<\!\(\*SubscriptBox[
StyleBox[\"w\",
FontSlant->\"Italic\"], \"\[Phi]\"]\)(\[Tau])\>\""}], "}"}]}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"p\[CapitalPsi]3", ",", "p\[CapitalPsi]4", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0.9", ",", "2"}], "}"}]}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"pd\[CapitalPsi]3", ",", "pd\[CapitalPsi]4", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "5"}], "}"}], ",", "Automatic"}], "}"}]}]}], "]"}],
    "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"pH3", ",", "pH4", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "5"}], "}"}], ",", "Automatic"}], "}"}]}]}], "]"}],
    "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"pdH3", ",", "pdH4", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "5"}], "}"}], ",", "Automatic"}], "}"}]}]}], "]"}],
    "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"pw3", ",", "pw4", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "5"}], "}"}], ",", "Automatic"}], "}"}]}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.80031752720434*^9, 3.800317553147628*^9}, {
  3.800318415822258*^9, 3.800318575872023*^9}, {3.800318630452027*^9, 
  3.80031874723182*^9}, {3.800318890342949*^9, 3.800318914793609*^9}, {
  3.8003189647837734`*^9, 3.8003189755354114`*^9}, {3.800319109039586*^9, 
  3.8003191095637536`*^9}, {3.8010286074484754`*^9, 3.8010286524647517`*^9}, {
  3.80102887155516*^9, 3.8010289223237443`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[1, 0.5, 0.5], Thickness[0.007], Opacity[1.], 
       LineBox[CompressedData["
1:eJwd1nc8ld8fAPBr32tcd4hECZFVSilRzidZFZGRUiQKpchOSQhll5XIqgj5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        "]]},
      Annotation[#, "Charting`Private`Tag$36422#1"]& ]}, {}, {}}, {{{}, {}, 
     TagBox[
      {RGBColor[0, 1, 0], Thickness[0.007], Opacity[1.], Dashing[Large], 
       LineBox[CompressedData["
1:eJwVkXk41Akcxkfuo8H8jCNSiJRxZJwzbd8v62hlKxV2LXabUTa2MHabTl1s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        "]]},
      Annotation[#, "Charting`Private`Tag$36462#1"]& ]}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"\[Tau]\"", TraditionalForm], 
    FormBox["\"\[CapitalPsi](\[Tau])\"", TraditionalForm]},
  AxesOrigin->{1.000000081632653, 0.9255841237713096},
  AxesStyle->Directive[
    RGBColor[1, 0, 0], 15],
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[
    RGBColor[1, 0, 0]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{1, 5}, {0.9, 2}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic},
  TicksStyle->Directive[
    RGBColor[1, 0, 0], 15]]], "Output",
 CellChangeTimes->{{3.8003175548707027`*^9, 3.8003175701328983`*^9}, 
   3.800317607763579*^9, {3.800317749411677*^9, 3.800317791341212*^9}, 
   3.8003179514235754`*^9, 3.800318033856316*^9, 3.800318086621545*^9, {
   3.8003182010094967`*^9, 3.80031825002969*^9}, {3.8003186880100346`*^9, 
   3.8003187489262576`*^9}, 3.800318919131569*^9, {3.800318967840953*^9, 
   3.8003189770411367`*^9}, 3.800319017326908*^9, 3.800319059576162*^9, 
   3.800319112524501*^9, 3.8003380847357664`*^9, 3.8004509171683855`*^9, 
   3.8005904877140994`*^9, 3.8006745138353815`*^9, 3.801028927811447*^9, 
   3.8187724353668537`*^9}],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[1, 0.5, 0.5], Thickness[0.007], Opacity[1.], 
       LineBox[CompressedData["
1:eJwVk3k8VV0Xxw0RGcI1hoy5NCBDA9U64qFSSCQZGjwUmUIvDShR1KOQKRVC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        "]]},
      Annotation[#, "Charting`Private`Tag$36502#1"]& ]}, {}, {}}, {{{}, {}, 
     TagBox[
      {RGBColor[0, 1, 0], Thickness[0.007], Opacity[1.], Dashing[Large], 
       LineBox[CompressedData["
1:eJwVlnk0ld0XxwldQyKXhBKK9IYkEso+JBQqZMoU8qpeGQsNIpShSKgkRZEi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        "]]},
      Annotation[#, "Charting`Private`Tag$36542#1"]& ]}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"\[Tau]\"", TraditionalForm], 
    FormBox["\"ln(\[CapitalPsi]'(\[Tau]))\"", TraditionalForm]},
  AxesOrigin->{1.000000081632653, -11.934513131098287`},
  AxesStyle->Directive[
    RGBColor[1, 0, 0], 15],
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[
    RGBColor[1, 0, 0]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{1, 5}, Automatic},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic},
  TicksStyle->Directive[
    RGBColor[1, 0, 0], 15]]], "Output",
 CellChangeTimes->{{3.8003175548707027`*^9, 3.8003175701328983`*^9}, 
   3.800317607763579*^9, {3.800317749411677*^9, 3.800317791341212*^9}, 
   3.8003179514235754`*^9, 3.800318033856316*^9, 3.800318086621545*^9, {
   3.8003182010094967`*^9, 3.80031825002969*^9}, {3.8003186880100346`*^9, 
   3.8003187489262576`*^9}, 3.800318919131569*^9, {3.800318967840953*^9, 
   3.8003189770411367`*^9}, 3.800319017326908*^9, 3.800319059576162*^9, 
   3.800319112524501*^9, 3.8003380847357664`*^9, 3.8004509171683855`*^9, 
   3.8005904877140994`*^9, 3.8006745138353815`*^9, 3.801028927811447*^9, 
   3.8187724353668537`*^9}],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[1, 0.5, 0.5], Thickness[0.007], Opacity[1.], 
       LineBox[CompressedData["
1:eJwd13c8Ve8fAHB7u+5ARApRSinSIJ5P0rAVKqJEpChCSUPTDJFR0UApSSkh
ZWWUBrJJSouvqJx7zTL6fc7vn3tf79c55znP+Dyf53NU3Xw3ewjw8fEB/tD/
Tc9/yPHxUaT418LLV65wSbxIV5CIMEX2mna65aBtLevfS0lQpCPJfLwMXd+e
d01RliJyY63h39Cvfx/T0JtPEYO0SL0FKVzyXJmh72lLkTGiFn0ffdKN75KP
A0VW3hsRKEUbZ/HG/Z0oUm393KQWXaLXXnJyN0UO7rBR7kc/MU8zvXKEIgPH
W5aop3LJgyO69rVpFEkavpQdhd5fNrewKZMi18MeJyajtYVmKLzPpsjS3PG1
GejsCxMfevIpcuKzALcInXm72v3fK4q861cO+Ybe/bPwhXA9RdzMY6J+odV0
786TaqaI03JNpzF0WmnMgMJHiqzpfrtG4iqXXG3ZEqDLpUi09/2Fi9DbZ5q1
rhylSNzKheb66JmuhivIBEXm+pVpGaEvDcyesBDmEj8V+YWW6C1L2S6bJbhE
ZN1mSzu0bJBQ+TYZLsnYk7DICX1R4McZD0Wc9ztMnT3oTRs/fPdW4ZJ55pXW
+9HM2Lr1/upcsuK6+6IAdKxinsTJRVwyZ42LZgjaauctn1BdLll0YT6cRUtl
JtefX8Elpm9ez4hARy45dvHyGi5JLvP7F4cOlI2cL7mBS+70r3NPQu8YTy47
YYnrkv4v6ArarOuWPbWJSxQS1xhdQy97ntfvtpVL7gvl5qWhVW49P9XqjOPo
6W+/iRaPqJff6IbjvHQp5zZ62Lsr59keXLcFW5fcRX+y6TdZtB+vG791u4d+
pTfeccOfS7pEktbeRz+eIeLLPsIlblYOTQ/Q1yc4wqEnuETCL4fxEB3RrZo6
doZLpncZjNP2r9JZui+CSzzvXY99hHa5Y1TTFYP93nukkfbG8xYuNglcssbK
8zltXV/HoYrLXFJ8WWQ7bWW7PZHLrnPJW92xNLo90RWHZt+5ySVhJ1rjc9G8
mWcLFO/i/ynjRXR/uqbjLKIfcElqa71/Dvrl1+tfph9zydabam7Z6Ecvc4IO
PuWS9Metf+/Q8ZL9TPp7GY7H/uzqTHRY7KubW6q55OyBl5oZaD//tlWvX3NJ
adiqp9fpeNry/Z3hOy4xuHd4KAW93oDn8aCFSxrCZrQmo5eo8E3O6eSSXVYF
LhfpeBNgXEzo5pLC933RMWjhXqX5Ij1c0nPB3I1e7877K+wHBrkkeHBs6ji6
On5dv8sIxs8W/6rD6NxDdqca/nJJi+WRRX7oc0a+OQXCPHKs6+SvXegDqidM
5kvySH9njgkdn47C5ztSmDwStqzEYDN6cd1toVNKPDLftoW1Bq3wKD+FN4dH
HmgLUyvQgkmVSzw0eeRSupfvYnSH8ydn86U8IqPIsZ2JPvtTrkB2A490v+VG
0/vvQIO6Rbglj8zkFnh9QW/LX/rlzyYeka5Y9bUFvfi4lXS3M49cdyvPeYbu
kAz1uOvPI048j4TT6MrBixNKR3iEnKmz9Uffb06Ljz3BIyXlXllu6DOpJaUB
ETwixNo/14TOFwuH5Yyv88jurZMmk3R+SjVfY3+TR9yk1wsMoJsk0332ZfHI
qOtdj/foIz+tqpLzeIRttnpGAbrq/h2/wZc8ErKfT8kLLa8ynSpcyyM9ZmGU
Hdor1r5GqZFH0oZn7SFohi+/ysYPPBKq+ldfDu20ZPvbtEEeqXh+1aYE8+f9
tEejhcM8sv3JD7VMNB9LTK3uD49k7VmaGIO+zc0/8kdwiKy2UrVxQXPzGJqb
FYbIQsMopXGM6wj9ylOCa4ZI+qBy4Uz0h0yFHMX1Q+QC88OqqUs4f/K+7ToW
Q2SRFDh0o1tGlRY7OwyRk4t2b8pAzy469CF/7xBpSG61U0cXGmgt97w4RHzL
ZOaxknF/3zu56/ilISJNfg3/TOISZ6W26ItXh8juNVN2r9D8k2e+ld0eImur
5apPoC1Lu+JmFA8Rbvw712+JXPKNxA28+jZEfmrlLb2C+3LZrzfnX/QNkTiL
spID6LAUYe3KX0PkT6Vs+1r0gpGjPsVjQ2SH+qyinxdxv2R7/LovOUzS4yRU
V6GnZA0HL+oNk4F1OwxK4rjEuvLQhQsrh8nJYxPRUeg034c60UbDJGLHD69t
cXQe1PAL3TBM/kqvKeZd4JKok0xu0PZhYv2zoFwVPaO/h+d8dpjkt8SMeWEe
8bo0J8ExYpioXGHl66CfmW7X2xKD7xddMTwSjfnyRkOAzaVhwnCRmD6FvmVf
PLzm3jDhC9qzOP48lywtjxvVbB4mSS9OF12J5BKLRMO/lNoIMTp61swsFPNf
d3y94/wR8tKx/dqfc7jfF/ZlVC4aIU+vBNvfRUNlokXiyhESLbL3PxH0curX
1RXWI0Tr3NnUZ5gH51imkZDgESLYC9OCp7hkVFA4VLJhhPCVecjNOsolATbb
HQNbR0iUUNCKp8FcQqU8WvSxc4TYlSoX2KMHlu5oe9AzQkxqWisjMe9+3vlk
3uaJESK02l7z52HMi8V731zWHCX7YleKXQzA+Qyol9E8MUrG2jqT3HxwvSz2
B+ueGSU7L69Zw/PmEm91qW/G4aNEPClu52n08mazwq3xo8SgqXzk2j4uqdN9
4RyZOUqsVzTGNnhxyV9u8d2fdaPkieT3B0oeXGLvd3ftY5Uxsnbi5pSFC5eI
7T8XBM/HyKucnyE6eC4pfjOWe/pijAjOAN5FC4wPxz95S9+OkbN5T3pGzPH8
W3fgt1rbGMnZoLrpmRmep7O2eQj/HCPL/rZtMcJzblb9Qrs3M8aJ6Kz5jEUm
eB7oNC+29x0ng2bTC4vxnHThqvbuUflDVF/P0+hQxfqgoD5G+/BfEmae6mww
QpGQhOvhbYUT5EZTx6PhWoqETjpExLCnyNQSA/csrEMueqb/uTFjiswe07KY
Q9clDT/35SlPEZXhyNDLtyhSeOusVbvmFLHpm+RG3qRIn+UjtqohXjfQzvFL
p4jlNalr+e5TZOzlg0KraxRhG1c9+pA/RVZf1zm1PokiN04u+aC1dZoINYZs
1QujSLama4Wa8zQxqtdwrQzF9usu3FHaNU1qj5CiTehapcEAae9pYuV5bsvB
cxQZf3JfihsyTWL8bM3yz1BkM7XAuOj2NFFrPjO68SRFhHdppK8fnSZybY8a
crDu8jaZucc96R85cCsoepsPRTLCPU6/SvlHgvUKinjeWAfWPkxdlPaPdMJW
gxj0+q0bGsay/xF+nqxR1T6KqPkErop+/o+cKT1pqLeXrhvrJQsG/pFw5aIh
NU+K3Axcs01QlQ9W/J0SBleKsF6NTNoH8UGcuP1PD6wTPz8st38fzAdHB6v9
FNEPr0TmuBznA6NZ3cvq7Cli6z3L2fM0H1Qnex3TR8cy1hUHneeDJ3kwJWZH
EQmHxOCUG3ywnBeZW4x1qNBX3dHuGj5QX8x/z9oS69IJ38F9CvyQWXh0SNWU
Il2PN+zSUOIHVZN5vz6tpUil9+zm7ln84Lo6UuMqOvpDfaG9Oj/kpmRsmoFW
K14UYryYH/I33YxnmlDE+uiAFNuUH/7GfzvHAIpkjnsueOrLD20fZ31cvpoi
UQ+Nrwb488OugteWE4YU8fOSZyw+xA8JvVPD5WiDjhfcjKP8YDhEfpuhG57M
fRodyg/GocMhrgYUmTz8dYNrKj9M+1QNXlpJEbsRFw/RGn648yD69WJ9ihS9
vcMqeM0PiwMCev8uo4hyBrfUrZYfAgVMl9Wge61D5csa+UF26d9druijWTk1
gV388Gq7Jn+SHkXStk9ofeXyg9HQkgWiuhT5XXH5d4myALikKEswdCgSEdsc
5O8vAA0pnw5e06KI6r2K39xAAfhV/sI6CP2sJtfjYJAAWDq/ttqE/skXbed3
XADqtR8/EkbbBpjqHAgTgOYWrrQfficobCvo3ZsiAJ1pbv/M51EkS/WSw65K
AThV6SGkqIF1t3Fo7edqATCrLvo9OpcinU4Ba11rBIBV8WSsBS2VaLN0Z60A
vGm19YhH+4mISbu0CcALI7kcSfTKgSPV2/oFINV6S6OwOkVq8p30bNmC8KVn
9hsZVYocTttSLSwnCHs++r/8PQfr9ujNDsUzBCFRbP63OvQZd/MgzVmC8MKM
nIhGG7MNiifnCcJ5k+Ylkuh8X8W1d40EQcHJ/xhjNu6PBR2bBfYKwsSa/KaF
syhyPM3BP79cEBpes44WK1JkZ9NInWGlICQTfs+baBOhZK2qakGol1rsdR4t
5tX2ufG1IMDk4IPt6ESdrTaDzYIwLDKwdkqBIjll27QX9AlC3qf0o6borq7t
vTeYQrBL5GzSV3mKlDMm18zjCIHXqifqdegMuHrtgZwQnBF78+IJ2utWl33p
TCFwLF+7LgY97O1S1TlXCC69TNRZhZaa2JEmt0oIlizdmJEoRxFDRTen87uE
4L/ClnBH/M5bNpPZsHG3EKjIRHeYorWVytaJ7BEC3VA54yVolVkzl572EYKW
FssNomgB1SbRoCAhOBvHsS3kUOTVfJMCtxgh+FcdoKWA3rJSjWnwVAgydLv9
+1kUsVnVEDpWLARlM6NWdKA3GoRM5JcJQVJfCuMletXqzl6daiGo2Jk5lI5W
houlGu+EoCHb/ZIT+tsGAW9WjxBEKvzSf8fEeNj69UUfUxg6Vn9weCGD+faw
wOErHGFQUx29UIB2TVbTNJcXhvubn73PRG9qdQu7pyQM4v78V8PQunbf1h/Q
FIbKpC/vN6KHrb/XDBkKw4O77xY1MCgStL739bSnMPw67tfwQ5oilIfI0dy9
+PzdWd8+oL1CNRe4+ghD+rZMwXr0tmrPqIqDwpD5S/pAHnqlyX/m544LQ6//
m95j6L9GfW/FLwrDvk/Wzix0iH5/nWypMJxTEZpaJ0WRBakPNl4qF4Yj0fvO
GaDb+QKqFCuFoTP/qLwOekntRJFKjTAMSR90UkB/cZO+Nb9RGBKLMl0HJCli
Grfk6OoeYdgg/sYlAS0xcFhzt7QIpNgkvu/H7/pCW8P0XhkR6CntuvkZ7V74
T2kvWwSOdWQGtaFLTkewDswQgeNylwwr0fsVUiaDVEWA/5jAshR0w7rSpvP6
+Hz78W4LdHKa4MnHLiLwtDe2t0Acx9/ayvFxFYEsB6Z0DnqmRFbWXHcRmLp7
zigDfSPAsinJSwSc9FVKYtFZ65M0jgSIQKMjn44X+tlPzdrVkSJwInzyqzL6
40pzxZf5IvBKI21NjBjmr/3KD0KeiIDsif6Ec2i3jN8mK56JwArTid/H0L2S
CT5Z5SJAeJbl+9C/P30oj3ojAht2l9RsRPOF7ve0+SwCL71NMZVgPmiMe9wh
KQqpVod7wkWxv5aiHHeGKKxVLa04hWbVnPD/xRSF18urbgWjp0v2LRWQF4Xs
9qEQb3R7lmnuwjmikCGx4qwNOurUeHbIMlHQ6ux4oYCmdFwz5rqIwvwRG/GH
Iji/sTrxfg9EoY6a2kgJY/zNV1j4+6EoGDkJVPWjsyr4Xng/FoWaW5omPeiE
4cZxzyJR0PlTbNOJ3ucU6OpSKQq7lyffqUYraD7VMW8ThUtNE+tS0IGlJvXq
06KwymBqlhm6f8tCr3Q+MVBdraFninalOAKzBcVge/tHS4K2UO/RnykmBq+n
BmP00WqR4deYbDGwalFbr4ZusK/1mdIQg47XGucnhSiy6KeDZLuVGHw3OGGR
jy6ytyyPshWD1spf53PRpqUmAcZ2YvCtW7MxG+0cq/Mhc5sYRN/p3puOjloi
fi/QXQza9HqbY9G9gSXm7GAxmPdNO2wfOm1KLcrqlhjsCSxbq4HW9lQ05r8j
BjnV1rKq6Cf1Mrz8u2Jwelz+hzK6/sako3KuGCirGN+QRU+tadMaeCoG114d
NBJCO4VFvo54Jwa6nu+MvgtSRFaGEqv+KwZ8bUT3DrqlNCrcbEoMkpjdz2+i
E300RN79E4NLz4o3p6E5b5wEO4XEQWCl6qkraHboi6lBhjj0e2/kj0YzJ1J4
SuricPTw/pSDaKn/1nUFWIjD9S/vOARdm/TZ6Y+VOATXHhBajY42PfY+xFYc
crUHx1aiJTMetkU6iMPwicj/dNESLkqNN3aKQ7zl+z5NtFgz9eJtgDjc+JB4
UAYtXJ6aq35VHA7mHIr8KoDn5WrTjd3X8X0LxpO70Q+f/fycki4OlheO3+lC
Oxcasdl3xOFdU0hjGzrvfncgX544vDKXNXuL3nFV3eBjjTiMk56qfHRR8L3q
5CFx6K2ra45Ex47ZuWweFYcisfeG4Wj3Q5Mj0n/EwfNP5O1zaMZBq3mh0+Kg
tbzp7Em0h9dgZIC4BFxb88jlEJq9Vc/GdrYExHRsj96F9llW/F7cQgI+y4VU
GaIrGlpziqwkoMW4O3QVWn4/dXKPrQQwd500X4F+nqmh+cJBAqYvBXTqomVn
xPmfcpUA98BfsgvQJX92S44dkoBsJUOeAlqqnGH0PU0CfghsIuP8FNm1XYuZ
cFMCuBOu60bRhWNrv625LQHiej5Ww2jXJcGRN+5JwMb9Pu4UOj/9W6tToQSs
5/94uw/tfK7oQONbCQh9Uhv5Hp1j5pZWNioBmlLP8krQ+tqqxuSPBOx/ephd
jC5jfP5QPiEBe14VBTxFNzS7zKjgk4R7LjUGhegRF8fYKglJGB/s7cxFG/vb
Hn+lIglXNozvuoluTDHe1rReEpTSBk6fRzudmBrZbCYJheU5MlHo7ztLEpot
JOGjyavrEejRuQbvWmwl4ZWHeEUoemau/vp2J0mw4I+XO4XeXaW9rOuAJJQE
p00F0vcPzGT2JkuC0Hq7ip3opGv/1Vy9gv3zNXHegV5mk3/S7qok5HSljjuj
/fOsBp+nS4Lgi3B9J/TvI6fqU3MkoUFI+bk9ule4N3pTpSScCZ2UN0e3zX4k
XvpLEgK/KlTqow81nqgIoCTh78Fb4cvQsmfNgxcMScIfjq+1Hnpz77e+S+OS
sOdsSfcSdH2O/Ct/QSnYzi/H0ka/XHU8bL6iFByXybqvRq+f3QbBRFMp2NQ0
9IKJjrQoClXeIAXbnu6tkqHXa62WWKaZFJgntFQw0AJ6ktKF1lIwdTK0Qgpt
w34n37FNCkI5hrVi6L6GLQuU90uBWvliBj9aydpz060kKRiv0zHm8VHk1MbQ
G/m9UlBwZWBOO7pph5fzkh9S0KYl4NiG1jhkoZgzIIXz1xTfin6Tzkq4SUlB
lfc14Ra07MS1sIt/pWDr4TcjDeis+4X7/RjScH3Zr7E36EZ2n6H2cmmonmwP
KUfP1Xo7fmelNJyR+VZbhj5MHhSoG0rDpsMJSrSVfQJ1lEAaRt9/eVaC9nzB
py5hLg2VdnP5n6H/BilK9LlIw+PrJffy0WofzTtuhkrDhKnhoWx0VKVhrkOE
NEwnu7y+ix66ox0mel4a/mkuUqFd7c9Y5h0nDSc3NL6+g/YQa7qgmyoNY6kz
tTLp/us5bqh4KA2NnsqiaejFUXsKP32Qhk/fHVYno5N9t8XEfZIGx7zOW0no
f/Zmu02+SIOv3rg07YbZC9m3e6XBsv/vlwT0wYLf+/dzpWHVSUZ8PDr/8yGN
SREGDJb3S8SgDVecS1TUZQBH9+jec+gON8Xl15YxIFby+8+z6MDYB+1zVjAg
TKHKj/aDno6Z81czYItsd/AZ9JzERenL1zNA9dqZ+FNoIW7bfTsnBrxNVWw7
jq7N1qqJOcMANa27jw6hvdrKvFihDGCHD5jQFhawl0gKZ8BSTnJLINrYMcTq
ajQDphep/QlAPxRtbs5OZoBpneQGf3Ti7uOfa7IZ8Li9YeQA2kXl3R/+ZgaM
+idd9UIzFf0LilsZ8Pza96W0KzlyBw91MOBrQlrNHrSm+Pa+vo8MyNN0GfZE
U0O9be/6GHDrW9dmD/S519OPr00z8Hv3krobOjtw8YFVC2TgVJoyyxnt7Nuo
NaQtA+m3lj/ejpbZF9iToyMDbXsfOtAO3PnMeY6+DLx7WJHqhDYyX28hCjJg
nGqr7fj/9dkxv9VBBhKDa3dsQY++ifnqd1oGauvyRTahuyRbvSbPyoBnXPhT
W3SVpfJgeJgM7G6+6UM7rj574vp5GRivfNJsg17QVCNblyQD9rnrMq3RO97z
b9DKlgHDj6UOluia/w7d+9IkAzkZVv0b0JYCOgZabCaYqs9tIXT8PDqf4sVh
Qr1/xGXaebv6/t6RZcJj77kutBUq0os1ZzBBNErgP2P095OyRnOVmeDVtGnK
CH186g+ZrckE8XnMZavR98ar18kZMGF676NXK+n+ZKnetjdkgs+ruwm0mdtC
RBJXM+HtveYdtA8/WVHDJkz4vrF4ZAXa5HD2RqYpEzzft2jQ7hy6YCFpzQT7
YvEL+miJQadN/G5M8PNaf04XvTGsrGy7OxPuzVDeRDtslpp24W4mrL+soUJb
wPKHiPceJnANm4uWov9kBZW0+DBhYEcCtQTd55Y4LyuICUoGR/fqoF+21U1Z
xzBBkhV2UpuO5wNLve/GYv8XB26mbSKc1CEYxwRh7gUN2mV6zo+LLjLh6H2b
2oXogrh+L7XLeF1gQIn2LXPRlpEMJmgk763SQp8tg+yrRUw4nGWnO48e35HR
ye6nTCj5bipNW1cvx0a9mAmFWo59muivd2aM3C1lwoRZ/3XaJvG/yZNKJtSY
3ZOmLbD7amtjLRO0e85z56LPiI/ziX5hQrvkQKMa3X7VfTvzr0wwPPXvIW3d
EPfbMd+Y8IajF0f7K6/eQraXCU/Vxqxpm3RlJqsOMEH+4WCdKt1+rp326hEm
rN0Z2TgHfdo+d+tBcRa8Vk79rYLePer95J0ECy7uHainvf7y/BmLpViQsdA5
l7ZUV3pbP4MFPuev+9G+7J7osFuWBZTSzeFZ9P72D7bbOpsFSqwLArQ/xa21
MdLH6x/l9JXQFbp8uanLWaD133JF2rdaShh/V7Bg3onAqZnofQrL6wsNWJD3
3vQl7ZEb862WAAvWLFzhSFsqV9pC3YIFaoZm5xTRBnXt68V3scBEdtfvGfR+
Dqlbu8uNBcp7bNpon9SpgqfuLJAZdCijXR3/wGCvJwv0je7F0rbeErr4tTcL
ti0IXELbvVtXPvIwC2pP7Tsij47mxvSIRbNgbtQGRTk6X2ac/eoawwIJFRkh
2o12wd1FsSw4K/7ztyxavnD3e694FlTE91TTTj9qWPcqGZ9ntR6kXSj4Iz8i
nQWXQxLecdDdcqbnxJ6wQDv43xU2fV71n/c0K2JBs+L5CNrbypo3Rj1lwfTM
eUG0mzzdpaVKWJDDH2dPu/rJmWSZChb890SdSTvbsSJL/i0LbNLWRbHo/HXN
uG5uNwsS/kpFMen1ORiW6/GZBacmw4/S/rWuPv72Fxb4xrK8aXv+dtky/zsL
eAttLWk7khPdC3+wIOBdsAxt4y/FXN0hFthLB1yWQYtrrJJfI8oGW8uMfAad
Dz+HC18TY4NifE4m7ctX24bHxdkwKP0ymfZ82cDmh1JsuH9QM5j2esHcuDls
NvxbmmpM+8yXuZJ8s9ig7ryhVho9eY3JV67LhugHa3lS9Hgddw7OXMaG/xQV
emifl3vw6bA+G3r7/7TTnhljUbp4JRu0wntKaa88Hnb0uhEbHi/dHkX7kNPk
8ImNbLhwN1+D9m/5vh+rd7BB5NkLD0m6/yMRZad3sqFzJc+J9qMWrYSXrmww
5dOypR140Xu1rTsbmCYFBrQnpAdj3b3YcP30BiZtMeFRvSh/NnBjzEsl0OpD
giHtYWz42R2pQnvbu9ls/1w2qHD4J8XQR0v/nH34EK8b3hyinXqveeT3Izb4
6VgN0P4UHv7eO58Nuo5FnbTdYTDN4ym+b6D/Ke0Dj8p0HKvYIPT5WTDtcwku
VtDOhvL01mlR9O3TK8pDOtiQF+0+RrvGl7W09D0bsj3HB2lLWL6QNehiw9K6
5V9oXxBa1KX3hQ1H84Sraaccmtw3b4AN+S69UbRzt6ZGMP6xQXxuxCzazouO
i3rxcYCS3iZPW0zQJayCnwPRBjoytF0fqJwLFOKABRnio80WzjjZKc6BF9qN
30Xo+czLOnxblgOMtZ/u014pXbjbeAEH3Iul1tH+/jX526WFHNB0eGJMO64o
yI2rzQF9B6+VtH+4r3K9pcOB4P0fF9JOeVayXUKfA/82cji0J/dUbW4jHDgw
L+urMJ1/KhvggAMHGrMswmhHFAtmPtzCge2b5U/Tts5fLj60lQMLenqO0e7M
vNoY5MQBoccJB2kPR3i5nd7JgR5fLRfamjZ85xL3cuDXoVX6tKM/6NQ8O8GB
dYO1fULozS1uC6dCOJDJ1v5OW7Eu6QI5xQGNhAvdtG+XTWytPsMBt1T3Ntrl
6TV9deEcuOtAqmnz9uyU+BLPgZqvFWm0tw3HWone5kCvRIcz7Zf1Jkt873Bg
70/YRnvZ3VF2exYHdDMe2NGW2bGj4/Y9DswIumz+//trFrmvf8SBlasyV9LW
T609ElrCgb8V1+Vos00kbgk2cyAAqCZB9CnlsjDvFg6cNuyvp/179ODe5lZc
X/++N7Rf33u/+GYHB+6f4Vb+/365u09NPnFgXo7+Y9qDfRvenf7BAR+XM4m0
nasmHv3o58AdsbI42m+u5SZu+skBm+ypaNq3N89wUh3kQNHziFDaO0p6vz8f
5oDjq7rDtGuTU2rmj3JAoWB+AG2Dg9bZcWMc2BcU7ktbTrPQ1/Uvzp+PrRft
M3z7Nr+a4EDHpWe7aVOds/SXTHHgd8T8Xf9vv6BxxuVpDgwZprj8v/0LoX//
/eNARY6ME+3/AZoUd/8=
        "]]},
      Annotation[#, "Charting`Private`Tag$36582#1"]& ]}, {}, {}}, {{{}, {}, 
     TagBox[
      {RGBColor[0, 1, 0], Thickness[0.007], Opacity[1.], Dashing[Large], 
       LineBox[CompressedData["
1:eJwd1nc8ld8fAPBr3HBdtztC0jAiJEQayDnK3mVFKTuyyggtKjsJ7VKpKCGb
SPaskFEkpNJQfLkee//O+f31vN6v87zO+Xw+53PO84g7+R505SSRSK0cJBJ+
dlT9FSSR2KCFULSKGB4Hiav6glaR2YCTJ5b76dQ4MDdu7aFS2OBNf7jJh8Vx
sDqpSp21mg3KWZ5hqZwEaO3OfyCyhg3uqh2Rf8FDgKsb0lY2ibBBmBElZwOV
AMbOtx2lN7LBx6yyJmk6Ad6OnpVSkWGDRxZtOcbCBIje4RO1ZxsbyLRw94Sv
I4DuGYe/QJkN9r++1R23gQB1ZJ2Xxhps8AX2G0tJEuCy0a7VFlpo/oe8Wyul
CLAvUfaUrS4bHFO5YqohQ4Cq9TRVN3M24Nka7TUsT4BQJ9JtLys2aLv74Ie4
IgE004lZPzs2yAj8UaG9nQBvVLrfhLqwQdRtsVQrVQK8MkzRvhvMBlDzTGud
BgFOJyQ9e3SeDU4dnGsM0yTAjq5w3meXUD28RcO3QwLkO3o058exgVaiYYH/
fgJkBytbNqewgR0cVY0xIIB3xebijjQ2KPD6wTFvSAB5buG1PRlsoHJgt6mz
MQEyri30/ipkg9F79EwxMwKkPatzXmligyUTF1lTSwK4jBTXk1vZINtpuCfW
igASyi+2UDtRPn8DhWusCZBSfnV4bT8bRCxS5sVsCZD80dpfeZwNJMPqGGn2
BDi8zuDT7mk2ULPNmHx9lADrHNR3gQU2mPx4K735GAFuD29aMCKPA4+/3Bw/
HQmQxPn3kqvIOKDFHbv+y5UAMUpnk+5ojYPlOT4PA28CBKyJkeHXGwdPX56T
U/chwNHZWxXnjcfBYkd3kawvqk9V/j8nm3Fwwa/yzNJJAnw1+7dvm/c4mN2k
2XAxgADKvrYT1XfGAV9lXCL/WQKstzges+PhODBzpC+2I/PsCtz0/Ok4oMde
lr11jgB9ywlGcdnj4HZt8rzwBQJExjc9ta4bB3quG1I4LxLgy8tdlsNj4yD/
oIz5uUjUL4k6/+xR39b/Mb8lGUWAnECLsLb5cdAjV6n8Fjl8r29WEZkAdq6j
satjCKDQ8ow7TJQATV2k0zFXUH+NCBat0SOAW+K1e7sS0H5tnRTUfEiA419u
mjy+g/rpvqGW5VM0b42LmNBdAnTwP/Y6kU4AdbNaaixy8IhJ7a18AuROH9nr
e48AtS+fnxxrIMDjF74GisloXaXD71PGCHB9zFkr+hHqf9WaMC6tCRAiXbXz
ZRoBetPWZonoTgBp1SudfM9QfEK+3YpGE2Cvid0HV+SP06IKR6wmgOe6+H+i
zwmwqSSwt9BjAjQ/LegNQ3EUq8nudEuaAO4CCnMKmQQYBAnDTYMToHTl9Q2p
XLQ//727Uj80AQYDQ474IkfeI8vX/DcBLvxQyi9Blps641U2MwHkgs/xG+YR
4GSG638v+SfBCQ3/hOMor6U16mNJKpPgzt2befGFBBD+94s4cnkSmLdLKV8v
IYD7bbHrttGTIFx/1KsN+bX2YRXrq5Mg9dVac4FS1C+P2vzNbk+CZS19ZiRy
qmXZpFbmJIgbvHvH/zUBtlcmTEt3ToJtih7q4A0BjG6oz7MlpoBT7sfp5Eq0
TwOJrbYyU4DzYXDDR2TdrUNParZNgd1/PmpTqwgAa24Y3dg9BbjvKZqfQd7J
/i95l+kU0DztmH+wmgBixingQsgUOGC9ectUDQGmucgR/G1TgFahfpcb7ZO/
2WHbgE9ToE1s0koFmX0vb1v/lymgV+nc4Yg8vP1oV/avKUA+pkKtQP527NWW
gwtTYF3O4DX/RgK8L/N4d0d6GtSChzs7m9D59G9dLX1+GsyH1DQef4/qbeQd
onxpGhSceJoWh+wpSR3UjJoGgTtcrPOQd3YaFNskToMGj+Tt88gtyvVHYtKm
QV61R1dMMwHmx8tejLRMg/Ux9azHLQSwPPlif8HGGRDz1EEw7wMB1PT1X1ZK
zoCNgleb25A3if0RapaZAZYrtkfZyP8+bP73U3kG1DdnMxXbCHBRMSVBSG8G
OCWK1WUgZ4/e6g/xnQFc7pVB99sJwOsdHgSrZkDIz1NnnTsJIDKoKVhaPwNU
/lioXESWs53L3/5+BtQOnm94iGyi4zMq0TUDjhhFhPYgJ2045EoemQF/E432
mXwkwIbWrRbvhGfBN62i3Qqf0H2g2Klg6TsL0l6a6XR3EUA77Wpzc8AsqAxR
f8tGthLVP6FzZhbwtF5XoHSj88VTnrYzYhZQh3c91EAuH3i2XuT+LFjlvSSY
gqyfcIbytWEWGFlwxjl+JoD9uPjv4xvngL796ecfegjgk1o12yA5B9Qn1bR+
IV+wOcYvLTsHQmo1a+aRH5YnK/1UmQPKMtFnpL6g+ytG+KyDwRy4bV7QGIJ8
VEKAbhswB6rlddkbegngYDG7x/DdHNg/0Wtq1YfOy6rbxi8+zAHD+hKqO3JY
qeox3k9zYCX4ZtEZ5JRN/uENA3Mg9MTrpkfI34f/a903NQe+30ueGUJ2Ch90
VhebB8lecfFB/ej+L2q9Kn96HvCZHjOL/Iruw8kiVcWz8yCHcjbyJrLVjgf9
28PmAWfC0stUZN0Cz227YucB9/7Q1hrkLXm8LVoP50H3qIfNMvK/rH1Um4Z5
YPJT6Y7fAAFOpRbHXhRaANmEhZH5NzQ++EA5XHQBvJCMzrVHdpKM+BIptgAW
Lu7m9UQ++MRCLk5uAbzKNbwWgbwjhf32luYCIJq/LJUiz96X48tyWwD6nnc8
xL6j+l5/GNVVvAAiihgDg8gSpx4767xZAO3KF7LZyA2mqaCwegGM9omcXEKm
UTJmEpsXQECM2DuhHwR4FFZ03OTHAkgQUOnVR67ybtarE1gEJecdQzOQOfXn
efJdFoFahbi6yyABnkktDYqdWATi4698fJENuUhV13wXwalup1tnkJMqyMHe
ZxYBZbtCTQKypCpjSCZhESwJi159g6wtIdP0qGwRXKtmLDJ+Eui7ahV9lbkE
yK+W7hQiJ7k9nnskvATCKOI15cgP20ZO5K9fAh+adH40IBenXjbpll4CqxpK
eXqQh4zzmOLqS+Beh+XQIrLxA+qDQuclIDtyhnf/LwIwNWvzeguXwPcEV663
yI9ClXplbZbBgiyztPw3+j+QdqiWOLIMnh+g1NYhF7dcey7quAzkzh1ueI/c
LDrmL+C5DFxfSJb2IM++ekkdv7AMHDzI5lPIB9lymiXPlkEPV4P+1j8EIDtK
PdadXgaj18KSkpDpvFZRYGEZaJ3m/3gHeX1OuPdu0gowEC9Z/QhZeWlwjxxl
BTSvjQ/MRD5690mHwMYVMGnRulCLXNK+ifuTzgpgDdydmUD23LfuuPPNFdBo
MtJhNkSAJ1GuF5vurYB+Mac+K+TPzbn3t6WsgIG+8oHDyLo2em0zGSsggU/r
43FkCa+APXFVeH65wFD8/s1W/qLhFSDvzkh+ifw0QOsQlzgJHuJdTif/Rf9z
wsd/FUmS4Fp99QUK8pfSOD93aRL8GCSmT0emr3THtWwlwSjpufZ1yBdifKpv
7yTBqpjQZ4rIdg/vy8kbk6DjVIbNIWRG09SiZRAJnq6/tpKG/C230rInhAR9
6FMOGci5d2Oy7M+R4CkbnYpsZHPPDUfcLpLgzpfFXq+Q42k6ZUFXSHAg2vBu
EzLF6kbIvUckGPD97o5/yNw/lKcHGtH8Ihvj5f6h7/m7RROXdyQoQNUOUEB+
WtCQNtRMgvzKzdbKyPsi7KzG20mQyclgqCFflLlUyNlHgiPWLXYGyMs+7X5S
bDS+i6J7HHlmwXfsxFoO2CualZSC3Feg5yglygGfdjGsU5FrPDd1DmzggK0K
BYLpyHG9rcWWkhywxaQkJgdZomzbBU0FDrjFe7dOBbLpmWEqU5sDpgc5C/Qi
p826yZX6ckCWqcwiY5gAsbmayf5+HPDOHWAqiHzSXYimEMgBd9nxPFiLrPa5
fvzJGQ6o/aVIaRNy26vNpXERaH3h/5TkkRdP/9BzuM8Bb6pn3tZBtpiyd+Vp
5IBHFH+sOY1c8v45o+gtB2SHPZ8KRl7/ZLzcqZkDUjUfdp5F/m0aIVTRzgEj
VbZGXUQ+k57VGNDHAc9yMlrikFMOL8j+GOeAZc/9up4gj1bfGX2znhPuTpIn
mpGj4zuD/Pw4oazZix6REQKIZ1aPjgdwwkZf80lR5NeNOa6ngjjhXje6wEbk
EVKcxclznJCz9/tuCWRzf21Fn0hOeClnIUQOee2hot8e9zhh8/iVp2rI6eK3
rRxrOCHY0/7IFrmx0E7FnMkF+239biYhn06xriMLcsF4Sa/jN5A3xx20KhPm
ghEDD3fdQr7kbBgkvYEL2msUd9xF1mSqlS1u4YIzkf0TKciFviL7X+zlgmpe
CYPZyE/kPh/k9OCClL8a4W+Rz6VY+RVWcsEAt2mJeeRjHVMt6jVc8M+ekqAF
5H3ct2Rr67ggvKb9fhGZ173rW/tbLvhge7XPCvINRRuzsU4u6AY9nnP/R4Cs
ikPyckNccMd+92805L6+w78f0bmh4N4rwRLIlbRFrS0sbrjvRF66JPITmPwg
W5Ab9lXUdm9Gdk/tsyxfxw1JnbnKW5AnPe1rv2zmhlkbmnq3IlMXjqYI7uGG
8iO1CzuQ1UWc7K44ckMDmagQXeQd6+ht+i7c0HBr3iM9ZHnRCp1Vx7lh+KXX
dfrIGzes237RixtKP/PlN0LmFO/gCQrihgdbL10xQ26S2VfkdJUbhuhq2RxC
tt4tQVcr5YYC87GbPZDN9rRFzJRxQ+HZQpkTyPpqFxYKK7jhwOzAVk/kPRpf
fivWccOSCQ1Fb+T1MKlc6gM3lJNTkDuFPKjH6cn4xQ3rxOvHg5FP2vyoH6KT
4a2N5q1RyEOnOU/fZZHhuVmt3Ghkh1sS0oZCZHjpiV1iDPKBT06RmaJkeCSP
68AVZGWLQV0faTI8HWvUEI/rZfqzcUKdDLdIucXcRA7S/f122Y0MDRQ1g54g
X1D917KmnAwFf9ete40sdz9b/3YlWj/oUhV2N8m/VqSGDEXSM13LkJWaF0o2
NpJh5eK+7DfI350EUmXaydB/5vruSmTtBKUzGr/Q+6XbleuQKcOnpV0EVsGc
0M9vWpBvpXCFFtivgsvk/YYDyIc+fWJ5OayCN3Z/7cFeR0lP3+y8CtppjLp/
Q37kb9xx030VfPXJJ+I7crruTalg/1WQROYoGUR+PSLdrBGzCrrr9HMNIffv
NhRpKFwFaU/n97CRN7cnFHzm54HasU5qK3h+Yx6WM40Hbpq7/RSb0Xje7z86
D4wz9qGSRtH9+ObEdk4hHpg2v9yH3Z2unbNVjAcGtZeGcCLHhs1mXNjBAxVs
Bh6TkdmKDk822/PAzRmyOfzIb+IVE09m80DFvvetQsjKMmu3jubywIV8AXFh
5PRqUr1nAQ8kFazyx74+2T7rVsIDDyltElqLfMIuwMG+hgce3TJ+SAR5rXSp
omEXDxQ+b94uihxQvq9VcpkHbh3NihdD3jZixd9twguPTGXryyKXWBpXxprz
wpHHcgnY2uX7/DUteOGvXMdu7CPxir1ph3hh2TKnqxzOR4kvM8CZF34OFzm/
Ffl3wBtDZggvDMttTdmGnLIkEWuSygsNu+gl25HXrGbz1s3zwvmQUeU9yB/L
Y6MMlnih2oDLcewbXlKrPqzwwmNGWfexWe/suL5w80HT79lcasjMiPqlMRof
7L8Z1Y5NX7hHiEryQev9mS4ayNQ/On3+RnyQuvDRAyCTK+/nSCbzQYVivllt
5C8a2voDD/ng3vpgKR3k3Ncj3+495oODtWUHsY8U72Uyn/NBukZFFnb+y4EA
Uj4fjHhdelQX+WiypFp/Ix+UjMl5rYfrFZJZd2uCD95mFlgYIsfPWNgfnOaD
FdNjZ7GdAxenBOb44GQXORWbdspkS8QyH+wWL5/AdnUfi/Hno8CeBftEI5yf
jYqZ+SYKTNseU2+M7LWjrIfPiAKbrlxkmiFXt33KKjGhwEy7C6rYQt7s0OPm
FPisz/YQdlWalHS9FQUeCXr5AHuNcIJfmAMFtgW9kzbH/TXnwj8TSIG/u6aV
D+B6VdL2/kyhQF+jERUL5CwDp5SKaQpU64j+ao2sKi+uCeYosF8AzmJX0L71
Vi5Q4HLgN4YNclunvXA1iR9uF+3Xxp6yt42vpfDDPezGF9iafubnmjbyw0Sl
QN9DyO33NA916PJDpXNF/2yRp4fX0X/f4ofzOh2pR5BvPvjTmHyXHzbWSpVh
7zArDLVI5odN9c7t2H75JmNVj/mhYfqjJezR4LDW+1n8kLJFxMoe9x/5d9yB
Gn54v24z6Shy16Y8vvL/+GGppIzeMeRiCz2uG9pUqJPETnZEjjEqiVivR4WG
HQdeYh/ZL8ubZkCF7w6nlmNzqvALFJtSIf/FDV+xzZgfhD4fosIDlxw3OiEP
tVnLrfemwskM9WRsUVO3A6k3qdDnT8JVZ+Qw/YhHhb+p0MnA3sAVueOo+xGl
v1RoI6BkjS0VaCSSNUyFq6JmnLDfPWZcf8qmwuUal3PYaxYeRCbNU6Gfb2k2
dvrLYu+TNAHooWLJcMP1ZA6py+8UgOdrE1uxJfoNPz+NEIBW4tJb3fH5rFHP
sYoWgEpks53YE8/lI3muCMBvwFsLu86PtsMzQQD6/IixwXbl7bimfF8Amq5o
X8ZOV7HVq84VgK/3v/+MrRB7vPhrrwAsrD98zgNZfVf4DRFlGsxJvfr8BPJn
J5GdD3bQ4IUDVTnYAfHZ3WK7aJCcO/wKO/vX53UyGjR4Mlm+CVvsxrbHO3Vp
0GDQZgibe7zrpYUdDS5+sN3iidycIdt49RINml3dmYJtv/HDHEcnDRKUhxe8
8PkX8Ssq+0SD25tKI7BrWIKnAj/ToP/z1jhsab7DQ0P9NPjz1+A9bPbE764P
QzT4WaK8GDv87XLBg2UaLNFS+g87I0DBZ4/cakhT07Hyxv357uqPkxdXQ4+i
IJYPch//J/fFy6uh5czLtdi1xuvHoiJXQ4eIgQ3YCa0ZCw+vrIYH7uyQwZbr
aFzTcnM11KY818A+2sOhJ5uxGr7oynXBbvwTmPm9YzWkaAbkYRtzKqrJMunQ
2jBR0xd5Je/KPXcWHYaMpe7Dznccmn++hg5N5gp1sddWPy6TFqbDav13ptg/
Q9fs3byeDoNU3x3FPrc0BzZJ02H6X/EL2JmzdTqCanRIW6/7GpsyZneAw4kO
P13mkj2JrB9ZUXHYmQ5Dr8TLY0dukJAvdqFD1jYhJWxO47+rPI/TYbSx6C7s
ufSgNx+96NDBZkkbe8jpxpb0IDr8fkDSAbuhq2XJ9CodTj6l3sC+XAEzkkvo
cF3LLIH9JXh6caCUDve+SJrCVlbJMpMso8NBJblZ7B/PhadelNPhc6ODS9j7
EkfBqxo6NGNH8pzC8bgkf2pvpsP9mZdFsS/xzZJ4vqN8+z9rYV+0zLE5xceA
TV8OR2O7THu++kBhQJp3ciy27h0ZYQUqA5LavsRhU/sed/2jMWAX40Ai9h3n
G1YuaxjQu1zyHnauX4iFzSYGTDvnnIn9NWG/2V5VBlQtsGvGrlYm5dzfyYDL
Frat2Kkf39DmdzGgJ9m6DfvE2p2txWoM2PrY4CP21CMZEyXIgN8Ikb7/r58j
YCRpxIA/Ux2GsdVaunX5HBlwc3ISrx++ny607Hd0YsDg+6YU7FDFWljqzIB2
E7xU7LrEbDUPNwaULgxejW1qHaHw1pMBY7O0hbCdB5SFYk4zYHjNNUnsuPGr
v3jjGNCBY0kDe0BQO5z3FQNmrFzyxF7/74qbQQkD/rF864V9qKJTP7aUAdWi
aT7YHW7OAtQ3DHg27ubJ/6//6tKt1dUMmCRzKxA7w7Y6Xeg9iu+eUyh2wAPN
ls0DDLh1UiEJm09qj5AWDxNeLWgqxG77FkV+wMuEMyODRdh3krsmZ/mYcHrN
cjG2zJqAzlwqE8qrKpZi63LlJIgxmfB8b3g59qXvm/lJG5hQ5fZyPfbiAzqp
UpkJ7VOVu7BHhYb+ahxlwtTUtgnsvI+y1xscmFDP33fq//EleWqYOzOhri3/
DPaCwFi8szsTGp1Vm8fmJU+rxPoxoXjVaZI/suQE14XuSCYcTvKkYh/6sInp
l8OEl/OPS2Dfz+ycGs1D8dtnSWJ/jYrq8SxkwvDm0c3YznAsxbWUCfP5vLdg
++RVKNrWMiHhbCaPHX7d3gR2M2HfWLYqdo7N/WjaChPGHCN0sXm57COrOVgw
ooqqj+2QvTE8gJsFe3mlDLCZ5CehX/hYcPiQmRF2QH766WdrWFD28BUz7N0C
xS6aciz4zzXVBru6pg36WLHgGo4AN+wvacntQXYsOOnGcMeejHZ3uniMBf3X
vPDAljYjhd/wYMGZ6EYv7LhexcbX51mQj1brh/2sYsGm7hILbi/fEYBd+bhx
qCWKBT3MHwdiE8ePUb4nsuBHa8/g/9dvMt6E5xkLfhqpO4+9+ujRz88yWfBM
pmoodkPjNmfdPBbsLE0Jw1a93xwc8YYFLalul/+f7z5KKlcnWp8nNxr7bWaP
wtPPLFgQNRWDHSb4onTfVxbsWlK9gj02pPfh4l8WrBdPv/r/eA8K24mPofGJ
nnjso29+/6yaZEE2H08CtqB0sa/DPAtyBSsmYjdfi5hfWWHBeDOLJOz/AYNR
f2k=
        "]]},
      Annotation[#, "Charting`Private`Tag$36622#1"]& ]}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"\[Tau]\"", TraditionalForm], 
    FormBox[
    "\"\\!\\(\\*\\nStyleBox[\\\"H\\\",\\nFontSlant->\\\"Italic\\\"]\\)(\[Tau])\
\"", TraditionalForm]},
  AxesOrigin->{1.000000081632653, 1.0000031965271747`},
  AxesStyle->Directive[
    RGBColor[1, 0, 0], 15],
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[
    RGBColor[1, 0, 0]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{1, 5}, Automatic},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic},
  TicksStyle->Directive[
    RGBColor[1, 0, 0], 15]]], "Output",
 CellChangeTimes->{{3.8003175548707027`*^9, 3.8003175701328983`*^9}, 
   3.800317607763579*^9, {3.800317749411677*^9, 3.800317791341212*^9}, 
   3.8003179514235754`*^9, 3.800318033856316*^9, 3.800318086621545*^9, {
   3.8003182010094967`*^9, 3.80031825002969*^9}, {3.8003186880100346`*^9, 
   3.8003187489262576`*^9}, 3.800318919131569*^9, {3.800318967840953*^9, 
   3.8003189770411367`*^9}, 3.800319017326908*^9, 3.800319059576162*^9, 
   3.800319112524501*^9, 3.8003380847357664`*^9, 3.8004509171683855`*^9, 
   3.8005904877140994`*^9, 3.8006745138353815`*^9, 3.801028927811447*^9, 
   3.8187724353825073`*^9}],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[1, 0.5, 0.5], Thickness[0.007], Opacity[1.], 
       LineBox[CompressedData["
1:eJwVl3k8VP0Xx++MfckyYydrDbIvpehxblIpFFmy5anQIiIteFpUKJ4iSSq7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        "]]},
      Annotation[#, "Charting`Private`Tag$36662#1"]& ]}, {}, {}}, {{{}, {}, 
     TagBox[
      {RGBColor[0, 1, 0], Thickness[0.007], Opacity[1.], Dashing[Large], 
       LineBox[CompressedData["
1:eJwVkXk0lG0DxjF2ssxjCSHLkGZElnwvcd8UCqksCRGD+oRsJa8UipDI3kJF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        "]]},
      Annotation[#, "Charting`Private`Tag$36701#1"]& ]}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"\[Tau]\"", TraditionalForm], 
    FormBox[
    "\"ln(\\!\\(\\*\\nStyleBox[\\\"H\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\\
(\\*\\nStyleBox[\\\"'\\\",\\nFontSlant->\\\"Italic\\\"]\\)(\[Tau]))\"", 
     TraditionalForm]},
  AxesOrigin->{1.000000081632653, -11.554838201938168`},
  AxesStyle->Directive[
    RGBColor[1, 0, 0], 15],
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[
    RGBColor[1, 0, 0]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{1, 5}, Automatic},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic},
  TicksStyle->Directive[
    RGBColor[1, 0, 0], 15]]], "Output",
 CellChangeTimes->{{3.8003175548707027`*^9, 3.8003175701328983`*^9}, 
   3.800317607763579*^9, {3.800317749411677*^9, 3.800317791341212*^9}, 
   3.8003179514235754`*^9, 3.800318033856316*^9, 3.800318086621545*^9, {
   3.8003182010094967`*^9, 3.80031825002969*^9}, {3.8003186880100346`*^9, 
   3.8003187489262576`*^9}, 3.800318919131569*^9, {3.800318967840953*^9, 
   3.8003189770411367`*^9}, 3.800319017326908*^9, 3.800319059576162*^9, 
   3.800319112524501*^9, 3.8003380847357664`*^9, 3.8004509171683855`*^9, 
   3.8005904877140994`*^9, 3.8006745138353815`*^9, 3.801028927811447*^9, 
   3.818772435398099*^9}],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[1, 0.5, 0.5], Thickness[0.007], Opacity[1.], 
       LineBox[CompressedData["
1:eJwd1nc81d8bAPBr7+sOkVV2oiKrYZyThEQqWzQQsjf1LaNCZio0jAgRIoWU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        "]]},
      Annotation[#, "Charting`Private`Tag$36739#1"]& ]}, {}, {}}, {{{}, {}, 
     TagBox[
      {RGBColor[0, 1, 0], Thickness[0.007], Opacity[1.], Dashing[Large], 
       LineBox[CompressedData["
1:eJwV13k4VF0YAPCx78PMVQrtUUmUUCjnkK1IIoUoe8pSlkiLVFRKPiTJEglZ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        "]]},
      Annotation[#, "Charting`Private`Tag$36778#1"]& ]}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"\[Tau]\"", TraditionalForm], 
    FormBox[
    "\"\\!\\(\\*SubscriptBox[\\n \
StyleBox[\\\"w\\\",\\nFontSlant->\\\"Italic\\\"], \
\\\"\[Phi]\\\"]\\)(\[Tau])\"", TraditionalForm]},
  AxesOrigin->{1.000000081632653, -1.0330436131606275`},
  AxesStyle->Directive[
    RGBColor[1, 0, 0], 15],
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[
    RGBColor[1, 0, 0]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{1, 5}, Automatic},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic},
  TicksStyle->Directive[
    RGBColor[1, 0, 0], 15]]], "Output",
 CellChangeTimes->{{3.8003175548707027`*^9, 3.8003175701328983`*^9}, 
   3.800317607763579*^9, {3.800317749411677*^9, 3.800317791341212*^9}, 
   3.8003179514235754`*^9, 3.800318033856316*^9, 3.800318086621545*^9, {
   3.8003182010094967`*^9, 3.80031825002969*^9}, {3.8003186880100346`*^9, 
   3.8003187489262576`*^9}, 3.800318919131569*^9, {3.800318967840953*^9, 
   3.8003189770411367`*^9}, 3.800319017326908*^9, 3.800319059576162*^9, 
   3.800319112524501*^9, 3.8003380847357664`*^9, 3.8004509171683855`*^9, 
   3.8005904877140994`*^9, 3.8006745138353815`*^9, 3.801028927811447*^9, 
   3.818772435398099*^9}]
}, Open  ]],

Cell["Comparing the vacuum energies in both de Sitter states...", "Text",
 CellChangeTimes->{{3.8003191313015394`*^9, 3.800319133791628*^9}, {
  3.800338097417169*^9, 3.8003381390102253`*^9}, {3.8187724479197865`*^9, 
  3.818772448410095*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Log", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"3", "\[Alpha]\[CapitalLambda]"}], ")"}], 
         RowBox[{"(", 
          FractionBox[
           SuperscriptBox[
            RowBox[{"a", "[", "\[Tau]", "]"}], "2"], 
           RowBox[{"3", 
            SuperscriptBox[
             RowBox[{
              RowBox[{"a", "'"}], "[", "\[Tau]", "]"}], "2"]}]], ")"}]}], 
        "]"}], "/.", "abun2"}], "/.", 
      RowBox[{"int3", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"Log", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"3", "\[Alpha]\[CapitalLambda]"}], ")"}], 
         RowBox[{"(", 
          FractionBox[
           SuperscriptBox[
            RowBox[{"a", "[", "\[Tau]", "]"}], "2"], 
           RowBox[{"3", 
            SuperscriptBox[
             RowBox[{
              RowBox[{"a", "'"}], "[", "\[Tau]", "]"}], "2"]}]], ")"}]}], 
        "]"}], "/.", "abun2"}], "/.", 
      RowBox[{"int4", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\[Tau]", ",", "\[Tau]i", ",", "\[Tau]f"}], "}"}], "/.", 
    "dom2"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"AxesStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"Directive", "[", "Red", "]"}]}], ",", 
   RowBox[{"Ticks", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"TicksStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.007", "]"}], ",", "Pink"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Dashing", "[", "Large", "]"}], ",", 
        RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Green"}], "}"}]}], 
     "}"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<\[Tau]\>\"", ",", 
      "\"\<ln \!\(\*SubscriptBox[\(\[CapitalOmega]\), \(\[CapitalLambda]\)]\)\
\>\""}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8003191371191874`*^9, 3.8003191663340364`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[1, 0.5, 0.5], Thickness[0.007], Opacity[1.], 
      LineBox[CompressedData["
1:eJwd1nk8lF8XAHD7vsxCCimUUmRPEeckUVkS0oZsSdaypMWWIhJJUklFi6RC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       "]]},
     Annotation[#, "Charting`Private`Tag$37121#1"]& ], 
    TagBox[
     {RGBColor[0, 1, 0], Thickness[0.01], Opacity[1.], Dashing[Large], 
      LineBox[CompressedData["
1:eJwVlnc0Fv4Xxx/jscczzDIKIRmFFvW5HyOjKF+rkhWiQslIqawQZSfK3qvs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       "]]},
     Annotation[#, "Charting`Private`Tag$37121#2"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"\[Tau]\"", TraditionalForm], 
    FormBox[
    "\"ln \\!\\(\\*SubscriptBox[\\(\[CapitalOmega]\\), \
\\(\[CapitalLambda]\\)]\\)\"", TraditionalForm]},
  AxesOrigin->{1.000000081632653, 0},
  AxesStyle->Directive[
    RGBColor[1, 0, 0], 15],
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[
    RGBColor[1, 0, 0]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{1.000000081632653, 4.999999918367347}, {0., 
   0.3364658435770809}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic},
  TicksStyle->Directive[
    RGBColor[1, 0, 0], 15]]], "Output",
 CellChangeTimes->{3.8003191685212374`*^9, 3.800338142943631*^9, 
  3.800450918751152*^9, 3.800590488595072*^9, 3.800674514557711*^9, 
  3.80102894924641*^9, 3.8187724516481123`*^9}]
}, Open  ]],

Cell["These are figures 5 and 6 in the text.", "Text",
 CellChangeTimes->{{3.8003381567718515`*^9, 3.8003383342342653`*^9}, {
  3.818772472283431*^9, 3.8187725186983347`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["4.4 Phase transitions", "Subsubsection",
 CellChangeTimes->{{3.8011868598768773`*^9, 3.801186865766466*^9}}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"SetDirectory", "[", 
    RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";", 
   "\[IndentingNewLine]", 
   RowBox[{"Get", "[", "\"\<self_tuning_GCCG.m\>\"", "]"}]}], "*)"}]], "Input",
 CellChangeTimes->{{3.818772553993004*^9, 3.8187725564552164`*^9}}],

Cell["\<\
In this section, we show that the self-tuning vacuum of tadpole-free shift \
symmetric KGB can survive phase transitions.

We implement this using the following effective source...\
\>", "Text",
 CellChangeTimes->{{3.8011869050303164`*^9, 3.801186985328811*^9}, {
  3.8011870192042437`*^9, 3.8011870288305683`*^9}, {3.818772566175888*^9, 
  3.8187726083322897`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"pt\[Rho]", "=", 
   RowBox[{"\[Rho]", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{"t", ",", 
      RowBox[{"\[CapitalLambda]", "+", 
       RowBox[{"(", 
        RowBox[{
         FractionBox["\[CapitalDelta]\[CapitalLambda]", "2"], 
         RowBox[{"Tanh", "[", 
          FractionBox[
           RowBox[{"t", "-", "T"}], "\[CapitalDelta]t"], "]"}]}], ")"}]}]}], 
     "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ptP", "=", 
   RowBox[{"P", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{"t", ",", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"\[Rho]", "[", "t", "]"}]}], "-", 
       FractionBox[
        RowBox[{
         RowBox[{"\[Rho]", "'"}], "[", "t", "]"}], 
        RowBox[{"3", 
         RowBox[{"H", "[", "t", "]"}]}]]}]}], "]"}]}]}], ";"}]}], "Input"],

Cell[TextData[{
 "...where ",
 Cell[BoxData[
  FormBox["\[CapitalLambda]", TraditionalForm]]],
 " is an initial cosmological constant that would be changed by ",
 Cell[BoxData[
  FormBox["\[CapitalDelta]\[CapitalLambda]", TraditionalForm]]],
 " in a short time interval ",
 Cell[BoxData[
  FormBox["\[CapitalDelta]t", TraditionalForm]]],
 " at a time ",
 StyleBox["T",
  FontSlant->"Italic"],
 ". Here is a plot of the effective energy density and pressure (figure 7)..."
}], "Text",
 CellChangeTimes->{{3.8011870392998533`*^9, 3.801187148389372*^9}, {
  3.80118726471025*^9, 3.8011872889469347`*^9}, {3.8011877964827957`*^9, 
  3.801187798347766*^9}, {3.8187726662489777`*^9, 3.81877268511417*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[Rho]nd", "[", "\[Tau]_", "]"}], "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Rho]", "[", "t", "]"}], "/.", "pt\[Rho]"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"t", "\[Rule]", 
         RowBox[{"h", " ", "\[Tau]"}]}], ",", 
        RowBox[{"T", "\[Rule]", 
         RowBox[{"h", " ", "\[CapitalTau]"}]}], ",", 
        RowBox[{"\[CapitalDelta]t", "\[Rule]", 
         RowBox[{"h", " ", "\[CapitalDelta]\[Tau]"}]}], ",", 
        RowBox[{"\[CapitalLambda]", "\[Rule]", 
         RowBox[{"3", 
          SuperscriptBox["h", "2"], "\[Lambda]"}]}], ",", 
        RowBox[{"\[CapitalDelta]\[CapitalLambda]", "\[Rule]", 
         RowBox[{"3", 
          SuperscriptBox["h", "2"], "\[CapitalDelta]\[Lambda]"}]}]}], "}"}]}],
      "//", "Simplify"}], ")"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Pnd", "[", "\[Tau]_", "]"}], "=", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"P", "[", "t", "]"}], "/.", "ptP"}], "/.", "pt\[Rho]"}], "/.", 
        RowBox[{
         RowBox[{"H", "[", "t", "]"}], "\[Rule]", "h"}]}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"t", "\[Rule]", 
          RowBox[{"h", " ", "\[Tau]"}]}], ",", 
         RowBox[{"T", "\[Rule]", 
          RowBox[{"h", " ", "\[CapitalTau]"}]}], ",", 
         RowBox[{"\[CapitalDelta]t", "\[Rule]", 
          RowBox[{"h", " ", "\[CapitalDelta]\[Tau]"}]}], ",", 
         RowBox[{"\[CapitalLambda]", "\[Rule]", 
          RowBox[{"3", 
           SuperscriptBox["h", "2"], "\[Lambda]"}]}], ",", 
         RowBox[{"\[CapitalDelta]\[CapitalLambda]", "\[Rule]", 
          RowBox[{"3", 
           SuperscriptBox["h", "2"], "\[CapitalDelta]\[Lambda]"}]}]}], 
        "}"}]}], "//", "Simplify"}], ")"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\"\<\!\(\*FractionBox[
RowBox[{SubscriptBox[\"\[Rho]\", \"eff\"], 
RowBox[{\"(\", \"\[Tau]\", \")\"}]}], 
RowBox[{\"3\", SuperscriptBox[
StyleBox[\"h\",
FontSlant->\"Italic\"], \"2\"]}]]\)\>\"", "\[Equal]", 
   FractionBox[
    RowBox[{"\[Rho]nd", "[", "\[Tau]", "]"}], 
    RowBox[{"3", 
     SuperscriptBox["h", "2"]}]]}], "//", "Expand"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\"\<\!\(\*FractionBox[
RowBox[{
StyleBox[SubscriptBox[
StyleBox[\"P\",
FontSlant->\"Italic\"], 
StyleBox[\"eff\",
FontSlant->\"Plain\"]],
FontSlant->\"Italic\"], 
RowBox[{\"(\", \"\[Tau]\", \")\"}]}], 
RowBox[{\"3\", SuperscriptBox[
StyleBox[\"h\",
FontSlant->\"Italic\"], \"2\"]}]]\)\>\"", "\[Equal]", 
     FractionBox[
      RowBox[{"Pnd", "[", "\[Tau]", "]"}], 
      RowBox[{"3", 
       SuperscriptBox["h", "2"]}]]}], "/.", 
    RowBox[{"h", "\[Rule]", "1"}]}], "//", "Expand"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      FractionBox[
       RowBox[{"\[Rho]nd", "[", "\[Tau]", "]"}], 
       RowBox[{"3", 
        SuperscriptBox["h", "2"]}]], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[Lambda]", "\[Rule]", "1"}], ",", 
        RowBox[{"\[CapitalDelta]\[Lambda]", "\[Rule]", 
         FractionBox["3", "2"]}], ",", 
        RowBox[{"\[CapitalTau]", "\[Rule]", "2"}], ",", 
        RowBox[{"\[CapitalDelta]\[Tau]", "\[Rule]", 
         FractionBox["1", "10"]}]}], "}"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Tau]", ",", "1", ",", "3"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "2"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"AxesStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", "Red", "]"}]}], ",", 
    RowBox[{"Ticks", "\[Rule]", "Automatic"}], ",", 
    RowBox[{"TicksStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.007", "]"}], ",", "Pink"}], "}"}], 
      "}"}]}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\[Tau]\>\"", ",", 
       "\"\<\!\(\*SubscriptBox[\(\[Rho]\), \(eff\)]\)/(3\!\(\*SuperscriptBox[
StyleBox[\"h\",
FontSlant->\"Italic\"], \"2\"]\))\>\""}], "}"}]}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"Pnd", "[", "\[Tau]", "]"}], 
        RowBox[{"3", 
         SuperscriptBox["h", "2"]}]]}], "/.", 
      RowBox[{"h", "\[Rule]", "1"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Lambda]", "\[Rule]", "1"}], ",", 
       RowBox[{"\[CapitalDelta]\[Lambda]", "\[Rule]", 
        FractionBox["3", "2"]}], ",", 
       RowBox[{"\[CapitalTau]", "\[Rule]", "2"}], ",", 
       RowBox[{"\[CapitalDelta]\[Tau]", "\[Rule]", 
        FractionBox["1", "10"]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Tau]", ",", "1", ",", "3"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"AxesStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"Directive", "[", "Red", "]"}]}], ",", 
   RowBox[{"Ticks", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"TicksStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Thickness", "[", "0.007", "]"}], ",", "Pink"}], "}"}], 
     "}"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<\[Tau]\>\"", ",", 
      "\"\<-\!\(\*SubscriptBox[\(P\), \(eff\)]\)/(3\!\(\*SuperscriptBox[
StyleBox[\"h\",
FontSlant->\"Italic\"], \"2\"]\))\>\""}], "}"}]}], ",", 
   RowBox[{"AxesOrigin", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1", ",", "0"}], "}"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.8011879467016973`*^9, 3.8011880974897566`*^9}, {
  3.8011881367180634`*^9, 3.801188235320382*^9}, {3.801188438148843*^9, 
  3.8011884603328557`*^9}, {3.8011885034615407`*^9, 3.8011886608416867`*^9}, {
  3.801188742868671*^9, 3.8011888335631957`*^9}, {3.801188869339261*^9, 
  3.801188911761942*^9}, {3.8012007143647366`*^9, 3.801200726945282*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*FractionBox[\\n RowBox[{SubscriptBox[\\\"\[Rho]\\\", \
\\\"eff\\\"], \\n  RowBox[{\\\"(\\\", \\\"\[Tau]\\\", \\\")\\\"}]}], \\n \
RowBox[{\\\"3\\\", SuperscriptBox[\\n   \
StyleBox[\\\"h\\\",\\nFontSlant->\\\"Italic\\\"], \\\"2\\\"]}]]\\)\"\>", 
  "\[Equal]", 
  RowBox[{"\[Lambda]", "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[CapitalDelta]\[Lambda]", " ", 
    RowBox[{"Tanh", "[", 
     FractionBox[
      RowBox[{"\[Tau]", "-", "\[CapitalTau]"}], "\[CapitalDelta]\[Tau]"], 
     "]"}]}]}]}]], "Output",
 CellChangeTimes->{{3.8011881733150215`*^9, 3.801188236083619*^9}, {
   3.801188448499634*^9, 3.8011884629057655`*^9}, {3.801188506420961*^9, 
   3.801188527341406*^9}, 3.801188661469714*^9, {3.801188790161458*^9, 
   3.801188834338284*^9}, {3.8011888947673182`*^9, 3.8011889125578938`*^9}, 
   3.801198543567152*^9, {3.801200719417013*^9, 3.8012007285333757`*^9}, 
   3.8012024373414106`*^9, 3.801203405585924*^9, 3.801211482252333*^9, 
   3.801212651618455*^9, 3.801213797628339*^9, 3.8012154178984222`*^9, 
   3.8012228055371284`*^9, 3.818772689224147*^9}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*FractionBox[\\n RowBox[{\\n  StyleBox[SubscriptBox[\\n \
   StyleBox[\\\"P\\\",\\nFontSlant->\\\"Italic\\\"], \\n    \
StyleBox[\\\"eff\\\",\\nFontSlant->\\\"Plain\\\"]],\\nFontSlant->\\\"Italic\\\
\"], \\n  RowBox[{\\\"(\\\", \\\"\[Tau]\\\", \\\")\\\"}]}], \\n RowBox[{\\\"3\
\\\", SuperscriptBox[\\n   StyleBox[\\\"h\\\",\\nFontSlant->\\\"Italic\\\"], \
\\\"2\\\"]}]]\\)\"\>", "\[Equal]", 
  RowBox[{
   RowBox[{"-", "\[Lambda]"}], "-", 
   FractionBox[
    RowBox[{"\[CapitalDelta]\[Lambda]", " ", 
     SuperscriptBox[
      RowBox[{"Sech", "[", 
       FractionBox[
        RowBox[{"\[Tau]", "-", "\[CapitalTau]"}], "\[CapitalDelta]\[Tau]"], 
       "]"}], "2"]}], 
    RowBox[{"6", " ", "\[CapitalDelta]\[Tau]"}]], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[CapitalDelta]\[Lambda]", " ", 
    RowBox[{"Tanh", "[", 
     FractionBox[
      RowBox[{"\[Tau]", "-", "\[CapitalTau]"}], "\[CapitalDelta]\[Tau]"], 
     "]"}]}]}]}]], "Output",
 CellChangeTimes->{{3.8011881733150215`*^9, 3.801188236083619*^9}, {
   3.801188448499634*^9, 3.8011884629057655`*^9}, {3.801188506420961*^9, 
   3.801188527341406*^9}, 3.801188661469714*^9, {3.801188790161458*^9, 
   3.801188834338284*^9}, {3.8011888947673182`*^9, 3.8011889125578938`*^9}, 
   3.801198543567152*^9, {3.801200719417013*^9, 3.8012007285333757`*^9}, 
   3.8012024373414106`*^9, 3.801203405585924*^9, 3.801211482252333*^9, 
   3.801212651618455*^9, 3.801213797628339*^9, 3.8012154178984222`*^9, 
   3.8012228055371284`*^9, 3.818772689239767*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[1, 0.5, 0.5], Thickness[0.007], Opacity[1.], 
      LineBox[CompressedData["
1:eJwd13k81E0YAPA9USSEJKUkJKkkIfVMkiRJQlIkV0qnXBWiJBFRSKiUI0lS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       "]]},
     Annotation[#, "Charting`Private`Tag$1031#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"\[Tau]\"", TraditionalForm], 
    FormBox[
    "\"\\!\\(\\*SubscriptBox[\\(\[Rho]\\), \
\\(eff\\)]\\)/(3\\!\\(\\*SuperscriptBox[\\n StyleBox[\\\"h\\\",\\nFontSlant->\
\\\"Italic\\\"], \\\"2\\\"]\\))\"", TraditionalForm]},
  AxesOrigin->{1, 0},
  AxesStyle->Directive[
    RGBColor[1, 0, 0], 15],
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[
    RGBColor[1, 0, 0]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{1, 3}, {0, 2}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic},
  TicksStyle->Directive[
    RGBColor[1, 0, 0], 15]]], "Output",
 CellChangeTimes->{{3.8011881733150215`*^9, 3.801188236083619*^9}, {
   3.801188448499634*^9, 3.8011884629057655`*^9}, {3.801188506420961*^9, 
   3.801188527341406*^9}, 3.801188661469714*^9, {3.801188790161458*^9, 
   3.801188834338284*^9}, {3.8011888947673182`*^9, 3.8011889125578938`*^9}, 
   3.801198543567152*^9, {3.801200719417013*^9, 3.8012007285333757`*^9}, 
   3.8012024373414106`*^9, 3.801203405585924*^9, 3.801211482252333*^9, 
   3.801212651618455*^9, 3.801213797628339*^9, 3.8012154178984222`*^9, 
   3.8012228055371284`*^9, 3.8187726893812456`*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[1, 0.5, 0.5], Thickness[0.007], Opacity[1.], 
      LineBox[CompressedData["
1:eJwd13dcjl8UAPB3t/fS0NLSJBRJ54rSIGnQ0NBSUamoUGalIYoWoZAQElFJ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       "]]},
     Annotation[#, "Charting`Private`Tag$1137#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"\[Tau]\"", TraditionalForm], 
    FormBox[
    "\"-\\!\\(\\*SubscriptBox[\\(P\\), \
\\(eff\\)]\\)/(3\\!\\(\\*SuperscriptBox[\\n StyleBox[\\\"h\\\",\\nFontSlant->\
\\\"Italic\\\"], \\\"2\\\"]\\))\"", TraditionalForm]},
  AxesOrigin->{1., 0.},
  AxesStyle->Directive[
    RGBColor[1, 0, 0], 15],
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[
    RGBColor[1, 0, 0]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{1., 2.9999999591836737`}, {0., 3.5562360802395605`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic},
  TicksStyle->Directive[
    RGBColor[1, 0, 0], 15]]], "Output",
 CellChangeTimes->{{3.8011881733150215`*^9, 3.801188236083619*^9}, {
   3.801188448499634*^9, 3.8011884629057655`*^9}, {3.801188506420961*^9, 
   3.801188527341406*^9}, 3.801188661469714*^9, {3.801188790161458*^9, 
   3.801188834338284*^9}, {3.8011888947673182`*^9, 3.8011889125578938`*^9}, 
   3.801198543567152*^9, {3.801200719417013*^9, 3.8012007285333757`*^9}, 
   3.8012024373414106`*^9, 3.801203405585924*^9, 3.801211482252333*^9, 
   3.801212651618455*^9, 3.801213797628339*^9, 3.8012154178984222`*^9, 
   3.8012228055371284`*^9, 3.818772689489539*^9}]
}, Open  ]],

Cell["\<\
We now setup the field equations. We proceed by eliminating the energy \
density in the Friedmann constraint and Hubble equation and substitute the \
effective pressure...\
\>", "Text",
 CellChangeTimes->{{3.801189648013976*^9, 3.801189697524333*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FHeq", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"HeqGCCG", "/.", 
       RowBox[{
        RowBox[{"Solve", "[", 
         RowBox[{"FeqGCCG", ",", 
          RowBox[{"\[Rho]", "[", "t", "]"}]}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "/.", "ptP"}], "/.", "pt\[Rho]"}], "//",
     "Simplify"}]}], ";", "FHeq"}]], "Input",
 CellChangeTimes->{{3.8011897092199736`*^9, 3.801189709609212*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"9", " ", 
    SuperscriptBox["2", "n"], " ", 
    SuperscriptBox[
     RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
   RowBox[{"3", " ", 
    SuperscriptBox["2", 
     RowBox[{"1", "+", "n"}]], " ", 
    RowBox[{
     SuperscriptBox["H", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}], "+", 
   FractionBox[
    RowBox[{"c", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], ")"}], "n"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", "h", " ", 
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "+", 
       RowBox[{"2", " ", "n", " ", 
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], 
    RowBox[{"h", " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]]}], "\[Equal]", 
  FractionBox[
   RowBox[{
    SuperscriptBox["2", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "n"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[CapitalDelta]\[CapitalLambda]", " ", 
       SuperscriptBox[
        RowBox[{"Sech", "[", 
         FractionBox[
          RowBox[{"t", "-", "T"}], "\[CapitalDelta]t"], "]"}], "2"]}], "+", 
      RowBox[{"3", " ", "\[CapitalDelta]t", " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "\[CapitalLambda]"}], "+", 
         RowBox[{"\[CapitalDelta]\[CapitalLambda]", " ", 
          RowBox[{"Tanh", "[", 
           FractionBox[
            RowBox[{"t", "-", "T"}], "\[CapitalDelta]t"], "]"}]}]}], 
        ")"}]}]}], ")"}]}], 
   RowBox[{"\[CapitalDelta]t", " ", 
    RowBox[{"H", "[", "t", "]"}]}]]}]], "Output",
 CellChangeTimes->{3.8011897150758934`*^9, 3.8011985463294535`*^9, 
  3.8012024402599792`*^9, 3.8012034123171053`*^9, 3.801212657667878*^9, 
  3.8012138005705013`*^9, 3.801215420552637*^9, 3.8012228082375526`*^9, 
  3.818772705169441*^9}]
}, Open  ]],

Cell["The dynamical system is given by...", "Text",
 CellChangeTimes->{{3.8011897260195093`*^9, 3.8011897383328714`*^9}, {
  3.818772719754921*^9, 3.818772729174882*^9}, {3.8187727650401974`*^9, 
  3.8187727655928893`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ds", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"FHeq", ",", "SeqGCCG"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Phi]", "''"}], "[", "t", "]"}], ",", 
          RowBox[{
           RowBox[{"H", "'"}], "[", "t", "]"}]}], "}"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}], "//", "Simplify"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ds1", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "''"}], "[", "t", "]"}], "\[Equal]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Phi]", "''"}], "[", "t", "]"}], "/.", "ds"}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ds2", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"H", "'"}], "[", "t", "]"}], "\[Equal]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"H", "'"}], "[", "t", "]"}], "/.", "ds"}], ")"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "ds1", \
"\[IndentingNewLine]", "ds2"}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"h", " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"9", " ", 
          SuperscriptBox["2", 
           RowBox[{"2", "+", "n"}]], " ", "h", " ", "\[CapitalDelta]t", " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
         RowBox[{"9", " ", 
          SuperscriptBox["2", 
           RowBox[{"1", "+", "n"}]], " ", "\[CapitalDelta]t", " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "t", "]"}], "3"]}], "-", 
         RowBox[{
          SuperscriptBox["2", "n"], " ", "\[CapitalDelta]\[CapitalLambda]", 
          " ", 
          SuperscriptBox[
           RowBox[{"Sech", "[", 
            FractionBox[
             RowBox[{"t", "-", "T"}], "\[CapitalDelta]t"], "]"}], "2"]}], "-", 
         RowBox[{"3", " ", "\[CapitalDelta]t", " ", 
          RowBox[{"H", "[", "t", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["2", 
              RowBox[{"1", "+", "n"}]], " ", "\[CapitalLambda]"}], "+", 
            RowBox[{
             SuperscriptBox["2", "n"], " ", "\[CapitalDelta]\[CapitalLambda]",
              " ", 
             RowBox[{"Tanh", "[", 
              FractionBox[
               RowBox[{"t", "-", "T"}], "\[CapitalDelta]t"], "]"}]}], "-", 
            RowBox[{"2", " ", "c", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox["\[Phi]", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], "2"], ")"}], 
              "n"]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"4", " ", "\[CapitalDelta]t", " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["2", "n"], " ", 
          SuperscriptBox["h", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", "n"}]}], ")"}]}], "-", 
         RowBox[{"3", " ", 
          SuperscriptBox["2", "n"], " ", "h", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", "n"}]}], ")"}], " ", 
          RowBox[{"H", "[", "t", "]"}]}], "+", 
         RowBox[{"c", " ", "n", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Phi]", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "2"], ")"}], 
           "n"]}]}], ")"}]}], ")"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.801189741304673*^9, 3.8011985480725927`*^9, 
  3.801202442012267*^9, 3.801203413986263*^9, 3.801212660543886*^9, 
  3.8012138024668827`*^9, 3.8012154223269243`*^9, 3.801222810655303*^9, 
  3.8187727110329027`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["H", "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"h", "-", 
         RowBox[{"H", "[", "t", "]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"9", " ", 
          SuperscriptBox["2", 
           RowBox[{"1", "+", "n"}]], " ", "h", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", "n"}]}], ")"}], " ", "\[CapitalDelta]t", " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "t", "]"}], "3"]}], "-", 
         RowBox[{
          SuperscriptBox["2", "n"], " ", "h", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", "n"}]}], ")"}], " ", 
          "\[CapitalDelta]\[CapitalLambda]", " ", 
          SuperscriptBox[
           RowBox[{"Sech", "[", 
            FractionBox[
             RowBox[{"t", "-", "T"}], "\[CapitalDelta]t"], "]"}], "2"]}], "-", 
         RowBox[{"12", " ", "c", " ", "n", " ", "\[CapitalDelta]t", " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "t", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Phi]", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "2"], ")"}], "n"]}],
          "-", 
         RowBox[{"3", " ", "h", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", "n"}]}], ")"}], " ", "\[CapitalDelta]t", " ", 
          RowBox[{"H", "[", "t", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["2", 
              RowBox[{"1", "+", "n"}]], " ", "\[CapitalLambda]"}], "+", 
            RowBox[{
             SuperscriptBox["2", "n"], " ", "\[CapitalDelta]\[CapitalLambda]",
              " ", 
             RowBox[{"Tanh", "[", 
              FractionBox[
               RowBox[{"t", "-", "T"}], "\[CapitalDelta]t"], "]"}]}], "-", 
            RowBox[{"2", " ", "c", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox["\[Phi]", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], "2"], ")"}], 
              "n"]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"4", " ", "\[CapitalDelta]t", " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["2", "n"], " ", 
          SuperscriptBox["h", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", "n"}]}], ")"}]}], "-", 
         RowBox[{"3", " ", 
          SuperscriptBox["2", "n"], " ", "h", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", "n"}]}], ")"}], " ", 
          RowBox[{"H", "[", "t", "]"}]}], "+", 
         RowBox[{"c", " ", "n", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Phi]", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "2"], ")"}], 
           "n"]}]}], ")"}]}], ")"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.801189741304673*^9, 3.8011985480725927`*^9, 
  3.801202442012267*^9, 3.801203413986263*^9, 3.801212660543886*^9, 
  3.8012138024668827`*^9, 3.8012154223269243`*^9, 3.801222810655303*^9, 
  3.8187727110485535`*^9}]
}, Open  ]],

Cell["Nondimensionalizing leads to Eqs. (4.48) and (4.49)...", "Text",
 CellChangeTimes->{{3.8011897444700317`*^9, 3.801189748141015*^9}, {
  3.8187727688011055`*^9, 3.8187727734081697`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"cto\[Beta]", "=", 
   RowBox[{"c", "\[Rule]", 
    RowBox[{"\[Beta]", " ", 
     SuperscriptBox["h", 
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "n"}], "-", "2"}], ")"}]}]]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nondim", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "\[Rule]", 
      RowBox[{"h", " ", 
       RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Phi]", "''"}], "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"h", " "}], "2"], 
       RowBox[{
        RowBox[{"\[CapitalPsi]", "'"}], "[", "\[Tau]", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"H", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"h", " ", 
       RowBox[{"y", "[", "\[Tau]", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"H", "'"}], "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox["h", "2"], " ", 
       RowBox[{
        RowBox[{"y", "'"}], "[", "\[Tau]", "]"}]}]}], ",", 
     RowBox[{"\[CapitalLambda]", "\[Rule]", 
      RowBox[{"3", 
       SuperscriptBox["h", "2"], "\[Lambda]"}]}], ",", 
     RowBox[{"\[CapitalDelta]\[CapitalLambda]", "\[Rule]", 
      RowBox[{"3", 
       SuperscriptBox["h", "2"], "\[CapitalDelta]\[Lambda]"}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nondim2", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"t", "\[Rule]", 
       RowBox[{"h", " ", "\[Tau]"}]}], ",", 
      RowBox[{"T", "\[Rule]", 
       RowBox[{"h", " ", "\[CapitalTau]"}]}], ",", 
      RowBox[{"\[CapitalDelta]t", "\[Rule]", 
       RowBox[{"h", " ", "\[CapitalDelta]\[Tau]"}]}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ds1nd", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"ds1", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "/.", "nondim"}], ")"}], "\[Equal]", 
    RowBox[{"(", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"ds1", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "/.", "cto\[Beta]"}], "/.", 
         "nondim"}], "/.", "nondim2"}], ",", 
       RowBox[{
        RowBox[{"Element", "[", 
         RowBox[{"n", ",", "Reals"}], "]"}], "&&", 
        RowBox[{"Element", "[", 
         RowBox[{"\[Beta]", ",", "Reals"}], "]"}], "&&", 
        RowBox[{"Element", "[", 
         RowBox[{"h", ",", "Reals"}], "]"}]}], ",", 
       RowBox[{"Assumptions", "\[Rule]", 
        RowBox[{
         RowBox[{"\[Beta]", ">", "0"}], "&&", 
         RowBox[{"h", ">", "0"}]}]}]}], "]"}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ds2nd", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"ds2", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "/.", "nondim"}], ")"}], "\[Equal]", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"ds2", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "/.", "cto\[Beta]"}], "/.", 
         "nondim"}], "/.", "nondim2"}], ",", 
       RowBox[{
        RowBox[{"Element", "[", 
         RowBox[{"n", ",", "Reals"}], "]"}], "&&", 
        RowBox[{"Element", "[", 
         RowBox[{"\[Beta]", ",", "Reals"}], "]"}], "&&", 
        RowBox[{"Element", "[", 
         RowBox[{"h", ",", "Reals"}], "]"}]}], ",", 
       RowBox[{"Assumptions", "\[Rule]", 
        RowBox[{
         RowBox[{"\[Beta]", ">", "0"}], "&&", 
         RowBox[{"h", ">", "0"}]}]}]}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "ds1nd", "\
\[IndentingNewLine]", "ds2nd"}], "Input",
 CellChangeTimes->{{3.801189835570445*^9, 3.8011898500877647`*^9}, 
   3.8187727404654694`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["h", "2"], " ", 
   RowBox[{
    SuperscriptBox["\[CapitalPsi]", "\[Prime]",
     MultilineFunction->None], "[", "\[Tau]", "]"}]}], "\[Equal]", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "3"}], " ", 
      SuperscriptBox["2", "n"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[CapitalDelta]\[Lambda]", " ", 
         SuperscriptBox[
          RowBox[{"Sech", "[", 
           FractionBox[
            RowBox[{"\[Tau]", "-", "\[CapitalTau]"}], 
            "\[CapitalDelta]\[Tau]"], "]"}], "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["h", "2"], " ", "\[CapitalDelta]\[Tau]", " ", 
         RowBox[{"y", "[", "\[Tau]", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[Lambda]"}], "+", 
           RowBox[{"\[CapitalDelta]\[Lambda]", " ", 
            RowBox[{"Tanh", "[", 
             FractionBox[
              RowBox[{"\[Tau]", "-", "\[CapitalTau]"}], 
              "\[CapitalDelta]\[Tau]"], "]"}]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", 
              RowBox[{"y", "[", "\[Tau]", "]"}]}], ")"}], " ", 
            RowBox[{"y", "[", "\[Tau]", "]"}]}]}], ")"}]}]}], ")"}], " ", 
      RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}]}], "+", 
     RowBox[{"6", " ", 
      SuperscriptBox["h", "2"], " ", "\[Beta]", " ", "\[CapitalDelta]\[Tau]", 
      " ", 
      RowBox[{"y", "[", "\[Tau]", "]"}], " ", 
      RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox[
         RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}], "2"], ")"}], "n"]}]}],
     ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"4", " ", "\[CapitalDelta]\[Tau]", " ", 
     RowBox[{"y", "[", "\[Tau]", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["2", "n"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"2", " ", "n"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"y", "[", "\[Tau]", "]"}]}], ")"}]}], "-", 
       RowBox[{"n", " ", "\[Beta]", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          SuperscriptBox[
           RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}], "2"], ")"}], 
         "n"]}]}], ")"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.801189777885708*^9, 3.801189869685524*^9, 
  3.8011985674051657`*^9, 3.8012024595256157`*^9, 3.8012034331231365`*^9, 
  3.8012126801944327`*^9, 3.8012138199722056`*^9, 3.8012154388367186`*^9, 
  3.801222834790397*^9, 3.8187727606768117`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["h", "2"], " ", 
   RowBox[{
    SuperscriptBox["y", "\[Prime]",
     MultilineFunction->None], "[", "\[Tau]", "]"}]}], "\[Equal]", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"3", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"y", "[", "\[Tau]", "]"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["2", "n"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"2", " ", "n"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[CapitalDelta]\[Lambda]", " ", 
           SuperscriptBox[
            RowBox[{"Sech", "[", 
             FractionBox[
              RowBox[{"\[Tau]", "-", "\[CapitalTau]"}], 
              "\[CapitalDelta]\[Tau]"], "]"}], "2"]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["h", "2"], " ", "\[CapitalDelta]\[Tau]", " ", 
           RowBox[{"y", "[", "\[Tau]", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", "\[Lambda]"}], "+", 
             RowBox[{"\[CapitalDelta]\[Lambda]", " ", 
              RowBox[{"Tanh", "[", 
               FractionBox[
                RowBox[{"\[Tau]", "-", "\[CapitalTau]"}], 
                "\[CapitalDelta]\[Tau]"], "]"}]}], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox[
               RowBox[{"y", "[", "\[Tau]", "]"}], "2"]}]}], ")"}]}]}], 
         ")"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["h", "2"], " ", "\[Beta]", " ", 
        "\[CapitalDelta]\[Tau]", " ", 
        RowBox[{"y", "[", "\[Tau]", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"2", " ", "n"}], "+", 
          RowBox[{"2", " ", "n", " ", 
           RowBox[{"y", "[", "\[Tau]", "]"}]}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          SuperscriptBox[
           RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}], "2"], ")"}], 
         "n"]}]}], ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"4", " ", "\[CapitalDelta]\[Tau]", " ", 
     RowBox[{"y", "[", "\[Tau]", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["2", "n"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"2", " ", "n"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"y", "[", "\[Tau]", "]"}]}], ")"}]}], "-", 
       RowBox[{"n", " ", "\[Beta]", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          SuperscriptBox[
           RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}], "2"], ")"}], 
         "n"]}]}], ")"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.801189777885708*^9, 3.801189869685524*^9, 
  3.8011985674051657`*^9, 3.8012024595256157`*^9, 3.8012034331231365`*^9, 
  3.8012126801944327`*^9, 3.8012138199722056`*^9, 3.8012154388367186`*^9, 
  3.801222834790397*^9, 3.8187727606924324`*^9}]
}, Open  ]],

Cell[TextData[{
 "There is an unaccounted units in the term ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"P", "~", 
     RowBox[{"-", 
      RowBox[{"\[Rho]", "'"}]}]}], "/", 
    RowBox[{"(", 
     RowBox[{"3", 
      SuperscriptBox["H", "2"]}], ")"}]}], TraditionalForm]]],
 " that amounts to ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["h", "2"], TraditionalForm]]],
 ". Overall both sides of both equations will have ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["h", "2"], TraditionalForm]]],
 " and so we set ",
 Cell[BoxData[
  FormBox[
   RowBox[{"h", "=", "1"}], TraditionalForm]]],
 "..."
}], "Text",
 CellChangeTimes->{
  3.8011898167730646`*^9, {3.818772795377285*^9, 3.81877279601225*^9}, {
   3.818772847354282*^9, 3.818772852754774*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ds1ND", "=", 
   RowBox[{"ds1nd", "/.", 
    RowBox[{"h", "\[Rule]", "1"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ds2ND", "=", 
    RowBox[{"ds2nd", "/.", 
     RowBox[{"h", "\[Rule]", "1"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "ds1ND", "\
\[IndentingNewLine]", "ds2ND"}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["\[CapitalPsi]", "\[Prime]",
    MultilineFunction->None], "[", "\[Tau]", "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "3"}], " ", 
      SuperscriptBox["2", "n"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[CapitalDelta]\[Lambda]", " ", 
         SuperscriptBox[
          RowBox[{"Sech", "[", 
           FractionBox[
            RowBox[{"\[Tau]", "-", "\[CapitalTau]"}], 
            "\[CapitalDelta]\[Tau]"], "]"}], "2"]}], "+", 
        RowBox[{"3", " ", "\[CapitalDelta]\[Tau]", " ", 
         RowBox[{"y", "[", "\[Tau]", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[Lambda]"}], "+", 
           RowBox[{"\[CapitalDelta]\[Lambda]", " ", 
            RowBox[{"Tanh", "[", 
             FractionBox[
              RowBox[{"\[Tau]", "-", "\[CapitalTau]"}], 
              "\[CapitalDelta]\[Tau]"], "]"}]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", 
              RowBox[{"y", "[", "\[Tau]", "]"}]}], ")"}], " ", 
            RowBox[{"y", "[", "\[Tau]", "]"}]}]}], ")"}]}]}], ")"}], " ", 
      RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}]}], "+", 
     RowBox[{"6", " ", "\[Beta]", " ", "\[CapitalDelta]\[Tau]", " ", 
      RowBox[{"y", "[", "\[Tau]", "]"}], " ", 
      RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox[
         RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}], "2"], ")"}], "n"]}]}],
     ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"4", " ", "\[CapitalDelta]\[Tau]", " ", 
     RowBox[{"y", "[", "\[Tau]", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["2", "n"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"2", " ", "n"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"y", "[", "\[Tau]", "]"}]}], ")"}]}], "-", 
       RowBox[{"n", " ", "\[Beta]", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          SuperscriptBox[
           RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}], "2"], ")"}], 
         "n"]}]}], ")"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.8011898232628975`*^9, 3.801189873299265*^9, 
  3.8011985675613456`*^9, 3.8012024596161313`*^9, 3.801203433232456*^9, 
  3.8012126802820787`*^9, 3.801213820046365*^9, 3.801215438921057*^9, 
  3.801222834939579*^9, 3.818772855584588*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["y", "\[Prime]",
    MultilineFunction->None], "[", "\[Tau]", "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"3", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"y", "[", "\[Tau]", "]"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["2", "n"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"2", " ", "n"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[CapitalDelta]\[Lambda]", " ", 
           SuperscriptBox[
            RowBox[{"Sech", "[", 
             FractionBox[
              RowBox[{"\[Tau]", "-", "\[CapitalTau]"}], 
              "\[CapitalDelta]\[Tau]"], "]"}], "2"]}], "+", 
          RowBox[{"3", " ", "\[CapitalDelta]\[Tau]", " ", 
           RowBox[{"y", "[", "\[Tau]", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", "\[Lambda]"}], "+", 
             RowBox[{"\[CapitalDelta]\[Lambda]", " ", 
              RowBox[{"Tanh", "[", 
               FractionBox[
                RowBox[{"\[Tau]", "-", "\[CapitalTau]"}], 
                "\[CapitalDelta]\[Tau]"], "]"}]}], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox[
               RowBox[{"y", "[", "\[Tau]", "]"}], "2"]}]}], ")"}]}]}], 
         ")"}]}], "+", 
       RowBox[{"2", " ", "\[Beta]", " ", "\[CapitalDelta]\[Tau]", " ", 
        RowBox[{"y", "[", "\[Tau]", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"2", " ", "n"}], "+", 
          RowBox[{"2", " ", "n", " ", 
           RowBox[{"y", "[", "\[Tau]", "]"}]}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          SuperscriptBox[
           RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}], "2"], ")"}], 
         "n"]}]}], ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"4", " ", "\[CapitalDelta]\[Tau]", " ", 
     RowBox[{"y", "[", "\[Tau]", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["2", "n"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"2", " ", "n"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"y", "[", "\[Tau]", "]"}]}], ")"}]}], "-", 
       RowBox[{"n", " ", "\[Beta]", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          SuperscriptBox[
           RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}], "2"], ")"}], 
         "n"]}]}], ")"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.8011898232628975`*^9, 3.801189873299265*^9, 
  3.8011985675613456`*^9, 3.8012024596161313`*^9, 3.801203433232456*^9, 
  3.8012126802820787`*^9, 3.801213820046365*^9, 3.801215438921057*^9, 
  3.801222834939579*^9, 3.818772855591674*^9}]
}, Open  ]],

Cell[TextData[{
 "We note the choice of \[Alpha] and ",
 Cell[BoxData[
  FormBox["\[CapitalDelta]\[Alpha]", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " should still respect the gradient stability constraint: ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", ">", 
    RowBox[{
     RowBox[{"-", "1"}], "/", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Alpha]", "i"], "-", "1"}], ")"}]}]}], 
   TraditionalForm]]],
 ".\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{"[", 
    RowBox[{"n", "=", 
     RowBox[{"-", "1"}]}], "]"}], TraditionalForm]],
  FontColor->RGBColor[1, 0.5, 0.5]],
 "\n\nSetting up the parameters and the integration function..."
}], "Text",
 CellChangeTimes->{{3.801189891327777*^9, 3.801189917569847*^9}, {
  3.8011962297168226`*^9, 3.8011962321308885`*^9}, {3.8011962958903894`*^9, 
  3.8011962981299553`*^9}, {3.818772864157874*^9, 3.8187728962307367`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"case1", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"n", "\[Rule]", 
       RowBox[{"-", "1"}]}], ",", 
      RowBox[{"\[Beta]", "\[Rule]", "1"}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"choice", " ", "is", " ", "so", " ", "that", " ", 
     SubscriptBox["\[Lambda]", "i"]}], "=", 
    RowBox[{
     RowBox[{"19", "/", "10"}], " ", "corresponding", " ", "to", " ", 
     "previous", " ", "cases"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ptparam1", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Lambda]", "\[Rule]", 
       FractionBox["33", "20"]}], ",", 
      RowBox[{"\[CapitalDelta]\[Lambda]", "\[Rule]", 
       RowBox[{"-", 
        FractionBox["1", "2"]}]}], ",", 
      RowBox[{"\[CapitalDelta]\[Tau]", "\[Rule]", 
       FractionBox["1", "10"]}], ",", 
      RowBox[{"\[CapitalTau]", "\[Rule]", "2"}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ng1", "=", 
   RowBox[{"n", ">", 
    RowBox[{"-", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Lambda]", "-", 
         FractionBox["\[CapitalDelta]\[Lambda]", "2"]}], ")"}], "-", 
       "1"}]]}]}]}], ";", 
  RowBox[{
   RowBox[{"ng1", "/.", "case1"}], "/.", 
   "ptparam1"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ng2", "=", 
    RowBox[{"n", ">", 
     RowBox[{"-", 
      FractionBox["1", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Lambda]", "+", 
          FractionBox["\[CapitalDelta]\[Lambda]", "2"]}], ")"}], "-", 
        "1"}]]}]}]}], ";", 
   RowBox[{
    RowBox[{"ng2", "/.", "case1"}], "/.", "ptparam1"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PTint", "[", 
   RowBox[{"\[CapitalPsi]0_", ",", "y0_", ",", "\[Tau]0_", ",", "\[Tau]f_"}], 
   "]"}], ":=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"ds1ND", "/.", "case1"}], "/.", "ptparam1"}], ",", 
      RowBox[{
       RowBox[{"ds2ND", "/.", "case1"}], "/.", "ptparam1"}], ",", 
      RowBox[{
       RowBox[{"\[CapitalPsi]", "[", "\[Tau]0", "]"}], "\[Equal]", 
       "\[CapitalPsi]0"}], ",", 
      RowBox[{
       RowBox[{"y", "[", "\[Tau]0", "]"}], "\[Equal]", "y0"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[CapitalPsi]", ",", "y"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Tau]", ",", "\[Tau]0", ",", "\[Tau]f"}], "}"}], ",", 
    RowBox[{"WorkingPrecision", "\[Rule]", "50"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.8011901492552853`*^9, 3.8011901641912055`*^9}, {
  3.801196234102021*^9, 3.801196275330675*^9}, {3.801196934424216*^9, 
  3.8011969390058403`*^9}, {3.801212675919751*^9, 3.801212699409402*^9}, {
  3.801212738261182*^9, 3.8012128419388747`*^9}, {3.8012129514505167`*^9, 
  3.8012129544731865`*^9}, {3.8012130998447313`*^9, 3.801213113680388*^9}, {
  3.8012131838359985`*^9, 3.8012132031726613`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.80119625348886*^9, 3.8011962759289956`*^9}, 
   3.8011969426270075`*^9, 3.801198567631522*^9, 3.8012024596487145`*^9, 
   3.801203449499844*^9, {3.801212729616165*^9, 3.8012127393460493`*^9}, {
   3.801212773960473*^9, 3.8012128424155245`*^9}, 3.801212955215149*^9, 
   3.8012131494126167`*^9, 3.8012138200929413`*^9, 3.801215438950034*^9, 
   3.8012228349898663`*^9, 3.818772917592002*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.80119625348886*^9, 3.8011962759289956`*^9}, 
   3.8011969426270075`*^9, 3.801198567631522*^9, 3.8012024596487145`*^9, 
   3.801203449499844*^9, {3.801212729616165*^9, 3.8012127393460493`*^9}, {
   3.801212773960473*^9, 3.8012128424155245`*^9}, 3.801212955215149*^9, 
   3.8012131494126167`*^9, 3.8012138200929413`*^9, 3.801215438950034*^9, 
   3.8012228349898663`*^9, 3.8187729175969243`*^9}]
}, Open  ]],

Cell["...we obtain...", "Text",
 CellChangeTimes->{{3.8011963012716465`*^9, 3.8011963037667418`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"PT1", "=", 
    RowBox[{
     RowBox[{"PTint", "[", 
      RowBox[{"1", ",", 
       FractionBox["11", "10"], ",", "0", ",", "5"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Log", "[", 
       RowBox[{
        RowBox[{"y", "[", "\[Tau]", "]"}], "-", "1"}], "]"}], "/.", "PT1"}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Tau]", ",", "1", ",", "3"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "Automatic"}], ",", 
    RowBox[{"AxesStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", "Red", "]"}]}], ",", 
    RowBox[{"Ticks", "\[Rule]", "Automatic"}], ",", 
    RowBox[{"TicksStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.007", "]"}], ",", "Pink"}], "}"}], 
      "}"}]}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<\[Tau]\>\"", ",", "\"\<ln(\[Delta]\!\(\*
StyleBox[\"H\",
FontSlant->\"Italic\"]\)/\!\(\*
StyleBox[\"h\",
FontSlant->\"Italic\"]\))\>\""}], "}"}]}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Log", "[", 
      RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}], "]"}], "/.", "PT1"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Tau]", ",", "1", ",", "3"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"AxesStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"Directive", "[", "Red", "]"}]}], ",", 
   RowBox[{"Ticks", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"TicksStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Thickness", "[", "0.007", "]"}], ",", "Pink"}], "}"}], 
     "}"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<\[Tau]\>\"", ",", "\"\<ln(\[CapitalPsi])\>\""}], "}"}]}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.801196318352993*^9, 3.8011963644945135`*^9}, {
  3.8011963975344567`*^9, 3.801196615705003*^9}, {3.8011969453165064`*^9, 
  3.8011969455163383`*^9}, {3.8012035683967876`*^9, 3.801203583208755*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[1, 0.5, 0.5], Thickness[0.007], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV13k4Vc8fB/BzkUtpIVnDsVxZS7QiM9ZoQSKSLSU/e5SlRPaIUJaESuor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       "]]},
     Annotation[#, "Charting`Private`Tag$4077#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"\[Tau]\"", TraditionalForm], 
    FormBox[
    "\"ln(\[Delta]\\!\\(\\*\\nStyleBox[\\\"H\\\",\\nFontSlant->\\\"Italic\\\"]\
\\)/\\!\\(\\*\\nStyleBox[\\\"h\\\",\\nFontSlant->\\\"Italic\\\"]\\))\"", 
     TraditionalForm]},
  AxesOrigin->{1.0000000408163265`, -10.610413482013394`},
  AxesStyle->Directive[
    RGBColor[1, 0, 0], 15],
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[
    RGBColor[1, 0, 0]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{1.0000000408163265`, 
   2.9999999591836737`}, {-10.610413482013394`, -5.810468613508928}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic},
  TicksStyle->Directive[
    RGBColor[1, 0, 0], 15]]], "Output",
 CellChangeTimes->{
  3.801196564191162*^9, {3.8011966037788696`*^9, 3.801196618818711*^9}, 
   3.801196948298752*^9, 3.8011985700046515`*^9, 3.8012024610624404`*^9, 
   3.801203453782811*^9, 3.8012128601232967`*^9, 3.8012131645782423`*^9, 
   3.801213821282196*^9, 3.801215440362337*^9, 3.8012228370800853`*^9, 
   3.8187729539679766`*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[1, 0.5, 0.5], Thickness[0.007], Opacity[1.], 
      LineBox[CompressedData["
1:eJwd13c8ld8fAPA75KqQZERJy1ZCy6jPoaJBWuJLRlKIKBQqUhGSVVIqkZAV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       "]]},
     Annotation[#, "Charting`Private`Tag$4118#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"\[Tau]\"", TraditionalForm], 
    FormBox["\"ln(\[CapitalPsi])\"", TraditionalForm]},
  AxesOrigin->{1.0000000408163265`, 0},
  AxesStyle->Directive[
    RGBColor[1, 0, 0], 15],
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[
    RGBColor[1, 0, 0]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{1.0000000408163265`, 
   2.9999999591836737`}, {-0.14923870280569737`, 0.25565353212841296`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic},
  TicksStyle->Directive[
    RGBColor[1, 0, 0], 15]]], "Output",
 CellChangeTimes->{
  3.801196564191162*^9, {3.8011966037788696`*^9, 3.801196618818711*^9}, 
   3.801196948298752*^9, 3.8011985700046515`*^9, 3.8012024610624404`*^9, 
   3.801203453782811*^9, 3.8012128601232967`*^9, 3.8012131645782423`*^9, 
   3.801213821282196*^9, 3.801215440362337*^9, 3.8012228370800853`*^9, 
   3.818772954697959*^9}]
}, Open  ]],

Cell[TextData[{
 "We can also just easily match the asymptotic solutions obtained in Sec. \
IIIC, namely, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Delta]H", "~", 
     SuperscriptBox["e", 
      RowBox[{
       RowBox[{"-", "3"}], "h", " ", "t"}]]}], "=", 
    SuperscriptBox["e", 
     RowBox[{
      RowBox[{"-", "3"}], "\[Tau]"}]]}], TraditionalForm]]],
 ". We input this asymptotic expression as follows and find its coefficient \
manually..."
}], "Text",
 CellChangeTimes->{{3.801203458598804*^9, 3.801203545138534*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"approx", "[", 
     RowBox[{"x_", ",", "dash_", ",", "thick_", ",", "color_"}], "]"}], ":=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"Log", "[", 
       RowBox[{"x", " ", 
        SuperscriptBox["E", 
         RowBox[{
          RowBox[{"-", "3"}], "\[Tau]"}]]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Tau]", ",", "1", ",", "3"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "Automatic"}], ",", 
      RowBox[{"AxesStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
      RowBox[{"LabelStyle", "\[Rule]", 
       RowBox[{"Directive", "[", "Red", "]"}]}], ",", 
      RowBox[{"Ticks", "\[Rule]", "Automatic"}], ",", 
      RowBox[{"TicksStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Dashing", "[", "dash", "]"}], ",", 
          RowBox[{"Thickness", "[", "thick", "]"}], ",", "color"}], "}"}], 
        "}"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pt1h", "=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Log", "[", 
         RowBox[{
          RowBox[{"y", "[", "\[Tau]", "]"}], "-", "1"}], "]"}], "/.", "PT1"}],
        "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Tau]", ",", "1", ",", "3"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "Automatic"}], ",", 
      RowBox[{"AxesStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
      RowBox[{"LabelStyle", "\[Rule]", 
       RowBox[{"Directive", "[", "Red", "]"}]}], ",", 
      RowBox[{"Ticks", "\[Rule]", "Automatic"}], ",", 
      RowBox[{"TicksStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Thickness", "[", "0.007", "]"}], ",", "Pink"}], "}"}], 
        "}"}]}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<\[Tau]\>\"", ",", "\"\<ln(\[Delta]\!\(\*
StyleBox[\"H\",
FontSlant->\"Italic\"]\)/\!\(\*
StyleBox[\"h\",
FontSlant->\"Italic\"]\))\>\""}], "}"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"pt1h", ",", 
   RowBox[{"approx", "[", 
    RowBox[{
     SuperscriptBox["E", 
      RowBox[{"-", "2.82"}]], ",", "Large", ",", "0.007", ",", "Green"}], 
    "]"}], ",", 
   RowBox[{"approx", "[", 
    RowBox[{
     SuperscriptBox["E", 
      RowBox[{"-", "1.6"}]], ",", "Medium", ",", "0.007", ",", "White"}], 
    "]"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.8012036586258383`*^9, 3.8012036793529243`*^9}, 
   3.801213327995326*^9}],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[1, 0.5, 0.5], Thickness[0.007], Opacity[1.], 
       LineBox[CompressedData["
1:eJwV13k4Vc8fB/BzkUtpIVnDsVxZS7QiM9ZoQSKSLSU/e5SlRPaIUJaESuor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        "]]},
      Annotation[#, "Charting`Private`Tag$4463#1"]& ]}, {}, {}}, {{{}, {}, 
     TagBox[
      {RGBColor[0, 1, 0], Thickness[0.007], Opacity[1.], Dashing[Large], 
       LineBox[CompressedData["
1:eJwVynk41HkcwPExmG+Jkmga0ZgxMz9ayaJVlO/XkaOmdTyIKWfZdTaZVnmy
Ks0oOuiQ2vCY0lNR8UwTW4o+qZBESUvHtp7tcOQYuY/Mtn+8n9c/b06U2D+a
TqPRNn3vf2M7R3RoNBXOy7ppUubJBC/NAScpXYWrtyWmn/BmgoWgK4GhrcKf
1ll8lmxkwuf41826Oips/7Ww3MGHCdvHq0+xDFW4VZTl+iCICRHzDxvbWajw
AquImLZoJgStZS3/xVeFM5v1bk1JmeB+bp13k1yFUxfFbvQEJuQZTemwfYZw
SlLlVm23JTDEbkj+ODSE104+T2BVLwF+o2laysmv+MNqP0mDPQta1nSh087D
+KIwRlRQyQLpT7VOZp3D2PKI0KVupTGUTegP2+WM4Mb8eh0jpTEoRF0ei51G
sTD66pNZu6VQ493iFv92FOcFBx12vr4UXGaXP/LIGsMT7Hyq2NoEmvG5/twf
xjFn4Y260KsmYM85rlQ0jmPrKt4WJdsU9BtGZwL2TOAAB7vWFRdMYWxaPBi3
ZBLj9/O9ZlnLwH80NBrVT2KPkHT5cMEyOJz9co9EMoWtjoUMSE3ZUHdLZOdr
MI3fds86xp1hQ6o8UHLr/jRuPWZaUTXPDBxZUaKjkTPY2JErjPcyA/Hmfx93
63/DiX6SAOsjZpC2qveZYfU3rHRPbq9pNIMzcs39ytBZ/K7pfcgUgwPmL04o
O+ap8cL7pzd5eXHgbvbKkzvL1Hi5RzlxyeCA0VhpxhcBjdiXpJWhBxzIRCla
UWk0smH32eOdGlw48M+z9oXNNOLewUzY7swF+/N/98n4GmTjpQ93p/ZzoY33
o294qgZxE0YdCgMuTCbrzdn1VIOwszx9E2e48LqkWGMDl06QTcrR7HXm4Hyp
1ke0i05a4xfUifaaQ84Oft+LWjrJkYakjlSYQ/5S10ZdliYJ1h68IB8zB6uc
rpkDsZpE2+RL/bgtD1I+eSTdBk1SU2AbHvkbD7zpKx0tDbTIlpudo8kKHqBB
kZ9GlBbpKXZBwf08OFBDSgtuaxGZuj9LaM2HfQHlm5PmahO6iqbbF8cHh2ft
HnMjtcnxDeHqwut8eGfkLpvzpzaZm74z0bSfDwz+msUuiEFihN1vPC0F8GVx
d8/aMAZpS792RxYngMAWtoGknEF4wldnE64I4Prm/Mz5agaJ/qpQcT4IoKb2
OdkRiMhN+puqHnMKAkeyN6HLiHy8EiPbGkFBbbOrjfgKIpVHxTviIimwKRkz
aL+KSKZ4d3BKFAW6YWEdl68hssJBZpW7nYJH9Su2eSgQ2VNX1PY0hgLb/KaU
jHuI6Hz6i+eURIG+q84lzZeI2HDXP2YdpGCfSc2h+DZE6AxhOSWloG8sKfbl
K0Re9fj/sUpGQcO119bFHYjsVUQk+h2iYL9RyR3X94g8JL8bZR2hYKDbsyW9
B5GgcGX0xCkKtj6cVvT0ImLpVuXDyKWgsbA8168PkRnBgzWGZyi47M8UcQYR
kQ8069mcpSD03uePMIJIb1pvxa/53/+88/UWY4jcixwqSi6gYHXSz6UnxhHJ
Xj+RJS2kwFBQKY6YQsROjxFWVETBQVqcf8M0IowhXa8bcgpUb0xX2XxDpKNt
ke3dCxSEVbxgnptFpPS2scmTixQ05WRMqdWIpBVwGO3FFPwHFV47ow==
        "]]},
      Annotation[#, "Charting`Private`Tag$4501#1"]& ]}, {}, {}}, {{{}, {}, 
     TagBox[
      {GrayLevel[1], Thickness[0.007], Opacity[1.], Dashing[Medium], 
       LineBox[CompressedData["
1:eJwVyms01GkcwPExY+aJ1cQwxrjPmL+kQikJeR6KJccll+qoVIrdSEJO5lTS
FtWpSAll62izSYXVSLbQ7wxlVi5NKtQmp+QyiRFGBtn2xfd83nwFkfHBUXQa
jeb/o//d0zOuTaMp8X32tX3R0RzwYQy7Hqcr8buBze0+v3LAxrp/L4upxMx6
fefFMRzoi+1q1dFW4pCDpzWUcRzYPVl7gW+gxKPvD+SIkzmwg33S2NFGie0q
/B6ePcGBjW582+ggJS4OmWJK/uDAuvw1vs2FSnwlP/TqXDcHcrlqbYvAUZyn
ul5Wu1MfRi1kyb2jo3hrak2d/K0+UE1mR1Kyv2J6nVtDWogBtK3uRxfdx7BU
HnI39JUBHHeSulr2jGHfBc4XUwO4UPZNd8wxaxwPWkq2tsi5UBHe723oOoFj
FRdNHgQbQp1v29rYtxP4/juPLlWTIXh8t23wPq3CvD8zxFv8edCK87/kLJ7E
JDffyLCRBysE5yQVTZM4AOuWxrobga5sYib04DecVGMu6ntsBKrp+JEYoykc
sUt9ucqZD8ET26JQ4xSO6t779c4jPpzMbD+YmKjGfnpexM3NGJ5WhjsGcaax
Ok5xVlhpDIcKwxIrH0/j+mvWNUudTMCFHxl+ZucMDpmyV2SWm0D8pg9PBnRn
sXrhc7WBoykcWaloMaidxens1zSnSlO4VMg4Ktn2HXeYlzBLl5iBlfy8pPOn
OezB0P/iU24GjzLts/eXzeEkvfXtLovMgau6nf7ZmkYyOvrKGgvN4RRK0Yw8
QiOSBOM4sdAC0t63dOi10kjxShPbYwUWsOLKu6ETlAZ5E93Vu3GBJbwULQva
fkiDvGBvLn8YaAlTyfPnJT3TIGV+a8T/nLGErpIbGuuFdJL7Na5S0WwJ7kXS
wPAkOom0Y45UaQkgax81JJfSibl3YFGQlwAKTDybdPgM0t/Y2zSTLoAlWf0z
aXsYJKe7RxkiFUDKJ++EamAQ/+02p2oZQvCl27ss4mgSxYHX5i+IENBI+AaN
SE2SEr3KofKwENLqyO3fqzWJvvTjvVu1QkgNLd+UoMUkF+6pVviohbCqpcNb
ayeTmM4Ps1G7WsG/3HUn5j1gkvy10bniw1bAolYbeiAWmWR3M4qqreCz4cCg
WwSL7Fp3/UPPlBWEtVlwEstZRMJ+BjInEdzdVHCKPcci45XF/NREEdRJn5N9
YYh4PGn76CURQdh4pj+6iUhSTERp9YgIpK2eDvHFiHgFROU9VYrAoUTF6biF
CG/53mMvR0WgExHRefMOIjVT4jDlmAgaGpfu8q5AhHX60uzCbyJYXtCckl6D
yOXiZv88GgW6ntpFjHZEHve6DCfrUZBqWpcR+xKRbJlH53EOBUOqhD3trxDZ
fddHmq1PgexOl92NTkS0DmzMLeVScJRb8rdnNyLBjET3T3wKhgd+bjs2iMgn
QUlmqJCCrfXTFYMKRKqZf6VEWlHQdLU8Z8MQImcGqyL3iyi4GcwLF4wgYl/R
4HTWmoJtNX29MI6ImPR019v++HOvNNqoEPET9cvkiylwTgi4fX4SEbN5w/fe
L6HAwLoqfocaEWnbdMa0HQW/0WKCZdOIXJLQE7QcKFC+MVvpMIvIL3laW3jL
KIi4L+flf0dk9SFdL2o5Bc1Z6eq5OUR0tvPsHR0p+A8dz0Iy
        "]]},
      Annotation[#, "Charting`Private`Tag$4539#1"]& ]}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"\[Tau]\"", TraditionalForm], 
    FormBox[
    "\"ln(\[Delta]\\!\\(\\*\\nStyleBox[\\\"H\\\",\\nFontSlant->\\\"Italic\\\"]\
\\)/\\!\\(\\*\\nStyleBox[\\\"h\\\",\\nFontSlant->\\\"Italic\\\"]\\))\"", 
     TraditionalForm]},
  AxesOrigin->{1.0000000408163265`, -10.610413482013394`},
  AxesStyle->Directive[
    RGBColor[1, 0, 0], 15],
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[
    RGBColor[1, 0, 0]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic},
  TicksStyle->Directive[
    RGBColor[1, 0, 0], 15]]], "Output",
 CellChangeTimes->{3.8012036813581095`*^9, 3.801213329643466*^9, 
  3.8012138226477413`*^9, 3.8012154418577757`*^9, 3.8012228396383967`*^9, 
  3.8187729663523645`*^9}]
}, Open  ]],

Cell["\<\
The three plots above make figure 8. Clearly, the asymptotic solutions hold \
in both phases.\
\>", "Text",
 CellChangeTimes->{{3.801203691097289*^9, 3.8012037334905586`*^9}, {
  3.818772981329316*^9, 3.818772992482974*^9}}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{"[", 
    RowBox[{"n", "=", 
     RowBox[{"-", "2"}]}], "]"}], TraditionalForm]],
  FontColor->RGBColor[1, 0.5, 0.5]],
 "\n\nSetting up the parameters and the integration function..."
}], "Text",
 CellChangeTimes->{{3.801196652206235*^9, 3.8011966546252356`*^9}, {
  3.801196757621277*^9, 3.801196760138147*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"case2", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"n", "\[Rule]", 
       RowBox[{"-", "2"}]}], ",", 
      RowBox[{"\[Beta]", "\[Rule]", "1"}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"chosen", " ", "so", " ", "that", " ", 
     SubscriptBox["\[Lambda]", "i"]}], "=", 
    RowBox[{
     RowBox[{"7", "/", "5"}], " ", "corresponding", " ", "to", " ", 
     "previous", " ", "cases"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ptparam2", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Lambda]", "\[Rule]", 
       FractionBox["51", "40"]}], ",", 
      RowBox[{"\[CapitalDelta]\[Lambda]", "\[Rule]", 
       RowBox[{"-", 
        FractionBox["1", "4"]}]}], ",", 
      RowBox[{"\[CapitalDelta]\[Tau]", "\[Rule]", 
       FractionBox["1", "10"]}], ",", 
      RowBox[{"\[CapitalTau]", "\[Rule]", "2"}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ng1", "=", 
   RowBox[{"n", ">", 
    RowBox[{"-", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Lambda]", "-", 
         FractionBox["\[CapitalDelta]\[Lambda]", "2"]}], ")"}], "-", 
       "1"}]]}]}]}], ";", 
  RowBox[{
   RowBox[{"ng1", "/.", "case2"}], "/.", 
   "ptparam2"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ng2", "=", 
    RowBox[{"n", ">", 
     RowBox[{"-", 
      FractionBox["1", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Lambda]", "+", 
          FractionBox["\[CapitalDelta]\[Lambda]", "2"]}], ")"}], "-", 
        "1"}]]}]}]}], ";", 
   RowBox[{
    RowBox[{"ng2", "/.", "case2"}], "/.", "ptparam2"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PTint2", "[", 
   RowBox[{"\[CapitalPsi]0_", ",", "y0_", ",", "\[Tau]0_", ",", "\[Tau]f_"}], 
   "]"}], ":=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"ds1ND", "/.", "case2"}], "/.", "ptparam2"}], ",", 
      RowBox[{
       RowBox[{"ds2ND", "/.", "case2"}], "/.", "ptparam2"}], ",", 
      RowBox[{
       RowBox[{"\[CapitalPsi]", "[", "\[Tau]0", "]"}], "\[Equal]", 
       "\[CapitalPsi]0"}], ",", 
      RowBox[{
       RowBox[{"y", "[", "\[Tau]0", "]"}], "\[Equal]", "y0"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[CapitalPsi]", ",", "y"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Tau]", ",", "\[Tau]0", ",", "\[Tau]f"}], "}"}], ",", 
    RowBox[{"WorkingPrecision", "\[Rule]", "50"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.8011966734476876`*^9, 3.8011967795684147`*^9}, {
  3.801196955426371*^9, 3.801196956314146*^9}, {3.801213378743013*^9, 
  3.8012133861566176`*^9}, {3.8012134212502556`*^9, 3.801213449648864*^9}, {
  3.8012138478031125`*^9, 3.801213868459365*^9}, {3.801214953759858*^9, 
  3.8012149721857786`*^9}, {3.8012150266568127`*^9, 3.801215091771795*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.80119676510635*^9, 3.8011967816454744`*^9}, 
   3.8011968854709296`*^9, 3.8011969578639207`*^9, 3.8011985718522024`*^9, 
   3.8012024621324472`*^9, 3.8012041310088186`*^9, 3.8012133884031444`*^9, {
   3.801213426576337*^9, 3.8012134507298417`*^9}, 3.80121382267548*^9, {
   3.801215027669325*^9, 3.801215054821061*^9}, {3.801215088011352*^9, 
   3.8012150921396914`*^9}, 3.801215441884702*^9, 3.8012228397302685`*^9, 
   3.818773010825033*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.80119676510635*^9, 3.8011967816454744`*^9}, 
   3.8011968854709296`*^9, 3.8011969578639207`*^9, 3.8011985718522024`*^9, 
   3.8012024621324472`*^9, 3.8012041310088186`*^9, 3.8012133884031444`*^9, {
   3.801213426576337*^9, 3.8012134507298417`*^9}, 3.80121382267548*^9, {
   3.801215027669325*^9, 3.801215054821061*^9}, {3.801215088011352*^9, 
   3.8012150921396914`*^9}, 3.801215441884702*^9, 3.8012228397302685`*^9, 
   3.8187730108310704`*^9}]
}, Open  ]],

Cell["...we obtain the results...", "Text",
 CellChangeTimes->{{3.8011968085849323`*^9, 3.801196811931019*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"PT2", "=", 
    RowBox[{
     RowBox[{"PTint2", "[", 
      RowBox[{"1", ",", 
       FractionBox["12", "11"], ",", "0", ",", "5"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pt2h", "=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Log", "[", 
         RowBox[{
          RowBox[{"y", "[", "\[Tau]", "]"}], "-", "1"}], "]"}], "/.", "PT2"}],
        "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Tau]", ",", "1", ",", "3"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "Automatic"}], ",", 
      RowBox[{"AxesStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
      RowBox[{"LabelStyle", "\[Rule]", 
       RowBox[{"Directive", "[", "Red", "]"}]}], ",", 
      RowBox[{"Ticks", "\[Rule]", "Automatic"}], ",", 
      RowBox[{"TicksStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Thickness", "[", "0.007", "]"}], ",", "Pink"}], "}"}], 
        "}"}]}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<\[Tau]\>\"", ",", "\"\<ln(\[Delta]\!\(\*
StyleBox[\"H\",
FontSlant->\"Italic\"]\)/\!\(\*
StyleBox[\"h\",
FontSlant->\"Italic\"]\))\>\""}], "}"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{"pt2h", ",", 
    RowBox[{"approx", "[", 
     RowBox[{
      SuperscriptBox["E", 
       RowBox[{"-", "1.05"}]], ",", "Large", ",", "0.007", ",", "Green"}], 
     "]"}], ",", 
    RowBox[{"approx", "[", 
     RowBox[{
      SuperscriptBox["E", "0.15"], ",", "Medium", ",", "0.007", ",", 
      "White"}], "]"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Log", "[", 
      RowBox[{"\[CapitalPsi]", "[", "\[Tau]", "]"}], "]"}], "/.", "PT2"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Tau]", ",", "1", ",", "3"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"AxesStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"Directive", "[", "Red", "]"}]}], ",", 
   RowBox[{"Ticks", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"TicksStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Thickness", "[", "0.007", "]"}], ",", "Pink"}], "}"}], 
     "}"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<\[Tau]\>\"", ",", "\"\<ln(\[CapitalPsi])\>\""}], "}"}]}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.8011968195931005`*^9, 3.801196867287266*^9}, {
   3.8011969650241356`*^9, 3.8011969653728523`*^9}, {3.801204175471151*^9, 
   3.801204197912633*^9}, 3.801204292626465*^9, {3.8012135108595095`*^9, 
   3.8012135336707006`*^9}, {3.801213642731721*^9, 3.801213669769216*^9}, 
   3.801213768116501*^9, {3.801215113116953*^9, 3.8012151149415903`*^9}, {
   3.8012153398496885`*^9, 3.80121534137558*^9}, 3.8012153891342707`*^9}],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[1, 0.5, 0.5], Thickness[0.007], Opacity[1.], 
       LineBox[CompressedData["
1:eJwV13k8Vc8bB/BzkUtS9pyjxVUklLSTmkklqSSRIpIsWSIUyhKyRIUSId8Q
SZFsWcNkyZqtbNEqS1kiS0r3nN/8/rqv9+t1z9yZeZ7nc+BYOhtY8xAEsYlF
EP//tPs8vZAgJkASefnIJ38RpMM7vuMazwR4Q1v3PL4mghQVhhz5F0wAN4c4
lwtBImjQoad50cIJ4CiR08QKFUFWv8vukBITIDgxR0U+UgRZLA6hNilOgBg5
r5tOD0TQcU1SyUZ/Amz084gUKhVBe2N3HmhKmgA7aadBx2kRFCP5d+HKI5OA
51kKx8tFFE2urLv0bXISuMG69F+Doki+YbmP5+1foGzqfFimiRhqUR9iR+2a
AvHUvVbULYauba3cIft5CmRt1jPr0xNHWXMiU5sipsGe7rwv+1rEUY7JkLbU
jhngUqe65cVhCVR+oGWPQ+8M2KewxHKsSgLtppWqtUNnwY5AuQ7LvZKoGcSO
3VX+DXj7Q4KCX0qizZxbeTkNv0HHiRrtyxulkEjdzD9DjzkQ4+HcGp8rhWbn
nX/aS/8Bbl0duXuUliKDGTNrdu0fUFjrG0dkLkUh4W89XF3/gpEFu1N3Kkuj
1/kmm/TF5sH8+xuFvsnSyCvJyDW/Yh78bdHXiZUlkQZpaXLjzD+QG2XxNecu
iZyNv9YMi3BBlpDtMuVFFBp253GPE+cCqo9J/CFMIYsYOQVdKS6I7ew98GQJ
hfQ7LIMzZLgg9EDUgtXiFNpwrF/bSYEL7E2qWhZTFPql9612agcXLDbvUCpc
QyF37cF62oYLVgTektmpRaFxa/4rz+24wHx23+3ePRSyCVJQsnDkglHY9Npz
H4WMq23CXrlwAcdEyPK5DoW2aw3pBnpzwcjZpNFFRyj0d+dwo+AdLhCXkW4M
MqWQz5YfbyTKuODllbSD+m4UUrqfpXOvggt+2VPiaRcp1Em4VZGVXMBf167z
9xKF1jfNF62o5YJZGbPx/zwp9NlSOFWxjQt8FZZktPlQaE/khiuaA1zA2+co
PRRCoYmZ6enyIS4wO2tUxgmlUIJpsfPuH9hka6hJGIWmFbSstX9yQWttSvDr
mxRKKzumr/+HC9wyiLCQ2xQSHHFXsBKmgdVPYacn8RQq0N+RPLiEBpG0/b7q
+xSyLGBk7MRooLpu80xfAoVK/K+LOi2lwVyHQj07kUKO0vH/PDg0WGTxMEsr
hUIt+8rab2yhwSET8yKdDAp5Z/gfXrydBrZqBnd3ZVJIUVS7LlKDBrd0WyfV
nlHIr6+5LBrQYHVFDSX6nEIb3T6nJx6gwaPNVYHZuRSKTuK9mmdGA2cyId2p
mEInOjrEHS1oMDLyeFC3hELUwvT01Wdp8NVbp25VKYUeuB1qjz5Hgy0mX4wb
X+LzakfLe7rRQCGlsn2igkLnvGxLNrjTwKxk2DgH4Xpkqx/57kmDcHfPPU6v
KPSc/Ohp4kuDlmvCqh8qKVQ0qtCkGUoDg49WfuE1FLrC+WMxc4MGY927zqi9
ppDm8caZZ+E0WMozbN+K/arCeeXKuzSwkf/ew1NHocDp3fldMTTY92NINQZb
e63Egcg4Grhc4ouUr6dQw50iV1YiDfrvL9Tf3kChm7Vh7JJkGnz2LE4qxdb7
dyrBNZUGgcWiHzQaKfTWmvW6/wkNrguE/FVpolDfdl3ydT4NrE2jZj++wec/
vyzLt5AGmw+4t8NmPB8Px7W2ldAgtNPC/AH2gFCUY3oFDS5Hq9kdaqFQOrRm
namkQWHX454EbPtL22LIGhpkqe//MIw9/rG3IqyBBt6fcv3dWimULZ5luOcN
DfSCvSVysV11/L7Pt9Bg/zWHFaPYm30MfPPbaXDxfFosp41Cv3NWi5/voIG+
nLW3AXbJ4Oxj+W4a+N2YrPTF9pap1/z4ngbDZunWadi79O+3xXyggenwH7N6
bCLovM2RzzT40mP/aAi7shjMs/vxfvmjt7Da8f2Oi0aiAXwedUUBKWztVd9W
Xx6mwWKeESkFbMETBcVqIzTYGVBqqobddPO63o8xGiTsjWzdhh3+yqT/4QQN
asjLzurY+rMqnqZTNGgcSty4FVtMmVkkMYv7M/iAxHrsd6fbkpvmaMCO6VzM
wY65m7I1aJ4GK02rly3BPlF/qXEnTYOtyc+2z+H9UvR+i1mCAeSdg2Z92H0b
qZksXgaoZroHlWI/sB0NteVnwMztNZnR2BYJ5StkBRngOOHRZI+9qi0yr1uI
AbvtUr5o/H+9Q2zxs4sZoJA0cUcQW6TWx3VMhAG6xnxdb/H982tNt3mIM+Dh
7aNP47D/vbRX45FiQHmtraAp9q9tXyJvSjPAPmxqYin291zjCSkZBsQpV5i1
4np3pu99rizLgDUjXSWbsJtWlS4ukGNA717DRx9x/1Q9UHOC8gxQ33xBMAg7
++6KdUZKDOApPLi5Gvdf2pLom59UGNDvrjV7CjshTGjUTpUBN7x0FCdxv4b6
zT313cwAnUdu74Sw/eadFgpuY8C556O6d3B/u7sP2EWpM6B1yQolCWxLx3bF
9F0M6OuZWLYQz4Pmicy0Nh0GMD8G88trcV68leM/dRD/3tZMfVnstXpx1oOH
GdB1rPGwD55Hqb3Bq+cNGKCZ6u+wFs/vT1WLh6vNGPDs/DkNXTzfg087Wc9P
M2DzdseBYDz/ffKHz6hbMmDqhOpMOc6HOhkNWT1bBoyVSOtwcH48ZEs88HBh
QLGT7I8snDexAWFc1kUGXNXzGX6N8yiCS5jddGdAdmK/yXucV95TYzLJXgwY
slZ7PFVIIaNPtXENQQz4ksSvPpFHoUMmu/4YXmdAtLCv2jecd1od+Sc+hTHA
C8qXvM3B74PG5KXTEQyQEJcIf4TzUaDQK3p5PN7Pqz8NEjhfS8NVb1/IwvU/
5puqkIzfd4rSyuPZDMhjP+7sw/mc9oqocchjQOOBLrmIBxS6M902Z1PEAPld
0WuGcb6fM7loYVaJ+8+TfuUYg+9LoVhVt5MBZd3mX2vx+8O1TKt5Fc2A+yUS
kcIuFLqYIZmvTxAw8YuSz0lnvL85Qf8IFgGdDK90PTxPodTbvyhhPgIamF1Z
uN6eQpHVVXoCggR0v/h6cs1ZCtkq2RTQYgQMVxfwKzCkkOTs06ARBQJu84mQ
zthKIROltNP7FAn4uy9yU+xmCiWZJ6snriVggWnt3cCNFFKpvTdmoELADU5j
fqbrKfz3VKBRiRoBB2l7Kz4FvF8Nc/lQTQK2rVKLMJKkULOvaI2CAQG97fbs
CJ8mkUTeokS/YwQcF1t+MvwXiUyG2JffGxKwIl7JKXKCRANHaJVwYwK+GlFt
jh8l0T/Zkbszpwh48sF0eMM3EilXVVtV2xJQzsqoJq2DRNfZnnyWPgRcEX0z
uamYRMPmNVWpvgS89XKrjW4RiXQKxK4NXSWgq9rNosYCEglYP2OdDyBgv/OC
DT15JAqp/Ep7hBBwHR8dIJtFomCfw39u3Sbgwan9TedSSDT4Lr6o9Q4B74nP
f171kETaKsMe4ncJSIo2ivYnkYi/N2A2NoaAWxJa+88/IFHQ9qKplPsEvByF
WAVxJAqckhsvfkRAXulLmyRvk+ib7oVn/9IIuGm874tEJIn2PixzBOkErKxv
5iUjSMR39MRI9VMCVk93Zq+/RaJrWbeGW54T8Mzh94KRoST6uqD3sVgOAWu6
rbLzrpNIy0zR1iiXgAvlj33tDSERz6Kqgff5BGyIj5hQDyZRgN3c14FiAl4X
sh1QuYafR/seKpYS8HCP7tJLAfh56agzDi8J2C0u9/mVP36+dt3niXIC/kgj
1O38SGS5witxEyLgR9eq+qqrJKq8VGfu/oqAizMnf8lh+68++2G+ioAm+YqL
f/qQ6LNXdsKuGlzfsijGFBu+5Zr6vyZgepPq9TfeJCICYt/z1xPQr/qPabkX
ifw+vekSbcb17F8+0XmZRA4r5FKdWwg4T+W6nMY+buZ+4U0rAXftbz845onr
37tCMPQtAa9plzLS2FKUW8fgOwJ++0/4XYEHXv9kbfLeTgJqxBGzJ7E7O501
iB4CvhHtlcx2J9EryWp+8/cElBDrW3QWO9NQ+m1pLz5vee4eGex7UY6J5Ac8
D45+Bd2X8P21IwePjwQMWLfzzH3s86KS2zs+ETC0oAicxT6hb8e36QsBjfXv
H96ArRVR1hr5lYAvX9sE82Cvaxb9b7yfgCWmHgM9F0kkLWxjd2iAgI2ZfDYF
2DyHSrY8HcTz9EiONxZ7LGwxj8AwARnbykJf7O56y2br7wQ03Jnna49dJVAY
X/WDgF4eKQam2Fn7hWw5owT0PM1ZfxQ7Lvj0pqtjBAyUSRA6hB1Yk8f0jRNw
9o7VwEFsZz6BJo0JAq4+lvVCH9tkz6nY2EkCFrlFuptg7w3Itpr9RUDKg1/O
Dlv1FZ+a4TQBy1dN5nhjU8RJbs4MASXPL5WNxuYDz+qX/CbgsNYam1zsnz6s
mPNzBCx1KfB5h/3+pZFl4x8CLvXZYzGPXTP/ZP3aeTxPFlvZa/D9ZGvQf4P/
4X4K++JgjB1/2aD2G5eASh4BITexg4rSorQYXJ8SrWOvsS/8/ns6iWBBjdvb
6/hwvUy2HlGhWSzo+cX2037sDfm/q4v5WNAnV6m7F1tm6uDtpfwsGJR4IUMF
9wP/xiSzS2wWvGxxnC8Au++5zuyGhSw431+xVgP3U+14QmW4EF6v3W8oATt3
3WT46CIW1DtpJsyH+zEkI25N+hIWnKk65fYJ2/XH2NQCURY8dMQ89dgVEp1a
q4XOirHgOkpjZRP2xsc/TqyUZMHRgndv63G/f3y4IyyGYsHlVcoWv/F81H+J
OD4tw4LTA93sW74kypf9JmewnAWfZOqVKuD5Cn1ws1RYFq+XyFGwwfO4Of7D
aKA8Cyp+DV8vgefZfNj+eJ8CC15/ZEu8xg7dOlexSZEFd5m99fIKxL/XLhb1
VYkFy1gORyeDcF4K6ajDDSwooPrrERvnSZ93btC8Bgs6ae47343zh78R/DTQ
xOuV2Z94hfNJjXxz4ulOFixqVnN/hvMr+MWQ8knIgtm/XVQiovB9jy9rL9jH
gqn30os87uF+Ox2ywlUfn3fjS+GuRNyfzySu1x9lQb+I0uqfOC975pMnZY+x
YFf/C00hnKfrY19WtxixYOh/hwx1U3G/t07arzNlwcF7/VbD6SRS0TpVOGzN
gu3vK7Qe5JLo3Wo1/dNeuF7K/xqra/E8xYgkJnqzYP2xJ8tE60lkxp4Y++TD
ghajXPnTDTi/v2fdsPBjwZZDtfrEGxLNZanUngliQZ6LAzeOt5NoubriLqsI
FuSqSH3Q+0Aim8MrVexS8H2f6HpngN9Xfy4JC7g14vvi5Y36Kk+hnicpLF05
Hrhtw6JAAv8/tiu18oiJGw/cmXt3RFNUBkU4yY+2VfLAk7Zn9ReHyKD7MloN
i0he2Lt31X5dgWVIJWLon58dL1Std75j5b8MeQ5ouxQhXpihrezxgW85OsCj
qrFWjA/GRZ1Z8uTqcsT+aXKUZckHK0sb1iyYW478yuHThCI+GCJmJR90ZQXy
NXxu7CK4ADYpglqt6RVo25subcEzC6BAZlazrOdK1Ce5N1CgcAHsX9cXEvpn
JeKXV5fazeaHZ94LjlPqsmhEavi7pjk/DLhuUuF/RRYZtawUc33OD50iB7bc
LJRFmcb3ry9m+OHfoLFnp6dkUXllK3QyYsMGfuWzezdzkNF0+GF2GhtmxyoK
tFzgoMpmrQ3Oj9kweOG54x9cOGjDk1mxrnQ2PKTnmjriykGLzM270zLYsNZ9
GAhc4qDq2nVntXPY8KjgqYu7L3PQxvtNnkEv2bBK3Ottnj8HiWgtTOV9i00b
OcTe4SDfZeXBDu/YcOr3mry0KA4anXWxe9vBhnqn6/7m3+Wguoye9SndbKjF
vRjaFsNBVyWfFGt9ZMPkHz6pC+9z0Pjw/hb/72x4oflcm3cKB52qms/5/oMN
Hx1QkbqRykEN/z2/e3SUDV2GK0ziHnFQmsFSE85PNpy4a9z/4jEHmb0c/Iam
2VBTWffXeAb+fkx8reIsG+brR27hZnLQdhe9p5G/2dBA6LGnUBYHSSgUOFv8
ZcNn/PvpNdkcFEDYG9TNs6F6fSvcmsNBE++Xb9nAZUPwVPna3lwOMn/RtjSW
ZsO0JOMagzwOaooI+sswbChWZ8g+k89B/wMviS+j
        "]]},
      Annotation[#, "Charting`Private`Tag$5042#1"]& ]}, {}, {}}, {{{}, {}, 
     TagBox[
      {RGBColor[0, 1, 0], Thickness[0.007], Opacity[1.], Dashing[Large], 
       LineBox[CompressedData["
1:eJwVyn881HccwPFzfnwidI47d6S78z0izY+J+dF8PpmdyVRElkZ+xGN+5MIs
JSFZqu3UKhPVrDzMr0ceovRDek+FyY9UiyiuHopQTjjHnaz98Xo8/3kJIsUB
0XQajeb3qf+Nlc7o0GgyfGggzt3RkQHfqL93z6HLcMVVixKWEwOsLEcStDRl
uCdfqqFwZsCb+GddujoyzPfa1tXoxoBdc7d/4xrJcFP1hgiRJwPC9Y+YOFrJ
sDKDc2S7PwO2reeuidkiwz/yWx5lihngVfilT0eJDMdEC+I6qhhQwFrQ4W2e
wrvuJqYfszWAKV5b6vDUFLbyPXr8QrkBWLSbZaSd/IC7j2mf9OMzodt1BJ3y
mMaSC/x9gotMyHFududLpzHruUa4r6khXFYwph3zZ/C1d5nWRRcMoTZkRMR2
n8UuDeGjOTwjaPLp/ip+YBZnV+qX3f3dCDZ8XHNPdFSOh5O2iqxMWNCFC9+d
tpnDelHRr1+dYsE6wa91te1z2ET3xT6X5WxgtM2qAvcqMD46LrvyCxvkSvFk
HGce29i3xuRoGkPAbGg0ap3HDlWud9LyjOGI5PHe5OQFzBk00NPW5kBLfYjj
FqYSt7o1bJ/M4kB6SVBy/R0lzo+fzlugc8GNGxlyPEKFeS2qazsOcEEc/Or+
KGMRt8yca325xIUMp7FOo9uL2H/gYic92wTOlKhn1oV+xJfGUx/tmzcBqudE
Xd/yJaz3cOgG64Ap3JLYndxzeQnjQXYJkpsCS16ZO25JI1tL69JP714JeShN
IzKDRjI9RlxFkysha6iz16CLRlLoo3K/H8xgXdGLicMWaiS7KLNg/7gZPBE6
bNmZrkaSxg7YeCasgvlUvWUpD9SI9S7vOzuHV8GziktqG83pZL623OliDA88
Sps3h6TQyQnr3ko3KQ/yEy0meprpJLf6qk6DDR+KTT3bdbnqZJOtr0NUAh/W
5o+osmLVidLLO/hmOR/SXouSroM6qb8veU+N8cGHbudmzdQg/gPrc11WCwBN
hvirRWqQoY7zBSZRAshqIpXnrmuQ/VYbuStKBXAwsCY4SVuTKDihxZelAvii
s1ekHaFJclJuScLNzeE5y+vwsgZNslTRoRqKNActC1f2BqRFwlK94nT+MIdx
9ujb9WFapL0S+XhLzSGom8dMrtEiJqkOq+3MKKgOLs7TX9IiO0z1s4a/o6Cp
+SFJDEKk3MZ5Y/VZCoJmJH6oDJH+h/cMeU8paO7ytBf/hUh1/YPFtb0U2FfI
mb3liBwsfDTi1keBblhYX1kVIlS49Na2fgrutX4WJapFZPekMkoySMHnxR1p
uY2I0PQd6xffUMDw1ClVf4yIpe+fgc/nKDi4sunn+CeIKGzLPcYUFEzIk2If
/4vIA2aNlWKegraqZ7aX+hDZ09+oMlRRkMmquOE5iMiN2L5SX5oQ3o96d2e/
ReTbvBWzN5cJ4fu7ytq3Y4jwEthDbdpCaD9fc9p/ApEPm83+eaojhLIA4xDB
JCIFxjbnP+gKIbTxzTDMICItE329xuDTX1DUaiVH5MoxPzsXphBckjZVnphD
5HBiIFdkKAQjy2vi8AVErJ0j30WwhHCIFhfQpkRExY3tFbOFIOs3c7JfRKRr
Ufx3hrEQwq72GBd+RKTk5U9VxzlC6MjPXVhaQiTlfsaZs1wh/AcQTD4u
        "]]},
      Annotation[#, "Charting`Private`Tag$5080#1"]& ]}, {}, {}}, {{{}, {}, 
     TagBox[
      {GrayLevel[1], Thickness[0.007], Opacity[1.], Dashing[Medium], 
       LineBox[CompressedData["
1:eJwVyn881HccwPHjuI9Dds6Pc3T4Vn7UFHUlST4fiqmN5JHaQ7nqSksKRx4x
U8yPajVS+d2aRm7nZ35MeuTHe6ciHZdRtJasQoTO7xyy9sfr8fznRQlDfAJU
aTSa5+f+N7B3UpNGU+AgntNLmYwBHvTRzfGqCny3vbwg9QkDrC0HTjDUFZiZ
ZBW6p5MB/UHP27Q1FbhglE3vfcGAIzN1V7j6CvymYdB6YogBB3XOGfOtFdhf
mHGKy0Swx4m76qi3AnuJx7WOuiHYlrlluyxXgflrJY6LdQjSDZSaZjvH8JqR
rf7RjRowZtYc8XZsDN+Zj4zJu8MEixZeTGTqOFb/Ieq8ilgT5JsG0FXnCRyf
J/5WUqgF8fbSzea9EzjVNNRy4bo2lH5kTfBTJvFfLkfvZuctgXK/AXfDzVO4
q9NqY/AtHajfLt8a9GIKB96LrxhJ+wJcPq26735hGnNuJUXt82RBG84cufbl
DCbpmUaGTSxYT/1cWd4yg70wqyTIWRdYzVPzu09/xGG1piv6G3Rhei7kw3Gj
WSw4rMyqdmCDz5R/AGqaxQE9J8aL7rHhXHLH6bAwJf5G1404OenBwyo/vjd7
DitPDl1aVqUH0bm+YVUNc1h6w7J2tb0+OHKFfhcPzWOfWduh5DJ9CNn7+sE7
1gJWWj1R6vMNIGbDUKt+3QJO0HlGs68ygLRc+tlK/0/4malEvcTGEJa3X67s
1lrELnS9EY8yQ7iXbJsaWrqIw3V3dDiu5IDBdGHie0saSerqL23K5cB5FKkm
jKGRCpHxyahlRhD7qrVLt41GxBtMVsXlGMH67JfDCRYqpKq14lGJKRc6V6z1
PhCtQvJ5twURv3JhNmKJRvhjFeKf8f34FY4xPJfkqexYpkps+l4ce5plDM75
0p1+4aqkcb9mz0k9E0gJthhul6oSp0s3PG7+ZAI5Jq4t2lw6kac8SpvVWgo2
KQPzsYF0Yl3357/ihKUQ2ecuqgE6ya73ZkUjHmxXtXVcyVYjnYPFW/LjeIA+
+O1SEaoRhSz44LFZHsTWk8LrNWrEMqEpYFe0KZzZXbZXxFQnywNGAi9PmsLG
1i535iF14mBc6D152gz+MdiWoHFHndidk9lMfDQDhsUmQxfEIDM6PfR8B3N4
b/hu0EnAIIe33XzdG2UOvnIzdlgZg1TqPIbmanMo3ptzXmeRQSarxNwz4+ZQ
L31Cgn0RcXkgf+PGp8B3MtkTFSASflxQUhNCgbTN1S5EjIibV0DGw1AK7CTT
7K7fEeGsOxHXKaJAWyDoLihCpHY2ylcRTsH9ptWH3csRYVxIW7CKpGBdjiwy
sRaRLLHMMyOWAparZj69A5GGt46jEakUnFlanxTUiUhqs0t3/BUKhqdFgR1P
ETlS7CFNvUpBc9HzNXndiDBP7UkvSaPgrIHkrmsPIj70MOe+LApG330ljxtE
pI+SJO/+jYL9jXPlg0OI1KjfjhTmUdDyS9m1XcOIXBysFobmU1Dgw/GjPiBi
W37f/lIBBf61/W9hEpEo0tvTWPj5T89usp5G5OsVA83tRRQ4iLwKL88gwtMY
rXhVTIG+ZXXIQSUiUvlc0lwpBT/Sjvs0zyGSVqkqYt6mQPE3b4PdAiLfZTD3
ccopEPzRzsn8hMimaJabRQUFspRE5eIiItoHOLb8Sgr+A4kkRtk=
        "]]},
      Annotation[#, "Charting`Private`Tag$5118#1"]& ]}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"\[Tau]\"", TraditionalForm], 
    FormBox[
    "\"ln(\[Delta]\\!\\(\\*\\nStyleBox[\\\"H\\\",\\nFontSlant->\\\"Italic\\\"]\
\\)/\\!\\(\\*\\nStyleBox[\\\"h\\\",\\nFontSlant->\\\"Italic\\\"]\\))\"", 
     TraditionalForm]},
  AxesOrigin->{1.0000000408163265`, -8.852302769755656},
  AxesStyle->Directive[
    RGBColor[1, 0, 0], 15],
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[
    RGBColor[1, 0, 0]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic},
  TicksStyle->Directive[
    RGBColor[1, 0, 0], 15]]], "Output",
 CellChangeTimes->{{3.801196862089266*^9, 3.8011968681589785`*^9}, 
   3.801196978258554*^9, 3.801198574082179*^9, 3.8012024633940396`*^9, 
   3.8012041994532003`*^9, 3.8012042945662575`*^9, 3.8012134629673157`*^9, {
   3.8012135133575816`*^9, 3.8012135379641294`*^9}, {3.8012136516681576`*^9, 
   3.8012136717705717`*^9}, 3.801213771422721*^9, 3.8012138243697395`*^9, {
   3.8012150978610916`*^9, 3.801215116494673*^9}, 3.801215392707281*^9, 
   3.8012154431886044`*^9, 3.801222841839926*^9, 3.818773015942757*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[1, 0.5, 0.5], Thickness[0.007], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV1nk4VU8YB/B7zy23RSWhEEm2pGi3lHcoklIqZImk7EKWUEKy1g8t9hKp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       "]]},
     Annotation[#, "Charting`Private`Tag$5159#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"\[Tau]\"", TraditionalForm], 
    FormBox["\"ln(\[CapitalPsi])\"", TraditionalForm]},
  AxesOrigin->{1.0000000408163265`, 0.2878785922086696},
  AxesStyle->Directive[
    RGBColor[1, 0, 0], 15],
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[
    RGBColor[1, 0, 0]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{1.0000000408163265`, 2.9999999591836737`}, {0.2878785922086696,
    0.5474579410003296}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic},
  TicksStyle->Directive[
    RGBColor[1, 0, 0], 15]]], "Output",
 CellChangeTimes->{{3.801196862089266*^9, 3.8011968681589785`*^9}, 
   3.801196978258554*^9, 3.801198574082179*^9, 3.8012024633940396`*^9, 
   3.8012041994532003`*^9, 3.8012042945662575`*^9, 3.8012134629673157`*^9, {
   3.8012135133575816`*^9, 3.8012135379641294`*^9}, {3.8012136516681576`*^9, 
   3.8012136717705717`*^9}, 3.801213771422721*^9, 3.8012138243697395`*^9, {
   3.8012150978610916`*^9, 3.801215116494673*^9}, 3.801215392707281*^9, 
   3.8012154431886044`*^9, 3.801222841839926*^9, 3.818773016456436*^9}]
}, Open  ]],

Cell["The above plots make figure 9.", "Text",
 CellChangeTimes->{{3.8187730677070475`*^9, 3.8187730737005196`*^9}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Section 5. Self-tuning exponential KGB",
 FontColor->RGBColor[1, 0.5, 0.5]]], "Subsection",
 CellChangeTimes->{{3.8184763069845715`*^9, 3.8184763289005594`*^9}}],

Cell["\<\
We check out cosmological dynamics in the exponential KGB. Importing the \
results of Sec. 3...\
\>", "Text",
 CellChangeTimes->{{3.8184763311031485`*^9, 3.8184763435531836`*^9}, {
  3.8187731050670447`*^9, 3.818773118651185*^9}}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"SetDirectory", "[", 
    RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";", 
   "\[IndentingNewLine]", 
   RowBox[{"Get", "[", "\"\<trivial_scalar_field_eqs.m\>\"", "]"}]}], 
  "*)"}]], "Input",
 CellChangeTimes->{{3.8187730963688445`*^9, 3.8187730987748423`*^9}}],

Cell["The field equations are given by...", "Text",
 CellChangeTimes->{{3.818476384993464*^9, 3.818476389023915*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ExpKGB", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"l", "\[Rule]", "0"}], ",", 
      RowBox[{"A", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{"x", ",", 
         RowBox[{"c", " ", 
          SuperscriptBox["E", 
           RowBox[{"x", "/", "d"}]]}]}], "]"}]}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\"\<A(X)\>\"", "\[Equal]", 
   RowBox[{"A", "[", "X", "]"}]}], "/.", "ExpKGB"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\"\<B(x)\>\"", "\[Equal]", 
   RowBox[{"\[Integral]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"B", "'"}], "[", "X", "]"}], "/.", "stmod"}], "/.", 
        "ExpKGB"}], "//", "Simplify"}], ")"}], 
     RowBox[{"\[DifferentialD]", "X"}]}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FeqExpKGB", "=", 
   RowBox[{
    RowBox[{"FeqTPST", "/.", "ExpKGB"}], "//", "FullSimplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"HeqExpKGB", "=", 
   RowBox[{
    RowBox[{"HeqTPST", "/.", "ExpKGB"}], "//", "FullSimplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SeqExpKGB", "=", 
    RowBox[{
     RowBox[{"SeqTPST", "/.", "ExpKGB"}], "//", "FullSimplify"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FE2ExpKGB", "=", 
    RowBox[{
     RowBox[{"FE2TPST", "/.", "ExpKGB"}], "//", "FullSimplify"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "FeqExpKGB", "\
\[IndentingNewLine]", "HeqExpKGB", "\[IndentingNewLine]", "SeqExpKGB"}], \
"Input",
 CellChangeTimes->{{3.818476437781791*^9, 3.8184765163712177`*^9}, {
  3.8184766696657147`*^9, 3.8184767190718555`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"A(X)\"\>", "\[Equal]", 
  RowBox[{"c", " ", 
   SuperscriptBox["\[ExponentialE]", 
    FractionBox["X", "d"]]}]}]], "Output",
 CellChangeTimes->{3.818476519401746*^9, 3.818476719556108*^9, 
  3.818561473366439*^9, 3.8185636551887293`*^9, 3.818565384921053*^9, 
  3.818567186436051*^9, 3.8185845433107758`*^9, 3.818586370625871*^9, 
  3.81858703300333*^9, 3.8185876858748207`*^9, 3.8185885206292925`*^9, 
  3.818606173373673*^9, 3.818648391349124*^9, 3.818648679165923*^9}],

Cell[BoxData[
 RowBox[{"\<\"B(x)\"\>", "\[Equal]", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{"c", " ", 
     SqrtBox["\[Pi]"], " ", 
     RowBox[{"Erfi", "[", 
      FractionBox[
       SqrtBox["X"], 
       SqrtBox["d"]], "]"}]}], 
    RowBox[{"3", " ", 
     SqrtBox["2"], " ", 
     SqrtBox["d"], " ", "h"}]]}]}]], "Output",
 CellChangeTimes->{3.818476519401746*^9, 3.818476719556108*^9, 
  3.818561473366439*^9, 3.8185636551887293`*^9, 3.818565384921053*^9, 
  3.818567186436051*^9, 3.8185845433107758`*^9, 3.818586370625871*^9, 
  3.81858703300333*^9, 3.8185876858748207`*^9, 3.8185885206292925`*^9, 
  3.818606173373673*^9, 3.818648391349124*^9, 3.8186486791895695`*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"d", " ", "h", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
       RowBox[{"\[Rho]", "[", "t", "]"}]}], ")"}]}], "+", 
    RowBox[{"c", " ", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], 
       RowBox[{"2", " ", "d"}]]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"d", " ", "h"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "h"}], "+", 
          RowBox[{"H", "[", "t", "]"}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Phi]", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}]}], ")"}]}]}], 
   RowBox[{"d", " ", "h"}]], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.818476519401746*^9, 3.818476719556108*^9, 
  3.818561473366439*^9, 3.8185636551887293`*^9, 3.818565384921053*^9, 
  3.818567186436051*^9, 3.8185845433107758`*^9, 3.818586370625871*^9, 
  3.81858703300333*^9, 3.8185876858748207`*^9, 3.8185885206292925`*^9, 
  3.818606173373673*^9, 3.818648391349124*^9, 3.818648681001919*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"P", "[", "t", "]"}], "+", 
   RowBox[{"\[Rho]", "[", "t", "]"}], "+", 
   RowBox[{"2", " ", 
    RowBox[{
     SuperscriptBox["H", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}], "+", 
   FractionBox[
    RowBox[{"c", " ", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], 
       RowBox[{"2", " ", "d"}]]], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        RowBox[{"(", 
         RowBox[{"h", "-", 
          RowBox[{"H", "[", "t", "]"}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], ")"}]}], 
    RowBox[{"3", " ", "d", " ", "h"}]]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.818476519401746*^9, 3.818476719556108*^9, 
  3.818561473366439*^9, 3.8185636551887293`*^9, 3.818565384921053*^9, 
  3.818567186436051*^9, 3.8185845433107758`*^9, 3.818586370625871*^9, 
  3.81858703300333*^9, 3.8185876858748207`*^9, 3.8185885206292925`*^9, 
  3.818606173373673*^9, 3.818648391349124*^9, 3.8186486810069623`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", 
    RowBox[{"d", " ", "h"}]], 
   RowBox[{"c", " ", 
    SuperscriptBox["\[ExponentialE]", 
     FractionBox[
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"], 
      RowBox[{"2", " ", "d"}]]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"d", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          RowBox[{"(", 
           RowBox[{"h", "-", 
            RowBox[{"H", "[", "t", "]"}]}], ")"}], " ", 
          RowBox[{"H", "[", "t", "]"}]}], "-", 
         RowBox[{
          SuperscriptBox["H", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], ")"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"h", "-", 
         RowBox[{"H", "[", "t", "]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"d", "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Phi]", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"]}], ")"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], "\[Equal]",
   "0"}]], "Output",
 CellChangeTimes->{3.818476519401746*^9, 3.818476719556108*^9, 
  3.818561473366439*^9, 3.8185636551887293`*^9, 3.818565384921053*^9, 
  3.818567186436051*^9, 3.8185845433107758`*^9, 3.818586370625871*^9, 
  3.81858703300333*^9, 3.8185876858748207`*^9, 3.8185885206292925`*^9, 
  3.818606173373673*^9, 3.818648391349124*^9, 3.8186486810130196`*^9}]
}, Open  ]],

Cell["\<\
The gradient stability constraint on the de Sitter vacuum becomes...\
\>", "Text",
 CellChangeTimes->{{3.818476538182892*^9, 3.8184765467121277`*^9}, {
  3.8184767697801003`*^9, 3.8184767735596294`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ggstab", "/.", "ExpKGB"}]], "Input",
 CellChangeTimes->{3.8184765546803894`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"3", " ", 
     SuperscriptBox["h", "2"]}], "X"]}], "<", 
  FractionBox[
   RowBox[{"c", " ", 
    SuperscriptBox["\[ExponentialE]", 
     FractionBox["X", "d"]]}], "d"], "<", "0"}]], "Output",
 CellChangeTimes->{3.818476555039708*^9, 3.818561479768162*^9, 
  3.8185633168304415`*^9, 3.81856365931017*^9, 3.8185653897137475`*^9, 
  3.818567191252359*^9, 3.8185845514232063`*^9, 3.818586375515349*^9, 
  3.8185870378386545`*^9, 3.8185876902644124`*^9, 3.8186061779830027`*^9, 
  3.8186484399516077`*^9, 3.8186486849224615`*^9}]
}, Open  ]],

Cell[TextData[{
 "Noting ",
 Cell[BoxData[
  FormBox[
   RowBox[{"c", ">", "0"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " because of the Hamiltonian constraint and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalLambda]", "\[GreaterGreater]", 
    RowBox[{"3", 
     SuperscriptBox["h", "2"]}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "..."
}], "Text",
 CellChangeTimes->{{3.8184766268409452`*^9, 3.818476644648323*^9}, {
  3.8184767814961753`*^9, 3.8184767819014654`*^9}, {3.81847706380142*^9, 
  3.818477086087391*^9}, {3.8184771425128746`*^9, 3.818477142705905*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"FeqExpKGB", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"H", "[", "t", "]"}], "\[Rule]", "h"}], ",", 
      RowBox[{
       RowBox[{"\[Rho]", "[", "t", "]"}], "\[Rule]", "\[CapitalLambda]"}]}], 
     "}"}]}], "/.", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "\[Rule]", 
    SqrtBox[
     RowBox[{"2", "X"}]]}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.8184767894261036`*^9, 3.818476799742407*^9}, {
  3.8184769860762463`*^9, 3.818477034134061*^9}, {3.8184775939698753`*^9, 
  3.8184776142636995`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"c", " ", 
    SuperscriptBox["\[ExponentialE]", 
     FractionBox["X", "d"]]}], "+", 
   RowBox[{"3", " ", 
    SuperscriptBox["h", "2"]}]}], "\[Equal]", "\[CapitalLambda]"}]], "Output",
 CellChangeTimes->{{3.818476796440057*^9, 3.818476800132907*^9}, {
   3.8184770041984425`*^9, 3.8184770096855807`*^9}, 3.818477039932609*^9, 
   3.818477614964238*^9, 3.8185614871615124`*^9, 3.8185636612860346`*^9, 
   3.8185653933456144`*^9, 3.8185671933768597`*^9, 3.8185845530946875`*^9, 
   3.8185863772494593`*^9, 3.818587040041231*^9, 3.8185878525971727`*^9, 
   3.8186484418079567`*^9, 3.8186486881605625`*^9}]
}, Open  ]],

Cell[TextData[{
 "...we find the gradient condition implies ",
 Cell[BoxData[
  FormBox[
   RowBox[{"d", "<", "0"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ". With this, we see that the constant ",
 Cell[BoxData[
  FormBox["c", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " must scale as ",
 Cell[BoxData[
  FormBox["\[CapitalLambda]", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " in order to counterbalance its effect on the de Sitter state. Also, unlike \
the previous case of the generalized cubic covariant Galileon, we find that \
the gradient constraint do not prevent the theory from tuning away an \
arbitrarily large vacuum energy. We show this explicitly by \
nondimensionalizing the gradient constraint and the Hamiltonian constraint..."
}], "Text",
 CellChangeTimes->{{3.8184771284020805`*^9, 3.8184771507413516`*^9}, {
  3.818477288515918*^9, 3.8184774906137505`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"$Assumptions", "=", 
   RowBox[{
    RowBox[{"\[Gamma]", ">", "0"}], "&&", 
    RowBox[{"\[CapitalGamma]", "<", "0"}], "&&", 
    RowBox[{"h", ">", "0"}], "&&", 
    RowBox[{"\[Chi]", ">", "0"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ndExpKGB", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[CapitalLambda]", "\[Rule]", 
       RowBox[{"r", 
        RowBox[{"(", 
         RowBox[{"3", 
          SuperscriptBox["h", "2"]}], ")"}]}]}], ",", 
      RowBox[{"c", "\[Rule]", 
       RowBox[{"\[Gamma]", 
        RowBox[{"(", 
         RowBox[{"3", 
          SuperscriptBox["h", "2"]}], ")"}]}]}], ",", 
      RowBox[{"d", "\[Rule]", 
       RowBox[{"\[CapitalGamma]", 
        RowBox[{"(", 
         RowBox[{"3", 
          SuperscriptBox["h", "2"]}], ")"}]}]}], ",", 
      RowBox[{"X", "\[Rule]", 
       RowBox[{"\[Chi]", 
        RowBox[{"(", 
         RowBox[{"3", 
          SuperscriptBox["h", "2"]}], ")"}]}]}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ggstabExpKGB", "=", 
   RowBox[{
    RowBox[{"ggstab", "/.", "ExpKGB"}], "/.", "ndExpKGB"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FeqExpKGBnd", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"FeqExpKGB", "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"H", "[", "t", "]"}], "\[Rule]", "h"}], ",", 
          RowBox[{
           RowBox[{"\[Rho]", "[", "t", "]"}], "\[Rule]", 
           "\[CapitalLambda]"}]}], "}"}]}], "/.", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "\[Rule]", 
        SqrtBox[
         RowBox[{"2", "X"}]]}]}], "/.", "ndExpKGB"}], "//", "Simplify"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", "ggstabExpKGB", "\
\[IndentingNewLine]", "FeqExpKGBnd"}], "Input",
 CellChangeTimes->{{3.8184775680795717`*^9, 3.8184775896325145`*^9}, {
  3.8184776581953373`*^9, 3.818477854847267*^9}, {3.8184779833562984`*^9, 
  3.8184779861183705`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", "\[Chi]"]}], "<", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     FractionBox["\[Chi]", "\[CapitalGamma]"]], " ", "\[Gamma]"}], 
   "\[CapitalGamma]"], "<", "0"}]], "Output",
 CellChangeTimes->{{3.8184778085236735`*^9, 3.818477857072114*^9}, 
   3.818477986616745*^9, 3.818561527460122*^9, 3.8185635096405134`*^9, 
   3.818563663259641*^9, 3.8185671954625487`*^9, 3.818584555859664*^9, 
   3.8185863795456486`*^9, 3.818587042134487*^9, 3.8185878547216763`*^9, 
   3.818588529877838*^9, 3.8186484440444202`*^9, 3.8186486909915943`*^9}],

Cell[BoxData[
 RowBox[{"r", "\[Equal]", 
  RowBox[{"1", "+", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     FractionBox["\[Chi]", "\[CapitalGamma]"]], " ", 
    "\[Gamma]"}]}]}]], "Output",
 CellChangeTimes->{{3.8184778085236735`*^9, 3.818477857072114*^9}, 
   3.818477986616745*^9, 3.818561527460122*^9, 3.8185635096405134`*^9, 
   3.818563663259641*^9, 3.8185671954625487`*^9, 3.818584555859664*^9, 
   3.8185863795456486`*^9, 3.818587042134487*^9, 3.8185878547216763`*^9, 
   3.818588529877838*^9, 3.8186484440444202`*^9, 3.818648691004879*^9}]
}, Open  ]],

Cell[TextData[{
 "The second part of the inequality ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["A", "X"], "<", "0"}], ")"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " is already satisfied. We focus on the first part, eliminating ",
 Cell[BoxData[
  FormBox["\[Chi]", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " from the Friedmann constraint and using the substitution ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Zeta]", "=", 
    SuperscriptBox["e", 
     RowBox[{"\[Chi]", "/", "\[CapitalGamma]"}]]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ",..."
}], "Text",
 CellChangeTimes->{{3.818477868709856*^9, 3.818477919724891*^9}, {
  3.818477952596858*^9, 3.818477956864361*^9}, {3.8184780255234275`*^9, 
  3.818478068199236*^9}, {3.8184781529118586`*^9, 3.8184782009865937`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ggExpKGB", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"ggstabExpKGB", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "<", 
         RowBox[{"ggstabExpKGB", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "/.", 
        RowBox[{
         SuperscriptBox["E", 
          RowBox[{"\[Chi]", "/", "\[CapitalGamma]"}]], "\[Rule]", 
         "\[Zeta]"}]}], "/.", 
       RowBox[{"\[Chi]", "\[Rule]", 
        RowBox[{"\[CapitalGamma]", " ", 
         RowBox[{"Log", "[", "\[Zeta]", "]"}]}]}]}], "/.", 
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{"FeqExpKGBnd", "/.", 
          RowBox[{
           SuperscriptBox["E", 
            RowBox[{"\[Chi]", "/", "\[CapitalGamma]"}]], "\[Rule]", 
           "\[Zeta]"}]}], ",", "\[Gamma]"}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "//", "Simplify"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "ggExpKGB"}], "Input",
 CellChangeTimes->{{3.8184779596094084`*^9, 3.818477976858613*^9}, {
  3.818478013605463*^9, 3.8184780203690214`*^9}, {3.8184780737536592`*^9, 
  3.8184780935232687`*^9}, {3.818478216240572*^9, 3.8184782285330725`*^9}, {
  3.8184783315938845`*^9, 3.818478388598665*^9}, {3.818478471663205*^9, 
  3.81847849749992*^9}, {3.8184788319044733`*^9, 3.818478911304942*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Log", "[", "\[Zeta]", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "r"}], ")"}], " ", 
      RowBox[{"Log", "[", "\[Zeta]", "]"}]}]}], ")"}]}], "<", "0"}]], "Output",
 CellChangeTimes->{{3.818477963846593*^9, 3.818477991103016*^9}, {
   3.8184780886854486`*^9, 3.818478093926696*^9}, 3.81847849850626*^9, {
   3.8184788579685984`*^9, 3.8184788801852665`*^9}, 3.818478911929188*^9, 
   3.81856155341006*^9, 3.8185635288969088`*^9, 3.818563668647764*^9, 
   3.818567198182909*^9, 3.8185845589683127`*^9, 3.8185863828107576`*^9, 
   3.818587044493328*^9, 3.818587857252359*^9, 3.8185885340799437`*^9, 
   3.818648448240531*^9, 3.8186486932188387`*^9}]
}, Open  ]],

Cell[TextData[{
 "Noting ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Chi]", "/", "\[CapitalGamma]"}], "<", "0"}], TraditionalForm]]],
 " since ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalGamma]", "<", "0"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Chi]", ">", "0"}], TraditionalForm]]],
 ", then ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Zeta]", "<", "1"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"ln", "(", "\[Zeta]", ")"}], "<", "0"}], TraditionalForm]]],
 ", the above inequality becomes ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"1", "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"r", "-", "1"}], ")"}], 
      RowBox[{"ln", "(", "\[Zeta]", ")"}]}]}], ">", "0"}], TraditionalForm]]],
 " which is Eq. (5.7). For ",
 Cell[BoxData[
  FormBox[
   RowBox[{"0", "<", "\[Zeta]", "<", "1"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"r", "=", 
    RowBox[{
     RowBox[{"\[CapitalLambda]", "/", 
      RowBox[{"(", 
       RowBox[{"3", 
        SuperscriptBox["h", "2"]}], ")"}]}], "\[GreaterGreater]", "1"}]}], 
   TraditionalForm]]],
 ", this is satisfied.\n\nWe end this section by setting up the dynamical \
system for this theory provided a single non-",
 Cell[BoxData[
  FormBox["\[CapitalLambda]", TraditionalForm]]],
 " cosmic fluid..."
}], "Text",
 CellChangeTimes->{{3.8184787041514206`*^9, 3.818478763368106*^9}, {
  3.8184788132541704`*^9, 3.818478825843979*^9}, {3.818478915571107*^9, 
  3.8184789606510043`*^9}, {3.8184790057112136`*^9, 3.81847907510446*^9}, {
  3.818479926244031*^9, 3.818479969164849*^9}, {3.8187731590428534`*^9, 
  3.8187731633219814`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"FHeqSFExpKGB", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"HeqExpKGB", "/.", 
       RowBox[{
        RowBox[{"\[Rho]", "[", "t", "]"}], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"P", "[", "t", "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", "w"}], ")"}], 
          RowBox[{"\[Rho]", "[", "t", "]"}]}]}]}]}], "/.", 
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{"FeqExpKGB", "/.", 
          RowBox[{
           RowBox[{"\[Rho]", "[", "t", "]"}], "\[Rule]", 
           RowBox[{
            RowBox[{"\[Rho]", "[", "t", "]"}], "+", "\[CapitalLambda]"}]}]}], 
         ",", 
         RowBox[{"\[Rho]", "[", "t", "]"}]}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "//", "Simplify"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "FHeqSFExpKGB"}], "Input",
 CellChangeTimes->{{3.818479997067315*^9, 3.8184800688628626`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"2", " ", 
    RowBox[{
     SuperscriptBox["H", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", "w"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "\[CapitalLambda]"}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
      FractionBox[
       RowBox[{"c", " ", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"], 
          RowBox[{"2", " ", "d"}]]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"d", " ", "h"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "h"}], "+", 
             RowBox[{"H", "[", "t", "]"}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "2"]}]}], ")"}]}], 
       RowBox[{"d", " ", "h"}]]}], ")"}]}], "+", 
   FractionBox[
    RowBox[{"c", " ", 
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], 
       RowBox[{"2", " ", "d"}]]], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        RowBox[{"(", 
         RowBox[{"h", "-", 
          RowBox[{"H", "[", "t", "]"}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], ")"}]}], 
    RowBox[{"3", " ", "d", " ", "h"}]]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{{3.8184800557084427`*^9, 3.818480069297478*^9}, 
   3.8185616099135056`*^9, 3.818563671373381*^9, 3.8185672011501427`*^9, 
   3.8185845617645283`*^9, 3.8185863851537085`*^9, 3.8185870466490536`*^9, 
   3.81858785933*^9, 3.818648452116103*^9, 3.8186486957974873`*^9}]
}, Open  ]],

Cell[TextData[{
 "However, instead of replacing the scalar field ",
 Cell[BoxData[
  FormBox["\[Phi]", TraditionalForm]]],
 " with the shift current ",
 Cell[BoxData[
  FormBox["J", TraditionalForm]]],
 ", we retain the use of ",
 Cell[BoxData[
  FormBox["\[Phi]", TraditionalForm]]],
 " to avoid dealing with subtleties of the Lambert W function (or \
ProductLog), i.e.,..."
}], "Text",
 CellChangeTimes->{{3.818480112901072*^9, 3.8184801372554216`*^9}, {
  3.8184806792189918`*^9, 3.818480739167391*^9}, {3.8185616404950542`*^9, 
  3.8185616426889353`*^9}, {3.818586397908005*^9, 3.8185863993297253`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[Phi]ToJExpKGB", "=", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"J", "[", "t", "]"}], "\[Equal]", 
         RowBox[{"Jst", "[", "t", "]"}]}], "/.", "ExpKGB"}], ",", 
       RowBox[{
        RowBox[{"\[Phi]", "'"}], "[", "t", "]"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "\[Phi]ToJExpKGB"}], "Input",
 CellChangeTimes->{{3.8184801536961193`*^9, 3.8184802258798866`*^9}, {
  3.8184802633090105`*^9, 3.81848026383889*^9}, {3.818480751378519*^9, 
  3.8184807653977222`*^9}}],

Cell[BoxData[
 TemplateBox[{
  "Solve","ifun",
   "\"Inverse functions are being used by \
\\!\\(\\*RowBox[{\\\"Solve\\\"}]\\), so some solutions may not be found; use \
Reduce for complete solution information.\"",2,25,1,16780116657061101486,
   "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{{3.8184802169613905`*^9, 3.8184802264524517`*^9}, 
   3.818480264710706*^9, 3.818480765765488*^9, 3.8185616448345113`*^9, 
   3.8185636740335093`*^9, 3.8185672034704714`*^9, 3.818584564467018*^9, 
   3.818586387809333*^9, 3.818587049663971*^9, 3.8185878620480843`*^9, 
   3.818648454436624*^9, 3.818648697944645*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{"-", 
     SqrtBox["d"]}], " ", 
    SqrtBox[
     RowBox[{"ProductLog", "[", 
      FractionBox[
       RowBox[{"d", " ", 
        SuperscriptBox["h", "2"], " ", 
        SuperscriptBox[
         RowBox[{"J", "[", "t", "]"}], "2"]}], 
       RowBox[{
        SuperscriptBox["c", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"h", "-", 
           RowBox[{"H", "[", "t", "]"}]}], ")"}], "2"]}]], "]"}]]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.8184801552771444`*^9, 3.818480226486044*^9}, 
   3.8184802647404013`*^9, 3.818480765787757*^9, 3.818561644864726*^9, 
   3.818563674062352*^9, 3.8185672034976797`*^9, 3.8185845644982605`*^9, 
   3.81858638784058*^9, 3.8185870496952124`*^9, 3.818587862063733*^9, 
   3.8186484544616547`*^9, 3.81864869797467*^9}]
}, Open  ]],

Cell["The dynamical system is therefore...", "Text",
 CellChangeTimes->{{3.818480770290626*^9, 3.8184808009572663`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"dsExpKGB", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"FHeqSFExpKGB", ",", "SeqExpKGB"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"H", "'"}], "[", "t", "]"}], ",", 
          RowBox[{
           RowBox[{"\[Phi]", "''"}], "[", "t", "]"}]}], "}"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}], "//", "Simplify"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dsExpKGB1", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "''"}], "[", "t", "]"}], "\[Equal]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Phi]", "''"}], "[", "t", "]"}], "/.", "dsExpKGB"}], "//", 
      "FullSimplify"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dsExpKGB2", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"H", "'"}], "[", "t", "]"}], "\[Equal]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"H", "'"}], "[", "t", "]"}], "/.", "dsExpKGB"}], "//", 
       "FullSimplify"}], ")"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "dsExpKGB1", "\
\[IndentingNewLine]", "dsExpKGB2"}], "Input",
 CellChangeTimes->{{3.8184808034173746`*^9, 3.818481002532816*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"3", " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"d", " ", "h", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", "w"}], ")"}], " ", "\[CapitalLambda]"}], "-", 
          RowBox[{"6", " ", "h", " ", 
           RowBox[{"H", "[", "t", "]"}]}], "-", 
          RowBox[{"3", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "w"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"H", "[", "t", "]"}], "2"]}]}], ")"}]}], "-", 
       RowBox[{"c", " ", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"], 
          RowBox[{"2", " ", "d"}]]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"d", " ", "h", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "w"}], ")"}]}], "+", 
          RowBox[{"w", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "h"}], "+", 
             RowBox[{"H", "[", "t", "]"}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "2"]}]}], ")"}]}]}], 
      ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"c", " ", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Phi]", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"], 
        RowBox[{"2", " ", "d"}]]], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
     RowBox[{"6", " ", "h", " ", 
      RowBox[{"(", 
       RowBox[{"h", "-", 
        RowBox[{"H", "[", "t", "]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"d", "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Phi]", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], ")"}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.818480790478323*^9, {3.8184808711494536`*^9, 3.8184808735704927`*^9}, 
   3.818481004449543*^9, 3.818561652911174*^9, 3.818563677881389*^9, 
   3.818567211177696*^9, 3.8185845683254867`*^9, 3.8185864082199183`*^9, 
   3.8185870538036213`*^9, 3.8185878661721106`*^9, 3.8186484590954065`*^9, 
   3.8186487017756987`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["H", "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"3", " ", 
     RowBox[{"(", 
      RowBox[{"h", "-", 
       RowBox[{"H", "[", "t", "]"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"d", " ", "h", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "w"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"\[CapitalLambda]", "-", 
          RowBox[{"3", " ", 
           SuperscriptBox[
            RowBox[{"H", "[", "t", "]"}], "2"]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"d", "+", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}], ")"}]}], "-", 
       RowBox[{"c", " ", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"], 
          RowBox[{"2", " ", "d"}]]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["d", "2"], " ", "h", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "w"}], ")"}]}], "+", 
          RowBox[{"d", " ", 
           RowBox[{"(", 
            RowBox[{"h", "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "w"}], ")"}], " ", 
              RowBox[{"H", "[", "t", "]"}]}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
          RowBox[{"w", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "h"}], "+", 
             RowBox[{"H", "[", "t", "]"}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "4"]}]}], ")"}]}]}], 
      ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"c", " ", "d", " ", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Phi]", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"], 
        RowBox[{"2", " ", "d"}]]], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
     RowBox[{"6", " ", "d", " ", "h", " ", 
      RowBox[{"(", 
       RowBox[{"h", "-", 
        RowBox[{"H", "[", "t", "]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"d", "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Phi]", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], ")"}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.818480790478323*^9, {3.8184808711494536`*^9, 3.8184808735704927`*^9}, 
   3.818481004449543*^9, 3.818561652911174*^9, 3.818563677881389*^9, 
   3.818567211177696*^9, 3.8185845683254867`*^9, 3.8185864082199183`*^9, 
   3.8185870538036213`*^9, 3.8185878661721106`*^9, 3.8186484590954065`*^9, 
   3.81864870179078*^9}]
}, Open  ]],

Cell[TextData[{
 "Nondimensionalizing using the length scale ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["h", 
    RowBox[{"-", "1"}]], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", we get..."
}], "Text",
 CellChangeTimes->{{3.8184810524615154`*^9, 3.818481080699803*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ndExpKGBds", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "\[Rule]", 
       RowBox[{"h", " ", 
        RowBox[{"x", "[", "\[Tau]", "]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Phi]", "''"}], "[", "t", "]"}], "\[Rule]", 
       RowBox[{
        SuperscriptBox["h", "2"], 
        RowBox[{
         RowBox[{"x", "'"}], "[", "\[Tau]", "]"}]}]}], ",", 
      RowBox[{
       RowBox[{"H", "[", "t", "]"}], "\[Rule]", 
       RowBox[{"h", " ", 
        RowBox[{"y", "[", "\[Tau]", "]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"H", "'"}], "[", "t", "]"}], "\[Rule]", 
       RowBox[{
        SuperscriptBox["h", "2"], 
        RowBox[{
         RowBox[{"y", "'"}], "[", "\[Tau]", "]"}]}]}], ",", 
      RowBox[{"\[CapitalLambda]", "\[Rule]", 
       RowBox[{"\[Lambda]", 
        RowBox[{"(", 
         RowBox[{"3", 
          SuperscriptBox["h", "2"]}], ")"}]}]}], ",", 
      RowBox[{"c", "\[Rule]", 
       RowBox[{"\[Gamma]", 
        RowBox[{"(", 
         RowBox[{"3", 
          SuperscriptBox["h", "2"]}], ")"}]}]}], ",", 
      RowBox[{"d", "\[Rule]", 
       RowBox[{"\[CapitalGamma]", 
        RowBox[{"(", 
         RowBox[{"3", 
          SuperscriptBox["h", "2"]}], ")"}]}]}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dsExpKGBxy", "=", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"dsExpKGB1", "/.", "ndExpKGBds"}], "//", "Simplify"}], ",", 
         RowBox[{
          RowBox[{"dsExpKGB2", "/.", "ndExpKGBds"}], "//", "Simplify"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"x", "'"}], "[", "\[Tau]", "]"}], ",", 
         RowBox[{
          RowBox[{"y", "'"}], "[", "\[Tau]", "]"}]}], "}"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dsExpKGB1nd", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "'"}], "[", "\[Tau]", "]"}], "\[Equal]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"x", "'"}], "[", "\[Tau]", "]"}], "/.", "dsExpKGBxy"}], "//", 
      "FullSimplify"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dsExpKGB2nd", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"y", "'"}], "[", "\[Tau]", "]"}], "\[Equal]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"y", "'"}], "[", "\[Tau]", "]"}], "/.", "dsExpKGBxy"}], "//",
        "FullSimplify"}], ")"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", "dsExpKGB1nd", "\
\[IndentingNewLine]", "dsExpKGB2nd"}], "Input",
 CellChangeTimes->{{3.8184811526539183`*^9, 3.818481170966659*^9}, {
  3.8184812090256863`*^9, 3.818481335767706*^9}, {3.818481368018926*^9, 
  3.818481547706173*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["x", "\[Prime]",
    MultilineFunction->None], "[", "\[Tau]", "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"3", " ", 
     RowBox[{"x", "[", "\[Tau]", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"x", "[", "\[Tau]", "]"}], "2"], 
          RowBox[{"6", " ", "\[CapitalGamma]"}]]], " ", "\[Gamma]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "w"}], ")"}], " ", "\[CapitalGamma]"}], "+", 
          RowBox[{"w", " ", 
           SuperscriptBox[
            RowBox[{"x", "[", "\[Tau]", "]"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"y", "[", "\[Tau]", "]"}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"3", " ", "\[CapitalGamma]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{"1", "+", "w"}], ")"}]}], " ", "\[Lambda]"}], "+", 
          RowBox[{
           RowBox[{"y", "[", "\[Tau]", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{"2", "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "w"}], ")"}], " ", 
              RowBox[{"y", "[", "\[Tau]", "]"}]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         SuperscriptBox[
          RowBox[{"x", "[", "\[Tau]", "]"}], "2"], 
         RowBox[{"6", " ", "\[CapitalGamma]"}]]]}], " ", "\[Gamma]", " ", 
      SuperscriptBox[
       RowBox[{"x", "[", "\[Tau]", "]"}], "2"]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "\[CapitalGamma]"}], "+", 
        SuperscriptBox[
         RowBox[{"x", "[", "\[Tau]", "]"}], "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"y", "[", "\[Tau]", "]"}]}], ")"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.818481548438057*^9, 3.818561675935646*^9, 
  3.818563684149545*^9, 3.8185672745516586`*^9, 3.8185845756206503`*^9, 
  3.8185864152981963`*^9, 3.8185870636450596`*^9, 3.8185878705460844`*^9, 
  3.818648465206706*^9, 3.81864870623205*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["y", "\[Prime]",
    MultilineFunction->None], "[", "\[Tau]", "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"y", "[", "\[Tau]", "]"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "w"}], ")"}], " ", "\[CapitalGamma]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "\[CapitalGamma]"}], "+", 
          SuperscriptBox[
           RowBox[{"x", "[", "\[Tau]", "]"}], "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Lambda]", "-", 
          SuperscriptBox[
           RowBox[{"y", "[", "\[Tau]", "]"}], "2"]}], ")"}]}], "-", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"x", "[", "\[Tau]", "]"}], "2"], 
          RowBox[{"6", " ", "\[CapitalGamma]"}]]], " ", "\[Gamma]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"9", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "w"}], ")"}], " ", 
           SuperscriptBox["\[CapitalGamma]", "2"]}], "+", 
          RowBox[{"w", " ", 
           SuperscriptBox[
            RowBox[{"x", "[", "\[Tau]", "]"}], "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"y", "[", "\[Tau]", "]"}]}], ")"}]}], "+", 
          RowBox[{"3", " ", "\[CapitalGamma]", " ", 
           SuperscriptBox[
            RowBox[{"x", "[", "\[Tau]", "]"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "w"}], ")"}], " ", 
              RowBox[{"y", "[", "\[Tau]", "]"}]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         SuperscriptBox[
          RowBox[{"x", "[", "\[Tau]", "]"}], "2"], 
         RowBox[{"6", " ", "\[CapitalGamma]"}]]]}], " ", "\[Gamma]", " ", 
      "\[CapitalGamma]", " ", 
      SuperscriptBox[
       RowBox[{"x", "[", "\[Tau]", "]"}], "2"]}], "+", 
     RowBox[{"2", " ", "\[CapitalGamma]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "\[CapitalGamma]"}], "+", 
        SuperscriptBox[
         RowBox[{"x", "[", "\[Tau]", "]"}], "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"y", "[", "\[Tau]", "]"}]}], ")"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.818481548438057*^9, 3.818561675935646*^9, 
  3.818563684149545*^9, 3.8185672745516586`*^9, 3.8185845756206503`*^9, 
  3.8185864152981963`*^9, 3.8185870636450596`*^9, 3.8185878705460844`*^9, 
  3.818648465206706*^9, 3.818648706244819*^9}]
}, Open  ]],

Cell[TextData[{
 "The fixed points at the self-tuning vacuum, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "=", "1"}], TraditionalForm]]],
 ", can be found easily..."
}], "Text",
 CellChangeTimes->{{3.8184815884383183`*^9, 3.8184816269955025`*^9}, {
   3.8184816905545874`*^9, 3.8184817294550896`*^9}, {3.818563701067389*^9, 
   3.818563709478218*^9}, 3.818564612319563*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"dsExpKGB1nd", "/.", 
   RowBox[{
    RowBox[{"y", "[", "\[Tau]", "]"}], "\[Rule]", "1"}]}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dsExpKGB2nd", "/.", 
   RowBox[{
    RowBox[{"y", "[", "\[Tau]", "]"}], "\[Rule]", "1"}]}], "//", 
  "Simplify"}]}], "Input",
 CellChangeTimes->{{3.818481629417392*^9, 3.8184816615263376`*^9}, {
  3.81848173250899*^9, 3.818481738930374*^9}, {3.8185617243606853`*^9, 
  3.8185617424429517`*^9}, {3.818561773282818*^9, 3.818561776204087*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["x", "\[Prime]",
    MultilineFunction->None], "[", "\[Tau]", "]"}], "\[Equal]", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{"9", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        SuperscriptBox[
         RowBox[{"x", "[", "\[Tau]", "]"}], "2"], 
        RowBox[{"6", " ", "\[CapitalGamma]"}]]}]], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "w"}], ")"}], " ", "\[CapitalGamma]", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"x", "[", "\[Tau]", "]"}], "2"], 
          RowBox[{"6", " ", "\[CapitalGamma]"}]]], " ", "\[Gamma]"}], "-", 
       "\[Lambda]"}], ")"}]}], 
    RowBox[{"\[Gamma]", " ", 
     RowBox[{"x", "[", "\[Tau]", "]"}]}]]}]}]], "Output",
 CellChangeTimes->{{3.818481644853522*^9, 3.8184816619488134`*^9}, {
   3.8185617345751762`*^9, 3.8185617428421087`*^9}, 3.8185672775865355`*^9, 
   3.8185845800029483`*^9, 3.818587070790081*^9, 3.8186484682258816`*^9, 
   3.8186487089558935`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["y", "\[Prime]",
    MultilineFunction->None], "[", "\[Tau]", "]"}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{{3.818481644853522*^9, 3.8184816619488134`*^9}, {
   3.8185617345751762`*^9, 3.8185617428421087`*^9}, 3.8185672775865355`*^9, 
   3.8185845800029483`*^9, 3.818587070790081*^9, 3.8186484682258816`*^9, 
   3.8186487089650264`*^9}]
}, Open  ]],

Cell[TextData[{
 "The fixed point on the positive ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " axis is given by..."
}], "Text",
 CellChangeTimes->{{3.818564621932946*^9, 3.818564635369567*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"xdsExpKGB", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"dsExpKGB1nd", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "/.", 
            RowBox[{
             RowBox[{"y", "[", "\[Tau]", "]"}], "\[Rule]", "1"}]}], "//", 
           "Simplify"}], ")"}], "\[Equal]", "0"}], ",", 
        RowBox[{"x", "[", "\[Tau]", "]"}]}], "]"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}], "//", "Quiet"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*
StyleBox[\"x\",
FontSlant->\"Italic\"]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"x", "[", "\[Tau]", "]"}], "/.", "xdsExpKGB"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.8185646368685436`*^9, 3.818564753585374*^9}, 
   3.8185672849517183`*^9}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*\\nStyleBox[\\\"x\\\",\\nFontSlant->\\\"Italic\\\"]\\)\
\"\>", "\[Equal]", 
  RowBox[{
   SqrtBox["\[CapitalGamma]"], " ", 
   SqrtBox[
    RowBox[{"Log", "[", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Lambda]"}], ")"}], "6"], 
      SuperscriptBox["\[Gamma]", "6"]], "]"}]]}]}]], "Output",
 CellChangeTimes->{{3.8185646572266235`*^9, 3.8185646638090687`*^9}, {
   3.8185647404714174`*^9, 3.818564754571782*^9}, 3.8185672992755847`*^9, 
   3.818584584002041*^9, 3.8185870733363504`*^9, 3.818587993502778*^9, 
   3.8186484700046616`*^9, 3.8186487112090297`*^9}]
}, Open  ]],

Cell[TextData[{
 "Given ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalGamma]", "<", "0"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " (gradient constraint), we take in mind that this will be only for..."
}], "Text",
 CellChangeTimes->{{3.8185647597379093`*^9, 3.81856478816677*^9}, {
  3.8185648224781775`*^9, 3.8185648232681274`*^9}, {3.818564870451745*^9, 
  3.8185648915360174`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"xdsExpKGBreal", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"\[Lambda]", "-", "1"}], "\[Gamma]"], "<", "1"}]}], ";", 
  "xdsExpKGBreal"}]], "Input",
 CellChangeTimes->{{3.818564828494496*^9, 3.818564855956354*^9}, {
  3.818564901841754*^9, 3.8185649055862904`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"-", "1"}], "+", "\[Lambda]"}], "\[Gamma]"], "<", "1"}]], "Output",
 CellChangeTimes->{{3.8185649025600033`*^9, 3.8185649068310585`*^9}, 
   3.818567301431164*^9, 3.818584594765964*^9, 3.8185870823030024`*^9, 
   3.8185879965020685`*^9, 3.818648474644657*^9, 3.8186487134371567`*^9}]
}, Open  ]],

Cell[TextData[{
 "The fixed point with ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["y", "2"], "=", "\[Lambda]"}], TraditionalForm]]],
 " can be similarly found. This will be at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "\[Rule]", "\[Infinity]"}], TraditionalForm]]],
 ". We also note about a fixed point at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", "0"}], TraditionalForm]]],
 " with ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]]],
 " given by..."
}], "Text",
 CellChangeTimes->{{3.818561781227872*^9, 3.818561790124508*^9}, {
  3.818561883767725*^9, 3.818561905919774*^9}, {3.8185650308731813`*^9, 
  3.8185650499786873`*^9}, {3.8185651268298235`*^9, 3.8185651823729253`*^9}, {
  3.8185673110743823`*^9, 3.8185673165668344`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"y0fpExpKGB", "=", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"dsExpKGB2nd", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "/.", 
           RowBox[{
            RowBox[{"x", "[", "\[Tau]", "]"}], "\[Rule]", "0"}]}], "//", 
          "Simplify"}], ")"}], "\[Equal]", "0"}], ",", 
       RowBox[{"y", "[", "\[Tau]", "]"}]}], "]"}], "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\"\<\!\(\*
StyleBox[\"y\",
FontSlant->\"Italic\"]\)\>\"", "\[Equal]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"y", "[", "\[Tau]", "]"}], "/.", "y0fpExpKGB"}], 
   ")"}]}]}], "Input",
 CellChangeTimes->{{3.818565193813024*^9, 3.8185652090666213`*^9}, {
  3.818565335042076*^9, 3.8185653586949058`*^9}, {3.8185673272586956`*^9, 
  3.8185674331089516`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*\\nStyleBox[\\\"y\\\",\\nFontSlant->\\\"Italic\\\"]\\)\
\"\>", "\[Equal]", 
  SqrtBox[
   RowBox[{
    RowBox[{"-", "\[Gamma]"}], "+", "\[Lambda]"}]]}]], "Output",
 CellChangeTimes->{
  3.8185651982455883`*^9, {3.8185673787051806`*^9, 3.818567433487714*^9}, 
   3.8185846006708317`*^9, 3.8185870865635853`*^9, 3.818587998501567*^9, 
   3.8186484767277308`*^9, 3.8186487153448567`*^9}]
}, Open  ]],

Cell[TextData[{
 "Note this will be real for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Lambda]", ">", "\[Gamma]"}], TraditionalForm]]],
 " but is compatible with the previous inequality ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Lambda]", "-", "1"}], "<", "\[Gamma]"}], TraditionalForm]]],
 " only in the narrow inequality ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Lambda]", "-", "1"}], "<", "\[Gamma]", "<", "\[Lambda]"}], 
   TraditionalForm]]],
 ". Also note the critical curve partitioning the phase space..."
}], "Text",
 CellChangeTimes->{{3.8185674610702*^9, 3.818567521489254*^9}, {
  3.818567615493917*^9, 3.8185676554637337`*^9}, {3.818567700342149*^9, 
  3.8185677123116207`*^9}, {3.8185712692327285`*^9, 3.818571300095648*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"CritCExpKGB", "=", 
    RowBox[{
     RowBox[{"DSolve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"dsExpKGB1nd", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "//", "Denominator"}], ")"}], 
        "\[Equal]", "0"}], ",", "y", ",", "\[Tau]"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\"\<\!\(\*
StyleBox[\"y\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"(\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"x\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\")\",
FontSlant->\"Italic\"]\)\>\"", "\[Equal]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"y", "[", "\[Tau]", "]"}], "/.", "CritCExpKGB"}], "/.", 
     RowBox[{
      RowBox[{"x", "[", "\[Tau]", "]"}], "\[Rule]", "x"}]}], ")"}]}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"define", " ", "GetyOnC"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"GetyOnC", "[", "z_", "]"}], ":=", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "\[Tau]", "]"}], "/.", "CritCExpKGB"}], "/.", 
    RowBox[{
     RowBox[{"x", "[", "\[Tau]", "]"}], "\[Rule]", "z"}]}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.818571302365131*^9, 3.8185714131933393`*^9}, {
  3.8185864444794464`*^9, 3.8185865045789948`*^9}, {3.8185870945149918`*^9, 
  3.8185870968113513`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*\\nStyleBox[\\\"y\\\",\\nFontSlant->\\\"Italic\\\"]\\)\
\\!\\(\\*\\nStyleBox[\\\"(\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\\
nStyleBox[\\\"x\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\\\")\
\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>", "\[Equal]", 
  FractionBox[
   RowBox[{
    RowBox[{"2", " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      FractionBox[
       SuperscriptBox["x", "2"], 
       RowBox[{"6", " ", "\[CapitalGamma]"}]]], " ", 
     SuperscriptBox["x", "2"], " ", "\[Gamma]"}], "+", 
    RowBox[{"6", " ", "\[CapitalGamma]"}]}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["x", "2"], "+", 
      RowBox[{"3", " ", "\[CapitalGamma]"}]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{{3.818571303145571*^9, 3.818571343759897*^9}, {
   3.8185714009384656`*^9, 3.818571413475712*^9}, 3.8185846040565834`*^9, {
   3.8185864868419733`*^9, 3.8185865051569815`*^9}, 3.818587098170232*^9, 
   3.818588001125951*^9, 3.8186484794487944`*^9, 3.8186487177089434`*^9}]
}, Open  ]],

Cell["Let us checkout the phase portrait of the system...", "Text",
 CellChangeTimes->{
  3.8185712713799243`*^9, {3.818584615382233*^9, 3.818584616351458*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SFCase1ExpKGB", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"w", "\[Rule]", "0"}], ",", 
      RowBox[{"\[Lambda]", "\[Rule]", 
       RowBox[{"9", " ", 
        SuperscriptBox["10", "10"]}]}], ",", 
      RowBox[{"\[Gamma]", "\[Rule]", 
       RowBox[{
        RowBox[{"9", " ", 
         SuperscriptBox["10", "10"]}], "-", 
        FractionBox["1", "2"]}]}], ",", 
      RowBox[{"\[CapitalGamma]", "\[Rule]", 
       RowBox[{"-", "1"}]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"checks", ":", " ", 
     RowBox[{
      StyleBox["x",
       FontSlant->"Italic"], " ", "real"}]}], ",", " ", 
    RowBox[{"gradient", " ", "stability"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"xdsExpKGBreal", "/.", "SFCase1ExpKGB"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ggstabExpKGB", "/.", "SFCase1ExpKGB"}], "/.", 
   RowBox[{
    RowBox[{"NSolve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"FeqExpKGBnd", "/.", 
        RowBox[{"r", "\[Rule]", "\[Lambda]"}]}], "/.", "SFCase1ExpKGB"}], ",",
       "\[Chi]", ",", "Reals"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SFp1ExpKGB", "=", 
    RowBox[{"StreamPlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"dsExpKGB1nd", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "/.", "SFCase1ExpKGB"}], "/.", 
         RowBox[{"y", "\[Rule]", 
          RowBox[{"Function", "[", 
           RowBox[{"a", ",", 
            SuperscriptBox["E", 
             RowBox[{"y", "[", "a", "]"}]]}], "]"}]}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"dsExpKGB2nd", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "/.", "SFCase1ExpKGB"}], "/.", 
         RowBox[{"y", "\[Rule]", 
          RowBox[{"Function", "[", 
           RowBox[{"a", ",", 
            SuperscriptBox["E", 
             RowBox[{"y", "[", "a", "]"}]]}], "]"}]}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x", "[", "\[Tau]", "]"}], ",", "0", ",", "20"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"y", "[", "\[Tau]", "]"}], ",", 
        SuperscriptBox["10", 
         RowBox[{"-", "5"}]], ",", "20"}], "}"}], ",", 
      RowBox[{"PlotTheme", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<Scientific\>\"", ",", "\"\<Red\>\""}], "}"}]}], ",", 
      RowBox[{"AxesStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
      RowBox[{"LabelStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Red", ",", "15"}], "]"}]}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"\"\<\!\(\*
StyleBox[\"h\",
FontSlant->\"Italic\"]\)\!\(\*OverscriptBox[\(\[Phi]\), \(.\)]\)\>\"", ",", 
           RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}], ",", 
         RowBox[{"Style", "[", 
          RowBox[{"\"\<ln(\!\(\*
StyleBox[\"H\",
FontSlant->\"Italic\"]\)/\!\(\*
StyleBox[\"h\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\")\",
FontSlant->\"Italic\"]\)\>\"", ",", 
           RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], "}"}]}], ",", 
      RowBox[{"RotateLabel", "\[Rule]", "False"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "20"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "20"}], "}"}]}], "}"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"yc1ExpKGB", "=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Log", "[", 
          RowBox[{"y", "[", "\[Tau]", "]"}], "]"}], "/.", "CritCExpKGB"}], "/.", 
        RowBox[{
         RowBox[{"x", "[", "\[Tau]", "]"}], "\[Rule]", "x"}]}], "/.", 
       "SFCase1ExpKGB"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", "20"}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"x\[Lambda]0ExpKGB", "=", 
   RowBox[{
    RowBox[{"NSolve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"y", "\[Equal]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"y", "[", "\[Tau]", "]"}], "/.", "CritCExpKGB"}], "/.", 
           RowBox[{
            RowBox[{"x", "[", "\[Tau]", "]"}], "\[Rule]", "x"}]}], ")"}]}], "/.", 
        RowBox[{"y", "\[Rule]", 
         SqrtBox["\[Lambda]"]}]}], "/.", "SFCase1ExpKGB"}], ",", "x", ",", 
      "Reals"}], "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"y\[Lambda]01ExpKGB", "=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Log", "[", 
         SqrtBox["\[Lambda]"], "]"}], "+", 
        FractionBox[
         RowBox[{"Sin", "[", 
          RowBox[{"10", "x"}], "]"}], "5"]}], "/.", "SFCase1ExpKGB"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"(", 
         RowBox[{"x", "/.", "x\[Lambda]0ExpKGB"}], ")"}], ",", "20"}], "}"}], 
      ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Pink"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"SFp1ExpKGB", ",", "yc1ExpKGB", ",", "y\[Lambda]01ExpKGB"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.818481792982904*^9, 3.8184818082348337`*^9}, {
   3.8184818496675234`*^9, 3.818482011387086*^9}, {3.8184820789259806`*^9, 
   3.8184822203520207`*^9}, {3.818563890967924*^9, 3.818563891515113*^9}, {
   3.818565265049858*^9, 3.818565288522395*^9}, 3.8185677184625835`*^9, {
   3.818567796310237*^9, 3.818567800067727*^9}, {3.8185678533598967`*^9, 
   3.8185678553650064`*^9}, {3.8185679523268824`*^9, 
   3.8185680149355135`*^9}, {3.8185680511203303`*^9, 
   3.8185681115971546`*^9}, {3.8185681842731447`*^9, 3.81856818478428*^9}, {
   3.8185682918138742`*^9, 3.818568332320932*^9}, {3.8185684063478355`*^9, 
   3.8185684286843734`*^9}, {3.818568493192749*^9, 3.8185685283364997`*^9}, {
   3.8185686034226084`*^9, 3.818568603554384*^9}, {3.81856879648161*^9, 
   3.818568802108909*^9}, {3.8185691874048405`*^9, 3.8185692577447047`*^9}, {
   3.818569606564947*^9, 3.8185696129849973`*^9}, {3.8185697609713564`*^9, 
   3.8185697732173147`*^9}, 3.8185706067995915`*^9, {3.818570739730901*^9, 
   3.818570754059864*^9}, {3.818571032312091*^9, 3.8185711065608807`*^9}, {
   3.8185714343548937`*^9, 3.818571504158368*^9}, {3.8185715579592333`*^9, 
   3.8185715938764935`*^9}, {3.8185716668409014`*^9, 
   3.8185717318158455`*^9}, {3.8185717691957226`*^9, 3.818571847625457*^9}, {
   3.8185719427734003`*^9, 3.8185720648237505`*^9}, {3.8185722679325495`*^9, 
   3.818572269138583*^9}, {3.818572377769212*^9, 3.8185724018837185`*^9}, {
   3.818572728048156*^9, 3.8185728393920374`*^9}, {3.818572898921222*^9, 
   3.81857289948108*^9}, {3.8185729760963087`*^9, 3.8185730352452917`*^9}, {
   3.8185733703083453`*^9, 3.818573393337249*^9}, {3.8185734292259874`*^9, 
   3.8185735242034764`*^9}, {3.8185737641702485`*^9, 
   3.8185737646111617`*^9}, {3.818573896913282*^9, 3.818573932936065*^9}, {
   3.81858479617058*^9, 3.818584854139716*^9}, {3.818584886878418*^9, 
   3.81858488737826*^9}, {3.818585561492922*^9, 3.8185855619146585`*^9}, {
   3.8185857741356816`*^9, 3.8185857955002594`*^9}, {3.81858652931927*^9, 
   3.8185865663495617`*^9}, {3.818587125335081*^9, 3.8185872515704727`*^9}, {
   3.81864873362682*^9, 3.818648735453245*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.8184818515832367`*^9, {3.8184819348780737`*^9, 3.818482013441454*^9}, {
   3.818482080080847*^9, 3.8184821418904257`*^9}, {3.81848217662327*^9, 
   3.818482221095478*^9}, 3.818563893409298*^9, {3.818565266194435*^9, 
   3.818565278934477*^9}, 3.81856780180866*^9, 3.818567975631635*^9, {
   3.8185680552180853`*^9, 3.8185681120434923`*^9}, 3.8185681856009555`*^9, {
   3.818568307160365*^9, 3.818568332793297*^9}, 3.8185685337998533`*^9, 
   3.8185686056581507`*^9, 3.8185687975631185`*^9, {3.818569195807132*^9, 
   3.818569258264633*^9}, 3.818569613376004*^9, 3.8185697736464233`*^9, 
   3.8185706083259926`*^9, {3.8185710537351265`*^9, 3.818571109570554*^9}, 
   3.8185715944780474`*^9, {3.8185720404193935`*^9, 3.818572065114059*^9}, {
   3.818572393057279*^9, 3.818572402513338*^9}, {3.818572729211737*^9, 
   3.818572839920105*^9}, {3.8185729798930874`*^9, 3.8185730364466662`*^9}, 
   3.8185737755734935`*^9, {3.818573912537221*^9, 3.8185739375382195`*^9}, {
   3.8185848687508574`*^9, 3.818584887815658*^9}, 3.818585799448018*^9, 
   3.818587253679386*^9, 3.8186485710634604`*^9, 3.8186487400916653`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.8184818515832367`*^9, {3.8184819348780737`*^9, 3.818482013441454*^9}, {
   3.818482080080847*^9, 3.8184821418904257`*^9}, {3.81848217662327*^9, 
   3.818482221095478*^9}, 3.818563893409298*^9, {3.818565266194435*^9, 
   3.818565278934477*^9}, 3.81856780180866*^9, 3.818567975631635*^9, {
   3.8185680552180853`*^9, 3.8185681120434923`*^9}, 3.8185681856009555`*^9, {
   3.818568307160365*^9, 3.818568332793297*^9}, 3.8185685337998533`*^9, 
   3.8185686056581507`*^9, 3.8185687975631185`*^9, {3.818569195807132*^9, 
   3.818569258264633*^9}, 3.818569613376004*^9, 3.8185697736464233`*^9, 
   3.8185706083259926`*^9, {3.8185710537351265`*^9, 3.818571109570554*^9}, 
   3.8185715944780474`*^9, {3.8185720404193935`*^9, 3.818572065114059*^9}, {
   3.818572393057279*^9, 3.818572402513338*^9}, {3.818572729211737*^9, 
   3.818572839920105*^9}, {3.8185729798930874`*^9, 3.8185730364466662`*^9}, 
   3.8185737755734935`*^9, {3.818573912537221*^9, 3.8185739375382195`*^9}, {
   3.8185848687508574`*^9, 3.818584887815658*^9}, 3.818585799448018*^9, 
   3.818587253679386*^9, 3.8186485710634604`*^9, 3.818648740111334*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], ArrowBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQ7c1hNunHf2UHlWtVkTc75B0Cyru2gvhXuT2iQyfJ
O7ycsP8WiP9i+oImhznyDt+S95n/BPLn5O7bFbZV3uGUtt5pEL/vY2KK5z15
ByGDf3K/gPw1lVK56d/kHWTnv/wP4i81sPtzXUbBwe+i1OTfQD67wd50ExMF
hx0/z1wC8f9PzEidbKfgYF9kx/MHyK8IubxazkPBIS069A6IP0HPYGJutoLD
abeALX+B/MzmKSprJyk4fPnvtOEfkJ9933alwhEFh8pJP3b+B/JX/1dn6P+r
4LD6zIUzDAwqDv7avNMYHBQddrVIPGEE8qP+xD651aPoIPxu6i8mIN9GmLHx
/lNFBz7Dr9wsQP6u/PnzzvoqOexk3yfACuSz2RnM1jmu5CB3tGQ+iO+4glXG
VVrZAQBmLI/O
        "]]}, 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{10.000043979996873`, 9.595002138812637}, {
        10.000046095881558`, 9.676712991787674}, {10.000052392211158`, 
        10.000074570442981`}, {10.000054842021601`, 10.235724051646914`}, {
        10.000056600753904`, 10.464493757022757`}, {10.00005812983912, 
        10.688563383933488`}, {10.000059275466898`, 10.907206366591451`}, {
        10.000060709949118`, 11.155763743623858`}, {10.000061274669592`, 
        11.264622157904972`}}]}, 
      {Arrowheads[{{0.015729101823100902`, 1.}}], 
       ArrowBox[{{10.00006149120513, 11.306362658384769`}, {
        10.000061934843846`, 11.391880731972897`}, {10.000062950151083`, 
        11.615557331638573`}, {10.000063755870823`, 11.826793542620882`}, {
        10.000064415397858`, 12.018719284080364`}, {10.00006500985741, 
        12.182540955667701`}, {10.000065567326931`, 12.315157353894227`}, {
        10.000066635190118`, 12.488964458591388`}, {10.000067678712728`, 
        12.565122572141677`}, {10.000068718207006`, 12.599569450021589`}, {
        10.000069330469026`, 12.611950149442045`}, {10.000071738114947`, 
        12.61944382235387}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], ArrowBox[CompressedData["
1:eJwBcQGO/iFib1JlAgAAABYAAAACAAAA6b93YNkEK0CS5IadpzprP0nZoPoQ
/SpARA3h5Og/aj/E2gjKiw0rQBqWSyz/QG4/rc74VhAmK0ARZP9DJaJyPx5B
KNP0MytAe735coIGdT/ufLPLtVgrQEonKCURz3w/G5JdKdWlK0AXmoQMwy6L
PxOrJcp6JyxAPdJsKjdgoj9OOXruUl0sQPWRvPlYr60/n+Q7IBeALECG8Tac
7Hu0P181psXv0yxA8LvMEL2DxT+m2uIzew0tQAgso0Pg6tI/y/swmVwRLUC7
Y3B3wrvTP6MzxtgOFS1AZhx7YKSM1D9me5OulRgtQGijYAeGXdU/v184r04a
LUBKW0fL9sXVPzCwvt39Gy1A3V7egGcu1j9t7kWYox0tQCTX7yjYltY/KGTM
N0AfLUAQVjfESP/WP029jBDUIC1ATCFjU7ln1z+J+UC/T10tQL4el10Of+U/
cl1Vr91qLUArc+0SGYDpP+DCn+Q=
        "]]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{14.7173624743627, 0.8377234773324682}, {14.747000469811852`,
         0.9778075329258784}, {14.779574854709455`, 1.2838519183759152`}, {
        14.801174863007102`, 1.5898957886901286`}, {14.81521112622791, 
        1.895939330711686}, {14.825094275894996`, 2.201982731283756}, {
        14.826603787077108`, 2.263191395680481}, {14.828013456916086`, 
        2.324400057064154}, {14.829330515206028`, 2.385608715686036}, {
        14.829966755550082`, 2.416213044336238}, {14.830581912535711`, 
        2.4468173723656332`}, {14.831176745641221`, 2.477421699799659}, {
        14.831623672339218`, 2.50119951816983}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{14.832393352211499`, 2.542932916497312}, {
        14.837383393497348`, 2.795434671903085}, {14.842831602770437`, 
        3.0522390015356144`}, {14.84753353405194, 3.3090433097552063`}, {
        14.85036977035447, 3.5658475644424534`}, {14.852086149646723`, 
        3.822651790799363}, {14.853926615255642`, 4.079456023251141}, {
        14.854750751192388`, 4.212372257807713}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{14.855009554681244`, 4.254111955951147}, {14.85551890823123,
         4.336260243513182}, {14.856490769623479`, 4.593064433300879}, {
        14.85706578824153, 4.867763768749438}, {14.85750159994701, 
        5.142463079075996}, {14.857752359365312`, 5.417162281795184}, {
        14.85794268025497, 5.6918613697148155`}, {14.858047789014998`, 
        5.9237274053590445`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{14.858066710681491`, 5.9654679015506495`}, {
        14.858119355581811`, 6.081600603819167}, {14.858162671209307`, 
        6.471334697625689}, {14.858152642957068`, 6.861066735313081}, {
        14.858169286644694`, 7.250799801060038}, {14.85820585972614, 
        7.635087904200752}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{14.858207222876496`, 7.676828404646822}, {
        14.858215499935321`, 8.029990827869456}, {14.858213447866547`, 
        8.41948202045047}, {14.858216986623125`, 8.808996395436749}, {
        14.858224084715095`, 9.198001727284975}, {14.858225566786778`, 
        9.346448423670536}}]}, 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{14.858225983518274`, 9.388188924148814}, {
        14.858227964871974`, 9.586644514635903}, {14.858231258192887`, 
        9.972937301109653}, {14.858233087644797`, 10.357542572166185`}, {
        14.858233247718038`, 10.382207974032097`}, {14.858233403983796`, 
        10.406858774810928`}, {14.858233556539322`, 10.431494246381018`}, {
        14.858233705479547`, 10.45611362532204}, {14.858233850897149`, 
        10.480716111308173`}, {14.858234134953998`, 10.529884726596645`}, {
        14.858234405799164`, 10.578976937059563`}, {14.858234664106602`, 
        10.627984999123292`}, {14.85823581043535, 10.870889916333361`}, {
        14.858236527350153`, 11.057808943326185`}}]}, 
      {Arrowheads[{{0.01805810531464514, 1.}}], 
       ArrowBox[{{14.858236687442911`, 11.099549443806236`}, {
        14.858236727391237`, 11.109965049900568`}, {14.858237465240581`, 
        11.342525725470047`}, {14.858238074249694`, 11.565887268686927`}, {
        14.858239033544866`, 11.965996425999004`}, {14.858239632824294`, 
        12.227457731341207`}, {14.858240178542268`, 12.412139414091905`}, {
        14.858240458048137`, 12.470946855132386`}, {14.858240733879509`, 
        12.512867702672017`}, {14.858241008798121`, 12.543400709141753`}, {
        14.858241283228944`, 12.564972987407236`}, {14.85824171405511, 
        12.58650912820499}, {14.858242144663897`, 12.597865091131855`}, {
        14.858242974030494`, 12.6070581508677}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{5.143064659615096, 19.92139674843989}, {5.143064659548324, 
        19.83999872443402}, {5.143064659498949, 19.77745238057165}, {
        5.143064659459189, 19.725699653024652`}, {5.143064659389916, 
        19.63293971530363}, {5.143064659337143, 19.55993169820658}, {
        5.143064659294218, 19.499137905869517`}, {5.143064659217816, 
        19.388244661059638`}, {5.143064659159907, 19.301786143408208`}, {
        5.143064659113589, 19.231182841419837`}, {5.14306465895193, 
        18.978016758434666`}, {5.143064658855227, 18.82048260594783}, {
        5.143064658786339, 18.705884907869876`}, {5.143064658607495, 
        18.40246056276601}, {5.143064658520888, 18.251776729225544`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{5.143064658497033, 18.210036228745185`}, {5.14306465827273, 
        17.81358519691593}, {5.143064658209775, 17.700311488375092`}, {
        5.1430646581590445`, 17.608633483639164`}, {5.1430646581165504`, 
        17.53159111788852}, {5.143064658046622, 17.40439623311267}, {
        5.143064657991495, 17.30376314493211}, {5.143064657946589, 
        17.22156555474667}, {5.143064657774938, 16.90623653534138}, {
        5.1430646576735155`, 16.718929229428568`}, {5.143064657601884, 
        16.586295099175274`}, {5.143064657577162, 16.54041620953084}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{5.14306465755467, 16.49867570905048}, {5.143064657417074, 
        16.243326317020976`}, {5.1430646573599885`, 16.137125352836208`}, {
        5.14306465731309, 16.049818961043695`}, {5.143064657273286, 
        15.97568553977217}, {5.14306465720765, 15.853387586629463`}, {
        5.143064657155161, 15.755551012378852`}, {5.143064657111716, 
        15.674554665868351`}, {5.143064656971586, 15.413312818341772`}, {
        5.14306465688135, 15.245175433204938`}, {5.143064656815155, 
        15.121955763813006`}, {5.143064656657428, 14.829055689836135`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{5.143064656634931, 14.787315189355777`}, {5.143064656583314,
         14.691882075482443`}, {5.143064656536954, 14.606397449285154`}, {
        5.143064656497337, 14.533543403275274`}, {5.143064656431508, 
        14.412949465204061`}, {5.143064656378375, 14.316147779859802`}, {
        5.1430646563339515`, 14.23567151721407}, {5.143064656200821, 
        13.997280710335335`}, {5.14306465611014, 13.838495552296722`}, {
        5.143064656041047, 13.72020154953883}, {5.143064655847586, 
        13.402588841246263`}, {5.1430646557812505`, 13.300816408678632`}, {
        5.14306465572419, 13.216450252742392`}, {5.143064655673691, 
        13.144399263281432`}, {5.143064655654051, 13.117695170141431`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{5.143064655623351, 13.075954669661073`}, {5.143064655585802,
         13.024902035128623`}, {5.143064655510372, 12.928790014566777`}, {
        5.143064655443472, 12.84868993290563}, {5.143064655235614, 
        12.626228198147386`}, {5.143064655065402, 12.474438451054045`}, {
        5.143064654915067, 12.359965586436852`}, {5.143064654392288, 
        12.049563422818066`}, {5.143064654160089, 11.94916475373049}, {
        5.143064653936927, 11.865735453256477`}, {5.143064653720187, 
        11.794362702328673`}, {5.143064653299589, 11.675799302927395`}, {
        5.143064652891266, 11.580280196273076`}, {5.143064652491332, 
        11.500510844141164`}, {5.143064651888068, 11.406334650446727`}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{5.1430646516206915`, 11.364594149966369`}, {
        5.1430646511636695`, 11.29324793521849}, {5.143064649869305, 
        11.148490257633936`}, {5.143064648593175, 11.037961161517117`}, {
        5.143064643562865, 10.735138309009953`}, {5.143064641075674, 
        10.636209014433565`}, {5.143064638597277, 10.553783101453515`}, {
        5.143064636125158, 10.483136019217284`}, {5.143064631193563, 
        10.36556750340265}, {5.143064626274055, 10.270673692911009`}, {
        5.143064621362791, 10.191245317037735`}, {5.143064606470023, 
        10.003924141942383`}, {5.143064591605161, 9.868932111376735}, {
        5.143064576756354, 9.764040936482338}, {5.1430645627133895`, 
        9.694974130752026}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{5.143064554226529, 9.653233630271668}, {5.143064517429312, 
        9.472255716497882}, {5.1430644877920155`, 9.37549354703357}, {
        5.143064458163163, 9.294542431624597}, {5.143064428540383, 
        9.224954787556266}, {5.143064369307135, 9.108819126844256}, {
        5.143064310085712, 9.014798248445878}, {5.143064250872341, 
        8.935827990447269}, {5.1430640683608235`, 8.749107860258809}, {
        5.143063885876814, 8.613679698036556}, {5.143063703408365, 
        8.507197182295801}, {5.143063520950216, 8.419829956113315}, {
        5.143062791170606, 8.168105737194965}, {5.143062061438754, 
        8.003709854789681}, {5.143061911389931, 7.983613611061195}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{5.143061599734028, 7.941873110582}, {5.14305914266334, 
        7.612794279120663}, {5.143056223999288, 7.403557197490328}, {
        5.143050386787545, 7.126558291919382}, {5.143044549681688, 
        6.947283067588764}, {5.14303768496227, 6.801625413852419}, {
        5.143030820333261, 6.688181998990123}, {5.143023955788183, 
        6.595132469606233}, {5.1430170913237765`, 6.516549896659934}, {
        5.14299743632478, 6.33749779555197}, {5.1429877730253155`, 
        6.272253094270597}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{5.142981590899509, 6.230512594248051}, {5.142977781947177, 
        6.204795295727682}, {5.142958128180552, 6.099779183245217}, {
        5.1428795191358905`, 5.801828886532231}, {5.14284021821195, 
        5.700749266096796}, {5.142800919677275, 5.615462009186564}, {
        5.1427616235291564`, 5.54179731236518}, {5.14260446276507, 
        5.312751159141365}, {5.142525891911667, 5.220883979759518}, {
        5.142447330578354, 5.142457251598672}, {5.142368788270255, 
        5.080574394193466}, {5.142290255468989, 5.024330330135831}, {
        5.142133208872515, 4.920857367359035}, {5.141976200276698, 
        4.832803930021858}, {5.1418192296592515`, 4.755974173533541}, {
        5.14140749885844, 4.58938385728383}, {5.141317895778169, 
        4.56089391545265}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{5.141186619310851, 4.519153621409124}, {5.140996029062312, 
        4.45855408534341}, {5.140584819908045, 4.35014273101544}, {
        5.139831846446568, 4.18796972376594}, {5.139079745101609, 
        4.058182370059167}, {5.138328513703908, 3.9494015729656393`}, {
        5.136930421954454, 3.782554791443483}, {5.1355353319388835`, 
        3.6482159301471517`}, {5.134143229872327, 3.5352249995955027`}, {
        5.131621724642762, 3.365470122003038}, {5.129109955103376, 
        3.2279033738350638`}, {5.126607841035689, 3.111828383580771}, {
        5.122189254645601, 2.940771984226413}, {5.119319176369342, 
        2.84973378787266}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{5.118003915091314, 2.808014014765399}, {5.117800416698351, 
        2.801559094420746}, {5.113440901098713, 2.6839577575065547`}, {
        5.105970980325283, 2.5149075536167507`}, {5.098585392586149, 
        2.377087666168181}, {5.091282121865649, 2.26079006520311}, {
        5.079180854733523, 2.098357313797966}, {5.067298120709834, 
        1.9660818538730198`}, {5.055625620366506, 1.8548592552684653`}, {
        5.036961031974742, 1.7042773205067565`}, {5.018806709136042, 
        1.5821563682340445`}, {5.001133580204917, 1.4800864144428267`}, {
        4.9738541266256915`, 1.3461178781992145`}, {4.947637050568804, 
        1.2382267342292184`}, {4.923830095506283, 1.1538599540685786`}}]}, 
      {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBUQGu/iFib1JlAgAAABQAAAACAAAAEND+z9CkE0CLWEermdPxP/+Q+NPh
iRNAiMxdWK6N8D/HQLeVPmUTQMiQ2gkcMe4/CQU+WWhCE0B9lNp+bszrP12n
R0aJDxNAXCbCf0XO6D9dm+/aA+ASQPad+9QfcuY/UiSpTWazEkCfzCmKbofk
P1VzPaoRcxJALFBxVnoo4j9cpbV71zcSQB8DsDNbUOA/LLeFD+kAEkAEYcQd
rqrdP6PVNiS7sRFA3WbVyo0B2j8XPx0S22kRQFRuxF4yNNc/nVAJ1PMnEUB/
mLuOoPvUP0gGS2npxxBA2JBBt9U20j/635RV7nEQQGhcPb94ItA/YXSKZPEj
EEDH3KrrEgXNP+sKEt4IYA9AEHrMl7XoyD+sO8R8WJMOQEwhsyfU48U/mdYy
1p/bDUDOJIYPppHDPzrgDkuXcw1Axd1zF2N1wj9RiZSU
        "]]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{3.6402960797380195`, 0.1371808404468324}, {
        3.5955584931460676`, 0.12954075735128612`}, {3.47660405094208, 
        0.11283058226210782`}, {3.37094198371692, 0.10020644846480314`}, {
        3.2066195126998442`, 0.08375021103703217}, {3.0656112260284334`, 
        0.0722650154451744}, {2.9416269019376116`, 0.06372798992447597}, {
        2.7496067443484065`, 0.052690073061633994`}, {2.586695028901644, 
        0.04510024722076977}, {2.4447058331121037`, 0.03950390353207324}, {
        2.2345855209716934`, 0.032539272183704136`}, {2.057398390351186, 
        0.027706083548887834`}, {1.9756333211056705`, 
        0.025790325571294598`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{1.9339042729739166`, 0.024812612746081476`}, {
        1.9040281800127339`, 0.024112615009176948`}, {1.6912390366826446`, 
        0.019820421103516807`}, {1.512875409162662, 0.01675269533518937}, {
        1.3600189130932756`, 0.014422886743003065`}, {1.1619988557389103`, 
        0.011723391502620412`}, {0.9986433850852745, 0.009729069079366317}, {
        0.8616477992186341, 0.00818378077373552}, {0.6967412818984214, 
        0.006466429081888263}, {0.5648604580541069, 0.005154359726571681}, {
        0.4589649627064544, 0.004139252086605957}, {0.37354091407547824`, 
        0.0033428246244292946`}, {0.2644477122357899, 
        0.002351243139033599}}]}, 
      {Arrowheads[{{0.0025009431344722275`, 1.}}], 
       ArrowBox[{{0.22270891287558922`, 0.001974408966541271}, {
        0.16420955725024006`, 0.0014486389162576998`}, {0.10884486872263259`, 
        0.000956236029349469}, {0.07224424720609497, 0.0006338457715736943}, {
        0.042053357133787, 0.0003686060832815995}, {0.02424969460372558, 
        0.00021198412145037983`}, {0.013935898284023652`, 
        0.00012166055801318234`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{12.438185490411009`, 20.}, {12.438185490451264`, 
        19.922276969932287`}, {12.438185490500642`, 19.835746999867265`}, {
        12.4381854905462, 19.762128077484554`}, {12.43818549062893, 
        19.640464316019415`}, {12.438185490703036`, 19.54296597931567}, {
        12.438185490770548`, 19.46208432859595}, {12.43818549101354, 
        19.210871877098814`}, {12.438185491210792`, 19.046665242402373`}, {
        12.438185491380441`, 18.92545450290603}, {12.438185491929293`, 
        18.602373148263045`}, {12.438185492150474`, 18.499556685531413`}, {
        12.438185492351762`, 18.41447508353743}, {12.438185492537707`, 
        18.341903245268707`}, {12.438185492570113`, 18.330379980785654`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{12.438185492687495`, 18.288639480305296`}, {
        12.438185492875789`, 18.221683115769657`}, {12.438185493178997`, 
        18.12510619915048}, {12.438185493455654`, 18.044741133780736`}, {
        12.438185494377672`, 17.81203734367742}, {12.438185495135995`, 
        17.655691637256055`}, {12.438185495792547`, 17.538712341467253`}, {
        12.438185497928783`, 17.2235546747012}, {12.438185498793668`, 
        17.122244835303416`}, {12.438185499581781`, 17.038194339444633`}, {
        12.438185500310501`, 16.966372647517208`}, {12.438185501636637`, 
        16.84719389660955}, {12.438185502827071`, 16.751288056923045`}, {
        12.438185503914514`, 16.67131062272139}, {12.438185504728468`, 
        16.61901946109095}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{12.438185505378192`, 16.57727896061059}, {
        12.438185507304468`, 16.453528464333793`}, {12.43818551012397, 
        16.303823405711494`}, {12.438185512593728`, 16.18926799637477}, {
        12.43818551282547, 16.179217294640832`}, {12.43818551305492, 
        16.169364831634315`}, {12.43818551340621, 16.154466682496878`}, {
        12.4381855174057, 16.006810391151078`}, {12.438185520942685`, 
        15.891434779135192`}, {12.438185527360892`, 15.699661619884138`}, {
        12.43818553276613, 15.564747631334345`}, {12.438185537566577`, 
        15.458721847763302`}, {12.438185545279026`, 15.308389760075386`}, {
        12.43818555203287, 15.193804293728586`}, {12.438185558129781`, 
        15.100854230366194`}, {12.438185570026334`, 14.940670458890343`}, {
        12.438185572875886`, 14.907658941396248`}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{12.438185576478922`, 14.86591844091589}, {
        12.438185580374325`, 14.820790938399488`}, {12.438185589689532`, 
        14.724508806051452`}, {12.438185606880822`, 14.568226074347162`}, {
        12.438185621925161`, 14.450798184557726`}, {12.438185635532056`, 
        14.35634724372573}, {12.438185661075218`, 14.201412228674219`}, {
        12.438185683580402`, 14.085396123613343`}, {12.438185704069042`, 
        13.992372447169293`}, {12.438185742473442`, 13.842019509158407`}, {
        12.438185776788806`, 13.729883031002375`}, {12.438185808426109`, 
        13.640408016164526`}, {12.438185867930478`, 13.498759447374074`}, {
        12.438185922345985`, 13.394077067877857`}, {12.43818597352308, 
        13.311433176096438`}, {12.438186061620288`, 13.196298421701645`}}]}, 
      {Arrowheads[{{0.006458798317371222, 1.}}], 
       ArrowBox[{{12.438186100871212`, 13.154557921221304`}, {
        12.438186159604275`, 13.095549636405655`}, {12.438186246729465`, 
        13.02541174666814}, {12.438186404611038`, 12.928020691485699`}, {
        12.438186558353102`, 12.859798214852619`}, {12.438186709853527`, 
        12.809242648563707`}, {12.438186961741911`, 12.749021492492838`}, {
        12.438187211788488`, 12.709276223545604`}, {12.438187460990553`, 
        12.681828185554705`}, {12.438187817866927`, 12.655776332601281`}, {
        12.438188174377458`, 12.639843377327953`}, {12.438188530750171`, 
        12.629770019148452`}, {12.438188961294555`, 12.622277853036673`}, {
        12.438189822313015`, 12.61537097276559}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{16.43699356194735, 20.}, {16.436993561974635`, 
        19.92862162594359}, {16.43699356201664, 19.83040904459962}, {
        16.43699356205486, 19.749132682216523`}, {16.43699356219954, 
        19.48488425599832}, {16.436993562315934`, 19.315415815762087`}, {
        16.436993562415598`, 19.19144104271334}, {16.43699356273686, 
        18.863275084720787`}, {16.436993562865947`, 18.759511705890578`}, {
        16.43699356298333, 18.673785841180237`}, {16.4369935630917, 
        18.600747559085384`}, {16.436993563288635`, 18.479883512612115`}, {
        16.436993563465162`, 18.38289503841805}, {16.436993563570038`, 
        18.330379980785654`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{16.436993563657612`, 18.288639480305296`}, {
        16.436993564182373`, 18.061053271317746`}, {16.4369935646371, 
        17.901021631008792`}, {16.436993565029574`, 17.782043061983494`}, {
        16.43699356630313, 17.463121543980183`}, {16.43699356681761, 
        17.361091988775183`}, {16.436993567286134`, 17.27654837324782}, {
        16.436993567719156`, 17.20436768954271}, {16.43699356850684, 
        17.084690393797093`}, {16.436993569213612`, 16.988463263789978`}, {
        16.436993569858885`, 16.908299888068324`}, {16.436993571937148`, 
        16.683364148957786`}, {16.436993572660455`, 16.61901946109095}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{16.43699357312967, 16.57727896061059}, {16.436993573656657`,
         16.53039871239042}, {16.436993575158898`, 16.413960308800693`}, {
        16.436993575299702`, 16.403766674955325`}, {16.436993575439097`, 
        16.393776844416962`}, {16.436993575652473`, 16.378676010334978`}, {
        16.436993578077896`, 16.229394468725314`}, {16.436993580219873`, 
        16.113034123342967`}, {16.43699358410312, 15.91988292448659}, {
        16.436993587368594`, 15.784326464416317`}, {16.43699359026668, 
        15.677873208837903`}, {16.436993594896514`, 15.527713839239507`}, {
        16.436993598949705`, 15.413180009144549`}, {16.436993602607217`, 
        15.320228601032792`}, {16.43699360975491, 15.159620190598842`}, {
        16.436993615964095`, 15.039404019959678`}, {16.43699362154685, 
        14.942823903194418`}, {16.43699362385284, 14.907658941396246`}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{16.436993626590027`, 14.865918440915888`}, {
        16.43699363183841, 14.785883725671587`}, {16.436993640822564`, 
        14.667878102021985`}, {16.436993648929448`, 14.572886929654887`}, {
        16.436993664133002`, 14.41651338516163}, {16.4369936774623, 
        14.299257019675867`}, {16.43699368954191, 14.205085907541887`}, {
        16.43699371214531, 14.05179871019241}, {16.43699373215855, 
        13.937136871855538`}, {16.436993750459404`, 13.845332896682372`}, {
        16.43699378484314, 13.69784046930308}, {16.436993815822355`, 
        13.588174158373876`}, {16.43699384459306, 13.500977068190158`}, {
        16.436993898663516`, 13.364992305163597`}, {16.43699394872448, 
        13.265101564604425`}, {16.436993990512587`, 13.196298421701599`}}]}, 
      {Arrowheads[{{0.006436852617460653, 1.}}], 
       ArrowBox[{{16.436994020987562`, 13.154557921221251`}, {
        16.43699408450639, 13.071664267337432`}, {16.436994168926567`, 
        12.989114508979517`}, {16.436994251140405`, 12.926230779580377`}, {
        16.436994396070876`, 12.843492882425073`}, {16.436994538586607`, 
        12.78676510322056}, {16.436994679872516`, 12.745784591774568`}, {
        16.43699490220521, 12.700996588569474`}, {16.436995123746556`, 
        12.672338009266939`}, {16.436995344953587`, 12.65324953311282}, {
        16.43699563977951, 12.636930274715667`}, {16.436995934497286`, 
        12.627223425268662`}, {16.43699656490482, 12.61720302170935}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQnRMe7ZuZruqgseTymt0/RB1+v57VkA7kc82stTR/
K+pw8VLdnxQg395aYKn4XVEHi4SNC5KA/K3BBQ+lz4k6XLqwpDYByL+eEWW2
54Cow9y/NWWxQH79jX2b+NaJOjyq/+4WDeT/WjX19ukFog4RKWWlkUD+xqc2
s59OFXWYl6SbGgbkd0zznHeiWdQh5+PzC8FAvqbrf8mTJaION7IZugKB/PjP
J0V3pwP5q+K+eAL5U5b92OJnK+ow+dinn85A/sn0dzlmsqIOwtxqMlJAfl7/
3nfFgSIOXWsW//ubpuow0WjBTIF7wg4RqR/+PwXy7YXtXiu0CjuULl0XdAHI
N7SOSOS3FnZION8wcy6QfzdZIvzRfCGHx3v5rQqA/ItP+8OfqQk5dM/MZXED
8ufci2jiPyTowOFtzywH5OuWTPhqli3owPmo+86KVFWHnmzzPTZ9Ag7TRf8r
2QD591Tvtuw+ze8gOtc1+0qKqkNama5t9g4+h3veE1qPAfnvftpvkZrG5wAA
QXCssQ==
        "]]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{10.696562968913286`, 3.7815534567647724`}, {
        10.696545063364091`, 3.778723915329862}, {10.696163030010789`, 
        3.722020511088002}, {10.695459072764871`, 3.631994761652753}, {
        10.694767076423624`, 3.5506367294367074`}, {10.693402454941058`, 
        3.401570198098958}, {10.69207152071646, 3.275707841985581}, {
        10.690766223205069`, 3.1665418765193407`}, {10.688141469629759`, 
        2.977988365122909}, {10.685580979975233`, 2.8247534420231815`}, {
        10.683070421265764`, 2.695577367458151}, {10.678953682913301`, 
        2.5157137881423965`}, {10.674931502410969`, 2.368921583799321}, {
        10.670989737402921`, 2.245136877654894}, {10.666013114480933`, 
        2.112283738996278}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{10.664416625851716`, 2.070573891482385}, {10.65843038715659,
         1.936896871971381}, {10.652388566931723`, 1.8207537725920446`}, {
        10.642959379453941`, 1.6663096357797236`}, {10.633855878045306`, 
        1.541109451023293}, {10.625049060424708`, 1.4366038723419554`}, {
        10.61172218471795, 1.3013628299957396`}, {10.599003058276496`, 
        1.1924955167814977`}, {10.586832660082745`, 1.1023428995800177`}, {
        10.568928296660406`, 0.9884685088682635}, {10.552077811330427`, 
        0.8976736201418022}, {10.536158602334865`, 0.823210058035932}, {
        10.513239558195526`, 0.7308373463470806}, {10.49199722189714, 
        0.6580601185807572}, {10.472196995773915`, 0.5990275061109267}, {
        10.44401952778319, 0.5264788404758131}, {10.418312080870885`, 
        0.47013724085890257`}, {10.399232652422226`, 0.43371020305645597`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], ArrowBox[CompressedData["
1:eJwB4QEe/iFib1JlAgAAAB0AAAACAAAAh4Kr65nBJEBK8DcoLHTZP8XFzTPY
uCRAkgE+SAam1z/BD1CtYKkkQL8A+y8u8NQ/JuZyYFabJEA+Yl/6/8vSP2A9
3jUjhyRAgMhkczkk0D/5/IKkS3UkQC0HjG20UMw/BwKg/U5lJEDNf90GNDvJ
P6U4hpTSTSRAeIMfN6BYxT/0uTYmcDkkQP4m9jr2hMI/GTGqfWonJEBK6dc0
Sl3APx4YAv0jDCRALnHepZcuuz9Esz9l7PQjQL3lkR0aR7c/mnAdNLDgI0Ac
Xw2io160P1XI+cTewCNA4BEehgeHsD9Cf20/Y6YjQOcoEyQ+3qs/R9i6vqqP
I0D9O3JwPRyoPzBfIhM9aiNAY9yFX7z9oj9FE3as50sjQN/p1AA4bp8/79Zy
kFUyI0BDqFnt6NWaP1lusuntBSNAAU3z2kFelD+nBBiZD+MiQN18vpx1f5A/
Z5UWRjvGIkC0Oy2Bo8KLP1k2Ev0nmCJAUiW4BPUHhT8TM9i1E3QiQArKOQeY
BIE/MfaJGUtWIkBPcZvIx518PzNyJwXWJCJApO3cIaRpdT+eigMSg/4hQAmZ
u0LrNnE/a0ta3Q/fIUDlSYDVWNJsP+TDPz34qSFA+KXUdAdQZT/6C8w2
        "]]}, 
      {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBQQG+/iFib1JlAgAAABMAAAACAAAAreNfWZmUIUAUfe6p/wtjP24VmA65
fyFA3vLsOGPeYD+2Rk8SH14hQKZIQj0hElw/eWC1C5EkIUBRL4pIaWxUP9P6
0ln3+CBAkVR29BEyUD8H0tysndUgQCvNMxq/3ko/9wsql6yZIED36R8/P4ND
P2hRCH5VbCBAoklIbcXsPj9EOKFrmEcgQCMbZDD0pDk/whSoY1oJIEAlfW4Q
u54yP84R0Q6MtB9AH3HjLgmELT+NW4xZPGgfQB3n1/94eyg/kOL5xsfmHkC4
FwvXRcghPwm7gkrShB5AlL5gEGgzHD80uCvGZDUeQHOC6soUZxc/bdEzmFmu
HUBrfoxwjAERPzjAxRgbSB1A2aPmLjv8Cj8pozirJ/UcQHFjN28vaAY/iXkd
0oJ7HEDC1oAKniUBP2EqfZQ=
        "]]}, 
      {Arrowheads[{{0.006051676227329792, 1.}}], 
       ArrowBox[{{7.078875728734545, 0.000029701745093283332`}, {
        6.996670457696941, 0.000024671465291751795`}, {6.911720899597027, 
        0.000020500084666425496`}, {6.770137325588834, 
        0.000015041357973190047`}, {6.662073825699472, 
        0.000011999266580414439`}, {6.573963616184049, 
        0.000010005131308024341`}, {6.573675740213859, 0.00001}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{8.789753473945437, 20.}, {8.789753474003724, 
        19.9213657230555}, {8.789753474085046, 19.823300919359383`}, {
        8.78975347415906, 19.742110128295014`}, {8.789753474436814, 
        19.480226860311635`}, {8.78975347466065, 19.311709695406822`}, {
        8.789753474852482, 19.188239360840964`}, {8.789753475471327, 
        18.861026941425827`}, {8.789753475720167, 18.757455122698968`}, {
        8.789753475946496, 18.671865851783114`}, {8.789753476155498, 
        18.598931470718465`}, {8.789753476535378, 18.478221021998753`}, {
        8.789753476875976, 18.38134170529765}, {8.789753477072583, 
        18.330379980785654`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{8.789753477240884, 18.288639480305296`}, {8.78975347825684, 
        18.06056612429435}, {8.789753479132658, 17.901002704185682`}, {
        8.789753479889102, 17.782309393137275`}, {8.789753482346011, 
        17.464041645714904`}, {8.78975348333959, 17.36219545972661}, {
        8.789753484244855, 17.277802673984755`}, {8.789753485081894, 
        17.205751815354102`}, {8.789753486605344, 17.08629531473734}, {
        8.78975348797326, 16.990254083404782`}, {8.789753489222853, 
        16.910264686763618`}, {8.789753493289158, 16.683953530875115`}, {
        8.789753494713782, 16.61901946109095}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{8.78975349562955, 16.57727896061059}, {8.789753496654843, 
        16.53054634810642}, {8.78975349959756, 16.413970585521987`}, {
        8.789753499873518, 16.40377266693875}, {8.78975350014673, 
        16.39377964778485}, {8.789753500564995, 16.37867586630916}, {
        8.78975350532669, 16.229513789928912`}, {8.789753509538489, 
        16.11337892482628}, {8.789753517185085, 15.92075992221936}, {
        8.789753523634724, 15.78580136252048}, {8.789753529373733, 
        15.679912248413132`}, {8.789753538536702, 15.531220685560896`}, {
        8.789753546592333, 15.417847587748716`}, {8.789753553887639, 
        15.325887074387717`}, {8.789753568191873, 15.167350999214003`}, {
        8.789753580696562, 15.048809384164304`}, {8.789753591999874, 
        14.953680206132603`}, {8.789753598255066, 14.90765894139625}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{8.789753603928418, 14.865918440915891`}, {8.78975361290731, 
        14.79985812810245}, {8.789753631324423, 14.68437527083788}, {
        8.789753648070596, 14.591575102514705`}, {8.789753679619288, 
        14.439972177895736`}, {8.78975370763997, 14.326596447413136`}, {
        8.789753733311558, 14.235816779217132`}, {8.789753781576854, 
        14.089992264382529`}, {8.789753825088448, 13.981450785001366`}, {
        8.789753865474507, 13.895042941314832`}, {8.789753941485642, 
        13.759594144536731`}, {8.789754011599538, 13.659890214266401`}, {
        8.789754077953626, 13.581554112399477`}, {8.789754201261978, 
        13.465287328577372`}, {8.78975431852011, 13.38172182206644}, {
        8.789754432178258, 13.317920350487386`}, {8.789754633167798, 
        13.233238774174405`}, {8.789754758520546, 13.196298421702359`}}]}, 
      {Arrowheads[{{0.0017809984538661888`, 1.}}], 
       ArrowBox[{{8.789754926288582, 13.154557921222345`}, {8.789755024645368,
         13.133436576929528`}, {8.789755329732433, 13.088073238180124`}, {
        8.789755633420915, 13.059291420751636`}, {8.78975593652308, 
        13.040320698796156`}, {8.789756333031583, 13.02455421717524}, {
        8.789756729362114, 13.01526459758332}, {8.789757568484918, 
        13.005878387640333`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{14.438286134143095`, 20.}, {14.438286134163342`, 
        19.953751633801954`}, {14.438286134222238`, 19.831388113136185`}, {
        14.438286134274966`, 19.733444926569387`}, {14.438286134322963`, 
        19.652316920626017`}, {14.438286134501377`, 19.39286739090141}, {
        14.438286134645383`, 19.225310586839775`}, {14.43828613476889, 
        19.10233383794232}, {14.438286135167523`, 18.77599590040492}, {
        14.438286135327868`, 18.672571358146072`}, {14.438286135473716`, 
        18.58707577868058}, {14.438286135608397`, 18.51420409348254}, {
        14.438286135853184`, 18.393569871219018`}, {14.438286135996385`, 
        18.330379980785654`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{14.438286136092756`, 18.288639480305296`}, {
        14.438286136272804`, 18.21621379776857}, {14.438286136955902`, 
        17.977961373185146`}, {14.438286137515504`, 17.81920951328942}, {
        14.438286137999018`, 17.700921992723227`}, {14.43828613956945, 
        17.383297132236784`}, {14.438286140204346`, 17.281514560188803`}, {
        14.438286140782647`, 17.197139986271612`}, {14.438286141317212`, 
        17.125082258700836`}, {14.438286142289742`, 17.005575551784943`}, {
        14.438286143162504`, 16.909458207719787`}, {14.438286143959473`, 
        16.829358082873494`}, {14.438286146359491`, 16.61901946109095}}]}, 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{14.438286146908075`, 16.57727896061059}, {
        14.438286148602863`, 16.454968232447907`}, {14.438286150442988`, 
        16.339158590422066`}, {14.438286150615525`, 16.329012590983492`}, {
        14.43828615078634, 16.319068529365055`}, {14.438286151047823`, 
        16.304035207056515`}, {14.438286154021718`, 16.155293987619075`}, {
        14.438286156649266`, 16.03925986494685}, {14.43828616141425, 
        15.846563838278948`}, {14.438286165423126`, 15.711217548145111`}, {
        14.43828616898175, 15.604903280553998`}, {14.438286174677476`, 
        15.454679468260835`}, {14.438286179664155`, 15.340122324883058`}, {
        14.438286184164504`, 15.2471656428337}, {14.438286192954685`, 
        15.086682970731344`}, {14.438286200593575`, 14.966565385010355`}, {
        14.438286204787884`, 14.907658941396246`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{14.438286207799903`, 14.865918440915888`}, {
        14.438286220134197`, 14.713318579386623`}, {14.438286231202488`, 
        14.595477539574016`}, {14.438286241196694`, 14.500640498470082`}, {
        14.438286259945082`, 14.344679487592591`}, {14.438286276405858`, 
        14.227778899530124`}, {14.438286291343287`, 14.133937086934946`}, {
        14.438286319309539`, 13.981494373358693`}, {14.438286344138175`, 
        13.867560247211578`}, {14.438286366898067`, 13.776428259321648`}, {
        14.438286409680316`, 13.630633605004107`}, {14.438286448402753`, 
        13.522418901819107`}, {14.438286484506113`, 13.436551536301334`}, {
        14.438286552296395`, 13.303787814909748`}, {14.438286615454848`, 
        13.20660893822845}, {14.438286623650376`, 13.196298421701616`}}]}, 
      {Arrowheads[{{0.005646874638229687, 1.}}], 
       ArrowBox[{{14.438286656828675`, 13.15455792122127}, {
        14.438286675752659`, 13.13075029544058}, {14.43828678693747, 
        13.021065718370426`}, {14.43828689398831, 12.942961643258988`}, {
        14.43828699869024, 12.883946232468167`}, {14.438287180177689`, 
        12.808595207560547`}, {14.438287359309008`, 12.757535045978793`}, {
        14.438287537279146`, 12.721158355392207`}, {14.438287809157696`, 
        12.683151174124339`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.01999999999999998, 1.}}], ArrowBox[CompressedData["
1:eJwBkQFu/iFib1JlAgAAABgAAAACAAAAJEMRIdG6LkDxaOOItfjkPpX89vl8
vi5A/lUPJViS5T63QTaztd0uQDxZdQUIPO0+TIud+Br1LkCWsBcbUGfyPtNX
paeXNC9AycKTuDm3AD9kNaRO9kwvQBvcjiNSTQU/D7uKaWtgL0AXeZkrPuIJ
PwerqDGadi9Aei0gXY5MED8VvtmWq78vQBksUghtMCA/HvbNIyLoL0Ccj6Yg
wDkoP3UWdqkwAjBAODjniHQhMD+VoN1CFCAwQFKOGJF2EDo/4e1oLXAyMEB7
ov73sP9BP0zSBtcNOTBAqF15Ymp7RD/4Pvvd2z4wQNR5gXwj90Y/aOrzmtpf
MEAA236bGepVP37MFyvwbjBAmhmMCZL8XT8U2kr3SHowQDV0nh2FB2M/y1gK
QS2GMEA5Z1EI7qxoP+5cJMZxtjBAYfldT216fj9ccxdNccUwQCqYGMvT+IQ/
EmSItqjQMEAUEU/tcLSKP1ZmR3dI3DBAFrTq2FxUkT+j83SxUwgxQDyT2Fv1
pKQ/ZfamXQ==
        "]]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], ArrowBox[CompressedData["
1:eJwBgQF+/iFib1JlAgAAABcAAAACAAAAwOC1kbUSMUBLEXNAEo2pP4LNauO9
FjFAGeuarHi+qz8PoSha5B8xQL8hMrZIDbE/5ZbrDccpMUBq8lKJtIW1P0nI
EXBfUjFARrGOdNYpyT9gqYOnnGMxQOVF7Vy+MdM/YeJtStRuMUBapJJ/kc7Z
P5GEipvvdjFAa9obUbI14D/c8c5tn3cxQAWzPXlWiuA/40x+x0p4MUBOi1+h
+t7gP+5RclBEeTFALU+S3fBd4T9RFQU65nkxQL4mtAWVsuE/BRNNNoR6MUD+
/dUtOQfiP6amPYUEfzFAaV+LLjS25D/APeqOyIIxQNCpQC8vZec/MsNNLPuF
MUBp2vUvKhTqP4do7xJGhjFAjCo749xY6j/DetTbj4YxQGN6gJaPneo/j5OG
oPyGMUCecWijmwTrP5U28PtDhzFAxMCtVk5J6z/EuLxMiocxQJoP8wkBjus/
0HbfpuCRMUCwjEhDwXzzP6FAdALSmDFAmUR2YwyD+D9ajq9B
        "]]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{17.600545852100357`, 1.5735799493366422`}, {
        17.600653894649838`, 1.574831014751037}, {17.621913225282388`, 
        1.931704282117822}, {17.633612157047963`, 2.2885775493936067`}, {
        17.63674347140436, 2.450093031053406}, {17.639363183521105`, 
        2.61160851264666}, {17.641211067016606`, 2.7731239940210375`}, {
        17.642767734192873`, 2.934639475220044}, {17.645072692225725`, 
        3.187615417282566}, {17.645513271302384`, 3.2422890057825606`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{17.64584962006965, 3.284028151076368}, {17.64711126161445, 
        3.4405913523475133`}, {17.648883442359057`, 3.6935672804148876`}, {
        17.650389234459535`, 3.946543201484686}, {17.651628637915888`, 
        4.19951911555691}, {17.65260165272812, 4.45249502263156}, {
        17.653308278896223`, 4.705470922708636}, {17.653740127290742`, 
        4.953626128313134}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{17.653790894099174`, 4.995366597172765}, {
        17.654038889822846`, 5.211422505031195}, {17.65429592362694, 
        5.464397793598943}, {17.65451961783248, 5.717372681491379}, {
        17.65470997243947, 5.970347168708503}, {17.654866987447914`, 
        6.223321255250316}, {17.654990662857806`, 6.476294941116819}, {
        17.6550580437565, 6.664986081970834}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{17.655072949131718`, 6.7067265797898665`}, {
        17.655080998669145`, 6.729268226308012}, {17.655137994881933`, 
        6.982241110823891}, {17.65517613419142, 7.235202341253329}, {
        17.655209899292856`, 7.488140664185194}, {17.655239290186238`, 
        7.741056079619487}, {17.655264306871565`, 7.993948587556208}, {
        17.655284949348836`, 8.246818187995355}, {17.655293283263592`, 
        8.376346581961622}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{17.655295968866042`, 8.418087082355584}, {17.65530121761806,
         8.499664880936932}, {17.655313111679224`, 8.752488666380934}, {
        17.65532063153234, 9.005289544327365}, {17.655325214359582`, 
        9.23405804641805}, {17.655329294698475`, 9.462062549260649}, {
        17.655332872549028`, 9.689303052855166}, {17.655335947911233`, 
        9.915779557201596}, {17.655337907695795`, 10.087707100866826`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{17.65533838349151, 10.129447601344474`}, {
        17.655338520785094`, 10.14149206229994}, {17.65534059117061, 
        10.3664405681502}, {17.655342159067782`, 10.590625074752376`}, {
        17.655343224476606`, 10.814045582106464`}, {17.655343971316636`, 
        11.034881202031105`}, {17.65534458350742, 11.251311046344938`}, {
        17.655345518680917`, 11.660670286145855`}, {17.65534579184021, 
        11.79906762053702}}]}, 
      {Arrowheads[{{0.009186060810204332, 1.}}], 
       ArrowBox[{{17.65534587422479, 11.840808121017297`}, {
        17.655346219658863`, 12.015823783767921`}, {17.655347176846647`, 
        12.436818406109596`}, {17.65534741219804, 12.48876213786389}, {
        17.65534764517081, 12.526207490369801`}, {17.655347877535934`, 
        12.553114336434202`}, {17.65534810958558, 12.571848695030035`}, {
        17.65534846575698, 12.590102501574261`}, {17.655348821798253`, 
        12.59977429442158}, {17.65534951134522, 12.607669672293905`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999993`, 1.}}], ArrowBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQXZ+eZGhxTN5BJeufX5mijoOKrTGYf0p2297dMjoO
P6OWGYD493bctTnDp+Ng/PyuPoj/e/rJ29t/aTtYReSA+farkgS532s7lKuL
gvmy21e+e/9U28HoJKMeiC9/Ilus74S2g6asuy6I318Q2f13s7YDe+BmHRD/
meuuHbGLgeYpJGmD+Fwbu906a7QdBG9la4H4N/Q2coTGazt0Mi3VBPEb7gUf
8nPXduix09cA8Q381ihHS2o7fBYUVAfxCw9r9vZ+1XK4XaCqBuLH26X3nL+u
5XDr8nQVED/U+ndz9lItB6/+aGUQ/+1yHaakWi2Hf56BSiD+k41Sxi+itRwc
eqcpgPipZW5S4qpaDm2HteVB/PMap8sDfmo6pEz6LAviT3yR47H5iqbDZ94t
0iD+gdxVZeJTNB3mrL8sCeJLzr7E3Zyo6eBdbCgB4i+cx7zC3ULTwY1PXxjE
P3hv+v25pzQcABstnsg=
        "]]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{7.943573269361109, 12.353995228058952`}, {7.943573253413259,
         12.308234667946726`}, {7.943573170853456, 12.124754066833285`}, {
        7.943573097888615, 11.99238911183059}, {7.943572839543263, 
        11.642473892943302`}, {7.943572722233857, 11.531059732527957`}, {
        7.943572608449737, 11.438410740424308`}, {7.943572497157273, 
        11.358958397850637`}, {7.943572279571632, 11.226340881747271`}, {
        7.94357206676708, 11.11868500455873}, {7.943571857209339, 
        11.027811236481861`}, {7.9435713315886955`, 10.843469311682131`}, {
        7.943570814501397, 10.70200204368641}, {7.943570736343635, 
        10.68437520884745}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{7.943570551265364, 10.642634708367503`}, {7.943570302696237,
         10.586575184201212`}, {7.943569794543881, 10.488866164646367`}, {
        7.943568458581419, 10.282611675037698`}, {7.943567133072386, 
        10.124972396727895`}, {7.943565814013057, 9.996540409090914}, {
        7.943564499413301, 9.887874494181814}, {7.943561029206159, 
        9.65852830712923}, {7.943557571812516, 9.483134176052417}, {
        7.943554122356536, 9.340158747517492}, {7.9435506784034295`, 
        9.219133224037781}, {7.943541938738072, 8.973014689485769}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{7.943540032205999, 8.931274189049033}, {7.943533107161784, 
        8.780914487609984}, {7.943524338595262, 8.625113207414802}, {
        7.943515576692155, 8.493057428033284}, {7.943494578282196, 
        8.237749839539944}, {7.94347359693225, 8.039057497039863}, {
        7.943452626838493, 7.875809857460149}, {7.943431664946125, 
        7.737067053286851}, {7.943387439915166, 7.497323606329556}, {
        7.9433432341639865`, 7.306228069455792}, {7.94333086121627, 
        7.2616541863426045`}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{7.943319274767567, 7.219913687470346}, {7.943299042826009, 
        7.147027563738892}, {7.943254863433743, 7.011297612137857}, {
        7.943099559364214, 6.6367946371286575`}, {7.942944348353803, 
        6.368968684707535}, {7.942789215864677, 6.159657054762717}, {
        7.942711668185137, 6.066129469953866}, {7.942634138256895, 
        5.981076229853825}, {7.94249647166794, 5.8583817326284695`}, {
        7.942358856825259, 5.748696049966969}, {7.942084687884314, 
        5.550294233399482}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{7.9420153474183195`, 5.508553790541844}, {7.941808801920872,
         5.384573413235155}, {7.941534072819577, 5.243424608961151}, {
        7.940975054263312, 5.005297802158178}, {7.940416836938423, 
        4.8144679569895885`}, {7.9398594136472225`, 4.654999591851495}, {
        7.938897910898306, 4.428092310238773}, {7.937938745893732, 
        4.24475598733533}, {7.936981902709849, 4.090811784699096}, {
        7.935335616630009, 3.871199431278441}, {7.93503860321874, 
        3.8389517156008424`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{7.9346541740471395`, 3.797212985450503}, {7.933696142561605,
         3.693196379520909}, {7.9320634188933274`, 3.543515040596442}, {
        7.929312187064153, 3.3334455073025944`}, {7.926579888635223, 
        3.1626662723757444`}, {7.923866254226902, 3.018909231032761}, {
        7.91938682983311, 2.8202946453629676`}, {7.9149572933546475`, 
        2.6585654295491112`}, {7.910576512961676, 2.522464065061425}, {
        7.9035126240457085`, 2.33783517472648}, {7.896571731582293, 
        2.187531765415093}, {7.893366911513436, 2.1282352056683123`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{7.891114237135371, 2.0865555363018546`}, {
        7.8897495094987296`, 2.0613049287465057`}, {7.879031456893599, 
        1.8935777607838533`}, {7.868593144404464, 1.7573994275067022`}, {
        7.858419956137187, 1.643519162128406}, {7.842876864092249, 
        1.4955650520653823`}, {7.8279125936451095`, 1.3760905982487701`}, {
        7.8134844595003505`, 1.2768301278326182`}, {7.792039103440387, 
        1.1507240510993595`}, {7.771673484273235, 1.0497164471925022`}, {
        7.752281261606202, 0.9665126822056245}, {7.724126513085836, 
        0.8627944414975858}, {7.697788891731632, 0.7805919753262266}, {
        7.673041902777659, 0.7135578405097459}, {7.637660975512164, 
        0.6310020325539882}, {7.605073559357344, 0.5664089598451811}, {
        7.574858966737309, 0.5143283345676987}, {7.545918457166874, 
        0.4712965105892276}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{15.436111579337023`, 20.}, {15.436111579360366`, 
        19.937924545695275`}, {15.436111579434185`, 19.780300972403282`}, {
        15.436111579662292`, 19.395327637332397`}, {15.436111579751085`, 
        19.281861751086012`}, {15.43611157983117, 19.189657962160357`}, {
        15.436111579904694`, 19.11199031350132}, {15.436111580037586`, 
        18.984807831762822`}, {15.436111580156085`, 18.88383068679704}, {
        15.436111580263379`, 18.80106369925375}, {15.436111580734545`, 
        18.493695612824197`}, {15.436111581058942`, 18.330379980785654`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{15.436111581149165`, 18.288639480305296`}, {
        15.436111581413877`, 18.176405090158543`}, {15.436111582404441`, 
        17.83521529298975}, {15.436111583156556`, 17.6414624001517}, {
        15.436111584388614`, 17.37750052935771}, {15.436111585389392`, 
        17.20103964969824}, {15.436111586225133`, 17.08231978745011}, {
        15.436111586975628`, 16.986707316422063`}, {15.436111587661516`, 
        16.906896091906802`}, {15.436111589730093`, 16.696058634920135`}, {
        15.436111590639657`, 16.61901946109095}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{15.436111591132466`, 16.57727896061059}, {
        15.436111591458761`, 16.5496420872554}, {15.436111592967562`, 
        16.43829874381124}, {15.436111597908328`, 16.134833796387877`}, {
        15.436111601756165`, 15.953128933442734`}, {15.436111613342272`, 
        15.52982933491023}, {15.436111617726914`, 15.413347315606154`}, {
        15.436111621674726`, 15.319244722349207`}, {15.43611162529294, 
        15.240427182545348`}, {15.436111634722304`, 15.058924883733699`}, {
        15.436111642797636`, 14.92720786180156}, {15.436111644154634`, 
        14.907658941396246`}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], ArrowBox[CompressedData["
1:eJxTTMoPSmViYGAQBmIQPePPLDav+3oOcZWFKyN36zrcsNgC5se/2la5bqmu
w0n+XWD+NJZggZ8LdB3qbu4H84UFVmyInKPr8HDHCTBf1emBeORUXQcmQX12
EP/xxmj/H366DpNXd4H5G4yF2r3FdR0mVRhxgPgOv7ZuMtql41DmewjMP9DJ
e5a3QschYIUzJ4h/bNeL2SwuOg4916W4QPxdP3vKWH5qO9RtugXmt0mf4gw/
oO0g9KqLG8TnkQt+uXuStkPf9Ic8IL4la3CEhru2w0R7cT4Q3+eHRbcFv7aD
yXpzfhBf7irzi6ePtBzWNAYIgvhr58q5vZ2n5aCc5iIM4q9bIb9KJlfLIfLR
WjD/71suq8YULQcAfS18Mg==
        "]]}, 
      {Arrowheads[{{0.006453171515163539, 1.}}], 
       ArrowBox[{{15.436112067172992`, 13.15455792122126}, {
        15.436112079935139`, 13.137087114788118`}, {15.436112182649207`, 
        13.026681532477593`}, {15.436112281473529`, 12.948017129024883`}, {
        15.436112378083182`, 12.888528615309005`}, {15.436112545790547`, 
        12.81234932751059}, {15.436112711256442`, 12.760654171248762`}, {
        15.43611287561332, 12.723763918746156`}, {15.436113127590605`, 
        12.685014740017346`}, {15.436113378929779`, 12.660553507904249`}, {
        15.436113630008625`, 12.644514090923732`}, {15.436113954721778`, 
        12.631381067034056`}, {15.4361142793603, 12.623644967643}, {
        15.43611496609883, 12.615840703810344`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{2.3435988110445596`, 20.}, {2.34359881104256, 
        19.944080410721476`}, {2.3435988110378205`, 19.81140996920263}, {
        2.3435988110256045`, 19.4691038277634}, {2.3435988110186927`, 
        19.275192312352797`}, {2.3435988110092882`, 19.011204726543347`}, {
        2.3435988110030057`, 18.83478904877488}, {2.343598810998783, 
        18.716140843481025`}, {2.343598810995383, 18.6205886145501}, {
        2.3435988109925447`, 18.54082592989629}, {2.3435988109850605`, 
        18.330445253499235`}, {2.3435988109850583`, 18.330379980785654`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{2.3435988109835737`, 18.288639480305296`}, {
        2.343598810979861, 18.184259340140226`}, {2.343598810975906, 
        18.073049960587806`}, {2.343598810965125, 17.76982923078765}, {
        2.343598810958667, 17.588167773384253`}, {2.3435988109436154`, 
        17.164716736283495`}, {2.3435988109394703`, 17.048085281629298`}, {
        2.34359881093612, 16.95382106279348}, {2.3435988109333117`, 
        16.874798351141404`}, {2.343598810927228, 16.703634166153638`}, {
        2.343598810924221, 16.61901946109095}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{2.3435988109227375`, 16.57727896061059}, {2.343598810922733,
         16.577152387854387`}, {2.3435988109191914`, 16.477501160943042`}, {
        2.3435988109092296`, 16.197243463470027`}, {2.3435988109030563`, 
        16.023588472770115`}, {2.343598810888412, 15.611806364510294`}, {
        2.343598810884314, 15.496662152639868`}, {2.343598810880992, 
        15.403360817266218`}, {2.3435988108781984`, 15.324920769603047`}, {
        2.3435988108736088`, 15.196119134454696`}, {2.3435988108699717`, 
        15.094134534517172`}, {2.343598810866999, 15.010837222663955`}, {
        2.343598810863309, 14.907658941396246`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{2.3435988108618164`, 14.865918440915888`}, {
        2.3435988108555197`, 14.68985834465144}, {2.343598810848693, 
        14.499834128344121`}, {2.343598810843847, 14.365555216568339`}, {
        2.343598810831233, 14.019023582573224`}, {2.343598810827278, 
        13.91195290473115}, {2.343598810824002, 13.823993929746754`}, {
        2.3435988108211983`, 13.749347480265408`}, {2.3435988108165233`, 
        13.626273859763357`}, {2.343598810812725, 13.527880468896868`}, {
        2.343598810809531, 13.44650498601013}, {2.3435988107993597`, 
        13.196298421701542`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{2.3435988107975914`, 13.154557921221183`}, {
        2.343598810791225, 13.008395347246866`}, {2.343598810785427, 
        12.883776998638513`}, {2.343598810768243, 12.554437008297027`}, {
        2.343598810761807, 12.450456940410165`}, {2.3435988107560144`, 
        12.36458392542735}, {2.3435988107506738`, 12.291439234338633`}, {
        2.343598810740891, 12.170428409160104`}, {2.343598810731958, 
        12.073346159787327`}, {2.343598810723609, 11.992696582507982`}, {
        2.3435988106926398`, 11.74958490986726}, {2.3435988106645937`, 
        11.588760427562066`}, {2.343598810641488, 11.484937902006838`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{2.3435988106297825`, 11.44319740152648}, {
        2.3435988105373324`, 11.149630747290757`}, {2.343598810489038, 
        11.047447012255086`}, {2.3435988104413665`, 10.96279701485488}, {
        2.343598810394135, 10.89053817939927}, {2.3435988103005507`, 
        10.770750681335228`}, {2.343598810207801, 10.674450541303127`}, {
        2.343598810115622, 10.594241840122923`}, {2.34359880977127, 
        10.367612408206462`}, {2.3435988094295106`, 10.213949437027388`}, {
        2.3435988090891064`, 10.09844103736385}, {2.343598807732807, 
        9.786069339594741}, {2.343598807648989, 9.773577382312133}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{2.343598807368921, 9.731836881831775}, {2.3435988070566256`,
         9.685293323279415}, {2.343598806381052, 9.601607323850716}, {
        2.3435988057059087`, 9.530049593336875}, {2.3435988043564855`, 
        9.41123385114975}, {2.3435988030078843`, 9.315557511072033}, {
        2.3435988016598452`, 9.235705515226604}, {2.34359879695209, 
        9.023699721125327}, {2.343598792246645, 8.876722630697998}, {
        2.3435987875424504`, 8.764947698567056}, {2.3435987687307143`, 
        8.459754487734939}, {2.343598759326737, 8.360382891655421}, {
        2.3435987499233515`, 8.27766373407468}, {2.3435987405203873`, 
        8.206811881267535}, {2.343598721715308, 8.088978025009425}, {
        2.343598716420632, 8.062216862617433}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{2.3435987081623058`, 8.020476362137074}, {
        2.3435987029110383`, 7.993934600786113}, {2.343598684107322, 
        7.914450273221552}, {2.3435986241364515`, 7.719072239418256}, {
        2.343598564167588, 7.580101732683717}, {2.3435985041998557`, 
        7.47288634213004}, {2.3435982643336883`, 7.177185769087739}, {
        2.343598143523407, 7.069977961693996}, {2.343598022713864, 
        6.983202246461893}, {2.3435978422720494`, 6.874586176064318}, {
        2.343597661831452, 6.798632492432851}, {2.3435974813912215`, 
        6.732219052859503}, {2.3435971205113235`, 6.613628372024436}, {
        2.3435967596323666`, 6.518324289661035}, {2.343596398754071, 
        6.43842110022614}, {2.3435959033509564`, 6.350856342927077}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{2.3435956672014533`, 6.309115842447387}, {2.343595535795074,
         6.285889166323765}, {2.3435946728380315`, 6.16999565178703}, {
        2.3435938098824227`, 6.076110385707655}, {2.3435921045708406`, 
        5.929397741585519}, {2.343590399263017, 5.816805121556951}, {
        2.343588693958483, 5.725088288674086}, {2.3435852891120637`, 
        5.579778282130592}, {2.3435818842769915`, 5.46800624125554}, {
        2.3435784794528067`, 5.376839546821617}, {2.3435717570644887`, 
        5.233663940016039}, {2.3435650347169195`, 5.1231421937359585`}, {
        2.343558312409656, 5.0328138127262925`}, {2.3435451499968636`, 
        4.891750997100365}, {2.3435319877369754`, 4.782479894290958}, {
        2.3435188256295616`, 4.692995283620721}, {2.343508986403804, 
        4.6394958273265825`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{2.343501309798676, 4.597755327552136}, {2.3434932869205727`,
         4.554132015413808}, {2.343467748784059, 4.446176372564235}, {
        2.3434422112195845`, 4.357584921067262}, {2.343393122883242, 
        4.22100332057648}, {2.343344036658881, 4.114427900661579}, {
        2.3432949525459192`, 4.026780596758829}, {2.343201522109487, 
        3.8925761800600425`}, {2.343108099320696, 3.7874570645680725`}, {
        2.3430146841778714`, 3.700814709842675}, {2.342838680865838, 
        3.5690977776228965`}, {2.34266270468744, 3.465524518594371}, {
        2.342486755633638, 3.379960168345138}, {2.3421587902743606`, 
        3.25086138474708}, {2.341830919111275, 3.148942396183825}, {
        2.341503142087899, 3.0645465951872226`}, {2.3408990488709422`, 
        2.9382252998955702`}, {2.3408382297380266`, 2.928139130305843}}]}, 
      {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBUQGu/iFib1JlAgAAABQAAAACAAAAEMm5b4W5AkA4tguQWBcHQNVmrbrs
uAJAUIVgyWu0BkBs015YsLcCQPFCSr41CgZA2Vs5NnC1AkCjlcjwmg0FQOc3
4qEwswJA77XiiJFEBEBADhGb8bACQGGbRwRPnQNAQ4k53+esAkCDUgEIWqcC
QJwLcOvfqAJALCs0H9biAUCrKxS+2aQCQCO6Fjz6PgFAfzd+cLedAkBmoYUU
bVAAQKYw06+algJAIz0BkEYi/z99wihzg48CQD5CBv+t4v0/CP0BfiKDAkAg
fKNdlBb8P+iVJDLSdgJAM30L1Yuk+j+Rx3ZhkmoCQGinNRYRb/k/gveRto1V
AkAsrUp6Nrf3P10FZdi4QAJAxmC/RNtU9j8sgAzpEiwCQLT2xJuDLPU/W/2l
E1YJAkBefV0Lqo3zP5Pxc8zTCAJAz8/Pk7KI8z8o/ol+
        "]]}, 
      {Arrowheads[{{0.010063365101954472`, 1.}}], 
       ArrowBox[{{2.2459306626963165`, 1.179982693125583}, {2.237844147543271,
         1.1405219678621517`}, {2.2213694896995353`, 1.072456182699441}, {
        2.194276021358468, 0.978888461322502}, {2.167806530565972, 
        0.9037991059644482}, {2.1419325419565443`, 0.8414506669120951}, {
        2.1004626972515825`, 0.7575625480721593}, {2.060435684787669, 
        0.6907420815615031}, {2.02175473147884, 0.6357278475276544}, {
        1.9614288500756818`, 0.5634165607685522}, {1.9041194276150175`, 
        0.5064875686216503}, {1.8495472644064814`, 0.46016372137202183`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{12.187788199102053`, 0.6039951444718302}, {
        12.189952005689396`, 0.6111968861636045}, {12.193513772135155`, 
        0.6232854262172159}, {12.197569539432598`, 0.6374718409012268}, {
        12.20297754760674, 0.6570549718534944}, {12.206938154703277`, 
        0.6719426452934667}, {12.210202270952996`, 0.684577827545412}, {
        12.220200083505262`, 0.7252824853669234}, {12.227578258177928`, 
        0.7576185556314257}, {12.233637239234955`, 0.7857896806956461}, {
        12.251886788064445`, 0.8799671047150912}, {12.264842322557419`, 
        0.9581507479747452}, {12.298929714674767`, 1.2210294166042117`}, {
        12.319317151243004`, 1.448039477143115}, {12.333562335990585`, 
        1.6607965358204413`}, {12.344074150244015`, 1.8656129865060496`}, {
        12.356468376762036`, 2.176492169392698}, {12.358873338900379`, 
        2.2609045290814107`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{12.360062070107968`, 2.3026280991403945`}, {
        12.365127959722598`, 2.48043700909197}, {12.371104480273807`, 
        2.7795609044355842`}, {12.375449519563775`, 3.0759772542552577`}, {
        12.378571840419152`, 3.3704033249184113`}, {12.380880205666587`, 
        3.663556382792464}, {12.383172134043662`, 3.9720502665180506`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{12.383482232889943`, 4.013789615088151}, {
        12.383571371624424`, 4.025787701357071}, {12.386489174926758`, 
        4.388360615032382}, {12.388953703540087`, 4.750250338486284}, {
        12.390285045430886`, 5.110432086386657}, {12.390900203692283`, 
        5.469529509061024}, {12.391297061752816`, 5.683385815397736}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{12.391374520425078`, 5.725126244007238}, {
        12.391566726671256`, 5.828701103509697}, {12.392130520215074`, 
        6.187724354409756}, {12.392437490170996`, 6.5463767464382725`}, {
        12.392569068187315`, 6.917123939444237}, {12.39265983063272, 
        7.287810773833696}, {12.39267230107854, 7.394745475648866}}]}, 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{12.392677168746728`, 7.436485975845398}, {
        12.392703049607244`, 7.658415660001674}, {12.392732881221022`, 
        8.028981213644908}, {12.392753145303704`, 8.295219931475712}, {
        12.392771051986326`, 8.561215548508846}, {12.392786601268886`, 
        8.826968064744307}, {12.392799793151385`, 9.092477480182094}, {
        12.392800349791425`, 9.106105990182003}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{12.392802054631783`, 9.147846490627545}, {
        12.392810627633821`, 9.35774379482221}, {12.3928191047162, 
        9.622767008664658}, {12.392825224398514`, 9.887547121709428}, {
        12.392828986680769`, 10.15208413395653}, {12.392831311481828`, 
        10.415594738663724`}, {12.392833118720564`, 10.677295629088775`}, {
        12.39283387943893, 10.817466509415206`}}]}, 
      {Arrowheads[{{0.01655879712308963, 1.}}], 
       ArrowBox[{{12.392834105967902`, 10.85920700989495}, {
        12.392834520631046`, 10.935613339385107`}, {12.392835629447353`, 
        11.188974403706139`}, {12.392836513655535`, 11.433701021481042`}, {
        12.392837241741644`, 11.666115392138984`}, {12.39283820585394, 
        11.990575789511055`}, {12.392839022768706`, 12.241551968426867`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{13.201541310413713`, 0.2465322093417413}, {
        13.301420324585525`, 0.400952784362423}, {13.417091472315779`, 
        0.7048317068883823}, {13.48178018720582, 1.0068114090738858`}, {
        13.51977767101355, 1.3313942664252396`}, {13.549224442238899`, 
        1.6558464577683236`}, {13.562029039115586`, 1.8545828061534693`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{13.564712817764123`, 1.8962369381515853`}, {
        13.570120500881863`, 1.980167983103139}, {13.582465846942448`, 
        2.3043588424296857`}, {13.593731449293895`, 2.7001147343287193`}, {
        13.602172018603113`, 3.0958435213245608`}, {13.606961918108361`, 
        3.491536648695475}, {13.607634811348964`, 3.565165575086166}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{13.60801626099329, 3.6069043325726997`}, {
        13.610578058094852`, 3.887219780606662}, {13.612628117854932`, 
        4.282890114693208}, {13.614956119117473`, 4.678563585015398}, {
        13.617395296980995`, 5.074238309831847}, {13.618613681880818`, 
        5.276489298511622}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{13.61886512724121, 5.318229041629921}, {13.619778886544026`,
         5.469912407401166}, {13.621940122905093`, 5.865583995981971}, {
        13.623712241162712`, 6.261251193832873}, {13.624928476415413`, 
        6.656912119212485}, {13.625341310643476`, 6.987834310773987}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{13.625393382986537`, 7.029574778773543}, {
        13.625422063761716`, 7.052564890379423}, {13.62549871418715, 
        7.448085673069196}, {13.625550311166839`, 7.843599190204085}, {
        13.625573700686683`, 8.239062453821584}, {13.625589453279847`, 
        8.634449747598023}, {13.625591159070716`, 8.69919476827709}}]}, 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{13.625592258777903`, 8.740935268742962}, {
        13.625599475037331`, 9.014835706566414}, {13.625602097901506`, 
        9.393570219017857}, {13.625601761208362`, 9.771644152862523}, {
        13.625602904293876`, 10.150048376010577`}, {13.625604517827, 
        10.410555287846291`}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{13.625604776360179`, 10.452295788325848`}, {
        13.625605231850468`, 10.52583525691568}, {13.625606867519446`, 
        10.895187233691331`}, {13.625608316984929`, 11.255162409849085`}, {
        13.625609394043423`, 11.596383984771041`}, {13.625610219114126`, 
        11.901788480305598`}, {13.625610823645992`, 12.1219158075286}}]}, 
      {Arrowheads[{{0.0036377789534977156`, 1.}}], 
       ArrowBox[{{13.625610948493298`, 12.163656308008768`}, {
        13.625612114532165`, 12.46734173631835}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{13.437896388707712`, 20.}, {13.437896388795533`, 
        19.825336918340824`}, {13.437896388958638`, 19.556679452968382`}, {
        13.437896389090758`, 19.37797713560915}, {13.43789638920083, 
        19.258433688812303`}, {13.437896389299604`, 19.16228993353523}, {
        13.437896389389794`, 19.082170139403914`}, {13.43789638967783, 
        18.859052199703317`}, {13.437896389916364`, 18.706965915855026`}, {
        13.437896390123527`, 18.592441239045048`}, {13.43789639069507, 
        18.330379980785654`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{13.437896390786102`, 18.288639480305296`}, {
        13.437896390798763`, 18.282834640741303`}, {13.437896391322226`, 
        18.099016091453805`}, {13.437896392893201`, 17.67244154143534}, {
        13.437896393485774`, 17.55540734817898}, {13.437896394018647`, 
        17.46088040258521}, {13.437896394506497`, 17.38169990214522}, {
        13.437896395756528`, 17.201842660668643`}, {13.437896396825652`, 
        17.0707597377898}, {13.437896397771281`, 16.96832989996709}, {
        13.43789640090659, 16.682428731003597`}, {13.437896401798392`, 
        16.61901946109095}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{13.437896402385439`, 16.57727896061059}, {
        13.437896403377222`, 16.50676082632068}, {13.437896410862056`, 
        16.092071446008056`}, {13.437896413705719`, 15.97659174336641}, {
        13.437896416266858`, 15.88309339538839}, {13.437896418615615`, 
        15.80456422644684}, {13.437896423501739`, 15.65791056070026}, {
        13.437896427793188`, 15.545216940364947`}, {13.437896431653764`, 
        15.454244218569931`}, {13.437896444688144`, 15.192443576678212`}, {
        13.437896455160779`, 15.026050312095874`}, {13.437896464718428`, 
        14.907658941396248`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{13.437896468088107`, 14.86591844091589}, {
        13.437896487401316`, 14.626684154097976`}, {13.437896499856034`, 
        14.514027210488798`}, {13.43789651114853, 14.422746422381906`}, {
        13.437896521564422`, 14.346166019448722`}, {13.437896547831883`, 
        14.176724130927862`}, {13.437896570773365`, 14.052597056548658`}, {
        13.437896591537054`, 13.95468297403959}, {13.437896593516367`, 
        13.94598884946073}, {13.437896595480895`, 13.93745420283921}, {
        13.437896598497717`, 13.924527092279222`}, {13.437896634086853`, 
        13.794859387205353`}, {13.43789666667885, 13.692890387407875`}, {
        13.437896727674241`, 13.523867459189693`}, {13.437896782290128`, 
        13.406365092577541`}, {13.437896833283931`, 13.315776125124684`}, {
        13.437896916496003`, 13.19629842170163}}]}, 
      {Arrowheads[{{0.004792588575958631, 1.}}], 
       ArrowBox[{{13.437896953653567`, 13.154557921221288`}, {
        13.43789699653129, 13.106653614580763`}, {13.437897073021185`, 
        13.037609519190156`}, {13.437897216841225`, 12.937736409553192`}, {
        13.437897356686722`, 12.86787656644147}, {13.437897494380866`, 
        12.81609760175988}, {13.437897722582681`, 12.754467829708274`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.020000000000000007`, 1.}}], ArrowBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQ/cBArWajgLpD/jqnR4zHmR1+Sbo/PQHkX9mwruTv
VWaHC+ZcSx4A+e/KrM74PmV2MHrwx0RHUN2h6GaW1l4xFgfeSBapECA/3cq2
OcuQxWHeCV/2YiCfvVooNd6NxeGe35lZJ4D85tPPV/Q2sjgsdZ+hyi6k7mAz
ff8z7nUsDuIJ8dusgPypfivZui+zODCeNYhOB/JTcyJFF35hcbCe9bjkK5DP
NaOmcX8iqwNT5qJLCcLqDk7PD3Ed2cHq0DlX5e8EEXWH5ybH0n2PsjlMflaR
ESeq7rB4T/b7oMnsDtEii8P/AvmHf9o/4XHhcMgtC4qfIq7usO5rTOahEC6H
I0aNfjMl1B20lmximMzF46CqfqAlTFLdIcvdKM16Cq/DKxXXyzlS6g587zRT
fUwFHHgtnzTPB/K990wq5p0o4AAAgrp6hg==
        "]]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{11.552178406658433`, 4.183392987448553}, {
        11.553023541346299`, 4.3792052256174}, {11.553974400331537`, 
        4.661300282706714}, {11.554664147177823`, 4.933427462302089}, {
        11.555050469898204`, 5.194061452879041}, {11.555344827403719`, 
        5.451231284574434}, {11.555740608230748`, 5.850901088533298}, {
        11.555742032376072`, 5.853008054972769}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{11.555770245699204`, 5.894748545918124}, {
        11.556007480400025`, 6.245727862859235}, {11.556182207395373`, 
        6.637095509978193}, {11.556301552700615`, 7.026387932316122}, {
        11.556380798907638`, 7.414173981735075}, {11.556401931308608`, 
        7.564368418075048}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{11.556407804209133`, 7.606108918142247}, {
        11.556435228608334`, 7.801022510097113}, {11.556460941432208`, 
        8.05082858161822}, {11.55648371989974, 8.300416186064007}, {
        11.556503564010931`, 8.549785323434474}, {11.556520473765787`, 
        8.798935993729625}, {11.5565344491643, 9.047868196949455}, {
        11.556544564488103`, 9.275728931084306}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{11.55654617162141, 9.317469431533002}, {11.556553596892309`,
         9.545077202163164}, {11.556558769221803`, 9.793354004157036}, {
        11.556559227843634`, 9.82504506188747}, {11.556559672264687`, 
        9.856727687878553}, {11.556560102935682`, 9.888401384504458}, {
        11.556560520293349`, 9.920065620439129}, {11.556560924760864`, 
        9.951719828575422}, {11.556561709129086`, 10.015006329724061`}, {
        11.556562445904419`, 10.07824624347155}, {11.556563138074617`, 
        10.141433679936576`}, {11.556566108958862`, 10.455798388283995`}, {
        11.556568315700163`, 10.767296198728655`}, {11.556569490673775`, 
        10.987089450519717`}}]}, 
      {Arrowheads[{{0.018905030765577206`, 1.}}], 
       ArrowBox[{{11.556569713810683`, 11.028829950999478`}, {
        11.556569948488413`, 11.072729304096823`}, {11.5565711975135, 
        11.36889989721477}, {11.556572168640027`, 11.648027615538258`}, {
        11.55657296773259, 11.902332096523036`}, {11.556573785850762`, 
        12.189561363393393`}, {11.556574516032192`, 12.397560845626181`}, {
        11.556574895460793`, 12.46418151870715}, {11.55657526786462, 
        12.50907804754477}, {11.556575639008452`, 12.54168537252587}, {
        11.556576009454641`, 12.564610773900279`}, {11.556576568623713`, 
        12.586318119365286`}, {11.556577127504708`, 12.597735681127475`}, {
        11.556578203799472`, 12.60704084240351}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{18.450916832710593`, 20.}, {18.450916832743037`, 
        19.90711253958524}, {18.4509168327784, 19.815778336506657`}, {
        18.450916832810893`, 19.738725789844754`}, {18.450916832869666`, 
        19.61237536866084}, {18.450916832922108`, 19.51191838345449}, {
        18.450916832969632`, 19.429427718191242`}, {18.450916833173437`, 
        19.129497626342513`}, {18.45091683333352, 18.946683959329857`}, {
        18.45091683346909, 18.815932371447342`}, {18.450916833902234`, 
        18.475585235364633`}, {18.45091683407507, 18.369609009314765`}, {
        18.450916834145623`, 18.330379980785654`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], ArrowBox[CompressedData["
1:eJxTTMoPSmViYGAQA2IQPcNQwTO/2Mjhqd0LtyeeRg7fbCH8xsMXS708jBz+
34HwZ+TKiwaaGjks+qsI5i8xmHXtn6iRAxeDMpj/wn7R6jd/DB3cXkP4BVZO
JhovDB3Kg9XB/HZ+iUnPlho6MItoQczPWPWPu9rQYWKJDpj/IPCbgE60oUPE
Wgj/xVqT/IwIQ4fWpxD+eZ1zhzeHGjoUWOuC+WbrrYznBRo6HE+G8Pf8PSu2
09/QweQohB+UV/LZ2NvQIUBGD8y/vk0yxMrd0EGqCMLXPsYQH+9s6PBtgiGY
bxDEqXFW0dBhSZgJmL+b9VNbFLuhg9cdMzC/UtHoYvVHAwfGQhswf27W+a/d
xwwczjg4gvnnGLN/7ltm4LBuuROYr/TThL9inoEDAIZIh98=
        "]]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{18.450916842665716`, 16.57727896061059}, {
        18.450916842920325`, 16.55205831630086}, {18.450916844705368`, 
        16.395653215800674`}, {18.450916846258934`, 16.27756303436367}, {
        18.45091684765594, 16.18222715639054}, {18.45091685029439, 
        16.022850625594057`}, {18.45091685258542, 15.903146878744954`}, {
        18.45091685464323, 15.806777274231347`}, {18.450916858467583`, 
        15.648347590681581`}, {18.450916861792116`, 15.529199004173197`}, {
        18.45091686478057, 15.433217521801758`}, {18.450916870360395`, 
        15.27480919298921}, {18.450916875214585`, 15.155751298859167`}, {
        18.4509168795815, 15.059888905242389`}, {18.450916887440407`, 
        14.907658941396246`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{18.450916889894305`, 14.865918440915888`}, {
        18.45091689483161, 14.783490522388067`}, {18.450916901232933`, 
        14.68806938181834}, {18.450916913192163`, 14.53132221807769}, {
        18.45091692365832, 14.41368854025799}, {18.450916933126816`, 
        14.319141454948118`}, {18.450916950846697`, 14.164684242340025`}, {
        18.450916966477486`, 14.049027798213771`}, {18.45091698072237, 
        13.956311414789962`}, {18.45091700745519, 13.806552214732282`}, {
        18.450917031385952`, 13.694939323011997`}, {18.45091705348552, 
        13.605952722068361`}, {18.450917095041902`, 13.465562585156448`}, {
        18.45091713315439, 13.361945345046202`}, {18.45091716908429, 
        13.280268322941035`}, {18.45091721494863, 13.196298421701588`}}]}, 
      {Arrowheads[{{0.006439279926271329, 1.}}], 
       ArrowBox[{{18.45091723822782, 13.154557921221237`}, {18.45091729974529,
         13.068494100676201`}, {18.450917361181897`, 13.00001013035788}, {
        18.450917471869023`, 12.906053452937817`}, {18.450917579935748`, 
        12.840553677487069`}, {18.45091768660313, 12.792293189035115`}, {
        18.450917861763752`, 12.735934538295759`}, {18.450918035837855`, 
        12.699009693558077`}, {18.450918209423445`, 12.673727518885418`}, {
        18.450918453729734`, 12.65033492696893}, {18.450918697838937`, 
        12.636132154838329`}, {18.450918941875216`, 12.627227478809267`}, {
        18.450919522539042`, 12.617000387534654`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{6.963448778230389, 20.}, {6.963448778302806, 
        19.920273136227177`}, {6.963448778524887, 19.73511739302145}, {
        6.963448778713852, 19.60427814640896}, {6.963448779324174, 
        19.268088582887334`}, {6.963448779798282, 19.079155607692638`}, {
        6.963448781256069, 18.654716323792886`}, {6.963448781827412, 
        18.54241271487673}, {6.963448782351565, 18.452708580830205`}, {
        6.963448782839785, 18.378600464924375`}, {6.963448783226553, 
        18.330379980785654`}}]}, 
      {Arrowheads[{{0.012950448731518899`, 1.}}], ArrowBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQHSeYHDjplrTDU7sXbk88jRyK55SA+Vsaz2zy0TRy
YNnSB+bfvpgfaMJq5HBPayKYn6ozZ7M9k5HDwjmTwXw1+9SGhP+GDqyx08H8
jo4z60V+Gzpku8wE8+0t3k74/MPQYfnmOWD+3an6Gw2+GjpoSC0A8xezvOec
+NHQIbViMZh/zWtehNA7Q4dXhw6D+esaV//IuGDo0M7+CMyvOv3N0myXocP/
r//A/Mq5fLvXrTB0eGFlEQTiX97OyZnTa+jAIJcP5v9LWKDpXWXosHrREjC/
8cs3Vr4cQwfGuX/BfL/1W+Y8iDJ0+BAYGgziu2bJ1Lb7Gzo8zloD5u/IrCjb
7m7o8NtYMwTE1zxjlxDlYOiQs30pmD+h6wvze2tDBz1FpVAQP6HWRsPY0tDh
rOJmMD///AQtV3NDB/mgnHAQv8BXw1rB1NABAH8GqDY=
        "]]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{10.610643904038978`, 20.}, {10.610643904097797`, 
        19.905543471370596`}, {10.610643904155673`, 19.821701550274682`}, {
        10.610643904431104`, 19.48747296943637}, {10.61064390464274, 
        19.29313645226565}, {10.610643904820304`, 19.156790518810258`}, {
        10.610643905383562`, 18.8066817088691}, {10.610643905607079`, 
        18.69898641096521}, {10.610643905809654`, 18.61060859676218}, {
        10.610643905996252`, 18.53566198217652}, {10.610643906334582`, 
        18.412177755884933`}, {10.61064390658549, 18.330379980785654`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], ArrowBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQzbi3MHCZharDU7sXbk88jRyCEovBfGvnuYdTrI0c
bCbUgPkbzRND3381dBB/3Qzmi7oxXb5w0tDB2L4LzP8RUXzAcaWhg9I1CP/Z
XDHTwmWGDvnZ3WC+4oIW7Q2LDR0O+PeA+bt/tud1zDd0cNwF4a+NbTaYN9fQ
IX13L5jvKpwvzTvT0MF7YR+YX3c7LZhzqqHDyuZ+MD/3T/MFlYmGDi77poP5
3hvEnTzzDR3ec88H82+9Xnt4ZYihw8v1S8F8SUPtkjV2hg4PXbeA+Rp3OCQu
Cxs6/L95AMx/z9pyVvCLgUOL9Bkw/1Lxh3Nrbxk4nNZ/AOafSZnuPmeTgYPp
pddgvtJPE/6KeQYOAJQyhdI=
        "]]}, 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{10.610643921656473`, 16.57727896061059}, {
        10.610643923442042`, 16.484152306705315`}, {10.610643926894303`, 
        16.324754845313716`}, {10.610643929891516`, 16.205024773403817`}, {
        10.610643932583201`, 16.108626722062237`}, {10.610643937585772`, 
        15.950092052990879`}, {10.610643941932889`, 15.830854447080496`}, {
        10.610643945839149`, 15.734791128726263`}, {10.6106439531309, 
        15.576175526047937`}, {10.610643959469385`, 15.456937147642236`}, {
        10.610643965167316`, 15.360906543490517`}, {10.610643975794195`, 
        15.20263735669194}, {10.610643985042222`, 15.083680212204234`}, {
        10.610643993364413`, 14.987901746038872`}, {10.610644001270048`, 
        14.907658941396248`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{10.610644005382381`, 14.86591844091589}, {
        10.610644008899374`, 14.830220689992588`}, {10.6106440224488, 
        14.711778097230301`}, {10.610644034667589`, 14.61647992401724}, {
        10.610644057499803`, 14.460070373881726`}, {10.610644077505125`, 
        14.342726655390035`}, {10.610644095623433`, 14.248447209721588`}, {
        10.610644129548323`, 14.094673294868558`}, {10.610644159541256`, 
        13.979605796188665`}, {10.610644186931257`, 13.887433424165751`}, {
        10.610644238362582`, 13.739055567598001`}, {10.610644284585495`, 
        13.628626157097651`}, {10.610644327419529`, 13.540726200076266`}, {
        10.610644407949783`, 13.403006382363767`}, {10.610644482239572`, 
        13.301650209445064`}, {10.610644552609399`, 13.222023130951152`}, {
        10.610644581116508`, 13.19629842170169}}]}, 
      {Arrowheads[{{0.006443717885972764, 1.}}], 
       ArrowBox[{{10.610644627371686`, 13.154557921221356`}, {
        10.610644683530014`, 13.103880853578792`}, {10.610644808330354`, 
        13.018862136737111`}, {10.610644929541566`, 12.953814363986822`}, {
        10.610645145105906`, 12.866814732464498`}, {10.610645356549231`, 
        12.806778242279023`}, {10.610645565854824`, 12.763073831447375`}, {
        10.610645900703162`, 12.714080601914471`}, {10.610646234073458`, 
        12.682451585489519`}, {10.610646566804645`, 12.661165817617702`}, {
        10.610647019308022`, 12.642429934525932`}, {10.610647471587082`, 
        12.631205431656214`}, {10.610647923785773`, 12.6242756760665}, {
        10.610648969949143`, 12.616629902299653`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQfbhR5NqvfmkH9nnOr56tNXBYupsDzH+VWJ8gttzA
YZ/0j6sg/ufs+RWBcw0cdr17B+Zf2l7Xe2S6gcPdN8/B/LDPGfYlkw0cHEMu
gvnTg1cHGLUaOLAZHwLzuSO3KHtUGzi88d4G5t+fu/iee7GBw5OKWRDzTpzt
+Bdv4LC4vQ3Md9ysqjoj0MBh7bIyML8z3fjvaVcDh1NvgsB8Zc3HN6K1DBz4
ai3B/Jkzyh78EDVwuH1FFcyvTpNl281q4KAiceMKiF9etNhlf6u+A9+TNWC+
pMxFl4Nm+g5xnn1g/lP7PeEqf/UcJq/tBvO9EvPktX/oOegqdoL5XY+3Gvp+
1nNY79UK5i8SPSn89bWeQ0xHApgvdfDJav0leg6bG13AfKZ7r9Tn5eg5bE0X
A/OjlIyulwvoOejtEwDzOzYopH5l0XMAAMJ2uh4=
        "]]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{6.890605271225166, 14.967944215019926`}, {6.89060527031313, 
        14.905738077755215`}, {6.89060526886429, 14.80606136362133}, {
        6.890605266812587, 14.66397878587212}, {6.890605265249794, 
        14.555144801954572`}, {6.890605263980202, 14.466496278470776`}, {
        6.890605261746595, 14.310417134181748`}, {6.890605260068964, 
        14.19335467438648}, {6.890605258713292, 14.099095948978123`}, {
        6.8906052564719715`, 13.944391232273722`}, {6.890605254761204, 
        13.827773360169495`}, {6.8906052533618745`, 13.733651761273121`}, {
        6.890605250982188, 13.576832008280162`}, {6.89060524913523, 
        13.458845117273542`}, {6.890605247600708, 13.363728876292091`}, {
        6.890605246499283, 13.29832419580558}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{6.890605245796367, 13.256583695325222`}, {6.890605244949364,
         13.206287002136065`}, {6.890605242827076, 13.087807482467282`}, {
        6.890605241015768, 12.992292651422286`}, {6.890605237774533, 
        12.834133372017206`}, {6.890605235061672, 12.71514093426009}, {
        6.890605232659654, 12.619228234996292`}, {6.890605228169374, 
        12.460546015677505`}, {6.890605224207247, 12.341160162492752`}, {
        6.890605220556111, 12.244930963038984`}, {6.890605213420203, 
        12.08572867968193}, {6.890605206813373, 11.96594790126109}, {
        6.890605200518293, 11.869395997099987`}, {6.8906051877811505`, 
        11.709630435698198`}, {6.8906051755751205`, 11.589412013193078`}, {
        6.890605175274681, 11.586963676110878`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{6.89060517015263, 11.54522317563052}, {6.89060516368225, 
        11.492494913402023`}, {6.89060513907668, 11.332033693000875`}, {
        6.890605115005716, 11.211267732520968`}, {6.890605091250203, 
        11.11388790280797}, {6.890605041466357, 10.952502678369267`}, {
        6.890604992222567, 10.831003412736791`}, {6.8906049432977285`, 
        10.732999138783752`}, {6.890604840008357, 10.570331962918155`}, {
        6.890604737267254, 10.447811247759603`}, {6.8906046348503365`, 
        10.348934014657326`}, {6.890604417592539, 10.184450452267214`}, {
        6.890604200895239, 10.060480110429518`}, {6.8906039845299, 
        9.96036232285023}, {6.890603750771628, 9.87560315641723}}]}, 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{6.890603635655025, 9.833862655937029}, {6.890603523737452, 
        9.793282102098903}, {6.890603063523758, 9.667239123256154}, {
        6.8906026036537, 9.565347769870495}, {6.8906016201931335`, 
        9.394549361802232}, {6.890600637339274, 9.265541325932878}, {
        6.890599654847299, 9.161115733884163}, {6.890597562666917, 
        8.986444790208543}, {6.890595471129811, 8.854020148619636}, {
        6.890593379982137, 8.746530385574985}, {6.890589000026663, 
        8.56877223678255}, {6.890584620772579, 8.432935975917026}, {
        6.890580241961568, 8.322110798289344}, {6.890572393374486, 
        8.164242637191458}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{6.890570065968403, 8.12250213677709}, {6.890562091506967, 
        7.998871166451147}, {6.8905530173291325`, 7.883454333992372}, {
        6.890534459939252, 7.6945327123448175`}, {6.8905159040459685`, 
        7.547607886669498}, {6.890497349369057, 7.426392514134668}, {
        6.890459999823457, 7.229692938080652}, {6.890422654104864, 
        7.075355901408263}, {6.890385311915395, 6.947358623630258}, {
        6.890311549456425, 6.7421933325226195`}, {6.890237799609896, 
        6.579929605100214}, {6.8901684802548955`, 6.452882184122037}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{6.890141564769287, 6.411141692369067}, {6.890021576187791, 
        6.2317084028385485`}, {6.889879134985431, 6.062078394593606}, {
        6.889736738081983, 5.920361830495877}, {6.889468235928788, 
        5.701376174041451}, {6.8891998898845435`, 5.526122364000204}, {
        6.888931699410578, 5.379390368551866}, {6.888438754882438, 
        5.157564582165318}, {6.88794633375413, 4.979254086958875}, {
        6.887454434518232, 4.829707283710654}, {6.8871030077051385`, 
        4.7415251966580865`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{6.8869366630985756`, 4.699785027638033}, {6.886572646232682,
         4.6084437703382335`}, {6.885692528495971, 4.429880133053042}, {
        6.8848140744022, 4.279885692555629}, {6.883276320214937, 
        4.062367030284649}, {6.881743634427634, 3.886191416079646}, {
        6.880215982146014, 3.7379938535648605`}, {6.877602257989509, 
        3.5270795392942014`}, {6.875003127293847, 3.355733477913534}, {
        6.872418421568874, 3.211461151667704}, {6.868533925247456, 
        3.030291147810304}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{6.867539890313468, 2.9885625982631407`}, {
        6.8638144762245945`, 2.8458118681618987`}, {6.859571292519341, 
        2.7076531752277444`}, {6.8526457117315465`, 2.5183210746327416`}, {
        6.8458212479645075`, 2.3641333077852464`}, {6.839094881479199, 
        2.2344988304263453`}, {6.828398573887732, 2.0605296175245957`}, {
        6.817940661418913, 1.919106467096206}, {6.807710359850697, 
        1.80061763637568}, {6.791888761869827, 1.645161021236773}, {
        6.776580363547948, 1.51934552822371}, {6.761751709809126, 
        1.4145369504844734`}, {6.746840092078625, 1.3246672178727819`}}]}, 
      {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBgQF+/iFib1JlAgAAABcAAAACAAAADC52lcT1GkCCCJJ+LIn0Px5f7PYz
9RpAFMrpHI579D+IanjeZN8aQMCeVhxJwfI/lCS+GITKGkCXuqNivlPxP4EW
qrzpqxpA0+FKkHoR7z/AbIllGY8aQIkqCvDjNuw/7i0Wid5zGkCFj+faxODp
P5R41vuwTBpA49Y4yeP85j9qBQbWWygaQPfbeH4Jt+Q/RzyzjHgGGkD8gI5Y
yd/iP8sRRVgg1hlAvZ8QjZ+c4D9tiSUI+KkZQGySM8U5t90/i0Aur02BGUBm
JSLwk+jaPxXUnU4hRxlAfNqCchVz1z9JBe9TyhIZQNaK2xlA0NQ/Au6DrCzj
GEABPztYf7vSP7Du7Y8lnhhAVBjSqR0k0D+xs7Qo+2AYQCxVnuD0acw/qqm5
uv4pGEDz//BZY2jJP7O+hSJ62BdABJvdpPmZxT94fVLUYpEXQOMtnocC1cI/
UEGNBj1SF0A/lQhHI7jAP04Tl2Az9RZAyiQN7QIrvD/+6a6w
        "]]}, 
      {Arrowheads[{{0.012312911208217061`, 1.}}], 
       ArrowBox[{{5.69844691377543, 0.10225252394138952`}, {
        5.6553512516221485`, 0.09421882035043336}, {5.584497886730567, 
        0.08297900456537369}, {5.472408858189369, 0.06810422161794952}, {
        5.378087263153672, 0.05799804800910183}, {5.296375869638467, 
        0.05063472293024925}, {5.162811049172549, 0.04070879320211266}, {
        5.052512774890117, 0.0342354951093699}, {4.958108613474391, 
        0.02963579631450813}, {4.801991490762611, 0.023446797709134083`}, {
        4.6748874504322195`, 0.019542997654829426`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.947207906507534, 20.}, {0.9472079065065157, 
        19.97470287444917}, {0.9472079065028234, 19.883113220348427`}, {
        0.9472079064997032, 19.805801038147752`}, {0.9472079064945788, 
        19.678972259918005`}, {0.947207906490498, 19.578103246452148`}, {
        0.9472079064871436, 19.49526566814759}, {0.9472079064749298, 
        19.19402877459233}, {0.9472079064674744, 19.010487990314004`}, {
        0.947207906462139, 18.879266082275052`}, {0.9472079064482452, 
        18.53784663502314}, {0.947207906443917, 18.431593332648923`}, {
        0.9472079064403542, 18.34415931466227}, {0.9472079064397926, 
        18.330379980785654`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], ArrowBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQneA49Uub/zv7p3Yv3J54GjmUq0H4qy0ZC8RcjRxm
l00B81ODJCM3qxo5XHk5Gcxv3uT5egqPkYNVKYR/vMXxxfHvhg4v/00E8xlN
7y5i3WroEMYL4YffTfn6udPQ4XLkBDD/LJ9Vw5dMQwdnLwjf7lB0hV66oQO7
NYS/yNu2rjzF0IFLBcrvY22NSzB0SJWE8HtyA0Ir4gwdfv/vB/NXhR1Z8yHS
0GHhSwj/TH724y+hhg5fLkP4f2vWPxAPMnQwF4fwp9h4+ZcaGDr0NPWB+QeO
sFz6LgrUzw7h/xdN1RFkMHSYJNYL5vdxS72Uu2rg8D+5B8wv3q2Y4L/VwOHI
424wX+mnCX/FPAMHALB8pTw=
        "]]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.947207906368242, 16.57727896061059}, {0.9472079063631409, 
        16.45240339893291}, {0.9472079063583132, 16.334233150488622`}, {
        0.9472079063544154, 16.238829729300242`}, {0.9472079063478982, 
        16.07932224191987}, {0.9472079063430023, 15.959508257258953`}, {
        0.9472079063390602, 15.863039044006332`}, {0.9472079063325756, 
        15.704366552510999`}, {0.9472079063276972, 15.585010707275952`}, {
        0.9472079063237661, 15.488839026898441`}, {0.9472079063172704, 
        15.329947786903528`}, {0.947207906312385, 15.210473248451843`}, {
        0.9472079063084488, 15.11422516948298}, {0.9472079063019517, 
        14.955399641051477`}, {0.9472079062999981, 14.907658941396246`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.94720790629829, 14.865918440915888`}, {0.9472079062970641,
         14.83596179144244}, {0.9472079062931249, 14.73973785223651}, {
        0.9472079062866192, 14.580898538269182`}, {0.9472079062817234, 
        14.461453645416535`}, {0.9472079062777762, 14.365225393617877`}, {
        0.9472079062712541, 14.206392699602832`}, {0.9472079062663417, 
        14.086951777303405`}, {0.9472079062623779, 13.990726273370953`}, {
        0.9472079062558207, 13.831893755696779`}, {0.9472079062508734, 
        13.712453172373337`}, {0.9472079062468747, 13.616228010644267`}, {
        0.9472079062402435, 13.457396832092872`}, {0.9472079062352222, 
        13.3379571535286}, {0.9472079062311496, 13.241732665797967`}, {
        0.947207906229208, 13.196298421701542`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.9472079062274242, 13.154557921221183`}, {
        0.9472079062243621, 13.082902110670931`}, {0.9472079062191844, 
        12.963462898931498`}, {0.9472079062149554, 12.867238778975107`}, {
        0.9472079062078372, 12.708408784339492`}, {0.9472079062023288, 
        12.588969976571125`}, {0.9472079061977691, 12.492746170491323`}, {
        0.9472079061899514, 12.333916598963956`}, {0.9472079061837435, 
        12.214478105358095`}, {0.9472079061784844, 12.118254549178763`}, {
        0.9472079061691875, 11.959425365412793`}, {0.9472079061615004, 
        11.839987163724068`}, {0.947207906154762, 11.743763843823555`}, {
        0.9472079061423367, 11.584935056028028`}, {0.9472079061332817, 
        11.484937902006838`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.9472079061292347, 11.44319740152648}, {0.9472079061216545,
         11.369274091372622`}, {0.9472079061026133, 11.210445767066023`}, {
        0.9472079060851819, 11.09100823287308}, {0.9472079060686992, 
        10.9947854699238}, {0.9472079060356664, 10.835957741534274`}, {
        0.9472079060042433, 10.71652067887281}, {0.9472079059737689, 
        10.620298316426062`}, {0.9472079059111459, 10.461471401166605`}, {
        0.9472079058501327, 10.342034985920552`}, {0.9472079057900682, 
        10.245813176551941`}, {0.9472079056648668, 10.08698740694182}, {
        0.9472079055412751, 9.967551906817691}, {0.9472079054186321, 
        9.871330881552526}, {0.9472079052601181, 9.773577382312133}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.947207905192433, 9.731836881831775}, {0.9472079051610879, 
        9.712506752673654}, {0.9472079049051534, 9.593072565224839}, {
        0.9472079046501676, 9.496852666342566}, {0.9472079041127414, 
        9.338030906052337}, {0.9472079035769247, 9.218598615065419}, {
        0.9472079030420568, 9.122380344648322}, {0.9472079019127317, 
        8.96356201683538}, {0.9472079007850163, 8.84413247514484}, {
        0.9472078996582494, 8.747916566300503}, {0.9472078972771759, 
        8.589103221783217}, {0.947207894897712, 8.469677672232349}, {
        0.9472078925191965, 8.373465193071034}, {0.94720788749213, 
        8.214691759495622}, {0.9472078824666723, 8.095289995696852}, {
        0.9472078807391928, 8.06221686261743}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{0.9472078785589984, 8.020476362137071}, {0.9472078774421627,
         7.9990941955663635`}, {0.9472078669609972, 7.842185864445581}, {
        0.9472078564814065, 7.723817243950566}, {0.9472078460027493, 
        7.628296029324051}, {0.947207824277713, 7.473113268883738}, {
        0.9472078025542205, 7.35570991135112}, {0.9472077808316484, 
        7.260822171421519}, {0.9472077361161357, 7.107435709342175}, {
        0.9472076914021367, 6.991045053824456}, {0.9472076466890454, 
        6.896824593056254}, {0.9472075553146135, 6.745279098938719}, {
        0.94720746394167, 6.629935391230292}, {0.9472073725696274, 
        6.536408075619374}, {0.9472071872420434, 6.3867569903674175`}, {
        0.947207129010427, 6.350856342923028}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.9472070613064443, 6.309115842442725}, {0.9472070019159461,
         6.2725007273744025`}, {0.9472068165907662, 6.179697288414856}, {
        0.9472064436020499, 6.0319993519832185`}, {0.9472060706149136, 
        5.918875723647436}, {0.9472056976288065, 5.826830982348844}, {
        0.9472049529312336, 5.681152169028855}, {0.9472042082357117, 
        5.569212605580545}, {0.9472034635417086, 5.4779667925975675`}, {
        0.9472019889338273, 5.334381908798036}, {0.9472005143299334, 
        5.223685576374462}, {0.9471990397295132, 5.133285713149112}, {
        0.9471961446336289, 4.991880531566815}, {0.9471932495492519, 
        4.882496299684071}, {0.9471903544758883, 4.79299800776413}, {
        0.9471847205743266, 4.653871927092025}, {0.9471839705774282, 
        4.639495823515703}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.9471817929883694, 4.597755323092146}, {0.947179086712675, 
        4.545880842318013}, {0.9471734528904586, 4.45735063259017}, {
        0.9471625891980463, 4.320619980013013}, {0.9471517256505545, 
        4.214118357053897}, {0.9471408622475257, 4.126636504745858}, {
        0.9471201121275965, 3.9924385810247487`}, {0.9470993625331029, 
        3.8875418149071588`}, {0.947078613463592, 3.8012059234510525`}, {
        0.947039368712261, 3.669703878284758}, {0.947000125837409, 
        3.5665510726654763`}, {0.9469608848384995, 3.4814804232238643`}, {
        0.9468874180487613, 3.3528690139198774`}, {0.9468139578326329, 
        3.2516284926096013`}, {0.9467405041889169, 3.1679692527002117`}, {
        0.9466044337114627, 3.0424814780103278`}, {0.9464683857846525, 
        2.9433571950332986`}, {0.9464431566355456, 2.928135602233483}}]}, 
      {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAABUAAAACAAAAhOlNErJI7j+n5FxYVhcHQON5Ys1a
SO4/dtacO+vjBkD7aXkjUEbuP8EwXUbj6QVAxiswokVE7j9hGdiHuCMFQEJh
gkk7Qu4/5MtHrVl/BEAmab4giT7uP1hae7L3jANAL3Irfdc67j+nDiTrP8wC
QI3Or14mN+4/6K75pCEsAkAfycqtijDuP+bFND40QgFAbNAOp/Ap7j+sMKx0
qocAQIo56UlYI+4/m/0Sm+vY/z9zqsSVrxfuP5u7PFHgF/4/5UxTEgwM7j+g
hsmM5bD8PxmybrxtAO4/zWMy2uSF+z+ep3vYJ+ztP3nN0FXg2fk/E6tisfHX
7T+cjAuFCoP4PzBhiTbLw+0/BbNw4VNl9z+0kRS8HaHtPzVaaifl0PU/f+qQ
iZ5+7T9SqZbFl4z0P3qngUtNXO0/DXyfK2F+8z8fCCOXnlvtP3Y/j4DyefM/
mJqmcg==
        "]]}, 
      {Arrowheads[{{0.009332610862094875, 1.}}], 
       ArrowBox[{{0.9142301134697854, 1.1756549272334138`}, {
        0.9104141975847901, 1.1260878380532817`}, {0.9033737629577591, 
        1.0521100221126167`}, {0.8963952807898253, 0.9905512068484786}, {
        0.8847531981042354, 0.9055618638432658}, {0.8732821837134246, 
        0.8375465307048238}, {0.8619789200026899, 0.7811143389311099}, {
        0.8434631128919748, 0.7042912121663601}, {0.8253920074456412, 
        0.6430837000738009}, {0.8077518301760307, 0.5925658455643993}, {
        0.779459620808629, 0.524843145510957}, {0.7522566755599015, 
        0.4713215130444179}, {0.7260907517130437, 0.4275218161261767}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{3.7354648285703838`, 20.}, {3.7354648285620855`, 
        19.912918096473646`}, {3.7354648285547847`, 19.836029294336992`}, {
        3.735464828542704, 19.7083411365084}, {3.7354648285331966`, 
        19.60744346479235}, {3.735464828525466, 19.52515096786217}, {
        3.7354648284955183`, 19.205072176820195`}, {3.7354648284779604`, 
        19.016278422277225`}, {3.7354648284655982`, 18.882959089666283`}, {
        3.7354648284337775`, 18.53886643546286}, {3.73546482842397, 
        18.43249176707247}, {3.7354648284159175`, 18.345075355409183`}, {
        3.735464828414565, 18.330379980785654`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], ArrowBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQ/Y3PO8n6Ea/DU7sXbk88jRwmMUD4HxIv9Ie7Gjl0
zfUC8/10ezOZ1IwcUv0gfJlDRfyfeYwc3vFA+Ovf6UaZ/jB0iLL0BPMdOO93
y281dMja6AHm96joLP3Zaegw0wfC//rB6u6XTEOHu84Q/sxU8/V66YYOgdYQ
/qz4wzPKUwwdsvUg/FWKrK1xCYYOhRoQfkO3ztqKOEMHIykI//lWrgcfIw0d
VvNC+KsvfH70LdTQoZURwq9/eWu9VJChw4np7mD+ol1fXBoMDB16XCD8AEnp
ai4xQ4eD/93A/AKmqcu1GAwdvldA+L1H1x73uWrgoCQK4Z/bUf+/a6uBw6wz
rmC+0k8T/op5Bg4A9N6IGg==
        "]]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{3.7354648282538414`, 16.57727896061059}, {3.73546482824253, 
        16.453620816288932`}, {3.735464828231732, 16.335561994668833`}, {
        3.735464828223014, 16.240245012324447`}, {3.7354648282084355`, 
        16.080856925222697`}, {3.735464828197483, 15.961127708734029`}, {
        3.7354648281886624`, 15.864723146532299`}, {3.7354648281741487`, 
        15.706128765876084`}, {3.7354648281632263`, 15.586829031382731`}, {
        3.7354648281544214`, 15.490700401594626`}, {3.7354648281398632`, 
        15.3318638272418}, {3.735464828128905, 15.212428375362338`}, {
        3.735464828120068, 15.116210212654677`}, {3.7354648281054628`, 
        14.957421916215822`}, {3.7354648281008753`, 14.907658941396246`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{3.7354648280970273`, 14.865918440915888`}, {
        3.7354648280944547`, 14.838010727338778`}, {3.7354648280855667`, 
        14.741807205811883`}, {3.735464828070848, 14.582993447088056`}, {
        3.735464828059726, 14.463566831458225`}, {3.7354648280507243`, 
        14.367352563607396`}, {3.735464828035767, 14.20853725268684}, {
        3.7354648280244067`, 14.089108751678094`}, {3.7354648280151665`, 
        13.992892739880265`}, {3.735464827999704, 13.834071934815466`}, {
        3.7354648279878386`, 13.714639698755471`}, {3.735464827978093, 
        13.618420896863464`}, {3.735464827961562, 13.459597414027245`}, {
        3.7354648279486278`, 13.340163188660693`}, {3.7354648279378138`, 
        13.24394282804846}, {3.735464827932177, 13.196298421701542`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{3.7354648279272387`, 13.154557921221183`}, {
        3.735464827919023, 13.085117046504207`}, {3.7354648279038294`, 
        12.965681169243588`}, {3.735464827890756, 12.869459530337755`}, {
        3.735464827867186, 12.710632063980954`}, {3.735464827847213, 
        12.591194944856136`}, {3.73546482782936, 12.494972325647591`}, {
        3.7354648277956835`, 12.336143396098072`}, {3.7354648277656035`, 
        12.216705185060244`}, {3.7354648277376437`, 12.120481690086457`}, {
        3.7354648276825917`, 11.961651353084186`}, {3.7354648276311364`, 
        11.842212067987736`}, {3.735464827581801, 11.745987692319883`}, {
        3.7354648274815436`, 11.587155792489}, {3.7354648273988205`, 
        11.484937902006838`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{3.735464827360794, 11.44319740152648}, {3.735464827290342, 
        11.371489902243843`}, {3.73546482709448, 11.212656065575608`}, {
        3.7354648269022155`, 11.09321403932623}, {3.735464826712071, 
        10.996987357602787`}, {3.7354648263140207`, 10.838150934454745`}, {
        3.7354648259195673`, 10.71870685344428}, {3.735464825527234, 
        10.622478419992934`}, {3.7354648247015794`, 10.463638394036105`}, {
        3.735464823879522, 10.34419143845266}, {3.735464823059585, 
        10.247960544563544`}, {3.735464821329594, 10.089115388371617`}, {
        3.7354648196032008`, 9.969664330643587}, {3.7354648178789276`, 
        9.873429918612471}, {3.7354648155892503`, 9.773577382312133}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{3.735464814632116, 9.731836881831775}, {3.7354648142363454`,
         9.714577377205897}, {3.735464810597361, 9.595120408032653}, {
        3.7354648069604974`, 9.498880921268828}, {3.735464799272895, 
        9.340017692535499}, {3.7354647915888917`, 9.220552164506225}, {
        3.735464783907009, 9.124305326991987}, {3.735464767664246, 
        8.965426594006448}, {3.735464751425082, 8.845948646708361}, {
        3.73546473518804, 8.749691140759603}, {3.7354647008506845`, 
        8.59078989010753}, {3.735464666516931, 8.471293903951132}, {
        3.7354646321853, 8.37502090095892}, {3.735464559608544, 
        8.216150699314081}, {3.735464487035393, 8.096663613034128}, {
        3.735464461069191, 8.062216862617497}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{3.7354644296049098`, 8.02047636213715}, {
        3.7354644144643694`, 8.000390928602814}, {3.735464263064096, 
        7.843344975875114}, {3.735464111667373, 7.7248544562642}, {
        3.7354639602727655`, 7.629223119960783}, {3.7354636463949684`, 
        7.47384790270738}, {3.7354633325207383`, 7.3562723915784405`}, {
        3.7354630186486792`, 7.261228365612263}, {3.735462372611396, 
        7.107571774946868}, {3.7354617265779657`, 6.990937820287838}, {
        3.735461080547032, 6.896495692919493}, {3.735459760584763, 
        6.744571211663515}, {3.7354584406277525`, 6.628884300079626}, {
        3.735457120674683, 6.5350433769927045`}, {3.7354544442601365`, 
        6.384861434360209}, {3.7354536510575143`, 6.350856342985359}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{3.7354526774187713`, 6.309115842516356}, {3.735451767856811,
         6.270122353690242}, {3.7354490914634266`, 6.1768766556051835`}, {
        3.7354437073913394`, 6.0284372027917925`}, {3.7354383233546815`, 
        5.914636770778533}, {3.7354329393522123`, 5.8219707883342515`}, {
        3.7354221970903594`, 5.675260127468906}, {3.7354114549599804`, 
        5.5623759643032695`}, {3.73540071295987, 5.470261527508945}, {
        3.7353794633928894`, 5.325247604654127}, {3.7353582143312014`, 
        5.213239725755931}, {3.735336965773616, 5.1216318855991885`}, {
        3.7352953086354495`, 4.978258970004416}, {3.7352536534303273`, 
        4.867064782655906}, {3.735212000156925, 4.775897146715789}, {
        3.735134199442398, 4.639495876857546}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{3.7351045148313546`, 4.597755386994272}, {
        3.7350502281445745`, 4.523609499250976}, {3.7349693530554533`, 
        4.432789527584342}, {3.734813867972772, 4.292410303371707}, {
        3.7346584097751006`, 4.182540869227947}, {3.734502978451129, 
        4.091946465984273}, {3.734207360054339, 3.9528523186391284`}, {
        3.7339118388055006`, 3.8434307215541352`}, {3.733616414633188, 
        3.7529109538490997`}, {3.733061063716301, 3.6149242272397655`}, {
        3.7325060554545204`, 3.5057749501598168`}, {3.7319513893807765`, 
        3.415160444591171}, {3.7309219969880636`, 3.2781066762376563`}, {
        3.7298937806852863`, 3.169061423154205}, {3.728866737511116, 
        3.078194509934846}, {3.7269878059633053`, 2.9419671357949815`}, {
        3.726750559229302, 2.9281706886743843`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{3.7260328865216277`, 2.886436358366645}, {
        3.7251127855321395`, 2.8329303545836626`}, {3.7232416582998566`, 
        2.741731417842892}, {3.7198739912890444`, 2.6064178374040927`}, {
        3.716518847591213, 2.497492259084322}, {3.7131761249104134`, 
        2.40608453857673}, {3.7072731372298935`, 2.2721804626334166`}, {
        3.701408410449706, 2.1638750860346976`}, {3.6955814015723223`, 
        2.0727857594833603`}, {3.6855202323784266`, 1.941500059285468}, {
        3.6755691715072665`, 1.8350119700122456`}, {3.665725593978328, 
        1.7454305321861712`}, {3.6491783813876193`, 1.6189947223712815`}, {
        3.632924563919253, 1.5164633119486242`}, {3.6169528965165436`, 
        1.430442531303282}, {3.5909309610598457`, 1.3121724978984446`}, {
        3.5687332868163963`, 1.228410062488087}}]}, 
      {Arrowheads[{{0.009636164715222247, 1.}}], 
       ArrowBox[{{3.5568741439131855`, 1.1883972587256484`}, {
        3.5409738414644014`, 1.137012194352955}, {3.502172719615052, 
        1.0307601847573065`}, {3.464899566551524, 0.9456404115115256}, {
        3.4290274447746656`, 0.8753240114209747}, {3.3743715599149593`, 
        0.784264814670363}, {3.322624910524111, 0.7121403147030115}, {
        3.2734659541364035`, 0.6532376372801588}, {3.2004129258426226`, 
        0.5786963850028776}, {3.1323038957520404`, 0.5204627591446553}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{3.04163783300532, 20.}, {3.041637832989852, 
        19.702886546714222`}, {3.041637832979122, 19.49583676735159}, {
        3.0416378329717784`, 19.353840665591825`}, {3.041637832953235, 
        18.994649976432534`}, {3.0416378329476146`, 18.885570675322565`}, {
        3.0416378329430183`, 18.796315898872173`}, {3.04163783293913, 
        18.72077323902618}, {3.0416378329327376`, 18.59652519736544}, {
        3.041637832927642, 18.497434142959463`}, {3.041637832923442, 
        18.4157284110879}, {3.041637832919057, 18.330379980785654`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{3.0416378329169125`, 18.288639480305296`}, {
        3.041637832908994, 18.13452383207637}, {3.0416378328999625`, 
        17.958628249394913`}, {3.041637832893432, 17.831391435946966`}, {
        3.041637832876296, 17.497407749039088`}, {3.0416378328709213`, 
        17.39261224458888}, {3.0416378328664897`, 17.306196493753568`}, {
        3.041637832862719, 17.232666466648954`}, {3.0416378328564875`, 
        17.111135723737792`}, {3.0416378328514937`, 17.013731724204764`}, {
        3.0416378328473503`, 16.93291335338555}, {3.0416378328345335`, 
        16.682896177205553`}, {3.041637832831259, 16.61901946109095}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{3.0416378328291196`, 16.57727896061059}, {
        3.0416378328261424`, 16.5192026371937}, {3.0416378328199434`, 
        16.39827323476034}, {3.041637832803408, 16.075734142598947`}, {
        3.0416378327981413`, 15.973027157781747`}, {3.0416378327937816`, 
        15.88802237018109}, {3.041637832790062, 15.815507647789492`}, {
        3.0416378327838984`, 15.69536876696008}, {3.041637832778945, 
        15.598845869280469`}, {3.041637832774821, 15.518513407472167`}, {
        3.0416378327629183`, 15.286838771005842`}, {3.041637832754898, 
        15.130946860611202`}, {3.041637832748884, 15.01421630663352}, {
        3.0416378327433793`, 14.907658941396246`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{3.041637832741223, 14.865918440915888`}, {3.041637832732627,
         14.699528346019283`}, {3.041637832727373, 14.59830724902715}, {
        3.0416378327230023`, 14.514316390359651`}, {3.041637832719257, 
        14.442536959209797`}, {3.0416378327130174`, 14.323414049904411`}, {
        3.0416378327079685`, 14.227540674532884`}, {3.0416378327037346`, 
        14.147575833830553`}, {3.041637832692135, 13.930759757459393`}, {
        3.0416378326839983`, 13.781548084451984`}, {3.041637832677715, 
        13.66851498121101}, {3.0416378326599824`, 13.36088711963844}, {
        3.04163783265388, 13.261035437261262`}, {3.041637832649794, 
        13.196298421701542`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{3.0416378326471127`, 13.154557921221183`}, {
        3.041637832644009, 13.106890708009498`}, {3.0416378326359808`, 
        12.988718812098837`}, {3.041637832629126, 12.893456673826236`}, {
        3.041637832623072, 12.813843765666538`}, {3.041637832606248, 
        12.612560612395816`}, {3.041637832592467, 12.470694207646956`}, {
        3.041637832580377, 12.36183564499336}, {3.0416378325389783`, 
        12.062339665083167`}, {3.0416378325209172`, 11.964101899005396`}, {
        3.0416378325036915`, 11.882165974028874`}, {3.0416378324870625`, 
        11.811887083571492`}, {3.0416378324550095`, 11.694851063984315`}, {
        3.041637832424109, 11.600321920570668`}, {3.0416378323939948`, 
        11.521138417022156`}, {3.0416378323768902`, 11.484937902006838`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{3.0416378323571682`, 11.44319740152648}, {3.041637832309101,
         11.341465298070647`}, {3.0416378322267, 11.210474061593114`}, {
        3.041637832145761, 11.108011791041891`}, {3.041637831828311, 
        10.821312013211537`}, {3.0416378316720305`, 10.725693569809856`}, {
        3.0416378315165447`, 10.645580290644734`}, {3.041637831361631, 
        10.576641999013622`}, {3.0416378310529675`, 10.461482525491208`}, {
        3.041637830745423, 10.36817023862493}, {3.0416378304386393`, 
        10.289722229755533`}, {3.041637829822628, 10.160756209515515`}, {
        3.041637829207993, 10.058660621758307`}, {3.0416378285942813`, 
        9.97458687982317}, {3.0416378266002684`, 9.773577382312133}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{3.0416378261862027`, 9.731836881831775}, {
        3.0416378261440067`, 9.727583242578591}, {3.041637823698136, 
        9.566552525775819}, {3.041637813927528, 9.173801865428365}, {
        3.0416378123121297`, 9.133990619099047}, {3.0416378106968818`, 
        9.097121710208764}, {3.041637809081764, 9.06278930667475}, {
        3.041637808597252, 9.052940558784488}, {3.0416378081934976`, 
        9.044866031431727}, {3.0416378025242587`, 8.951005827809869}, {
        3.041637796855741, 8.87122995738388}, {3.0416377855197245`, 
        8.731569799206046}, {3.041637774185322, 8.623423683904104}, {
        3.041637762851915, 8.53470122705142}, {3.041637736645742, 
        8.373628330875233}, {3.041637710441639, 8.252969281845248}, {
        3.0416376842387485`, 8.155958298083938}, {3.041637651816448, 
        8.062216862617445}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{3.0416376373796834`, 8.020476362137089}, {3.041637629798446,
         7.998557001503406}, {3.041637575360131, 7.879897302505611}, {
        3.041637520922994, 7.784174927906939}, {3.041637407592927, 
        7.628154660698338}, {3.041637294264826, 7.510261480969314}, {
        3.0416371809378986`, 7.415038180551375}, {3.041636946992287, 
        7.2608093680672985`}, {3.041636713048641, 7.143913273869572}, {
        3.0416364791061916`, 7.049339539056385}, {3.041635999559953, 
        6.896889962391192}, {3.041635520015808, 6.78098955679167}, {
        3.0416350404730106`, 6.687065241550848}, {3.0416340648151072`, 
        6.5364381426443545`}, {3.041633089159952, 6.4215624166322565`}, {
        3.0416323494230695`, 6.350856342937779}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{3.0416318594055043`, 6.309115842460336}, {
        3.0416301437088795`, 6.179537999891158}, {3.0416281739164597`, 
        6.065711405882456}, {3.0416262041288595`, 5.973140430070262}, {
        3.041622258777679, 5.826266135633712}, {3.04161831344321, 
        5.713512715534518}, {3.041614368124774, 5.621641341825223}, {
        3.0416065308711073`, 5.476696345315269}, {3.0415986936781834`, 
        5.365038309882327}, {3.0415908565453442`, 5.273879431831187}, {
        3.0415754211653425`, 5.130896212670915}, {3.0415599860159865`, 
        5.020353087601796}, {3.041544551096635, 4.929916654934646}, {
        3.041514421718986, 4.78892431245785}, {3.041484293215386, 
        4.679511887732906}, {3.041470854179976, 4.639495837177921}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{3.041456836004155, 4.597755339051502}, {3.041454165585169, 
        4.589803903708034}, {3.041395900988796, 4.450827174285989}, {
        3.041337639656391, 4.3425565624284665`}, {3.0412793815869645`, 
        4.253578201868625}, {3.0411678099646453`, 4.116636988657777}, {
        3.0410562503055574`, 4.009514215164081}, {3.0409447026063248`, 
        3.9212614984827434`}, {3.040733262136514, 3.7863718135147937`}, {
        3.0405218646203576`, 3.680398854190164}, {3.040310510038202, 
        3.5928638069446057`}, {3.0399142339551055`, 3.4600418832927673`}, {
        3.0395181086946033`, 3.3552209458018334`}, {3.0391221341304884`, 
        3.268396074889416}, {3.0383883278630104`, 3.1376689619108142`}, {
        3.0376550384504086`, 3.0340134028326697`}, {3.036922265095435, 
        2.9479029423608822`}, {3.036716228460584, 2.9281472609648884`}}]}, 
      {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBQQG+/iFib1JlAgAAABMAAAACAAAA5VsVqE1KCED6UCGeXRcHQPfQ1OHe
SAhAVNAstP2NBkDfRIPEIEYIQLL165IwvAVAVm/tjWNDCEBEvzF+YQ0FQB4v
WxNyPghA+sSK4cQKBEDgaw+FgzkIQBo7PNW3OwNAzOpD35c0CEDNmtXwtI4C
QJWmcYnZKwhAC/hnCGuRAUCLFqhQJCMIQGuydHC4xQBAMtQ1IHgaCECxqMjU
GRsAQI4klQdUCwhAX4Gs9r1I/j/p66waS/wHQNOuEkt9uvw/xcm071ztB0Aa
XTgMcmz7Pw77vqLT0wdAt3N5lJqQ+T8qTB/klroHQNNeQajnD/g/qrAxxaSh
B0DPI26xYM32P5LF2mH+dwdACbsM+n8K9T9JSSakIE8HQMqBEjdonvM/JxIx
ij5OB0DV1xc+tZfzP5vAhiw=
        "]]}, 
      {Arrowheads[{{0.009887683253428434, 1.}}], 
       ArrowBox[{{2.902562864241215, 1.1841770898430233`}, {2.894049629161111,
         1.1518907687090303`}, {2.8622488867460385`, 1.0504298269674992`}, {
        2.8313637347806457`, 0.9689073036732252}, {2.8013387612699776`, 
        0.9012353831010718}, {2.754060049064054, 0.8112406798796771}, {
        2.7087465182083497`, 0.7395899313226275}, {2.665229920337251, 
        0.6807057423164422}, {2.5986891282627647`, 0.6044398690113576}, {
        2.535905057311916, 0.5444892116724694}, {2.4764525017949683`, 
        0.49582741042384126`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{16.074827826676554`, 0.6585953260115593}, {
        16.123101026471524`, 0.9610871656674063}, {16.151931954901553`, 
        1.2635790042015322`}, {16.154125235669035`, 1.2938281880223526`}, {
        16.15622867762902, 1.324077371839318}, {16.158246909292597`, 
        1.3543265556526556`}, {16.159235280697125`, 1.3694511475584443`}, {
        16.160203697200586`, 1.3845757394633886`}, {16.16115266212948, 
        1.3997003313675116`}, {16.162082662160675`, 1.4148249232708352`}, {
        16.162994168034402`, 1.42994951517338}, {16.184225439421606`, 
        1.7466996892832878`}, {16.200417331423804`, 2.0634498631410496`}, {
        16.208333014641866`, 2.3214024165799754`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{16.20961328544777, 2.3631232781124796`}, {
        16.210137312871687`, 2.380200036788591}, {16.217682977273174`, 
        2.696950210100134}, {16.2224009662335, 3.013700396289496}, {
        16.227738669663008`, 3.3304506015957385`}, {16.233324258880188`, 
        3.647200814548734}, {16.238785905203528`, 3.9639510236783515`}, {
        16.239859968277344`, 4.032460541958173}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{16.240514277676265`, 4.074195913761493}, {16.24375177995153,
         4.2807012175144665`}, {16.247850054442676`, 4.5974513845869485`}, {
        16.250708899995455`, 4.914201513425668}, {16.251956487928368`, 
        5.2309515925604995`}, {16.252317402341532`, 5.547701910705571}, {
        16.252558483793894`, 5.743748332919167}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{16.25260981272281, 5.785488801839531}, {16.252706915544046`,
         5.864452407307683}, {16.25303923116786, 6.181202546995714}, {
        16.253228552844927`, 6.497951794398542}, {16.25332980114316, 
        6.814703791012215}, {16.253439064363977`, 7.131458036832874}, {
        16.25353229773962, 7.448207784239557}, {16.253533455895425`, 
        7.455108481602238}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{16.253540461274685`, 7.496848981494734}, {
        16.253585456502307`, 7.764946285611289}, {16.25361959050524, 
        8.195562649780797}, {16.25364177982861, 8.626142714819448}, {
        16.25365116610963, 9.05643393389932}, {16.253652731223386`, 
        9.166468994895151}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{16.2536533249308, 9.208209495371287}, {16.253657279659272`, 
        9.48624601970392}, {16.25366037001804, 9.829734167561309}, {
        16.253662249528077`, 10.172241124884492`}, {16.253663844197973`, 
        10.509671369772825`}, {16.253664845358205`, 10.843390076193186`}, {
        16.253664972039154`, 10.877829514532946`}}]}, 
      {Arrowheads[{{0.01583014173875962, 1.}}], 
       ArrowBox[{{16.2536651255761, 10.919570015013022`}, {
        16.253665709688093`, 11.07836649918099}, {16.25366645186437, 
        11.30477005655769}, {16.25366707188704, 11.522600748323287`}, {
        16.2536675697561, 11.731858574477776`}, {16.253667978993626`, 
        11.926291226482011`}, {16.253668343928695`, 12.097407152960388`}, {
        16.25366868203757, 12.241086092709722`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{4.4371685639448115`, 20.}, {4.437168563923234, 
        19.904690077556104`}, {4.437168563905422, 19.825020647790833`}, {
        4.437168563831164, 19.487320891290704`}, {4.437168563790213, 
        19.296334835110898`}, {4.437168563761997, 19.16317572937521}, {
        4.4371685636903875`, 18.821775730359004`}, {4.437168563668599, 
        18.716689807328482`}, {4.437168563650761, 18.63036300678166}, {
        4.43716856363566, 18.557082444201853`}, {4.437168563610813, 
        18.436195790987234`}, {4.4371685635909905`, 18.33947021163891}, {
        4.437168563589132, 18.330379980785654`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{4.437168563580597, 18.288639480305296`}, {4.437168563574604,
         18.25932660734441}, {4.437168563522929, 18.005883800135795`}, {
        4.437168563489512, 17.841326960606928`}, {4.437168563464966, 
        17.720184661930823`}, {4.437168563399789, 17.39782030642309}, {
        4.4371685633791245`, 17.295355877809886`}, {4.4371685633620395`, 
        17.21057727431062}, {4.437168563347476, 17.138266863359533`}, {
        4.437168563323365, 17.01847709240043}, {4.437168563304007, 
        16.922237836901765`}, {4.437168563287902, 16.842132640959594`}, {
        4.437168563243072, 16.61901946109095}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{4.437168563234691, 16.57727896061059}, {4.4371685632105535`,
         16.45706048247984}, {4.437168563187253, 16.340960569706365`}, {
        4.437168563124564, 16.02851027780579}, {4.437168563087522, 
        15.843856340959013`}, {4.437168563001702, 15.416238892883634`}, {
        4.437168562978166, 15.299119515217432`}, {4.437168562959147, 
        15.204547117747602`}, {4.437168562943206, 15.125349361105009`}, {
        4.437168562906443, 14.942988726859266`}, {4.437168562899302, 
        14.907658941396246`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{4.437168562890865, 14.865918440915888`}, {4.437168562879687,
         14.810617341689431`}, {4.437168562858769, 14.707422866347573`}, {
        4.437168562800181, 14.419987045804545`}, {4.437168562763847, 
        14.243770761080881`}, {4.437168562676382, 13.828220291898946`}, {
        4.43716856265108, 13.712592081328102`}, {4.437168562630181, 
        13.61897740328581}, {4.437168562612279, 13.540345404060899`}, {
        4.437168562578376, 13.395681238482833`}, {4.437168562551082, 
        13.284070862672333`}, {4.437168562528732, 13.196298421701542`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{4.437168562517646, 13.154557921221183`}, {4.437168562485216,
         13.038798835253663`}, {4.437168562454803, 12.937113988882164`}, {
        4.437168562400159, 12.764665286742591`}, {4.437168562354826, 
        12.638781319332585`}, {4.4371685623146, 12.538441025932125`}, {
        4.43716856224332, 12.382706674662327`}, {4.437168562179638, 
        12.264969794217798`}, {4.437168562120479, 12.169853043079454`}, {
        4.437168562002233, 12.010158053573948`}, {4.437168561891942, 
        11.890245321376543`}, {4.437168561786325, 11.793713674456633`}, {
        4.437168561572894, 11.63511061739256}, {4.437168561367319, 
        11.51579376047645}, {4.4371685613028315`, 11.484937902006838`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{4.4371685612155956`, 11.44319740152648}, {4.437168561166377,
         11.41964735805168}, {4.437168560749814, 11.26073940051085}, {
        4.437168560341134, 11.141254156431604`}, {4.437168559937098, 
        11.04499766332429}, {4.437168559091824, 10.886163161877391`}, {
        4.437168558254426, 10.7667161056036}, {4.4371685574216695`, 
        10.670483035817492`}, {4.437168555669223, 10.511614926809957`}, {
        4.437168553924657, 10.392146630020473`}, {4.437168552184734, 
        10.295897910011252`}, {4.437168548513894, 10.137019689381217`}, {
        4.437168544850934, 10.017541773498289`}, {4.4371685411926185`, 
        9.921284105990468}, {4.4371685340086815`, 9.773577382312133}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{4.4371685314907054`, 9.731836881831775}, {
        4.4371685257435125`, 9.642883429117852}, {4.437168518027547, 
        9.546609152237558}, {4.4371685017165925`, 9.387672665276808}, {
        4.437168485413524, 9.268148400792422}, {4.437168469115105, 
        9.171851072333673}, {4.437168434649725, 9.012865499114918}, {
        4.437168400192238, 8.893301947223826}, {4.437168365739404, 
        8.796970884883885}, {4.437168292868554, 8.637914234507239}, {
        4.43716822000561, 8.518293736234087}, {4.437168147147328, 
        8.421913749826112}, {4.4371679930188845`, 8.262753772500531}, {
        4.4371678388983815`, 8.143050504332706}, {4.4371677097371425`, 
        8.062216862617792}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{4.4371676313978945`, 8.020476362137508}, {4.437167362920162,
         7.889100497578489}, {4.437167041065649, 7.770278110962241}, {
        4.437166719215875, 7.674376166997292}, {4.437166051508026, 
        7.5184545548706545`}, {4.437165383808384, 7.400459463595227}, {
        4.437164716113874, 7.305063750962022}, {4.437163340952991, 
        7.150717417084829}, {4.437161965802076, 7.033534032645257}, {
        4.4371605906581335`, 6.9386218510841555`}, {4.43715777954288, 
        6.7858106887526475`}, {4.437154968445349, 6.6693946823394334`}, {
        4.437152157362624, 6.574919214918996}, {4.437146455445784, 
        6.423578257342212}, {4.43714287213516, 6.350856343251537}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{4.437140815407413, 6.30911584282185}, {4.4371407535788165`, 
        6.307861055189885}, {4.437135051758884, 6.213752374535551}, {
        4.437123580215537, 6.063779996432111}, {4.437112108851892, 
        5.948658755374023}, {4.43710063766518, 5.854814900043665}, {
        4.437077755758274, 5.706062061373515}, {4.43705487454501, 
        5.591389527579071}, {4.4370319940226475`, 5.497667050804335}, {
        4.436986766723431, 5.349924815222728}, {4.436941542113451, 
        5.235497796318278}, {4.4368963201897325`, 5.141701182322221}, {
        4.436807796940675, 4.994688712496027}, {4.4367192839733445`, 
        4.8802371622666465`}, {4.436630781282569, 4.786109032220269}, {
        4.436459385117395, 4.639496061759189}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{4.436397088162275, 4.5977556077689785`}, {4.436287957222152,
         4.524646675903885}, {4.436116602970248, 4.429862738512522}, {
        4.435788500649576, 4.2831543185090215`}, {4.4354605394066295`, 
        4.167556971996789}, {4.435132719106796, 4.071733674742866}, {
        4.434513055767286, 3.9244828348408274`}, {4.433893895279751, 
        3.8076636751547763`}, {4.433275236753241, 3.71039289400255}, {
        4.432122780422499, 3.562164698872327}, {4.430972061200087, 
        3.4437305575441344`}, {4.4298230733867365`, 3.344664088353226}, {
        4.427718545737368, 3.19523606109161}, {4.425619797692033, 
        3.0750110182204176`}, {4.4235267947606856`, 2.9740239494550904`}, {
        4.422382041144811, 2.928227991619}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{4.421338986913954, 2.886500525625696}, {4.419768554826825, 
        2.823675267291237}, {4.41602867253022, 2.701976154010506}, {
        4.412306953479761, 2.59942960007299}, {4.405780295310985, 
        2.4493433279276604`}, {4.399308624518006, 2.327347209830878}, {
        4.392890940594805, 2.224423171407737}, {4.381948891555629, 
        2.0770862849061618`}, {4.371159682367636, 1.9571644764268128`}, {
        4.360518729147979, 1.8561386466683945`}, {4.3429615867131615`, 
        1.7154537142491186`}, {4.32579122256936, 1.6011984371942305`}, {
        4.308989492312588, 1.5053899675811533`}, {4.282251640675121, 
        1.3761325006276761`}, {4.256388691179185, 1.2717728828969521`}, {
        4.244456902199438, 1.2304035226043395`}}]}, 
      {Arrowheads[{{0.00696227933875862, 1.}}], 
       ArrowBox[{{4.232889581779471, 1.1902978312544499`}, {4.231340323512881,
         1.184926312907482}, {4.192887559061595, 1.0714733324137424`}, {
        4.156184172130924, 0.9806997135381612}, {4.121064491678787, 
        0.9058996112200582}, {4.0687636963592215`, 0.810824981403504}, {
        4.019563173277633, 0.7356251409203773}, {3.973085096975195, 
        0.6743449515932869}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.020000000000000007`, 1.}}], ArrowBox[CompressedData["
1:eJwBkQFu/iFib1JlAgAAABgAAAACAAAAB+YrWKfRMUBW1qg+NCpUP/ca4Wkl
3jFAmRZdXIvIWj+9Jmq2yecxQLruBj1xs2A/1Nd9h/HxMUDW1aGpDj9lP8yR
iMiUGzJACYK5jq0TeT9xiK3OvDUyQFFRaqQtboY/GegtWwNJMkC9qNFnJO6R
P1elN/L3iDJA93umi+ksrj9Uo0N0ZJ8yQIb8sXFgsbk/t291tDGtMkC4VsgO
JibCP8cbesFhrzJAxppeBqQ1wz/szFoPc7EyQI7e9P0hRcQ/qeFs5O2yMkA3
kaV3wBDFP3cZoBtuzTJA3GRCf6x81D+kp72fKtsyQCG4scL4cN4/JMhLyzHc
MkDzbtYvzW/fP09UOZEu3TJAYZJ9zlA34D85dYCWId4yQMPsDwW7tuA/MfSh
vJjeMkDTGVkgcPbgP4kaiqEN3zJAv0aiOyU24T+H919WgN8yQIlz61badeE/
1yaO6/DfMkAuoDRyj7XhP5BuzXBf4DJAr8x9jUT14T+AOS2WTO4yQGAGCfXV
1us/8Si7fg==
        "]]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{18.936948440179986`, 0.9112426078763436}, {
        18.969601127503886`, 1.2292388084752117`}, {18.988465289614844`, 
        1.5632632551476562`}, {19.00100855555866, 1.8972877017592835`}, {
        19.002814507480487`, 1.964092591073169}, {19.00448523637545, 
        2.030897480382}, {19.0060321360927, 2.0977023696850536`}, {
        19.00677597705079, 2.13110481433504}, {19.007492062410446`, 
        2.164507258983324}, {19.008181546450732`, 2.1979097036297888`}, {
        19.00884552686286, 2.231312148274308}, {19.009485048148303`, 
        2.2647145929167474`}, {19.01478584018442, 2.5202439947666657`}, {
        19.016078216011735`, 2.5782545431979305`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{19.01700789230984, 2.6199846891637852`}, {19.02047859833506,
         2.7757733968377907`}, {19.025387424256664`, 3.0313027984665037`}, {
        19.028336419605694`, 3.286832198989196}, {19.03010545228787, 
        3.542361601300297}, {19.032002430792694`, 3.797891005319817}, {
        19.033643517652237`, 4.053420405922503}, {19.03456858441987, 
        4.289481643387577}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{19.034695902612643`, 4.331221935931986}, {
        19.035230320750983`, 4.564482456221902}, {19.035871055944522`, 
        4.820020786200632}, {19.036554321785104`, 5.075563479056234}, {
        19.03726735907861, 5.331109225925644}, {19.037997408630936`, 
        5.586656717945803}, {19.038731711247962`, 5.842204646253649}, {
        19.039182250589917`, 6.000835893846055}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{19.039300800132057`, 6.042576225976465}, {
        19.039457507735577`, 6.0977517019861205`}, {19.040162038899677`, 
        6.353296576280156}, {19.040832545546152`, 6.608837960272698}, {
        19.04145626848087, 6.864374545100677}, {19.042020448509753`, 
        7.11990502190104}, {19.04251232643866, 7.375428081810721}, {
        19.042919143073494`, 7.63094241596666}, {19.043017402817593`, 
        7.712191931087771}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{19.04306788198526, 7.753932401044451}, {19.04322813922014, 
        7.886446715505797}, {19.043426555684487`, 8.14193967156507}, {
        19.043501633272427`, 8.397419975281414}, {19.043510473152914`, 
        8.619631305922239}, {19.04351989861714, 8.841872476743948}, {
        19.043528152913886`, 9.064053967203886}, {19.043533479291902`, 
        9.286086256759392}, {19.043535729303702`, 9.42355223466651}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{19.0435364125027, 9.465292735141277}, {19.04353711608006, 
        9.508278265082875}, {19.043540992837038`, 9.73064637967374}, {
        19.043544389656365`, 9.95266228172984}, {19.043546586631557`, 
        10.173797652449014`}, {19.04354862586235, 10.473617572817336`}, {
        19.04355026054991, 10.770789895783738`}, {19.043551394451615`, 
        11.068212252455925`}, {19.043551607226007`, 11.13491275426524}}]}, 
      {Arrowheads[{{0.01714471641870151, 1.}}], 
       ArrowBox[{{19.043551740378074`, 11.176653254745387`}, {
        19.04355231629531, 11.357191749510761`}, {19.043552849458372`, 
        11.642870619761625`}, {19.043553298289435`, 11.897407780260862`}, {
        19.043554101465705`, 12.302961218867232`}, {19.0435548127946, 
        12.51835272752888}, {19.043554986171014`, 12.543409319608262`}, {
        19.04355515922708, 12.5614833958006}, {19.04355533214177, 
        12.574947471302979`}, {19.043555660025575`, 12.591619973857036`}, {
        19.043555987808563`, 12.600477182085239`}, {19.043556624094222`, 
        12.607911342523394`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.01999999999999999, 1.}}], ArrowBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQfaH+xpHoJUoOIemhvb1aKg63vFkPgvhbU3aZpaqp
OJRWL9oN4vtynCudqKDi0GJzbSuI376stTJeSsUhyuvNehD/S5mYjYKIigOH
dsBqEP+OtF+cP7+Kg8i/5OUgvgZr0mx7bhWHmM6js0D8W08e1cf/U3b49slg
Iogf6O+hfvWLssPmzz/TQfwol5Nfks8qO9yLTfYG8V8otkud36zs4N4yyxjE
X/NIJathvrJD/xGXV1FA/lf+qnX8qcoOLHnP1oP456b+1OK3VnZ4mrGpBsTf
v2z767cSyg7cRzb9iQTyL9y7fuj2aSUH7sOnekF872LWW5MmKjn0X3fRAPFd
W1PaZyUCzb2g+D4cyN+88lB7xhNFh417hK+GAfnmB1Z/T+xUdHi5uvB0KJDf
+9orJMNB0UH6TPeZEJB9RSWHrZgVHT7caboUDORrrvwlu/WyggMA6CekDg==

        "]]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{9.320948662401133, 8.371750688512419}, {9.320930489733419, 
        8.145394063985467}, {9.32090304373483, 7.894488230611514}, {
        9.32087637749847, 7.699591531954818}, {9.320850208710866, 
        7.540372161199701}, {9.32079871397516, 7.282202231763227}, {
        9.320748004421127, 7.080018262483803}, {9.320647970941991, 
        6.773809330852924}, {9.320616947277024, 6.702130710051678}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{9.32059888131584, 6.660390213480939}, {9.320549045094014, 
        6.545246124271547}, {9.320352805133698, 6.197985062597837}, {
        9.320157947125212, 5.942074338501169}, {9.319881173165184, 
        5.665340472048216}, {9.31960548684214, 5.450588137454658}, {
        9.319330568378609, 5.274880499741265}, {9.319193274439924, 
        5.194876496166646}, {9.319056123494846, 5.121126724531654}, {
        9.318801203634916, 5.007377722565845}, {9.31875992343402, 
        4.990771447407208}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{9.318656164408882, 4.949031075889748}, {9.318546634818821, 
        4.904969310900114}, {9.318038132457206, 4.718104279974551}, {
        9.317530823357597, 4.561692350021256}, {9.317024584002823, 
        4.427058703246525}, {9.315995651169592, 4.198464691824348}, {
        9.314970489304848, 4.014293464164369}, {9.313948874444039, 
        3.8599617413243994`}, {9.312233574974496, 3.644814364777695}, {
        9.310527592356825, 3.4700817350945914`}, {9.308830656124332, 
        3.3230035715089628`}, {9.308228778387823, 3.27945132252754}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{9.30765199349439, 3.2377148073455375`}, {9.305988439296524, 
        3.1173389864358296`}, {9.303170715091074, 2.949995979912554}, {
        9.30037690655419, 2.8091173173124564`}, {9.295809570034052, 
        2.6159112204665007`}, {9.291304248732583, 2.4585427551285424`}, {
        9.286859120019503, 2.3261765843968463`}, {9.279766319862965, 
        2.148061607351734}, {9.272821028133524, 2.003154272669097}, {
        9.26601701371371, 1.8816218941102012`}, {9.255450298594557, 
        1.721588584214898}, {9.245206328759197, 1.5918800038249232`}, {
        9.243168490082688, 1.5696943577014126`}}]}, 
      {Arrowheads[{{0.013493862824448841`, 1.}}], 
       ArrowBox[{{9.239350533771917, 1.528128836052336}, {9.23526552810032, 
        1.4836559877904663`}, {9.220257342195023, 1.344364925661181}, {
        9.205889346798283, 1.2322044322327266`}, {9.19210810251366, 
        1.1393133523133565`}, {9.171848492501848, 1.0223085734199495`}, {
        9.152732655907846, 0.9289540840503883}, {9.13463593192625, 
        0.8523513112017818}, {9.108583772207577, 0.7574670719484113}, {
        9.084381525056006, 0.6826324742692058}, {9.061778926350053, 
        0.6218788726115503}, {9.029614136344474, 0.5472892267994489}, {
        9.000202243482017, 0.48927818567457615`}, {8.973099983635468, 
        0.44274389706829737`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], ArrowBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQXfQ0JOfbPRWH3M0aTRfXSDrMM1qy/yuQ35d9xlFk
kaSDt/6dhu9A/v3ZNqLn90k6KHY+m/IDJH/NN3DjBUmH9B0Jfj+B/G3htV3P
70g6xIWzRP4G8pXT599hYZByuBByZtcfIP9qVvLDPgkpB/E4sxkM91UcjAUz
5/MmSDns6GrJYAby7bex3lo6XcqhdtqxLyD+n+8Ku+8sknJ4d2OnCTuQv4p3
5+OIV1IO+9RnX+UE8pf+OsR4X13awUpxRyQfkF/NWRhxapq0w42TE08IAvn+
xjK2kV+kHeZdPTldBMj/vmte3Ut3GYcMto5sKSB/wfETa/fwyDos8Lw4Xw7I
f8hU9ap3u6xDm/6RR4pA/oFzGYwuwXIOfQuFq9WB/FbNC8LXFsg7BD2yqdEE
8vlFNN81Kyk4AAAnOJFI
        "]]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{10.435867363850482`, 8.109153298708977}, {
        10.435876333368725`, 8.203195720009582}, {10.435896238644654`, 
        8.482209744444633}, {10.435912838673117`, 8.785678333339622}, {
        10.435924878456818`, 9.079720223619566}, {10.43593353881371, 
        9.366673720056681}, {10.43594000056175, 9.648877127423196}, {
        10.435942233510891`, 9.778773315861176}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{10.43594295104091, 9.820513816335367}, {10.435944784231594`,
         9.92715506407724}, {10.435948410353902`, 10.202332148376952`}, {
        10.435951901739141`, 10.541161417965913`}, {10.435954720659037`, 
        10.870272457285775`}, {10.435956867113592`, 11.189665266336544`}, {
        10.435958297284037`, 11.490133835469388`}}]}, 
      {Arrowheads[{{0.008568940056522352, 1.}}], 
       ArrowBox[{{10.435958455999652`, 11.53187433594944}, {
        10.435959365192119`, 11.78932364842709}, {10.435960211022241`, 
        12.042802672050511`}, {10.4359609588357, 12.247218029035926`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.01944373024693259, 1.}}], ArrowBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQfWb2e/WjbxUdcpl7NA8GqDncYAjTBPELYxTnpIeq
OfRNT9UD8TV99ixtSlVz+C26zwTEP/X9ZYlIlZpDzmFFCxD/s8Fs89RWNYfb
lYesQPwNO55FBvepOWyd7mIP4n+8wPT401w1h/mbbzmB+O5mRbrrVqk5tH58
7griK/tyLNq9Vc3BYeYkfxB/52Mns4831RzSJu0OA/GrtjSetPqm5nAp1S4b
xJdf1c9l76vuIB4lWAniN//eUWHXp+6QeNmhCsS3/eMsKDhF3YGVOasaxO/c
c03o7Ex1h+PM2rUg/sFbFR5ti9QdqnhcO0H82K1ftt5/qO7w68yWySC+y98/
Z85Iaji8dVywDMR/emjxE/E6DYel5au2gfiv9HqK7pzVcKgP8zsK4ut9N1K8
z6PpcKUj6jGIv/mfVPKxNE2HQ0UZDMeA/PxZ2x9e6td0AADPybG3
        "]]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{19.47304964733436, 20.}, {19.473049647366818`, 
        19.90231341845669}, {19.47304964740044, 19.811019156799656`}, {
        19.473049647431335`, 19.73399491023696}, {19.47304964748722, 
        19.607682827249374`}, {19.473049647537085`, 19.50724984796774}, {
        19.47304964758228, 19.424771984381092`}, {19.47304964777586, 
        19.12519023010059}, {19.473049647927944`, 18.942499839591875`}, {
        19.473049648056758`, 18.81180936550226}, {19.47304964846834, 
        18.471570319108498`}, {19.473049648632582`, 18.3656133966618}, {
        19.473049648692808`, 18.330379980785654`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], ArrowBox[CompressedData["
1:eJxTTMoPSmViYGAQA2IQ3X1Z6YRkpbHDU7sXbk88jRxOPIPwbwRcLXF1N3J4
VasM5qcdU9joY2LkYDpBBcy3LxHz+i1i5HC8VRXMfz/v7/KXvw0dQlLVwPye
Hpca1eeGDnsWaoL5DB1xNW+XGDr8stMB86+9Mj8tVmXoINCoB9H/Yd9viyhD
B4btEP7ZNTJNpeGGDrFvIPwN3hp/D4QYOvyx1Qfz4yWllq4OMHQITIHw1Zdu
nnHMz9DhwQEI/8SjlbMcvQwdFgsbgPl7c/ikPdwMHVRSIfw3uZedc50MHaRi
jMH8ANXCT7cVDB3C/5mC+ax79e9lshk67E+2APMFGTZ0dH8wcLDfaAvmL6/e
kT77qIHDYmcnMJ+Zp8b93FIDhyeFzmC+0k8T/op5Bg4AEyeP/w==
        "]]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{19.473049656759127`, 16.57727896061059}, {
        19.473049657036285`, 16.54838428432247}, {19.473049658732307`, 
        16.391980660859836`}, {19.473049660208403`, 16.273891409426533`}, {
        19.473049661535747`, 16.178556224620284`}, {19.473049664042648`, 
        16.01918016301007}, {19.473049666219456`, 15.899476921421035`}, {
        19.473049668174678`, 15.803107833983649`}, {19.473049671808376`, 
        15.644679868418448`}, {19.47304967496719, 15.525532745043474`}, {
        19.473049677806696`, 15.429552609892815`}, {19.47304968310843, 
        15.27114771340841}, {19.473049687720753`, 15.152092801241837`}, {
        19.47304969187013, 15.056233181981304`}, {19.473049699158615`, 
        14.907658941396246`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{19.473049701461775`, 14.865918440915888`}, {
        19.47304970636085, 14.77984838373024}, {19.473049712443654`, 
        14.684433097043287`}, {19.473049723807964`, 14.527701184637301`}, {
        19.473049733754017`, 14.410080702299297`}, {19.47304974275245, 
        14.315545855765068`}, {19.473049759593007`, 14.161120317969404`}, {
        19.473049774449713`, 14.045491206949196`}, {19.473049787990462`, 
        13.952800105689027`}, {19.473049813402604`, 13.803105372084524`}, {
        19.47304983615541, 13.691547807020376`}, {19.473049857170654`, 
        13.602612087556016`}, {19.473049896687975`, 13.46234776074397}, {
        19.47304993294074, 13.358837260757198`}, {19.47304996712544, 
        13.277257209423372`}, {19.473050009267514`, 13.196298421701583`}}]}, 
      {Arrowheads[{{0.005768716714639683, 1.}}], 
       ArrowBox[{{19.473050031005393`, 13.15455792122123}, {19.47305009143908,
         13.065894832672068`}, {19.473050149915142`, 12.997576060295135`}, {
        19.473050255205813`, 12.903959211314756`}, {19.47305035802921, 
        12.83872792927617}, {19.473050459536868`, 12.790692891263632`}, {
        19.47305062601719, 12.734708133058724`}, {19.47305079148163, 
        12.698054744670287`}, {19.473050956490198`, 12.672979675625745`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwB0QEu/iFib1JlAgAAABwAAAACAAAAhFNWxphUM0BqmP8xxNW2P6VBoeju
aTNA3I8HoGiPwz8VyFXF2XYzQElCDyfvs8s/EHeFieF3M0Ad01wBY4TMPyDA
VvrgeDNAv2Oq29ZUzT9LL9ttUnozQFe8HqOEjc4/PZAlukB7M0CETGx9+F3P
P6SHWxEofDNAPu7cKzYX0D9KazZ4H5EzQBPwozHT/dw/30ezj2KcM0AzKLUb
OPLkP7W6L2s6nTNALUEyj1mX5T8BRtyMCZ4zQOxYrwJ7POY/cW/eedCeM0Bl
byx2nOHmP9CvHPMxnzNAT/rqLy005z+U2kSFkZ8zQOOEqem9huc/UzpSPu+f
M0AfD2ijTtnnP2s5ritLoDNAAZkmXd8r6D8ZLzhapaAzQIgi5RZwfug//mTf
U1KpM0AXcGnKCgTxP6snj97nrjNABxpfid3I9T/M6ZC7rq8zQOMRkK8HvfY/
FziAh2awM0Dc8cDVMbH3Pxh6MqUQsTNA67bx+1ul+D9tlQtyYrEzQFISCg9x
H/k/g44mNbGxM0DuZSIihpn5P8OkKhH9sTNARLE6NZsT+j93WMomRrIzQNPz
Ukiwjfo/Ss4RG12yM0BIlYIeerX6P5QFz/Y=
        "]]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{19.698327509993977`, 1.711015864823254}, {
        19.714248873191625`, 2.10669006401415}, {19.732565388644407`, 
        2.5239829297139216`}, {19.747831407917534`, 2.9412757944897208`}, {
        19.755471186741527`, 3.3585686569555935`}, {19.75560471915875, 
        3.3795643893507967`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{19.7558701824966, 3.421304045669064}, {19.758125160699528`, 
        3.7758615373273767`}, {19.761014176956465`, 4.1931544307144}, {
        19.763433108615526`, 4.610447298070944}, {19.764676828779912`, 
        5.027740100351287}, {19.764746711763024`, 5.090897990639741}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{19.7647928967906, 5.132638465568688}, {19.764972482690737`, 
        5.294942163453303}, {19.765305325712067`, 5.562144992292499}, {
        19.76565304437761, 5.829348127426567}, {19.765993325221046`, 
        6.0965511094131974`}, {19.766303854776073`, 6.363753478810085}, {
        19.766562319576384`, 6.630954776174922}, {19.766680338063157`, 
        6.802257389102479}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{19.76670909506488, 6.843997879676809}, {19.76674640615567, 
        6.898154542065398}, {19.766833801047618`, 7.165352317039208}, {
        19.76686846172087, 7.432587478010038}, {19.76690747874708, 
        7.699877688413425}, {19.766948238314473`, 7.9671899185898365`}, {
        19.76698812661127, 8.234491138879733}, {19.767024529825704`, 
        8.501748319623585}, {19.767025876102156`, 8.513617858011186}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{19.76703061042718, 8.555358358223055}, {19.767054834146002`,
         8.768928431161859}, {19.76707642576038, 9.035998443835018}, {
        19.767086690857063`, 9.302925327983527}, {19.76709061884808, 
        9.558576056099259}, {19.767093834758356`, 9.813922526039043}, {
        19.767096194877084`, 10.069233706946752`}, {19.76709737945173, 
        10.224978374927618`}}]}, 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{19.767097696924804`, 10.266718875406768`}, {
        19.76709813033665, 10.32370269139077}, {19.767099057574786`, 
        10.573542928522876`}, {19.767099737324457`, 10.821139530577398`}, {
        19.767100329591337`, 11.061431576405354`}, {19.767100781040202`, 
        11.29610603972308}, {19.76710160487927, 11.688029147993488`}, {
        19.767102068985572`, 11.936338894614348`}}]}, 
      {Arrowheads[{{0.0048915459121391105`, 1.}}], 
       ArrowBox[{{19.767102147001154`, 11.978079395094634`}, {
        19.767102243355275`, 12.029631522815908`}, {19.767102505501164`, 
        12.174293421530383`}, {19.7671027515958, 12.29278186144858}, {
        19.76710298943961, 12.386430544084426`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], ArrowBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQnay0LHZDgaEDAxiYOKw2g/DXPi9W6ftk7HAvGcIv
7KpU+H3d2GFaD4Q/n09MKOuQsYNy8HIwv735eM/sLGOHT68g/EsL5BhlLIwd
FLJXgPnVfosNXUWMHf6UQfha/o//mwsaO2xpgvBPrbr334bP2GH2FAi/amth
4AFOY4cdcyD8Pwe+T9zHbuzguQHCn8/Ddusbk7HDkYMQPvtP/o1H/hk5/LgE
4cf1v1q85ZeRw6yilWD+/a65r3quGzms/w/hzzkx+YTKHiOHhfWrwHzp4yKr
5y81cpjZvxrMn6Ym+ken2sghv2oNmM/TFce8KNrIQXcrhG+7y+fE5BAjBwCQ
t48I
        "]]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{17.440191130399526`, 18.288639480305296`}, {
        17.440191130456427`, 18.259285118743293`}, {17.440191130800287`, 
        18.102330846922584`}, {17.44019113109938, 17.98392273558334}, {
        17.440191131368223`, 17.888368471683542`}, {17.440191131874546`, 
        17.729028566475204`}, {17.440191132314077`, 17.609312154823982`}, {
        17.44019113270874, 17.5129094220499}, {17.440191133442596`, 
        17.354227527181823`}, {17.44019113408, 17.234872238271112`}, {
        17.440191134652512`, 17.13870439117858}, {17.44019113572078, 
        16.979852393915905`}, {17.440191136648536`, 16.86040660192849}, {
        17.440191137481804`, 16.76418209355272}, {17.440191138901895`, 
        16.61901946109095}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{17.440191139352876`, 16.57727896061059}, {
        17.440191140384368`, 16.48599180120791}, {17.440191141596255`, 
        16.38979845945379}, {17.440191143856104`, 16.231035593896834`}, {
        17.44019114581917, 16.111655775099674`}, {17.44019114758268, 
        16.015487147740586`}, {17.440191150871172`, 15.856805045986617`}, {
        17.44019115372864, 15.73749409892592}, {17.440191156296347`, 
        15.641388938246976`}, {17.440191161085323`, 15.482868846716755`}, {
        17.440191165249168`, 15.363698673643118`}, {17.44019116899297, 
        15.267724513345026`}, {17.44019117597774, 15.10954872354431}, {
        17.440191182058594`, 14.990676880931185`}, {17.44019118680746, 
        14.907658941396246`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{17.440191189419075`, 14.865918440915888`}, {
        17.44019119775267, 14.737528576356109`}, {17.44019120667385, 
        14.619284305749979`}, {17.440191214725274`, 14.524170122226744`}, {
        17.44019122977645, 14.368237673338273`}, {17.44019124298639, 
        14.251307414481795`}, {17.440191254969157`, 14.157411884449907`}, {
        17.44019127742013, 14.004632378079164`}, {17.440191297333136`, 
        13.890422618712218`}, {17.440191315571404`, 13.799043194221746`}, {
        17.4401913498406, 13.65267601946245}, {17.440191380810145`, 
        13.543968410725656`}, {17.44019140964687, 13.457648043471767`}, {
        17.440191463815665`, 13.323778594545145`}, {17.440191514177855`, 
        13.225670985934569`}, {17.44019153256204, 13.196298421701593`}}]}, 
      {Arrowheads[{{0.0030789819965913595`, 1.}}], 
       ArrowBox[{{17.440191558687275`, 13.154557921221242`}, {
        17.44019156218017, 13.148977288960499`}, {17.440191650883524`, 
        13.037445989371873`}, {17.44019173611751, 12.957839810162323`}, {
        17.440191819366383`, 12.897521422205907`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{7.837371492327208, 20.}, {7.8373714924290665`, 
        19.880125042861646`}, {7.8373714925619735`, 19.74843382657659}, {
        7.837371492986599, 19.40670286558039}, {7.837371493156152, 
        19.300611840759835`}, {7.837371493310135, 19.21336767900862}, {
        7.837371493452205, 19.139278868483487`}, {7.83737149371028, 
        19.017058538141978`}, {7.837371493941597, 18.919302028093284`}, {
        7.837371494152341, 18.83843036120735}, {7.83737149495984, 
        18.573335087288}, {7.837371495611304, 18.404005204971426`}, {
        7.837371495944617, 18.330379980785654`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], ArrowBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQbfvn5svySHmHp3Yv3J54GjmcnX8LzH++V/DlSXcj
B+XjP8H8CUunLnL8YujAmcz2CsT/+qdY8O1NQ4f4p4Jg/jrL7FrjI4YOqv0y
YL6lq0Hrto2GDhvZDMB8fonOFs3Jhg7yUxzBfPbL7dYbqwwdupcHgvnvJsd/
y08zdHh3qB/MZ+15rKOnYujwY80hMJ8hbXvY458GDkIO78H8xqldlutvGThM
K/gM5nOnJbj8vW7g8HvadzBfPn6JZ9RVA4eaT3/B/IYVfhoJFw0cKp4xvAbx
H5bNONF73sDhGBcHmC8dt/aA6Wmg+YV8YP7bioN+KccNHI4cFAHzvfi4T204
bODwRyUAzD806/mFrsUGDou/RoH5Sj9N+CvmGTgAAAaPmX4=
        "]]}, 
      {Arrowheads[{{0.018348428953089097`, 1.}}], ArrowBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQLbu38HV5pLzDqdoLvScmGzi03GoF8/ev/MwQ2WXg
IN2wHcx/zJUYMa/UwEF/o+obEN+h51UXg5+Bw4E/7WC+taXl9DsGBg4s9Y/A
fJ23K2sPSRo4SDxofQviG77yW6LzVt/h8nepdyB++D7BLad26DvMnboMzN+l
X6yo3a/vYH90/XsQnzc+/KqDn77Dvj/LPoD4Mo+Md92U03eYfGLSRxCfKbLk
wMefeg4H2x0/g/jsrdfn6hzVc7CVv/8FxG9iOh/8YL6ew46DRd9A/K3KzhsZ
WvQc4sTkfoL4UadCDI4m6jnsvr7/N4jvfGdNmLW3nsNK7th/IP435pZJh6yB
6v+IMFUA+Xpr/Z/66eo56H88xQriu+51XrBYRc9BULuBE8TnW5B+x11ez4H5
0gVeEL/UWn9Wo7SewxHvj1Ig/gL2H0YB4noOAJrQnMU=
        "]]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.008317688870060694, 1.}}], ArrowBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQrfCgI2yGk4SD3E7msANVRg7nV3SC+T1v7du/1xg5
ZKzuBfM71nV4O3QYObRbTQbz86estUufbuTQvWsamH9rA8O3uAVGDgsWzATz
U+8pOlctN3LQ2L8AzPeJeZJzdbuRw/Hdy8D8c7fY5/odMXIo114D5k9INYla
e87IoeX4OjD/3a4/suGXgfygjWA+V/Tz05uuGzlknt8M5p9Y+fD9ydtGDq0a
W8H8OWHPm9/fNXKYdHg7mP/eY2H4p4dGDs45O8H8aA2dXRlPjBxYBHdD7A88
tPz4MyMHsZ+nwPw7H76xTvtl5CBqfQvMf7n2augqDmMHJtOXYP7cgLy6+0LG
DrHqzOEg/p/eJTqdcsYOjV9lwPyL11SXfVExdjiz0wzM31muLDtBw9jBTisA
zP8t8PzBAi1jB2bOZjB/nfi0hiYdYwcAotelqw==
        "]]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], ArrowBox[CompressedData["
1:eJxTTMoPSmViYGAQBmIQnVv+8egyDnUHBjAwcVjF/gnMn8tjbb/9kbHD8VkQ
fp81y3WzE8YO8fKfwfxvO9/Hrt9k7PBk/lcwX9K+r3hftLHD0q7vYH5V/QW/
Fk1jhwjNn2C+5+L7x86zGjts84fwA7nnshxlMnZYVArhz/fJDj/z38ihfz2E
n9t4hy/4t5HD1ZMQ/lSfXJugn0YOtpy/wHyhiOurer4YOTxyhPCN10aFxHww
cphfCeHfudP1x/eNkcPnuj9gvtb9n9bGJ40crD3+gfmtVw7eubTWyOHPs/9g
/ukrZ38ETTdy2BrJfAzEn1IW4HMnx8jBdwkrmG+7y+fE5BAjBwA6aowI
        "]]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{11.516897381130637`, 18.288639480305296`}, {
        11.516897381398982`, 18.20331327377195}, {11.516897381956795`, 
        18.046375123930993`}, {11.516897382441991`, 17.927975959205394`}, {
        11.51689738287812, 17.832427561774715`}, {11.516897383699572`, 
        17.67308368933841}, {11.516897384412662`, 17.553365246018053`}, {
        11.516897385052964`, 17.456961300975724`}, {11.516897386243533`, 
        17.298281489026554`}, {11.516897387277632`, 17.178927623206548`}, {
        11.516897388206461`, 17.08276091381669}, {11.516897389939599`, 
        16.923910455961387`}, {11.516897391444788`, 16.80446610107788}, {
        11.516897392796686`, 16.70824297725631}, {11.516897394212844`, 
        16.61901946109095}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{11.51689739487535, 16.57727896061059}, {11.516897395316878`,
         16.549460898555584`}, {11.516897397505854`, 16.430060143463226`}, {
        11.516897399472084`, 16.333869990152134`}, {11.516897403138612`, 
        16.175115363374033`}, {11.516897406323725`, 16.05574269186151}, {
        11.516897409185132`, 15.959580708940107`}, {11.516897414521019`, 
        15.800916032682952`}, {11.516897419157834`, 15.681620185715412`}, {
        11.516897423324714`, 15.585529055088461`}, {11.516897431096552`, 
        15.427045686208121`}, {11.516897437854825`, 15.307907338379712`}, {
        11.516897443932137`, 15.21196274828168}, {11.516897455271337`, 
        15.053864311834744`}, {11.516897465145947`, 14.935059484432806`}, {
        11.516897467693562`, 14.907658941396248`}}]}, 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{11.516897471574461`, 14.86591844091589}, {
        11.516897474037762`, 14.839424742692199`}, {11.516897490640732`, 
        14.682135901967186`}, {11.516897505142367`, 14.56403228284295}, {
        11.516897518237496`, 14.469048631404021`}, {11.516897542723914`, 
        14.31345528021437}, {11.51689756424021, 14.1968180525064}, {
        11.516897583779048`, 14.10319397046678}, {11.516897620402528`, 
        13.951112435125795`}, {11.516897652957576`, 13.837503553930606`}, {
        11.516897682833942`, 13.746678547346116`}, {11.51689773898966, 
        13.601706542685383`}, {11.516897789924059`, 13.494190461547612`}, {
        11.516897837498878`, 13.408960228993799`}, {11.516897926783273`, 
        13.277714876752924`}, {11.516897997598525`, 13.196298421701663`}}]}, 
      {Arrowheads[{{0.004894713369338383, 1.}}], 
       ArrowBox[{{11.516898039312093`, 13.154557921221326`}, {
        11.516898090010281`, 13.107097863609678`}, {11.51689823671189, 
        12.999929502368813`}, {11.516898378325964`, 12.9238644697465}, {
        11.516898517076946`, 12.866610673026972`}, {11.516898755634449`, 
        12.794525613442161`}, {11.516898991433983`, 12.745942349734547`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], ArrowBox[CompressedData["
1:eJxTTMoPSmViYGAQBmIQvX7q2w+HMpQdGMDAxKHM6R2Yv9ZZMWfHI2OH7Z8g
fFu3oH/mJ4wdJk98D+YHleW1b9hk7MA68ROYz2uwevu+aCD/7hcwv+SFfVyL
prHD07PfwHzF03ePn2c1drj7G8L/rabHepTJ2MFH8zuYv1xgdfiZ/0YOm/Ig
/NW/z/MF/zZy0O2D8AUUc2yDfho5qN6C8Jt9ctb1fDFyYJb7AeZnfwqKivlg
5HAmAcLvPviWxe+NkcOSM7/A/Nez5GKNTxo5dH/4A+b/NT8kdnmtkUPdw39g
/m2Ow17B040c1JiZP4L4eqcMP97JMXKQPMQK5tvu8jkxOcTIAQCLy5Ta
        "]]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{9.70461228571508, 18.288639480305296`}, {9.70461228603656, 
        18.203330153621483`}, {9.704612286704945, 18.046398210964504`}, {
        9.704612287286329, 17.928004059669924`}, {9.70461228780893, 
        17.832459987367294`}, {9.70461228879326, 17.67312545894956}, {
        9.70461228964777, 17.553414488934123`}, {9.704612290415074, 
        17.457016959673567`}, {9.704612291841817, 17.298350629641465`}, {
        9.704612293081105, 17.179007571313473`}, {9.704612294194273, 
        17.082850150685697`}, {9.704612296271435, 16.92401934308308}, {
        9.704612298075512, 16.80459073249871}, {9.704612299695945, 
        16.70838113754458}, {9.704612301396406, 16.61901946109095}}]}, 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{9.704612302190684, 16.57727896061059}, {9.70461230271686, 
        16.549627635573454`}, {9.704612305340989, 16.430249781695228`}, {
        9.704612307698271, 16.334079310088132`}, {9.704612312094273, 
        16.175366283396638`}, {9.704612315913582, 16.056026953644153`}, {
        9.704612319345115, 15.959893629606722`}, {9.7046123257447, 
        15.80128954801869}, {9.704612331306915, 15.682042280905502`}, {
        9.704612336306216, 15.585992921193995`}, {9.704612345631778, 
        15.427597948076816`}, {9.704612353743386, 15.308530508765328`}, {
        9.70461236103938, 15.212646929279732`}, {9.704612374654792, 
        15.054677818669978`}, {9.704612386516347, 14.935976850071665`}, {
        9.704612389683072, 14.907658941396248`}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{9.704612394350816, 14.86591844091589}, {9.704612397200952, 
        14.840431588728787`}, {9.704612417156266, 14.683333039846111`}, {
        9.704612434595916, 14.565382579742458`}, {9.704612450351668, 
        14.47053122746268}, {9.704612479822467, 14.315220944237407`}, {
        9.704612505739354, 14.198812500236524`}, {9.704612529290102, 
        14.10538699913413}, {9.704612573449293, 13.953734741956136`}, {
        9.704612612745676, 13.840475268845966`}, {9.704612648840854, 
        13.749955961996289`}, {9.704612716701373, 13.605653691545847`}, {
        9.70461277833691, 13.49868779587249}, {9.704612835969755, 
        13.413943655841722`}, {9.704612944086673, 13.283768454636652`}, {
        9.704613037212393, 13.196298421701725`}}]}, 
      {Arrowheads[{{0.0033067181862245693`, 1.}}], 
       ArrowBox[{{9.704613090064642, 13.1545579212214}, {9.704613142152484, 
        13.114818030229896`}, {9.704613319870798, 13.009310453119577`}, {
        9.704613491651068, 12.934593947301096`}, {9.704613660107292, 
        12.878509777141}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], ArrowBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQ7SWqtyLCVMJh3W+pJ45pRg6mJ7TB/F/r2s/XxRk5
SP3VBPPl8yW6/SOMHO45qYL5uxynH+l0N3JY90kRzLdMerrQ19rIQStQHsyf
uzLuT4ChkYPEZ0mI+iU3qn1kjBx8/4mC+Z55Gw4Z8hg5tFwQAvP9w488ePLP
0MGzkQfMryx4u3X9Y0OHvDvsYL7YzE19L88ZOvwzYwHz+y51amnsM3Q4xvdp
OYj/Lj9hdk26ocMszZdg/rWNXOV8VoYOb9geg/nyeU4B9yUNHQqbHoH53Z2O
qQrihg66jBD+wZZTPYUihg5n7R6C+au+sb1PEzB04Hz+AMyfMfPWn0l8hg6W
YhD+tS3neC24DB1s4u+D+eFVb3+msBk6BKy7B+YbNRhN28Bk6HBl1w0wv5/n
rmrfIwOHJIUrYP4HB2OthJMGDt9qL4L5r7emr7m6y8ABAA6Go40=
        "]]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{6.05209600643509, 16.688082397735865`}, {6.052096006061913, 
        16.548535915434723`}, {6.05209600575271, 16.431615546677655`}, {
        6.0520960055061925`, 16.337728570861376`}, {6.052096005111507, 
        16.186403265114986`}, {6.052096004815303, 16.072020621773277`}, {
        6.052096004576941, 15.979543392612669`}, {6.052096004177704, 
        15.823965499373383`}, {6.052096003878809, 15.706934799383415`}, {
        6.052096003638555, 15.612583262624742`}, {6.052096003241957, 
        15.456419797201482`}, {6.0520960029441975`, 15.33886318348173}, {
        6.052096002704445, 15.244069452308757`}, {6.05209600230733, 
        15.086905001516765`}, {6.052096002134486, 15.01846237852152}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{6.052096002029075, 14.976721878041161`}, {6.052096002008724,
         14.968663275113661`}, {6.052096001767982, 14.873357333122296`}, {
        6.052096001369265, 14.715691140962793`}, {6.05209600106862, 
        14.597082323145463`}, {6.052096000825646, 14.501492347268842`}, {
        6.052096000422071, 14.343438373904554`}, {6.052096000116317, 
        14.224554126070588`}, {6.052095999868126, 14.128753957284255`}, {
        6.052095999453528, 13.970446144325514`}, {6.052095999136566, 
        13.851379101352505`}, {6.0520959988770855`, 13.755438287377016`}, {
        6.052095998438581, 13.596948769103514`}, {6.052095998097593, 
        13.477751024925492`}, {6.0520959978140345`, 13.381709476845485`}, {
        6.052095997583823, 13.307101858826815`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{6.0520959974550275`, 13.265361358346457`}, {
        6.0520959973245905`, 13.22308918172381}, {6.0520959969325885`, 
        13.103796563181916`}, {6.052095996597988, 13.00768127646283}, {
        6.052095996000571, 12.848960158393046`}, {6.05209599550056, 
        12.729593599437557`}, {6.052095995057938, 12.633420132297475`}, {
        6.05209599423203, 12.47461394996063}, {6.05209599350352, 
        12.355183903458453`}, {6.052095992832404, 12.258959543839913`}, {
        6.0520959915231645`, 12.100071698711961`}, {6.052095990311349, 
        11.980579429065445`}, {6.052095989156949, 11.884304117383389`}, {
        6.052095986825343, 11.725326386182347`}, {6.052095984591221, 
        11.605764299305436`}, {6.052095984364751, 11.595741339132111`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{6.05209598342162, 11.554000838651753`}, {6.052095982414555, 
        11.509430724100419`}, {6.052095977920137, 11.350342096539046`}, {
        6.052095973523307, 11.23069267332988}, {6.052095969184, 
        11.134285245683595`}, {6.052095960113258, 10.975048989406568`}, {
        6.052095951140261, 10.85528233339831}, {6.0520959422248914`, 
        10.758775002390076`}, {6.052095923468296, 10.599333488383383`}, {
        6.052095904809688, 10.479403116990753`}, {6.05209588620886, 
        10.382755704967824`}, {6.052095846943915, 10.223022302883937`}, {
        6.052095807777314, 10.102858616682868`}, {6.05209576866872, 
        10.006011180922528`}, {6.052095705851474, 9.884380819437448}}]}, 
      {Arrowheads[{{0.01999999999999999, 1.}}], 
       ArrowBox[{{6.052095683749925, 9.842640318957095}, {6.052095603342209, 
        9.725358652401264}, {6.052095520786736, 9.628223109203065}, {
        6.052095345954579, 9.467463629510151}, {6.052095171222101, 
        9.346478821432655}, {6.052094996548494, 9.248926725018704}, {
        6.052094626178002, 9.087289297609917}, {6.052094255908499, 
        8.965601844603475}, {6.052093885698767, 8.867446762302261}, {
        6.052093099590878, 8.704538008990161}, {6.052092313586493, 
        8.58183340432417}, {6.052091527643794, 8.48280577857494}, {
        6.052089870721717, 8.319367006088402}, {6.052088213907958, 
        8.195919412494929}, {6.052087833807271, 8.17302029977508}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{6.052087140959774, 8.131279799300472}, {6.052086557160679, 
        8.096108904500527}, {6.052083104283078, 7.932706564945385}, {
        6.052079651531162, 7.808656992785641}, {6.052076198863558, 
        7.708039291844625}, {6.052069061265557, 7.543947154830794}, {
        6.052061923867001, 7.418664261582489}, {6.052054786626673, 
        7.3166724135307435`}, {6.052040170783388, 7.151081269253716}, {
        6.052025555444011, 7.023819358283379}, {6.052010940567168, 
        6.919767939733076}, {6.051981326380942, 6.751643268234732}, {
        6.051951713934108, 6.621463515984987}, {6.051922103184582, 
        6.514499171185092}, {6.05190387802286, 6.461659796571511}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{6.051889481044623, 6.419919298574029}, {6.051862825229265, 
        6.342637316949725}, {6.0518035539139605`, 6.208458373749595}, {
        6.051744289194235, 6.097609423535523}, {6.051627307467921, 
        5.9207644936962325`}, {6.051510351266306, 5.781486757984842}, {
        6.0513934205332935`, 5.665784991252235}, {6.0511664103583, 
        5.4829381030137085`}, {6.050939495940313, 5.337692629361179}, {
        6.050712677148082, 5.216405263002301}, {6.050280865656303, 
        5.027179907609488}, {6.049849400106013, 4.87569422270727}, {
        6.0494238893636965`, 4.750301819151445}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{6.049253261694718, 4.708561667835172}, {6.04861605649532, 
        4.553768335678408}, {6.047815025585356, 4.396744261019864}, {
        6.047015183365714, 4.264642383124791}, {6.045564864357761, 
        4.066192391339968}, {6.044118435543999, 3.9054953595967867`}, {
        6.0426758749990634`, 3.770046025422878}, {6.040132525212596, 
        3.571331596776019}, {6.0376011022329275`, 3.409846877504383}, {
        6.035081489010487, 3.273622874530745}, {6.030766822368884, 
        3.078700017313163}, {6.029698728440168, 3.039088475132093}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{6.028573637768227, 2.9973631404859726`}, {6.026486308615146,
         2.9199520396733973`}, {6.022239384062511, 2.7860738887307357`}, {
        6.01517869549816, 2.5992810458840983`}, {6.00820874535536, 
        2.4470709579697014`}, {6.00132711454038, 2.3189171734573386`}, {
        5.990224020993879, 2.144588550303955}, {5.979342654921385, 
        2.0027531106351426`}, {5.968673895893254, 1.8837444146359503`}, {
        5.951976997827788, 1.7259508336617175`}, {5.9357731125261415`, 
        1.5980883628158278`}, {5.920032533042944, 1.4913982499124576`}, {
        5.896128835998219, 1.3534664393503009`}, {5.892330638907556, 
        1.3350657425366335`}}]}, 
      {Arrowheads[{{0.009542407527659997, 1.}}], 
       ArrowBox[{{5.883892620883363, 1.29418702885611}, {5.873212994967422, 
        1.2424486503907959`}, {5.851202617504757, 1.1505180159217707`}, {
        5.818677338856104, 1.0343464842835421`}, {5.787929655606608, 
        0.9417019028413582}, {5.7587658228486704`, 0.8656956012317918}, {
        5.7165529839093825`, 0.7712756731715489}, {5.677233738943661, 
        0.6968342287279754}, {5.6404171195336295`, 0.636400866420724}, {
        5.5876961506316265`, 0.5619699053848861}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], ArrowBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAABUAAAACAAAAXPOxvrUqJ0BucdSG81ICQGMMAU5l
KidA12YHXEUpAkCjQfcGIConQCJH+FsnBgJAKEr2noMpJ0BCf1PCPbkBQJ4T
uOgsKCdAFsdB1XQaAUD2MgDYTScnQJ+m0IeIugBA8DnxdJcmJ0DHpY6f628A
QNl2c1tZJCdAteptwfYs/z/6vh7EmCInQMuziKEP/P0/yPDs6hQhJ0BAouFh
Twn9P/I2fk8QHCdAE3oqpcJI+j91RxQp8hcnQOlygByAZ/g/qApHeEwUJ0Cj
hRd12PT2P8VpOtPyBydAaBiZfskC8z/KObD0Uv8mQL+TDl+v5vA/boRDcI73
JkDqbsiESKHuPw1aYcpo8CZAs8r2aw0c7D8AfY4QB+0mQB/E+zyxB+s/X4s8
JMHpJkBbvGM7CgvqPxrqrqXW5SZAbArVWUrw6D8GHL9WLNImQF1tTLl3SOQ/
5YaUyA==
        "]]}, 
      {Arrowheads[{{0.011531213502960295`, 1.}}], ArrowBox[CompressedData["
1:eJwBkQFu/iFib1JlAgAAABgAAAACAAAAV2PfFsHLJkBCJ1QEcgLjPxwnRR08
xiZAnXUDJzz44T/UOc5Od7wmQAFZGdX3W+A/QHLuLWazJkDa4+WaCg/eP2X8
vMEGryZAgDJz9iXZ3D9mOSmMzKomQBwh856/vNs/OsWvIwOkJkCFWxj3Ryja
P5QQ6n2MnSZAHGubhoHA2D+Y6kGHMZEmQDrWqoFVOdY/LoUvCuKFJkCKb1IO
ay7UP8rVhgdyeyZAGQL/Shx+0j8HxY6gnmgmQHhqqRwlqs8/O3Ls7BFYJkDM
8lfEo7fLPw4nfw9KSSZANb+qbLCpyD/4ekWw4jMmQIktsMaK3sQ/MlXRY1Qh
JkDCk2Qz0RvCP2AdcafvECZA7qKqx9sAwD87M+sc+PclQFLI8+nljLo/kspS
qMDiJUB+oFq8a7e2P01Y5I5I0CVAEvmPhC7dsz8kouy/L7MlQEcH9xyVFrA/
cdWuvAObJUAyHP14aherPxTU8SZOhiVAuyoGOMZppz+OD7TbGWQlQMmntyY/
ZKI/5iuuoA==
        "]]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], ArrowBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQbfXh7QPPSWfsGcDAxOGL5xsw31AhMeLJD2MHfqGn
YD734S9Bb24bO2T+vgfms9+NSuY5YuyQuu0mmF8qxJ5yYL2xw6qbF8B8wdUb
Djn0GTu8nHMSzL+eOiO9rNjYoazrMJgfIrJeIyLW2EEgaB2Yv9BJeNUmQWOH
3vkLwPwnczOCox4ZOWTmTQPzTd8es9i038iBp2cqmH9VMU9i2x4jh5J1U8B8
cea9J07tNHJ4Ez8ZzN/0VPhz8lYjB/7jk8D8GcH9UxM3Gzm4RU0E8/mM9sVN
X2fk4Co5AcyXFrt4NXGVkcORh31gfnUGd5PvMiOHSc4tYD5Px02pR01GDgH3
qiHhM3VVpXy6kUOtZRmYb7vL58TkECMHALyHomQ=
        "]]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.22321437320162646`, 18.288639480305296`}, {
        0.22321437318069307`, 18.14189077802453}, {0.22321437316242268`, 
        18.014799016013693`}, {0.2232143731477535, 17.913266350469023`}, {
        0.2232143731245749, 17.75357907367086}, {0.22321437310700734`, 
        17.633146957800815`}, {0.22321437309279177`, 17.53601334170147}, {
        0.22321437306906425`, 17.37439815672465}, {0.22321437305118882`, 
        17.253065403823165`}, {0.22321437303677147`, 17.15542804304499}, {
        0.2232143730130662, 16.99524045889751}, {0.22321437299520058`, 
        16.87480026597503}, {0.22321437298078908`, 16.77779756242011}, {
        0.2232143729571644, 16.61901946109095}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.22321437295094393`, 16.57727896061059}, {
        0.22321437293907528`, 16.497641601850823`}, {0.22321437292463006`, 
        16.40082000705026}, {0.22321437290080137`, 16.241268491352905`}, {
        0.22321437288286577`, 16.121310630109708`}, {0.2232143728684085, 
        16.02468814357556}, {0.2232143728445501, 15.86534777183941}, {
        0.22321437282659767`, 15.74554388993561}, {0.22321437281212939`, 
        15.649040492887252`}, {0.22321437278825282`, 15.48986166557561}, {
        0.22321437277029002`, 15.370172824966568`}, {0.2232143727558149, 
        15.27375734457606}, {0.22321437273192493`, 15.114686234634735`}, {
        0.22321437271395436`, 14.995074759478314`}, {0.22321437270081756`, 
        14.907658941396246`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.22321437269454358`, 14.865918440915888`}, {
        0.22321437267557423`, 14.739723048848633`}, {0.22321437265759758`, 
        14.620165608888485`}, {0.22321437264311286`, 14.523850888588559`}, {
        0.22321437261920452`, 14.364907071371645`}, {0.2232143726012219, 
        14.245386736875759`}, {0.22321437258673238`, 14.149100455361644`}, {
        0.2232143725628144, 13.990192414916416`}, {0.22321437254482393`, 
        13.870697701377642`}, {0.22321437253032736`, 13.77443105083612}, {
        0.22321437250639478`, 13.615547642636193`}, {0.22321437248839096`, 
        13.496070573637532`}, {0.22321437247388157`, 13.399817444685127`}, {
        0.2232143724499221, 13.240951024162008`}, {0.22321437244318304`, 
        13.196298421701542`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.22321437243688347`, 13.154557921221183`}, {
        0.2232143724318922, 13.12148612463514}, {0.22321437241735714`, 
        13.025242322870675`}, {0.22321437239334346`, 12.866387629261133`}, {
        0.22321437237525993`, 12.746931133996828`}, {0.2232143723606715, 
        12.650693776507726`}, {0.22321437233654504`, 12.491847208291516`}, {
        0.22321437231834915`, 12.372396540896903`}, {0.2232143723036485, 
        12.276163656293818`}, {0.22321437227928484`, 12.117322760496263`}, {
        0.223214372260852, 11.997876168585794`}, {0.2232143722459145, 
        11.901646418024843`}, {0.22321437222105, 11.742809545052442`}, {
        0.22321437220211646`, 11.623365853456347`}, {0.22321437218667836`, 
        11.527138341991996`}, {0.22321437217979084`, 11.484937902006838`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.2232143721729784, 11.44319740152648}, {
        0.22321437216075515`, 11.368304412190705`}, {0.223214372140763, 
        11.248862856678352`}, {0.22321437212426634`, 11.152637006639571`}, {
        0.22321437209610448`, 10.993805357598537`}, {0.22321437207387373`, 
        10.874365476774173`}, {0.22321437205513847`, 10.77814094604073}, {
        0.22321437202224234`, 10.619311238780798`}, {0.22321437199527733`, 
        10.499872808742042`}, {0.22321437197180782`, 10.403649442295068`}, {
        0.22321437192889948`, 10.244821613268101`}, {0.22321437189192223`, 
        10.125384615902439`}, {0.22321437185844042`, 10.029162423876922`}, {
        0.22321437179435774`, 9.870336675986405}, {0.2232143717472468, 
        9.773577382312133}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.22321437172537692`, 9.731836881831775}, {
        0.22321437168154976`, 9.654680455567123}, {0.22321437157268662`, 
        9.495857286967478}, {0.22321437146975434`, 9.376423939863727}, {
        0.22321437137031738`, 9.280204818605062}, {0.22321437116675125`, 
        9.12138509336903}, {0.22321437096911573`, 9.001954481709891}, {
        0.22321437077497536`, 8.905737692438082}, {0.22321437037112996`, 
        8.746922763110476}, {0.22321436997321484`, 8.627495977926081}, {
        0.22321436957879465`, 8.531282463830843}, {0.22321436875140024`, 
        8.372474363228614}, {0.22321436792993563`, 8.253053038300745}, {
        0.22321436711196563`, 8.156844207116158}, {0.22321436608616615`, 
        8.06221686261743}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.2232143656336819, 8.020476362137071}, {
        0.22321436540245504`, 7.999146282243805}, {0.22321436369879924`, 
        7.88033981410516}, {0.2232143619986057, 7.78453277339981}, {
        0.22321435847051121`, 7.628618004604425}, {0.2232143549481521, 
        7.510805079135106}, {0.22321435142920323`, 7.415648803820265}, {
        0.22321434416935912`, 7.261501320549777}, {0.22321433691513315`, 
        7.144681764767401}, {0.22321432966426594`, 7.050179129775394}, {
        0.22321431480642748`, 6.8978546384979325`}, {0.22321429995408784`, 
        6.782068437381954}, {0.22321428510505414`, 6.688248862099461}, {
        0.22321425489612334`, 6.5377975903335495`}, {0.22321422469257216`, 
        6.423083040935963}, {0.2232142012651436, 6.350856342922739}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{0.2232141859279754, 6.309115842442384}, {0.2232141335147144,
         6.181454696259787}, {0.22321407254242137`, 6.067855603588288}, {
        0.22321401157333756`, 5.975493960863807}, {0.22321388943197645`, 
        5.82896722935813}, {0.22321376729580533`, 5.716533223558641}, {
        0.22321364516283457`, 5.62495609551134}, {0.22321340246923557`, 
        5.480495858039899}, {0.22321315978089387`, 5.369283990659197}, {
        0.2232129170958891, 5.2785366034808066`}, {0.22321243888679523`, 
        5.136225692818275}, {0.2232119606835902, 5.026302310667184}, {
        0.22321148248442393`, 4.9364381207812915`}, {0.2232105483569385, 
        4.796372466896443}, {0.22320961423811048`, 4.6878156053472635`}, {
        0.22320910661821888`, 4.639495823241993}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{0.223208665113976, 4.597755322763973}, {0.2232068717619655, 
        4.461190346462535}, {0.22320506341711224`, 4.354092724146896}, {
        0.2232032550898954, 4.2661998463620465`}, {0.22319978680814104`, 
        4.13098164478642}, {0.22319631858514458`, 4.0254543656681046`}, {
        0.22319285041927348`, 3.9386795032877537`}, {0.22318626259870866`, 
        3.806108733556858}, {0.22317967497846486`, 3.702285786409465}, {
        0.22317308755698043`, 3.6167436333286287`}, {0.22316069931375665`, 
        3.4870083759674744`}, {0.22314831176800023`, 3.3850519860906108`}, {
        0.22313592491819392`, 3.3008831709150734`}, {0.22311287075042033`, 
        3.1742085610647965`}, {0.2230898189882693, 3.074315378660073}, {
        0.22306676963008754`, 2.9916923195916967`}, {0.22304490101315266`, 
        2.9281353183827763`}}]}, 
      {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAABUAAAACAAAArrh9w0OMzD94xuYqVhcHQCL7X6wP
jMw/m+NAQWDyBkBnjQy6q4rMPxNYc++BKgZAz3c12UeJzD/OqsCT5IQFQIsH
Dta/hsw/qwFLh8KPBEB6w90MOITMPyF8guwwzQNAV6+efbCBzD/TmzW8sisD
QGDmD+Qifcw/KWBWwdE+AkCXoTgGlnjMP/ZV0UtAggFAGUn54wl0zD/+EXPc
guUAQFPw22Dza8w/LcyPwMsBAEDBbCMv32PMP4uWZ3EcmP4/5vkgTs1bzD8m
qbkXo2n9P7+FfU6gTcw/QCxZQ6G2+z/R7a1zej/MP0RL9UO6Wvo/cNsBulsx
zD+S9f5IAzn5P0YmIp3fGMw/rcp4psyc9z8nAZvveADMP08o6Z2qUvY/A3U2
nifoyz+G+6YYuD/1P8+oc1+Ovss/gfdR5+q88z/DegfAXLXLP7iFugwEePM/
bk+low==
        "]]}, 
      {Arrowheads[{{0.008768920974819431, 1.}}], 
       ArrowBox[{{0.2157761349181681, 1.1750660414720455`}, {
        0.2154907725967719, 1.1579572187435008`}, {0.21423613799822278`, 
        1.0949848919799006`}, {0.2121207930144345, 1.0074419029893074`}, {
        0.2100264900162215, 0.9373552549217727}, {0.20795301512144626`, 
        0.8791327053006411}, {0.20451198488916011`, 0.7991968541640082}, {
        0.20112828483446318`, 0.7353671874738268}, {0.1978009406322118, 
        0.6825241590420241}, {0.19237731336242334`, 0.6109200060411099}, {
        0.1871032940606373, 0.554040504124367}, {0.1819746839017713, 
        0.5072230125274176}, {0.17379258990351423`, 0.4446666592401621}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{8.6861791080677, 10.885586732479334`}, {8.686178253224169, 
        10.74356185274366}, {8.686177455418902, 10.629148649889332`}, {
        8.68617619579025, 10.46891553799929}, {8.6861750384907, 
        10.358026663812788`}, {8.686173909134084, 10.260548006352776`}, {
        8.686171691568335, 10.085257287845508`}, {8.686169541433589, 
        9.942130019877892}, {8.68616743622943, 9.820326720319217}, {
        8.686162404295802, 9.57812353309101}, {8.68615748741016, 
        9.389928546571568}, {8.686152641402261, 9.234794371921021}, {
        8.686151921450174, 9.2159667135422}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{8.686150325332388, 9.174226213092357}, {8.686143183631984, 
        8.987461707491859}, {8.686133841466809, 8.793476907450147}, {
        8.686124572349831, 8.633014999730085}, {8.686106584330462, 
        8.379542489239517}, {8.68608871566149, 8.180263464267082}, {
        8.686070923262113, 8.015378576046245}, {8.68603716283359, 
        7.761061529016255}, {8.686003523583507, 7.560387495264898}, {
        8.685992265585483, 7.504606203102983}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{8.68598384135499, 7.46286570347273}, {8.685969963246901, 
        7.394102251897295}, {8.685907329984138, 7.1416224631025855`}, {
        8.685844823489822, 6.94163077930046}, {8.68578240285784, 
        6.775591749548322}, {8.68566765664768, 6.526742992077819}, {
        8.685553059580892, 6.328813516284495}, {8.685438572468648, 
        6.164111843610728}, {8.685231100542044, 5.920058498656487}, {
        8.685096290954096, 5.793245974192104}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{8.685051918235276, 5.751505497297216}, {8.685023856713876, 
        5.72510861838594}, {8.684816803620915, 5.562484973124353}, {
        8.684446916822543, 5.3241144641750395`}, {8.684077513876403, 
        5.132872206827256}, {8.6837085588162, 4.972937218985018}, {
        8.683059190994346, 4.741086222260827}, {8.682411091905033, 
        4.554274825296965}, {8.6817642241845, 4.397664459803031}, {
        8.68064374278335, 4.173294130476772}, {8.680081326153703, 
        4.081894591761221}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{8.679824485610506, 4.040154881492866}, {8.679526832146879, 
        3.991782575556929}, {8.67841343934037, 3.8392907901672833`}, {
        8.676518233391414, 3.623641433675956}, {8.674633036836974, 
        3.448583936641713}, {8.672757715209496, 3.301289780735772}, {
        8.66962698298128, 3.096025240850211}, {8.666523292516317, 
        2.928992121232417}, {8.663446146493257, 2.7883775063156957`}, {
        8.65842012115113, 2.5956910587811}, {8.653463202410233, 
        2.4387559971514077`}, {8.650947277772413, 2.3708470229884466`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{8.649401915660585, 2.3291351393544732`}, {8.648573453693265,
         2.3067735783251457`}, {8.640780752112304, 2.1293738478165043`}, {
        8.633152487066184, 1.9850729085106784`}, {8.62568169584285, 
        1.8640779633620317`}, {8.614093425971953, 1.7049264691426558`}, {
        8.602863920441775, 1.5759716138683348`}, {8.59197114508218, 
        1.4684136912548595`}, {8.57554417929137, 1.3301242090639906`}, {
        8.559825865457599, 1.2188178689810272`}, {8.544756281669612, 
        1.1266742330647264`}, {8.522621485495906, 1.0107072223229574`}, {
        8.501747139775912, 0.9182297666458313}, {8.48199435210262, 
        0.8423836842474951}, {8.453568176971762, 0.7484774173514017}, {
        8.429241291064606, 0.680259764355927}}]}, 
      {Arrowheads[{{0.0027706598178591116`, 1.}}], 
       ArrowBox[{{8.413666528268166, 0.641540048033222}, {8.402530949024833, 
        0.6143989846581066}, {8.36745425715915, 0.5406550092167316}, {
        8.335391379837166, 0.48334041726330934`}, {8.30585375139821, 
        0.43738872308469257`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{16.667725171806214`, 0.44190124625990107`}, {
        16.672618421205282`, 0.4568445945646161}, {16.67731235222961, 
        0.47178794286868864`}, {16.681819879037, 0.4867312911721779}, {
        16.686152721046266`, 0.5016746394751358}, {16.773694189731867`, 
        0.8547251976416306}, {16.83935407122057, 1.2077757557242603`}, {
        16.88313236551238, 1.560826313723024}, {16.905029072607295`, 
        1.9138768716379229`}, {16.909470134431057`, 2.056988566973377}, {
        16.910299140076752`, 2.0885328946243}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{16.911395729213346`, 2.130258988050552}, {
        16.913231203764678`, 2.200100262284209}, {16.915955620786352`, 
        2.343211957519289}, {16.91828345489895, 2.486323652697003}, {
        16.924225374970447`, 2.893178513711115}, {16.928815450597387`, 
        3.300033370658263}, {16.93205368177978, 3.7068882235384475`}, {
        16.932484129123747`, 3.7997268687316312`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{16.93267765730818, 3.841466920566681}, {16.93394006851762, 
        4.113743072351668}, {16.93502855057033, 4.52059786644155}, {
        16.935873067697315`, 4.927452555151715}, {16.936473619898578`, 
        5.334307138482164}, {16.936628553354005`, 5.511081169549689}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{16.936665136767573`, 5.552821653998299}, {
        16.936830207174122`, 5.741161616432899}, {16.937041232206354`, 
        6.148014676281297}, {16.937205097677698`, 6.5548650053047375`}, {
        16.93732180358815, 6.961712603503222}, {16.93736637276897, 
        7.2224414926000655`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{16.937373507919556`, 7.26418199247058}, {
        16.937391349937702`, 7.3685574708767465`}, {16.937419603926607`, 
        7.687116323559444}, {16.93743438034919, 8.00509771982619}, {
        16.937438789413065`, 8.322634918849902}, {16.937435941325838`, 
        8.639861179803486}, {16.9374294561206, 8.933802008448732}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{16.93742847420708, 8.975542508917485}, {16.937420914528545`,
         9.273913924191922}, {16.937414956233706`, 9.591006925972593}, {
        16.93741418161822, 9.908322026374785}, {16.93741605030254, 
        10.223099440158478`}, {16.937417262136375`, 10.536081416839805`}, {
        16.93741763408339, 10.645162527970612`}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{16.937417776411003`, 10.686903028450729`}, {
        16.93741830238667, 10.841156210560762`}, {16.93741900929778, 
        11.14036106994068}, {16.937419680624473`, 11.37937796750045}, {
        16.937420265554252`, 11.602172082779955`}, {16.937420764087122`, 
        11.808743415779194`}, {16.937421176223076`, 11.999091966498167`}, {
        16.937421531998886`, 12.167092038222444`}, {16.9374218663757, 
        12.303955884455748`}, {16.937422029661818`, 12.356523047659547`}}]}, 
      {Arrowheads[{{0.002500958724530815, 1.}}], 
       ArrowBox[{{16.937422159317745`, 12.398263548139704`}, {
        16.937422188317555`, 12.407599539905576`}, {16.937422710850626`, 
        12.515950098519015`}, {16.937423228164473`, 12.566580969114527`}, {
        16.93742374443941, 12.587604892676001`}, {16.937424105757273`, 
        12.596173240407605`}, {16.937424828352075`, 12.60704608578306}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{15.151626048382154`, 0.26063836953313085`}, {
        15.291984949261266`, 0.5169275431529581}, {15.367726916484758`, 
        0.7732162855104054}, {15.376024948182506`, 0.8244739898329116}, {
        15.383593806704159`, 0.8757316922851819}, {15.390521772165233`, 
        0.9269893931799537}, {15.393835560762835`, 0.9526182432723357}, {
        15.397012145159158`, 0.9782470930504259}, {15.400059280300082`, 
        1.0038759425389268`}, {15.402984121641303`, 1.0295047917600288`}, {
        15.405793285029473`, 1.0551336407337217`}, {15.436251714570385`, 
        1.3624207188127595`}, {15.462894932099617`, 1.669707790430504}, {
        15.478335475986265`, 1.87755246664197}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{15.481427808853326`, 1.9191782622234375`}, {
        15.485722937617162`, 1.9769948555869556`}, {15.504735731123024`, 
        2.2842819142821136`}, {15.519933312617205`, 2.591568966515979}, {
        15.531315682099702`, 2.898856012288552}, {15.538882839570514`, 
        3.2061430515998306`}, {15.542634785029644`, 3.5134300844498165`}, {
        15.54313781508686, 3.5873472337308887`}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{15.54342186608668, 3.6290867676930727`}, {15.54472597249516,
         3.820717121965516}, {15.546981725302157`, 4.128004164745455}, {
        15.548908347426188`, 4.435291196996915}, {15.5500121428428, 
        4.742578202927174}, {15.550610156560879`, 5.049865280521908}, {
        15.551132280001303`, 5.298684918202245}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{15.551219868127133`, 5.340425326785188}, {15.55125496827673,
         5.357152418176186}, {15.551806183997037`, 5.664439435711378}, {
        15.552123409728466`, 5.971726152948847}, {15.55229438171056, 
        6.314139274454753}, {15.552415690109362`, 6.656551820449793}, {
        15.552476796310842`, 6.998960961122457}, {15.552478200456736`, 
        7.010044581326434}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{15.552483488417788`, 7.051785081471835}, {15.55252017438369,
         7.341365611679886}, {15.552521270199964`, 7.350065752012535}, {
        15.552522715481693`, 7.361665932292262}, {15.55253018625424, 
        7.425466691888372}, {15.552536560338712`, 7.483467141115582}, {
        15.552557909314363`, 7.773452650443619}, {15.552572243992199`, 
        8.063427001899639}, {15.552584198812937`, 8.353353569433706}, {
        15.552592228963006`, 8.643244561729132}, {15.552594029797676`, 
        8.721405095897067}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{15.552594991507332`, 8.763145596366346}, {
        15.552600556418481`, 9.004676057365485}, {15.552602936514983`, 
        9.364744011206009}, {15.552602937667897`, 9.724266548328199}, {
        15.552604128292604`, 10.084061793809557`}, {15.552605803418032`, 
        10.384078313040554`}, {15.552605986790091`, 10.432765615501726`}}]}, 
      {Arrowheads[{{0.020000000000000007`, 1.}}], 
       ArrowBox[{{15.552606143998258`, 10.474506115981788`}, {
        15.552606924927156`, 10.681851344522858`}, {15.552607894517298`, 
        10.970533917226435`}, {15.552608578289352`, 11.252408354827967`}, {
        15.552609742269796`, 11.672842927540412`}, {15.552610619125558`, 
        12.031709533256883`}, {15.552610882621178`, 12.144126135189214`}}]}, 
      {Arrowheads[{{0.0026108373177188534`, 1.}}], 
       ArrowBox[{{15.552610981391563`, 12.185866635669456`}, {
        15.552611310749942`, 12.30778690170618}, {15.552611635887695`, 
        12.403821948297225`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{1.660892211106932, 20.}, {1.6608922111062003`, 
        19.97696376956437}, {1.6608922111032807`, 19.88504090099111}, {
        1.6608922111008197`, 19.8075675379956}, {1.6608922110967879`, 
        19.680640878986733`}, {1.660892211093585, 19.579817515667003`}, {
        1.660892211090958, 19.49712522630983}, {1.6608922110812698`, 
        19.19218833724357}, {1.6608922110754047`, 19.0076030727232}, {
        1.660892211071222, 18.875970370906597`}, {1.660892211060357, 
        18.534055437906527`}, {1.6608922110569802`, 18.42779521966908}, {
        1.6608922110542021`, 18.340379699913015`}, {1.6608922110538844`, 
        18.330379980785654`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], ArrowBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQzZ3HtY158i/7p3Yv3J54GjmUJEL4Ul38sxVcjBw+
ykD4QUIvth1UMXKQf8YJ5pcJncxazm3ksHMHhF8473jovW+GDtfUIHy9Q/Jy
QlsMHQ6f4ADzf5ho9//vMHR42AThh51g+s6QaehwqQbCn7oykM86zdDhSRmE
X6LGatKSbOjwMRfCF7+nlZsdb+hwOhPCr3+SldQaa+jwPB7CZ5QoFv4XYehg
Gg7hv3apn8UUauhwzA/Cl00Qfq4aaOgQxgrhv2L7q92mb+hQf5odzJ9hc0SA
W9TQYe1sCP8j9/cstf8GDi9tIXyxVc/2WFwxcCj5wQbmS8vxhuVsMXBoOAHh
K/004a+YZ+AAAINdjjU=
        "]]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{1.6608922109981652`, 16.57727896061059}, {1.660892210994088,
         16.449012244481867`}, {1.6608922109903324`, 16.330869273612507`}, {
        1.6608922109872999`, 16.235486937429073`}, {1.6608922109822295`, 
        16.076007722316323`}, {1.6608922109784203`, 15.956213863291296`}, {
        1.6608922109753532`, 15.859760021058394`}, {1.6608922109703073`, 
        15.701106336101494`}, {1.660892210966511, 15.581763987670099`}, {
        1.6608922109634512`, 15.485602658562634`}, {1.6608922109583946`, 
        15.326724513197828`}, {1.6608922109545905`, 15.20725934355452}, {
        1.6608922109515247`, 15.11101843860212}, {1.6608922109464623`, 
        14.952201869616866`}, {1.6608922109450412`, 14.907658941396246`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{1.6608922109437094`, 14.865918440915888`}, {
        1.6608922109426518`, 14.832770437202395`}, {1.6608922109395792`, 
        14.736551414425039`}, {1.6608922109345001`, 14.577718268054243`}, {
        1.6608922109306732`, 14.45827779038417}, {1.660892210927584, 
        14.362052920086388`}, {1.6608922109224709`, 14.203224457203524`}, {
        1.6608922109186095`, 14.083786563727099`}, {1.660892210915486, 
        13.987563379166506`}, {1.6608922109103001`, 13.828733761462377`}, {
        1.6608922109063662`, 13.709295253031135`}, {1.66089221090317, 
        13.613071679350615`}, {1.6608922108978306`, 13.454242479603385`}, {
        1.660892210893743, 13.334804215584326`}, {1.6608922108903934`, 
        13.238580809369182`}, {1.6608922108888855`, 13.196298421701542`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{1.660892210887397, 13.154557921221183`}, {1.660892210884729,
         13.079751592980962`}, {1.6608922108803168`, 12.960313336322196`}, {
        1.6608922108766424`, 12.864089944913225`}, {1.6608922108702913`, 
        12.705260838782172`}, {1.660892210865192, 12.585822662076222`}, {
        1.6608922108608306`, 12.48959933490264}, {1.6608922108530269`, 
        12.33077032773295}, {1.660892210846475, 12.211332230720817`}, {
        1.660892210840661, 12.115108971763153`}, {1.660892210829785, 
        11.95628010827271}, {1.6608922108201611`, 11.836842124974547`}, {
        1.6608922108112751`, 11.740618962779049`}, {1.6608922107939021`, 
        11.581790296621088`}, {1.6608922107808295`, 11.484937902006838`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{1.6608922107747186`, 11.44319740152648}, {
        1.6608922107623978`, 11.366129443705619`}, {1.6608922107312845`, 
        11.207301059657219`}, {1.660892210701423, 11.087863459522247`}, {
        1.6608922106722994`, 10.991640625754044`}, {1.6608922106121276`, 
        10.832812647768488`}, {1.6608922105532076`, 10.713375372693283`}, {
        1.6608922104950254`, 10.617152817996669`}, {1.6608922103733992`, 
        10.458325427876163`}, {1.6608922102530248`, 10.338888623609128`}, {
        1.6608922101333883`, 10.242666473284968`}, {1.6608922098817958`, 
        10.083839936180663`}, {1.6608922096314551`, 9.964403815238676}, {
        1.6608922093818523`, 9.868182251941997}, {1.660892209068271, 
        9.773577382312133}}]}, 
      {Arrowheads[{{0.02000000000000001, 1.}}], 
       ArrowBox[{{1.660892208929916, 9.731836881831775}, {1.660892208855403, 
        9.70935695405716}, {1.6608922083302056`, 9.589921825923954}, {
        1.660892207805746, 9.493701115609714}, {1.660892206698021, 
        9.334877618976424}, {1.6608922055915476`, 9.21544393400357}, {
        1.660892204485812, 9.11922446365566}, {1.660892202148792, 
        8.960403585888002}, {1.6608921998130237`, 8.840971999199246}, {
        1.6608921974779933`, 8.744754331742646}, {1.6608921925412463`, 
        8.585937262047509}, {1.6608921876057512`, 8.466508726494894}, {
        1.6608921826709937`, 8.370293680670423}, {1.6608921722400924`, 
        8.211531998000046}, {1.6608921618104422`, 8.092135342116096}, {
        1.660892158566797, 8.06221686261743}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{1.6608921540414543`, 8.020476362137071}, {
        1.6608921513815293`, 7.995941954221117}, {1.6608921296255956`, 
        7.839042376432706}, {1.6608921078708867`, 7.720676685137481}, {
        1.6608920861169043`, 7.625156083957035}, {1.6608920410157646`, 
        7.4699803061180985`}, {1.660891995915827, 7.352578104677966}, {
        1.6608919508166067`, 7.257689265834239}, {1.6608918579847343`, 
        7.104306797899484}, {1.6608917651540447`, 6.987914504907965}, {
        1.660891672324067, 6.893690330634255}, {1.660891482630907, 
        6.7421445631550085`}, {1.6608912929389292`, 6.626795228397637}, {
        1.6608911032476767`, 6.5332604719011576`}, {1.6608907185300923`, 
        6.383603017822692}, {1.6608906082785089`, 6.350856342924015}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{1.660890467746492, 6.309115842443893}, {1.6608903338137648`,
         6.26933544802441}, {1.6608899490982516`, 6.176519275346542}, {
        1.6608891748790402`, 6.0288063660977675`}, {1.660888400661466, 
        5.915663425469552}, {1.6608876264451, 5.823598500079753}, {
        1.6608860808101675`, 5.677892681689221}, {1.6608845351784556`, 
        5.5659226170869776`}, {1.66088298954955, 5.474646213191023}, {
        1.660879929320041, 5.331017645581529}, {1.6608768691000033`, 
        5.220275300879075}, {1.6608738088890378`, 5.129830420885654}, {
        1.6608678015745866`, 4.988358634552422}, {1.6608617942936301`, 
        4.878907062073763}, {1.6608557870457832`, 4.7893439119769186`}, {
        1.6608440987191002`, 4.650120004155859}, {1.6608429498576502`, 
        4.639495824443726}}]}, 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{1.6608384361866726`, 4.597755324207413}, {
        1.6608324105163623`, 4.542032500310482}, {1.6608207224371974`, 
        4.45341036798406}, {1.6607981890713206`, 4.31653975636465}, {
        1.6607756561633933`, 4.209902433794537}, {1.6607531237130444`, 
        4.122292077875041}, {1.6607100962515247`, 3.9878979321493055`}, {
        1.6606670704572135`, 3.8828129527894166`}, {1.6606240463296558`, 
        3.796299626773355}, {1.6605426994781454`, 3.6645271243558994`}, {
        1.6604613585832873`, 3.5611167477428642`}, {1.6603800236439714`, 
        3.475804016673838}, {1.6602278213312958`, 3.3468256053385}, {
        1.6600756398689311`, 3.245237251057502}, {1.659923479251417, 
        3.1612518085735983`}, {1.6596417900348628`, 3.03527372573121}, {
        1.6593601722336966`, 2.935686328812806}, {1.6593344078637215`, 
        2.928136534192686}}]}, 
      {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBUQGu/iFib1JlAgAAABQAAAACAAAAiQ3S3wyM+j+S3V/uVhcHQOjidQeW
i/o/NmsUMVLTBkCMz12ceYn6P8KjMo341wVA5IZxcV2H+j+2zai5jxAFQNVG
o4ZBhfo/+0ypqAdrBEBDy3DIcIH6P+fCvsPydgNAM03c26B9+j+K7L5worQC
QFC+lMDRefo/JTdhXwcTAkCbsW2MA3P6P8PlfYz3JgFAOV8p8zds+j/vXetN
bmoAQFWr/PJuZfo/E9epjb2a/z85m05FeFn6P6WvIEmC1P0/wySDpIlN+j8j
TyFms2j8P7N+4wajQfo/0oxLYj45+z8LH3gT8yz6PyEYXfA3h/k/cW3hMlsY
+j8E9Y7p1yr4P0bSIzPbA/o/1MLNgRMI9z8AE4MFxeD5P6Jn2FIwbfU/1MMb
H/S9+T/nbQ4vCCP0P0C0jztnqfk/Chv2BDF/8z+fIJ3g
        "]]}, 
      {Arrowheads[{{0.009770405363406735, 1.}}], 
       ArrowBox[{{1.598303677116189, 1.1771864044971334`}, {1.586250699781024,
         1.0975519600935297`}, {1.572242381931817, 1.0222685344595175`}, {
        1.5584115496153963`, 0.9595889125673325}, {1.535592879192991, 
        0.8735418531669847}, {1.5132453970088109`, 0.8046696555554819}, {
        1.4913525146901705`, 0.7475830172342111}, {1.456024174824348, 
        0.6705847598757213}, {1.421836085218422, 0.6093734749788342}, {
        1.3887276998299596`, 0.559022512028557}, {1.3366075954428083`, 
        0.49241961878481166`}, {1.2870269015431268`, 
        0.44006100778168844`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.02, 1.}}], 
       ArrowBox[{{18.15677883073016, 0.4759105884681802}, {18.16198596206769, 
        0.49542901677432216`}, {18.16693773556459, 0.5149474450804412}, {
        18.171653648461096`, 0.5344658733865364}, {18.173954935119756`, 
        0.5442250875395779}, {18.17620268183901, 0.5539843016926131}, {
        18.178398829900534`, 0.5637435158456421}, {18.18054521935956, 
        0.5735027299986645}, {18.18264359595235, 0.5832619441516802}, {
        18.228970858182443`, 0.843106229554839}, {18.258680728893843`, 
        1.102950514949521}, {18.277375493888215`, 1.362794800327988}, {
        18.290657438967212`, 1.622639085682506}, {18.3000176186633, 
        1.8824833709911901`}, {18.306761934836086`, 2.135384719477604}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{18.307808788218544`, 2.177112079944188}, {
        18.313384106763326`, 2.402171941714072}, {18.320303063240367`, 
        2.662016227379195}, {18.3262581452721, 2.921860512677905}, {
        18.329803541190582`, 3.181704797060587}, {18.33189080090201, 
        3.4415490829990074`}, {18.33413048999492, 3.7013933704020703`}, {
        18.335210646531987`, 3.846456479115594}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{18.335521442467705`, 3.8881958225009083`}, {
        18.33606532032486, 3.961237654875851}, {18.337238003747373`, 
        4.221081932026424}, {18.3379140590069, 4.480929408596971}, {
        18.33865403036493, 4.740782439714297}, {18.339443167952584`, 
        5.000639743559915}, {18.34026672190097, 5.260500038315334}, {
        18.341109942341205`, 5.520362042162073}, {18.34123214893231, 
        5.5578051669133535`}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{18.341368380540654`, 5.5995454450784505`}, {
        18.3419580794044, 5.78022447328164}, {18.34279638322167, 
        6.040086049855548}, {18.343610103924135`, 6.29994549006531}, {
        18.344384491642902`, 6.559801512092441}, {18.345104796509084`, 
        6.819652834118449}, {18.345756268653805`, 7.079498174324853}, {
        18.346170781003533`, 7.2691584539343355`}}]}, 
      {Arrowheads[{{0.019999999999999993`, 1.}}], 
       ArrowBox[{{18.346262006808146`, 7.3108988547254565`}, {
        18.346324158208166`, 7.33933625089316}, {18.34679371530329, 
        7.599165782004884}, {18.347150190070284`, 7.858985485841539}, {
        18.34737883264027, 8.118794080584639}, {18.347464893144355`, 
        8.378590284415692}, {18.347477295959123`, 8.755381668753817}, {
        18.347482449936944`, 8.980518022069075}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{18.34748340548948, 9.022258522538497}, {18.347485918538617`,
         9.13203367836986}, {18.347491764029456`, 9.508302787350669}, {
        18.347495835578247`, 9.883945469783077}, {18.34749860735358, 
        10.257889397493056`}, {18.347500553524043`, 10.629062242306567`}, {
        18.34750083424409, 10.691878541640603`}}]}, 
      {Arrowheads[{{0.019379898063369316`, 1.}}], 
       ArrowBox[{{18.347501020778406`, 10.733619042120546`}, {
        18.34750154696368, 10.851362722975281`}, {18.34750238451602, 
        11.070624590092736`}, {18.347503591958784`, 11.50003248367385}, {
        18.347503853406888`, 11.63455871093566}, {18.347504091785293`, 
        11.76261388180887}, {18.347504535709536`, 12.001198973666664`}, {
        18.347504928511395`, 12.199778923769355`}, {18.34750529402699, 
        12.351472330961093`}}]}}, 
     {RGBColor[0.9, 0.36, 0.054], AbsoluteThickness[1], 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{10.009431325959, 6.177282132012765}, {10.009331522547107`, 
        6.032832975291746}, {10.009234306580268`, 5.909877228946775}, {
        10.009017124375529`, 5.679481208093915}, {10.00880582354481, 
        5.497340163965835}, {10.00859833071751, 5.346079221935635}, {
        10.008393555242865`, 5.216562660704893}, {10.007883753952875`, 
        4.951723232316335}, {10.007381787281995`, 4.746073361410433}, {
        10.006885018053257`, 4.577575199485001}, {10.006643233318728`, 
        4.507664968517844}}]}, 
      {Arrowheads[{{0.019999999999999997`, 1.}}], 
       ArrowBox[{{10.006498874541322`, 4.4659247176693615`}, {
        10.006392106566961`, 4.435053563781215}, {10.004773443108084`, 
        4.071473556789054}, {10.003175173330655`, 3.810476779283617}, {
        10.001591752207672`, 3.6066267180730804`}, {10.00002075900426, 
        3.4405565385037846`}, {9.996910096248817, 3.1743565248070036`}, {
        9.993837252450048, 2.968697169352432}, {9.990551411462858, 
        2.7963994178872045`}}]}, 
      {Arrowheads[{{0.020000000000000004`, 1.}}], 
       ArrowBox[{{9.989755535067074, 2.7546665056821658`}, {9.988877833364553,
         2.70864296699261}, {9.984003282986826, 2.5094353983070317`}, {
        9.979208407838271, 2.348693208254586}, {9.976830359932865, 
        2.2760616656518824`}, {9.974471144482672, 2.2095961516328346`}, {
        9.971456071525841, 2.1369103534402645`}, {9.968470498321, 
        2.0702304543037626`}, {9.962556722510232, 1.946912354860448}, {
        9.956755264098689, 1.8412313829645548`}, {9.95106149767678, 
        1.749105060811672}, {9.939744646882094, 1.5913607814705582`}, {
        9.928827870779486, 1.464454745794093}, {9.918282690425839, 
        1.359225547325029}, {9.902859729509629, 1.2279148248127}, {
        9.888164953852076, 1.1223915376130364`}, {9.882889724977948, 
        1.0896165637659783`}}]}, 
      {Arrowheads[{{0.0070354298348290385`, 1.}}], 
       ArrowBox[{{9.876256834118378, 1.0484064419608219`}, {9.874131142656793,
         1.0351995302376125`}, {9.853603998444084, 0.9257127900346372}, {
        9.834339507031137, 0.8386741978555455}, {9.816188518966959, 
        0.7675000712023392}, {9.790204208104388, 0.6797144398458512}, {
        9.766198557275485, 0.610780280485882}, {9.743886357108517, 
        0.5550321413784706}, {9.712190808874116, 
        0.48665735864232235`}}]}}}}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJxF13c81e/7OHCjQVFIlGzCcfZJma/XfTWMjJQiLUWSJBmhIpSoiDTsGVnJ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        "]]},
      Annotation[#, "Charting`Private`Tag$11525#1"]& ]}, {}, {}}, {{{}, {}, 
     TagBox[
      {RGBColor[1, 0.5, 0.5], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJwUm3c8lX8Ux1V2ykwl5O773CEUEelYGamUhqwiIkShoqys0EBLRRFCVpKR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        "]]},
      Annotation[#, "Charting`Private`Tag$11951#1"]& ]}, {}, {}}},
  AspectRatio->1,
  AxesStyle->Directive[
    RGBColor[1, 0, 0], 15],
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{
    FormBox[
     StyleBox[
     "\"\\!\\(\\*\\nStyleBox[\\\"h\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\
\\*OverscriptBox[\\(\[Phi]\\), \\(.\\)]\\)\"", FontSize -> 16, StripOnInput -> 
      False], TraditionalForm], 
    FormBox[
     StyleBox[
     "\"ln(\\!\\(\\*\\nStyleBox[\\\"H\\\",\\nFontSlant->\\\"Italic\\\"]\\)/\\!\
\\(\\*\\nStyleBox[\\\"h\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\\
nStyleBox[\\\")\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"", FontSize -> 16, 
      StripOnInput -> False], TraditionalForm]},
  FrameStyle->Automatic,
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{{0}, {0}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[
    RGBColor[1, 0, 0], 15],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "TransparentPolygonMesh" -> True},
  PlotRange->{{0, 20}, {0, 20}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  RotateLabel->False,
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.8184818515832367`*^9, {3.8184819348780737`*^9, 3.818482013441454*^9}, {
   3.818482080080847*^9, 3.8184821418904257`*^9}, {3.81848217662327*^9, 
   3.818482221095478*^9}, 3.818563893409298*^9, {3.818565266194435*^9, 
   3.818565278934477*^9}, 3.81856780180866*^9, 3.818567975631635*^9, {
   3.8185680552180853`*^9, 3.8185681120434923`*^9}, 3.8185681856009555`*^9, {
   3.818568307160365*^9, 3.818568332793297*^9}, 3.8185685337998533`*^9, 
   3.8185686056581507`*^9, 3.8185687975631185`*^9, {3.818569195807132*^9, 
   3.818569258264633*^9}, 3.818569613376004*^9, 3.8185697736464233`*^9, 
   3.8185706083259926`*^9, {3.8185710537351265`*^9, 3.818571109570554*^9}, 
   3.8185715944780474`*^9, {3.8185720404193935`*^9, 3.818572065114059*^9}, {
   3.818572393057279*^9, 3.818572402513338*^9}, {3.818572729211737*^9, 
   3.818572839920105*^9}, {3.8185729798930874`*^9, 3.8185730364466662`*^9}, 
   3.8185737755734935`*^9, {3.818573912537221*^9, 3.8185739375382195`*^9}, {
   3.8185848687508574`*^9, 3.818584887815658*^9}, 3.818585799448018*^9, 
   3.818587253679386*^9, 3.8186485710634604`*^9, 3.8186487407624474`*^9}]
}, Open  ]],

Cell["This is figure 10(a).", "Text",
 CellChangeTimes->{{3.8186488031063943`*^9, 3.8186488100469093`*^9}, {
  3.818649315549188*^9, 3.8186493770303917`*^9}, {3.818773230604724*^9, 
  3.8187732307565174`*^9}, {3.818773270342625*^9, 3.818773288183251*^9}}]
}, Closed]]
}, Open  ]]
},
WindowSize->{672, 808},
WindowMargins->{{110, Automatic}, {Automatic, 92}},
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (September 21, 2016)",
StyleDefinitions->"ReverseColor.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 240, 5, 111, "Section"],
Cell[823, 29, 651, 14, 106, "Text"],
Cell[1477, 45, 120, 2, 30, "Input"],
Cell[CellGroupData[{
Cell[1622, 51, 178, 2, 49, "Subsection"],
Cell[1803, 55, 571, 18, 115, "Text"],
Cell[CellGroupData[{
Cell[2399, 77, 2436, 73, 835, "Input"],
Cell[4838, 152, 3475, 96, 266, "Output"],
Cell[8316, 250, 3870, 108, 337, "Output"],
Cell[12189, 360, 10151, 310, 921, "Output"]
}, Open  ]],
Cell[22355, 673, 162, 3, 113, "Text"],
Cell[22520, 678, 566, 18, 115, "Input"],
Cell[23089, 698, 130, 1, 67, "Text"],
Cell[CellGroupData[{
Cell[23244, 703, 521, 13, 369, "Input"],
Cell[23768, 718, 2530, 61, 193, "Output"],
Cell[26301, 781, 2806, 70, 193, "Output"],
Cell[29110, 853, 4817, 128, 266, "Output"]
}, Open  ]],
Cell[33942, 984, 223, 4, 110, "Text"],
Cell[34168, 990, 762, 24, 188, "Input"],
Cell[34933, 1016, 438, 15, 156, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[35408, 1036, 220, 3, 41, "Subsection"],
Cell[CellGroupData[{
Cell[35653, 1043, 116, 1, 86, "Subsubsection"],
Cell[35772, 1046, 402, 11, 110, "Text"],
Cell[CellGroupData[{
Cell[36199, 1061, 556, 15, 369, "Input"],
Cell[36758, 1078, 2379, 58, 193, "Output"],
Cell[39140, 1138, 2593, 65, 193, "Output"],
Cell[41736, 1205, 4111, 108, 266, "Output"]
}, Open  ]],
Cell[45862, 1316, 703, 14, 196, "Text"],
Cell[CellGroupData[{
Cell[46590, 1334, 1168, 33, 460, "Input"],
Cell[47761, 1369, 2421, 58, 193, "Output"],
Cell[50185, 1429, 2602, 64, 193, "Output"],
Cell[52790, 1495, 4255, 109, 266, "Output"]
}, Open  ]],
Cell[57060, 1607, 527, 12, 152, "Text"],
Cell[CellGroupData[{
Cell[57612, 1623, 1982, 62, 550, "Input"],
Cell[59597, 1687, 3483, 88, 266, "Output"],
Cell[63083, 1777, 3075, 77, 193, "Output"]
}, Open  ]],
Cell[66173, 1857, 520, 15, 163, "Text"],
Cell[CellGroupData[{
Cell[66718, 1876, 2424, 73, 737, "Input"],
Cell[69145, 1951, 1966, 43, 151, "Output"],
Cell[71114, 1996, 1698, 35, 109, "Output"]
}, Open  ]],
Cell[72827, 2034, 1061, 32, 250, "Text"],
Cell[CellGroupData[{
Cell[73913, 2070, 3288, 96, 610, "Input"],
Cell[77204, 2168, 1106, 16, 99, "Output"],
Cell[78313, 2186, 1106, 16, 99, "Output"]
}, Open  ]],
Cell[79434, 2205, 526, 14, 152, "Text"],
Cell[CellGroupData[{
Cell[79985, 2223, 949, 28, 505, "Input"],
Cell[80937, 2253, 1854, 43, 145, "Output"],
Cell[82794, 2298, 2395, 56, 161, "Output"],
Cell[85192, 2356, 2215, 52, 159, "Output"]
}, Open  ]],
Cell[87422, 2411, 240, 5, 110, "Text"],
Cell[CellGroupData[{
Cell[87687, 2420, 336, 9, 70, "Input"],
Cell[88026, 2431, 975, 13, 70, "Output"]
}, Open  ]],
Cell[89016, 2447, 230, 5, 110, "Text"],
Cell[CellGroupData[{
Cell[89271, 2456, 217, 6, 70, "Input"],
Cell[89491, 2464, 2371, 55, 133, "Output"]
}, Open  ]],
Cell[91877, 2522, 343, 6, 110, "Text"],
Cell[CellGroupData[{
Cell[92245, 2532, 2374, 74, 462, "Input"],
Cell[94622, 2608, 1389, 25, 99, "Output"],
Cell[96014, 2635, 1542, 28, 127, "Output"]
}, Open  ]],
Cell[97571, 2666, 782, 21, 371, "Text"],
Cell[CellGroupData[{
Cell[98378, 2691, 84, 2, 99, "Input"],
Cell[98465, 2695, 606, 20, 109, "Output"]
}, Open  ]],
Cell[99086, 2718, 659, 26, 110, "Text"],
Cell[CellGroupData[{
Cell[99770, 2748, 431, 14, 188, "Input"],
Cell[100204, 2764, 774, 24, 103, "Output"]
}, Open  ]],
Cell[100993, 2791, 121, 1, 67, "Text"],
Cell[CellGroupData[{
Cell[101139, 2796, 669, 21, 188, "Input"],
Cell[101811, 2819, 369, 12, 136, "Output"]
}, Open  ]],
Cell[102195, 2834, 682, 18, 196, "Text"],
Cell[CellGroupData[{
Cell[102902, 2856, 567, 20, 145, "Input"],
Cell[103472, 2878, 75, 1, 99, "Output"],
Cell[103550, 2881, 75, 1, 99, "Output"]
}, Open  ]],
Cell[103640, 2885, 151, 2, 67, "Text"],
Cell[CellGroupData[{
Cell[103816, 2891, 999, 32, 460, "Input"],
Cell[104818, 2925, 1072, 34, 223, "Output"],
Cell[105893, 2961, 1284, 42, 241, "Output"]
}, Open  ]],
Cell[107192, 3006, 164, 3, 67, "Text"],
Cell[CellGroupData[{
Cell[107381, 3013, 270, 8, 145, "Input"],
Cell[107654, 3023, 75, 1, 99, "Output"]
}, Open  ]],
Cell[107744, 3027, 101, 1, 67, "Text"],
Cell[CellGroupData[{
Cell[107870, 3032, 37, 0, 99, "Input"],
Cell[107910, 3034, 260, 8, 103, "Output"]
}, Open  ]],
Cell[108185, 3045, 512, 16, 156, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[108734, 3066, 196, 2, 69, "Subsubsection"],
Cell[108933, 3070, 280, 5, 110, "Text"],
Cell[CellGroupData[{
Cell[109238, 3079, 105, 1, 188, "Input"],
Cell[109346, 3082, 2357, 58, 193, "Output"],
Cell[111706, 3142, 2571, 65, 193, "Output"],
Cell[114280, 3209, 4091, 108, 266, "Output"]
}, Open  ]],
Cell[118386, 3320, 546, 13, 198, "Text"],
Cell[CellGroupData[{
Cell[118957, 3337, 368, 10, 145, "Input"],
Cell[119328, 3349, 2271, 56, 188, "Output"]
}, Open  ]],
Cell[121614, 3408, 558, 16, 163, "Text"],
Cell[CellGroupData[{
Cell[122197, 3428, 1701, 50, 475, "Input"],
Cell[123901, 3480, 1006, 14, 99, "Output"]
}, Open  ]],
Cell[124922, 3497, 610, 13, 152, "Text"],
Cell[CellGroupData[{
Cell[125557, 3514, 1084, 30, 476, "Input"],
Cell[126644, 3546, 1570, 35, 125, "Output"],
Cell[128217, 3583, 2010, 46, 140, "Output"],
Cell[130230, 3631, 957, 14, 99, "Output"]
}, Open  ]],
Cell[131202, 3648, 229, 5, 110, "Text"],
Cell[CellGroupData[{
Cell[131456, 3657, 603, 16, 188, "Input"],
Cell[132062, 3675, 1281, 23, 99, "Output"]
}, Open  ]],
Cell[133358, 3701, 548, 10, 283, "Text"],
Cell[CellGroupData[{
Cell[133931, 3715, 2144, 61, 698, "Input"],
Cell[136078, 3778, 2378, 57, 218, "Output"],
Cell[138459, 3837, 2953, 69, 198, "Output"],
Cell[141415, 3908, 4209, 107, 271, "Output"]
}, Open  ]],
Cell[145639, 4018, 288, 6, 110, "Text"],
Cell[CellGroupData[{
Cell[145952, 4028, 2290, 74, 567, "Input"],
Cell[148245, 4104, 3026, 84, 386, "Output"]
}, Open  ]],
Cell[151286, 4191, 518, 10, 241, "Text"],
Cell[CellGroupData[{
Cell[151829, 4205, 541, 16, 145, "Input"],
Cell[152373, 4223, 995, 22, 122, "Output"]
}, Open  ]],
Cell[153383, 4248, 1663, 52, 288, "Text"],
Cell[CellGroupData[{
Cell[155071, 4304, 3495, 105, 692, "Input"],
Cell[158569, 4411, 1107, 24, 99, "Output"]
}, Open  ]],
Cell[159691, 4438, 1154, 34, 250, "Text"],
Cell[CellGroupData[{
Cell[160870, 4476, 921, 27, 115, "Input"],
Cell[161794, 4505, 9214, 245, 1050, "Output"]
}, Open  ]],
Cell[171023, 4753, 555, 9, 110, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[171615, 4767, 288, 3, 69, "Subsubsection"],
Cell[171906, 4772, 397, 9, 240, "Text"],
Cell[CellGroupData[{
Cell[172328, 4785, 2017, 57, 460, "Input"],
Cell[174348, 4844, 1095, 18, 99, "Output"],
Cell[175446, 4864, 1008, 17, 99, "Output"],
Cell[176457, 4883, 1080, 18, 99, "Output"]
}, Open  ]],
Cell[177552, 4904, 377, 11, 110, "Text"],
Cell[CellGroupData[{
Cell[177954, 4919, 1643, 47, 392, "Input"],
Cell[179600, 4968, 6657, 171, 495, "Output"],
Cell[186260, 5141, 1312, 28, 104, "Output"]
}, Open  ]],
Cell[187587, 5172, 175, 2, 67, "Text"],
Cell[CellGroupData[{
Cell[187787, 5178, 4364, 130, 1000, "Input"],
Cell[192154, 5310, 4263, 111, 438, "Output"],
Cell[196420, 5423, 4212, 110, 325, "Output"],
Cell[200635, 5535, 3576, 90, 255, "Output"]
}, Open  ]],
Cell[204226, 5628, 1150, 39, 243, "Text"],
Cell[CellGroupData[{
Cell[205401, 5671, 268, 7, 99, "Input"],
Cell[205672, 5680, 1103, 22, 99, "Output"]
}, Open  ]],
Cell[206790, 5705, 161, 3, 110, "Text"],
Cell[CellGroupData[{
Cell[206976, 5712, 472, 13, 99, "Input"],
Cell[207451, 5727, 1174, 26, 104, "Output"]
}, Open  ]],
Cell[208640, 5756, 390, 12, 110, "Text"],
Cell[CellGroupData[{
Cell[209055, 5772, 1223, 35, 369, "Input"],
Cell[210281, 5809, 3962, 105, 322, "Output"],
Cell[214246, 5916, 3415, 87, 255, "Output"]
}, Open  ]],
Cell[217676, 6006, 1926, 48, 500, "Text"],
Cell[CellGroupData[{
Cell[219627, 6058, 2434, 68, 774, "Input"],
Cell[222064, 6128, 4139, 110, 555, "Output"],
Cell[226206, 6240, 4127, 111, 527, "Output"],
Cell[230336, 6353, 3250, 89, 318, "Output"]
}, Open  ]],
Cell[233601, 6445, 281, 8, 67, "Text"],
Cell[CellGroupData[{
Cell[233907, 6457, 773, 22, 369, "Input"],
Cell[234683, 6481, 1218, 33, 175, "Output"],
Cell[235904, 6516, 1238, 33, 150, "Output"],
Cell[237145, 6551, 815, 21, 150, "Output"]
}, Open  ]],
Cell[237975, 6575, 177, 2, 67, "Text"],
Cell[CellGroupData[{
Cell[238177, 6581, 1493, 44, 413, "Input"],
Cell[239673, 6627, 2259, 60, 326, "Output"],
Cell[241935, 6689, 564, 11, 99, "Output"]
}, Open  ]],
Cell[242514, 6703, 382, 11, 67, "Text"],
Cell[CellGroupData[{
Cell[242921, 6718, 388, 11, 145, "Input"],
Cell[243312, 6731, 1422, 36, 180, "Output"]
}, Open  ]],
Cell[244749, 6770, 446, 7, 152, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[245232, 6782, 250, 3, 69, "Subsubsection"],
Cell[245485, 6787, 520, 10, 240, "Text"],
Cell[CellGroupData[{
Cell[246030, 6801, 5004, 155, 926, "Input"],
Cell[251037, 6958, 663, 9, 99, "Output"]
}, Open  ]],
Cell[251715, 6970, 484, 13, 110, "Text"],
Cell[CellGroupData[{
Cell[252224, 6987, 1006, 31, 280, "Input"],
Cell[253233, 7020, 1804, 41, 122, "Output"],
Cell[255040, 7063, 858, 12, 99, "Output"]
}, Open  ]],
Cell[255913, 7078, 311, 5, 67, "Text"],
Cell[CellGroupData[{
Cell[256249, 7087, 938, 29, 280, "Input"],
Cell[257190, 7118, 1427, 33, 143, "Output"],
Cell[258620, 7153, 738, 11, 99, "Output"]
}, Open  ]],
Cell[259373, 7167, 555, 14, 110, "Text"],
Cell[CellGroupData[{
Cell[259953, 7185, 1073, 31, 238, "Input"],
Cell[261029, 7218, 1321, 29, 148, "Output"]
}, Open  ]],
Cell[262365, 7250, 582, 15, 152, "Text"],
Cell[CellGroupData[{
Cell[262972, 7269, 2039, 63, 427, "Input"],
Cell[265014, 7334, 1026, 22, 130, "Output"],
Cell[266043, 7358, 998, 20, 135, "Output"]
}, Open  ]],
Cell[267056, 7381, 1013, 29, 326, "Text"],
Cell[CellGroupData[{
Cell[268094, 7414, 311, 9, 99, "Input"],
Cell[268408, 7425, 1249, 28, 140, "Output"]
}, Open  ]],
Cell[269672, 7456, 340, 6, 110, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[270049, 7467, 135, 1, 69, "Subsubsection"],
Cell[270187, 7470, 1467, 37, 412, "Text"],
Cell[CellGroupData[{
Cell[271679, 7511, 4314, 132, 577, "Input"],
Cell[275996, 7645, 2656, 81, 196, "Output"],
Cell[278655, 7728, 2738, 85, 196, "Output"]
}, Open  ]],
Cell[281408, 7816, 175, 2, 67, "Text"],
Cell[CellGroupData[{
Cell[281608, 7822, 1414, 42, 422, "Input"],
Cell[283025, 7866, 2435, 69, 240, "Output"],
Cell[285463, 7937, 2015, 58, 241, "Output"]
}, Open  ]],
Cell[287493, 7998, 407, 7, 152, "Text"],
Cell[CellGroupData[{
Cell[287925, 8009, 1558, 48, 510, "Input"],
Cell[289486, 8059, 1465, 37, 159, "Output"],
Cell[290954, 8098, 936, 21, 155, "Output"]
}, Open  ]],
Cell[291905, 8122, 262, 5, 67, "Text"],
Cell[CellGroupData[{
Cell[292192, 8131, 407, 13, 145, "Input"],
Cell[292602, 8146, 1136, 29, 152, "Output"],
Cell[293741, 8177, 829, 19, 155, "Output"]
}, Open  ]],
Cell[294585, 8199, 269, 5, 110, "Text"],
Cell[CellGroupData[{
Cell[294879, 8208, 747, 20, 208, "Input"],
Cell[295629, 8230, 802, 17, 136, "Output"]
}, Open  ]],
Cell[296446, 8250, 214, 3, 67, "Text"],
Cell[296663, 8255, 322, 10, 109, "Input"],
Cell[296988, 8267, 415, 9, 198, "Text"],
Cell[297406, 8278, 825, 17, 206, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[298280, 8301, 306, 5, 41, "Subsection"],
Cell[298589, 8308, 470, 10, 48, "Text"],
Cell[CellGroupData[{
Cell[299084, 8322, 336, 4, 37, "Subsubsection"],
Cell[299423, 8328, 123, 1, 29, "Text"],
Cell[299549, 8331, 421, 10, 49, "Input"],
Cell[299973, 8343, 213, 4, 29, "Text"],
Cell[CellGroupData[{
Cell[300211, 8351, 1092, 30, 101, "Input"],
Cell[301306, 8383, 699, 12, 30, "Output"],
Cell[302008, 8397, 993, 23, 57, "Output"]
}, Open  ]],
Cell[303016, 8423, 466, 8, 67, "Text"],
Cell[CellGroupData[{
Cell[303507, 8435, 124, 2, 30, "Input"],
Cell[303634, 8439, 637, 15, 42, "Output"]
}, Open  ]],
Cell[304286, 8457, 684, 24, 49, "Text"],
Cell[CellGroupData[{
Cell[304995, 8485, 667, 19, 52, "Input"],
Cell[305665, 8506, 907, 21, 31, "Output"]
}, Open  ]],
Cell[306587, 8530, 316, 10, 30, "Text"],
Cell[CellGroupData[{
Cell[306928, 8544, 641, 15, 49, "Input"],
Cell[307572, 8561, 823, 19, 31, "Output"]
}, Open  ]],
Cell[308410, 8583, 563, 19, 49, "Text"],
Cell[CellGroupData[{
Cell[308998, 8606, 1188, 32, 114, "Input"],
Cell[310189, 8640, 936, 21, 45, "Output"]
}, Open  ]],
Cell[311140, 8664, 439, 9, 67, "Text"],
Cell[CellGroupData[{
Cell[311604, 8677, 1022, 27, 183, "Input"],
Cell[312629, 8706, 1211, 30, 45, "Output"],
Cell[313843, 8738, 1715, 45, 68, "Output"],
Cell[315561, 8785, 1812, 49, 60, "Output"]
}, Open  ]],
Cell[317388, 8837, 183, 2, 29, "Text"],
Cell[CellGroupData[{
Cell[317596, 8843, 500, 15, 68, "Input"],
Cell[318099, 8860, 833, 22, 47, "Output"]
}, Open  ]],
Cell[318947, 8885, 134, 1, 29, "Text"],
Cell[CellGroupData[{
Cell[319106, 8890, 835, 22, 105, "Input"],
Cell[319944, 8914, 821, 24, 45, "Output"],
Cell[320768, 8940, 1087, 29, 47, "Output"]
}, Open  ]],
Cell[321870, 8972, 236, 3, 29, "Text"],
Cell[322109, 8977, 882, 18, 68, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[323028, 9000, 188, 2, 30, "Subsubsection"],
Cell[323219, 9004, 412, 9, 49, "Input"],
Cell[323634, 9015, 942, 32, 85, "Text"],
Cell[CellGroupData[{
Cell[324601, 9051, 965, 28, 125, "Input"],
Cell[325569, 9081, 1233, 34, 45, "Output"],
Cell[326805, 9117, 1692, 48, 68, "Output"]
}, Open  ]],
Cell[328512, 9168, 662, 20, 48, "Text"],
Cell[CellGroupData[{
Cell[329199, 9192, 458, 12, 49, "Input"],
Cell[329660, 9206, 2791, 68, 65, "Output"]
}, Open  ]],
Cell[332466, 9277, 1470, 43, 104, "Text"],
Cell[CellGroupData[{
Cell[333961, 9324, 686, 19, 68, "Input"],
Cell[334650, 9345, 1180, 20, 40, "Message"],
Cell[335833, 9367, 1492, 32, 49, "Output"]
}, Open  ]],
Cell[337340, 9402, 217, 4, 29, "Text"],
Cell[CellGroupData[{
Cell[337582, 9410, 2830, 81, 240, "Input"],
Cell[340415, 9493, 1238, 23, 42, "Output"],
Cell[341656, 9518, 4195, 109, 180, "Output"]
}, Open  ]],
Cell[345866, 9630, 342, 6, 48, "Text"],
Cell[346211, 9638, 1446, 43, 73, "Input"],
Cell[347660, 9683, 125, 1, 29, "Text"],
Cell[CellGroupData[{
Cell[347810, 9688, 1476, 36, 125, "Input"],
Cell[349289, 9726, 1407, 25, 42, "Output"],
Cell[350699, 9753, 4842, 124, 250, "Output"]
}, Open  ]],
Cell[355556, 9880, 746, 17, 85, "Text"],
Cell[CellGroupData[{
Cell[356327, 9901, 1785, 54, 139, "Input"],
Cell[358115, 9957, 825, 11, 30, "Output"],
Cell[358943, 9970, 827, 11, 30, "Output"]
}, Open  ]],
Cell[359785, 9984, 757, 24, 85, "Text"],
Cell[CellGroupData[{
Cell[360567, 10012, 2153, 58, 221, "Input"],
Cell[362723, 10072, 1173, 21, 42, "Output"],
Cell[363899, 10095, 4148, 107, 225, "Output"]
}, Open  ]],
Cell[368062, 10205, 281, 3, 29, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[368380, 10213, 262, 4, 30, "Subsubsection"],
Cell[368645, 10219, 743, 23, 67, "Text"],
Cell[CellGroupData[{
Cell[369413, 10246, 1108, 33, 86, "Input"],
Cell[370524, 10281, 597, 10, 42, "Output"],
Cell[371124, 10293, 538, 8, 42, "Output"]
}, Open  ]],
Cell[371677, 10304, 430, 14, 49, "Text"],
Cell[CellGroupData[{
Cell[372132, 10322, 755, 21, 49, "Input"],
Cell[372890, 10345, 365, 5, 42, "Output"],
Cell[373258, 10352, 2043, 61, 91, "Output"]
}, Open  ]],
Cell[375316, 10416, 244, 6, 49, "Text"],
Cell[CellGroupData[{
Cell[375585, 10426, 1716, 44, 159, "Input"],
Cell[377304, 10472, 2786, 75, 201, "Output"]
}, Open  ]],
Cell[380105, 10550, 2470, 64, 198, "Text"],
Cell[CellGroupData[{
Cell[382600, 10618, 1836, 51, 198, "Input"],
Cell[384439, 10671, 733, 14, 58, "Output"],
Cell[385175, 10687, 479, 6, 42, "Output"]
}, Open  ]],
Cell[385669, 10696, 209, 4, 29, "Text"],
Cell[CellGroupData[{
Cell[385903, 10704, 7549, 208, 430, "Input"],
Cell[393455, 10914, 158979, 2495, 372, "Output"]
}, Open  ]],
Cell[552449, 13412, 606, 19, 70, "Text"],
Cell[CellGroupData[{
Cell[553080, 13435, 1047, 29, 49, "Input"],
Cell[554130, 13466, 496, 11, 47, "Output"]
}, Open  ]],
Cell[554641, 13480, 1336, 38, 127, "Text"],
Cell[CellGroupData[{
Cell[556002, 13522, 1813, 51, 198, "Input"],
Cell[557818, 13575, 699, 17, 58, "Output"],
Cell[558520, 13594, 373, 5, 42, "Output"]
}, Open  ]],
Cell[558908, 13602, 218, 4, 29, "Text"],
Cell[CellGroupData[{
Cell[559151, 13610, 6909, 194, 377, "Input"],
Cell[566063, 13806, 177861, 2812, 402, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[743973, 16624, 224, 3, 30, "Subsubsection"],
Cell[744200, 16629, 406, 9, 49, "Input"],
Cell[744609, 16640, 1287, 35, 89, "Text"],
Cell[CellGroupData[{
Cell[745921, 16679, 3683, 111, 273, "Input"],
Cell[749607, 16792, 1021, 19, 55, "Output"],
Cell[750631, 16813, 1106, 22, 56, "Output"]
}, Open  ]],
Cell[751752, 16838, 181, 2, 29, "Text"],
Cell[CellGroupData[{
Cell[751958, 16844, 2922, 88, 391, "Input"],
Cell[754883, 16934, 2080, 52, 65, "Output"],
Cell[756966, 16988, 2588, 65, 65, "Output"],
Cell[759557, 17055, 2020, 51, 65, "Output"]
}, Open  ]],
Cell[761592, 17109, 1036, 33, 69, "Text"],
Cell[CellGroupData[{
Cell[762653, 17146, 3637, 99, 303, "Input"],
Cell[766293, 17247, 2119, 51, 65, "Output"],
Cell[768415, 17300, 2531, 61, 65, "Output"],
Cell[770949, 17363, 2116, 52, 65, "Output"]
}, Open  ]],
Cell[773080, 17418, 434, 7, 67, "Text"],
Cell[CellGroupData[{
Cell[773539, 17429, 1498, 45, 125, "Input"],
Cell[775040, 17476, 4366, 114, 129, "Output"],
Cell[779409, 17592, 3688, 95, 109, "Output"]
}, Open  ]],
Cell[783112, 17690, 1487, 42, 122, "Text"],
Cell[CellGroupData[{
Cell[784624, 17736, 1456, 44, 146, "Input"],
Cell[786083, 17782, 964, 23, 56, "Output"]
}, Open  ]],
Cell[787062, 17808, 1037, 29, 110, "Text"],
Cell[CellGroupData[{
Cell[788124, 17841, 2337, 66, 180, "Input"],
Cell[790464, 17909, 390, 9, 54, "Output"]
}, Open  ]],
Cell[790869, 17921, 170, 2, 29, "Text"],
Cell[CellGroupData[{
Cell[791064, 17927, 555, 16, 30, "Input"],
Cell[791622, 17945, 218, 5, 42, "Output"]
}, Open  ]],
Cell[791855, 17953, 154, 2, 29, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[792046, 17960, 257, 4, 30, "Subsubsection"],
Cell[792306, 17966, 2045, 56, 198, "Text"],
Cell[CellGroupData[{
Cell[794376, 18026, 1941, 53, 198, "Input"],
Cell[796320, 18081, 691, 10, 42, "Output"],
Cell[797014, 18093, 738, 12, 42, "Output"],
Cell[797755, 18107, 853, 16, 55, "Output"]
}, Open  ]],
Cell[798623, 18126, 234, 5, 48, "Text"],
Cell[CellGroupData[{
Cell[798882, 18135, 2534, 67, 258, "Input"],
Cell[801419, 18204, 693, 12, 42, "Output"],
Cell[802115, 18218, 775, 15, 52, "Output"],
Cell[802893, 18235, 792, 14, 42, "Output"]
}, Open  ]],
Cell[803700, 18252, 368, 11, 30, "Text"],
Cell[804071, 18265, 1218, 30, 86, "Input"],
Cell[805292, 18297, 173, 6, 30, "Text"],
Cell[805468, 18305, 932, 23, 68, "Input"],
Cell[806403, 18330, 115, 1, 29, "Text"],
Cell[CellGroupData[{
Cell[806543, 18335, 22811, 588, 1919, "Input"],
Cell[829357, 18925, 13127, 233, 257, "Output"],
Cell[842487, 19160, 6302, 121, 258, "Output"],
Cell[848792, 19283, 13187, 234, 257, "Output"],
Cell[861982, 19519, 8310, 155, 255, "Output"],
Cell[870295, 19676, 63407, 1057, 258, "Output"],
Cell[933705, 20735, 32941, 613, 276, "Output"],
Cell[966649, 21350, 13700, 243, 258, "Output"]
}, Open  ]],
Cell[980364, 21596, 313, 6, 48, "Text"],
Cell[CellGroupData[{
Cell[980702, 21606, 3035, 79, 310, "Input"],
Cell[983740, 21687, 648, 11, 42, "Output"],
Cell[984391, 21700, 709, 13, 42, "Output"],
Cell[985103, 21715, 745, 13, 42, "Output"]
}, Open  ]],
Cell[985863, 21731, 111, 1, 29, "Text"],
Cell[CellGroupData[{
Cell[985999, 21736, 11886, 311, 1000, "Input"],
Cell[997888, 22049, 15372, 272, 270, "Output"],
Cell[1013263, 22323, 10193, 187, 258, "Output"],
Cell[1023459, 22512, 21590, 375, 263, "Output"],
Cell[1045052, 22889, 11141, 204, 248, "Output"],
Cell[1056196, 23095, 25816, 444, 258, "Output"]
}, Open  ]],
Cell[1082027, 23542, 356, 8, 85, "Text"],
Cell[CellGroupData[{
Cell[1082408, 23554, 2395, 70, 235, "Input"],
Cell[1084806, 23626, 22718, 393, 263, "Output"]
}, Open  ]],
Cell[1107539, 24022, 1415, 35, 161, "Text"],
Cell[CellGroupData[{
Cell[1108979, 24061, 1932, 55, 231, "Input"],
Cell[1110914, 24118, 418, 6, 42, "Output"],
Cell[1111335, 24126, 462, 8, 42, "Output"],
Cell[1111800, 24136, 576, 12, 55, "Output"]
}, Open  ]],
Cell[1112391, 24151, 165, 3, 29, "Text"],
Cell[1112559, 24156, 4071, 101, 347, "Input"],
Cell[1116633, 24259, 131, 1, 29, "Text"],
Cell[1116767, 24262, 1073, 28, 100, "Input"],
Cell[1117843, 24292, 118, 1, 29, "Text"],
Cell[1117964, 24295, 1281, 33, 119, "Input"],
Cell[1119248, 24330, 105, 1, 29, "Text"],
Cell[CellGroupData[{
Cell[1119378, 24335, 20399, 545, 1693, "Input"],
Cell[1139780, 24882, 14840, 262, 258, "Output"],
Cell[1154623, 25146, 11981, 215, 258, "Output"],
Cell[1166607, 25363, 22354, 387, 257, "Output"],
Cell[1188964, 25752, 12210, 220, 248, "Output"],
Cell[1201177, 25974, 25891, 445, 258, "Output"]
}, Open  ]],
Cell[1227083, 26422, 243, 3, 29, "Text"],
Cell[CellGroupData[{
Cell[1227351, 26429, 2383, 70, 235, "Input"],
Cell[1229737, 26501, 23423, 406, 257, "Output"]
}, Open  ]],
Cell[1253175, 26910, 175, 2, 29, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[1253387, 26917, 114, 1, 30, "Subsubsection"],
Cell[1253504, 26920, 306, 7, 49, "Input"],
Cell[1253813, 26929, 376, 8, 85, "Text"],
Cell[1254192, 26939, 847, 26, 85, "Input"],
Cell[1255042, 26967, 699, 17, 67, "Text"],
Cell[CellGroupData[{
Cell[1255766, 26988, 6690, 185, 557, "Input"],
Cell[1262459, 27175, 1112, 20, 42, "Output"],
Cell[1263574, 27197, 1549, 30, 49, "Output"],
Cell[1265126, 27229, 17505, 302, 253, "Output"],
Cell[1282634, 27533, 20373, 352, 258, "Output"]
}, Open  ]],
Cell[1303022, 27888, 261, 5, 67, "Text"],
Cell[CellGroupData[{
Cell[1303308, 27897, 456, 13, 49, "Input"],
Cell[1303767, 27912, 2187, 62, 103, "Output"]
}, Open  ]],
Cell[1305969, 27977, 223, 3, 29, "Text"],
Cell[CellGroupData[{
Cell[1306217, 27984, 1168, 39, 145, "Input"],
Cell[1307388, 28025, 3177, 83, 131, "Output"],
Cell[1310568, 28110, 3751, 100, 159, "Output"]
}, Open  ]],
Cell[1314334, 28213, 191, 2, 29, "Text"],
Cell[CellGroupData[{
Cell[1314550, 28219, 3878, 116, 321, "Input"],
Cell[1318431, 28337, 2751, 73, 131, "Output"],
Cell[1321185, 28412, 3047, 83, 130, "Output"]
}, Open  ]],
Cell[1324247, 28498, 764, 27, 50, "Text"],
Cell[CellGroupData[{
Cell[1325036, 28529, 373, 11, 105, "Input"],
Cell[1325412, 28542, 2608, 68, 131, "Output"],
Cell[1328023, 28612, 2898, 78, 130, "Output"]
}, Open  ]],
Cell[1330936, 28693, 896, 26, 120, "Text"],
Cell[CellGroupData[{
Cell[1331857, 28723, 3019, 85, 297, "Input"],
Cell[1334879, 28810, 444, 6, 42, "Output"],
Cell[1335326, 28818, 446, 6, 42, "Output"]
}, Open  ]],
Cell[1335787, 28827, 101, 1, 29, "Text"],
Cell[CellGroupData[{
Cell[1335913, 28832, 2729, 76, 275, "Input"],
Cell[1338645, 28910, 8379, 156, 258, "Output"],
Cell[1347027, 29068, 14481, 256, 247, "Output"]
}, Open  ]],
Cell[1361523, 29327, 540, 16, 67, "Text"],
Cell[CellGroupData[{
Cell[1362088, 29347, 3035, 84, 288, "Input"],
Cell[1365126, 29433, 11942, 218, 252, "Output"]
}, Open  ]],
Cell[1377083, 29654, 234, 5, 48, "Text"],
Cell[1377320, 29661, 365, 10, 67, "Text"],
Cell[CellGroupData[{
Cell[1377710, 29675, 2954, 84, 297, "Input"],
Cell[1380667, 29761, 497, 7, 42, "Output"],
Cell[1381167, 29770, 499, 7, 42, "Output"]
}, Open  ]],
Cell[1381681, 29780, 111, 1, 29, "Text"],
Cell[CellGroupData[{
Cell[1381817, 29785, 3526, 95, 337, "Input"],
Cell[1385346, 29882, 12459, 225, 248, "Output"],
Cell[1397808, 30109, 11083, 198, 257, "Output"]
}, Open  ]],
Cell[1408906, 30310, 116, 1, 29, "Text"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[1409071, 30317, 185, 2, 41, "Subsection"],
Cell[1409259, 30321, 240, 5, 48, "Text"],
Cell[1409502, 30328, 319, 8, 49, "Input"],
Cell[1409824, 30338, 117, 1, 29, "Text"],
Cell[CellGroupData[{
Cell[1409966, 30343, 1830, 55, 297, "Input"],
Cell[1411799, 30400, 500, 9, 35, "Output"],
Cell[1412302, 30411, 679, 17, 57, "Output"],
Cell[1412984, 30430, 1337, 36, 55, "Output"],
Cell[1414324, 30468, 1486, 38, 54, "Output"],
Cell[1415813, 30508, 1729, 47, 69, "Output"]
}, Open  ]],
Cell[1417557, 30558, 213, 4, 29, "Text"],
Cell[CellGroupData[{
Cell[1417795, 30566, 104, 2, 30, "Input"],
Cell[1417902, 30570, 594, 14, 48, "Output"]
}, Open  ]],
Cell[1418511, 30587, 603, 17, 29, "Text"],
Cell[CellGroupData[{
Cell[1419139, 30608, 616, 18, 32, "Input"],
Cell[1419758, 30628, 651, 13, 35, "Output"]
}, Open  ]],
Cell[1420424, 30644, 917, 21, 122, "Text"],
Cell[CellGroupData[{
Cell[1421366, 30669, 2082, 62, 208, "Input"],
Cell[1423451, 30733, 618, 13, 48, "Output"],
Cell[1424072, 30748, 557, 11, 32, "Output"]
}, Open  ]],
Cell[1424644, 30762, 850, 23, 67, "Text"],
Cell[CellGroupData[{
Cell[1425519, 30789, 1389, 34, 109, "Input"],
Cell[1426911, 30825, 786, 17, 30, "Output"]
}, Open  ]],
Cell[1427712, 30845, 1707, 56, 126, "Text"],
Cell[CellGroupData[{
Cell[1429444, 30905, 999, 28, 105, "Input"],
Cell[1430446, 30935, 2371, 66, 119, "Output"]
}, Open  ]],
Cell[1432832, 31004, 607, 15, 67, "Text"],
Cell[CellGroupData[{
Cell[1433464, 31023, 658, 17, 68, "Input"],
Cell[1434125, 31042, 633, 12, 40, "Message"],
Cell[1434761, 31056, 970, 27, 52, "Output"]
}, Open  ]],
Cell[1435746, 31086, 120, 1, 29, "Text"],
Cell[CellGroupData[{
Cell[1435891, 31091, 1383, 43, 183, "Input"],
Cell[1437277, 31136, 2843, 80, 141, "Output"],
Cell[1440123, 31218, 3316, 93, 185, "Output"]
}, Open  ]],
Cell[1443454, 31314, 286, 9, 29, "Text"],
Cell[CellGroupData[{
Cell[1443765, 31327, 3031, 93, 245, "Input"],
Cell[1446799, 31422, 2509, 70, 140, "Output"],
Cell[1449311, 31494, 2950, 81, 161, "Output"]
}, Open  ]],
Cell[1452276, 31578, 374, 9, 29, "Text"],
Cell[CellGroupData[{
Cell[1452675, 31591, 536, 13, 49, "Input"],
Cell[1453214, 31606, 1136, 30, 67, "Output"],
Cell[1454353, 31638, 402, 9, 30, "Output"]
}, Open  ]],
Cell[1454770, 31650, 237, 7, 30, "Text"],
Cell[CellGroupData[{
Cell[1455032, 31661, 921, 27, 105, "Input"],
Cell[1455956, 31690, 671, 16, 52, "Output"]
}, Open  ]],
Cell[1456642, 31709, 403, 10, 29, "Text"],
Cell[CellGroupData[{
Cell[1457070, 31723, 304, 8, 47, "Input"],
Cell[1457377, 31733, 346, 7, 42, "Output"]
}, Open  ]],
Cell[1457738, 31743, 762, 22, 49, "Text"],
Cell[CellGroupData[{
Cell[1458525, 31769, 959, 28, 86, "Input"],
Cell[1459487, 31799, 421, 9, 31, "Output"]
}, Open  ]],
Cell[1459923, 31811, 767, 20, 67, "Text"],
Cell[CellGroupData[{
Cell[1460715, 31835, 1464, 44, 145, "Input"],
Cell[1462182, 31881, 1110, 24, 58, "Output"]
}, Open  ]],
Cell[1463307, 31908, 160, 2, 29, "Text"],
Cell[CellGroupData[{
Cell[1463492, 31914, 7720, 191, 645, "Input"],
Cell[1471215, 32107, 1168, 16, 30, "Output"],
Cell[1472386, 32125, 1166, 16, 30, "Output"],
Cell[1473555, 32143, 261236, 4065, 345, "Output"]
}, Open  ]],
Cell[1734806, 36211, 255, 3, 29, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)

